%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for bootstrapping the LR/F test     %
%          for restrictions on beta and estimate confidence      %
%          intervals for the free beta parameters                %
%                                                                %
%          NOTE: doesn't impose any restrictions you may have    %
%                on alpha or C                                   %
%                                                                %
%          Function: beta_bootstrap                              %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       cm: structure with model info            %
%                                                                %
%          Output:                                               %
%                                                                %
%          This version:        July 5, 2006                     %
%          Written by:          Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function beta_bootstrap(varargin)

%
% GUI for bootstrapping the Beta distributions
%

selector = varargin{1};
if (nargin==0)|(strcmp(selector,'init')==1);
   tm = varargin{2};
   if tm.restrict(1,1)==1;
      tm.resalpha = 'alpha-';
   else;
      tm.resalpha = '';
   end;
   %
   % check if we need to determine if there are over-identifying restrictions on beta
   %
   if tm.dfbeta==0;
      tm.dfbeta = dfbeta_fcn(tm);
   end;
   %
   % toolbar images
   %
   button_images = read_images;
   %
   % more initialization
   %
   selector = 'init';
   my_exit = 1;
   tm.const_model = [0 0 0 0 0];
   if tm.deterselect(1)==1;
      tm.const_model(3) = 1;
   elseif tm.deterselect(2)==1
      tm.const_model(2) = 1;
   elseif tm.deterselect(3)==1;
      tm.const_model(5) = 1;
   else;
      tm.const_model(4) = 1;
   end;
   %
   % Set screen size directly instead of using
   % get(0,'ScreenSize')!
   %
   tm.realscrsz = get(0,'ScreenSize');
   tm.beta_run = 0;
   %
   % read var.in
   %
   curr_ini = find_inisettings;
   my_T = tm.T;
   rep = curr_ini.nRep;
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   nRep_value = 1;
   for i=1:size(repvalues,2);
      if curr_ini.nRep==repvalues(1,i);
         nRep_value = i;
         break;
      end;
   end;
   if direxist(curr_ini.simulatedir)==0;
      mystatus = makedirs(curr_ini.simulatedir);
   else;
      mystatus = 2;
   end;
   if mystatus==0;
      curr_ini.simulatedir = pwd;
      if ispc==1;
         curr_ini.simulatedir = [curr_ini.simulatedir '\'];
      end;
   end;
   if isnumeric(curr_ini.external)==0;
      curr_ini.external = 0;
   end;
   if curr_ini.sscorrect==1;
      tm.testtype = '-f';
   else;
      tm.testtype = '-lr';
   end;
   if curr_ini.parametric==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(curr_ini.blocksize) '-'];
   end;
   full_mat = '';
   if tm.const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-full-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
   elseif tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-full-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-full-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-full-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-full-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
      if tm.r<tm.n;
         view_enable = 'on';
      else;
         view_enable = 'off';
      end;
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      beta_mat = load(full_mat);
      beta_sorted = beta_mat.beta_sorted;
      beta_vec_sorted = beta_mat.beta_vec_sorted;
      if isfield(beta_mat,'beta_t_dist')==1;
         beta_t_dist = beta_mat.beta_t_dist;
         beta = beta_mat.beta;
         stdbeta = beta_mat.stdbeta;
      else;
         beta_t_dist = [];
         beta = [];
         stdbeta = [];
      end;
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
   else;
      view_enable = 'off';
      beta_sorted = [];
      beta_vec_sorted = [];
      beta_t_dist = [];
      beta = [];
      stdbeta = [];
      full_mat = '';
      full_enable = 'off';
   end;
   summary_txt = '';
   if tm.const_model(1)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-summary-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
      mod_type = 'noconst';
      model_type = 'No Constant';
   elseif tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-summary-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
      mod_type = 'resconst';
      model_type = 'Restricted Constant';
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-summary-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
      mod_type = 'const';
      model_type = 'Constant';
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-summary-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
      mod_type = 'restrend';
      model_type = 'Restricted Linear Trend';
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-summary-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
      mod_type = 'trend';
      model_type = 'Linear Trend';
   end;
%   if curr_ini.texoutputformat>=2;
%      summary_txt = strrep(summary_txt,'.txt','.ltx');
%   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
   end;
   %
   % check if file with bootstrapped residuals exists
   %
   epsfile = [curr_ini.simulatedir tm.modelfile '-' 'beta-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
   testfile = strrep(epsfile,'.mat',['-' 'beta-data.mat']);
   if fileexist(epsfile)==1;
      boot_enable = 'on';;
   else;
      epsfile = '';
      boot_enable = 'off';
   end;
   if fileexist(testfile)==0;
      testfile = '';
   end;
   %
   tm.interpolate = curr_ini.interpolate;
   if strcmp(tm.interpolate,'nearest')==1;
      tm.interpolate_value = 1;
   elseif strcmp(tm.interpolate,'linear')==1;
      tm.interpolate_value = 2;
   elseif strcmp(tm.interpolate,'spline')==1;
      tm.interpolate_value = 3;
   elseif strcmp(tm.interpolate,'cubic')==1;
      tm.interpolate_value = 4;
   elseif strcmp(tm.interpolate,'knorm')==1;
      tm.interpolate_value = 5;
   elseif strcmp(tm.interpolate,'kepan')==1;
      tm.interpolate_value = 6;
   elseif strcmp(tm.interpolate,'krect')==1;
      tm.interpolate_value = 7;
   elseif strcmp(tm.interpolate,'ktria')==1;
      tm.interpolate_value = 8;
   elseif strcmp(tm.interpolate,'kbiwe')==1;
      tm.interpolate_value = 9;
   elseif strcmp(tm.interpolate,'ktriw')==1;
      tm.interpolate_value = 10;
   elseif strcmp(tm.interpolate,'klapl')==1;
      tm.interpolate_value = 11;
   elseif strcmp(tm.interpolate,'klogi')==1;
      tm.interpolate_value = 12;
   end;
else;
   my_exit = 0;
   beta_boot_gui = findobj('Type','figure','Tag','BetaBoot')';
   boot_beta = get(beta_boot_gui,'UserData');
   curr_ini = get(boot_beta.matfilebutton,'UserData');
   tm = curr_ini.models;
   button_images = curr_ini.images;
end;

switch selector
case 'init'
   beta_boot_gui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','beta_bootstrap.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(tm.realscrsz(3)-560)/2 (tm.realscrsz(4)-430)/2 560 430], ...
         'Tag','BetaBoot', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name','Bootstrap Distributions for Beta', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','beta_bootstrap done', ...
         'ToolBar','none');

   if matlabnumber>=7.0;
      set(beta_boot_gui,'DockControl','off');
   end;

   if strcmp(curr_ini.helpexe,'')==1;
      helpenable = 'off';
   else;
      helpenable = 'on';
   end;

   %
   % File menu
   %

   filemenu = uimenu('Parent',beta_boot_gui, ...
      'Label','&File', ...
      'Tag','FileMenu');

   boot_beta.simulatemenu = uimenu('Parent',filemenu, ...
         'Label','&Run Bootstrap', ...
         'Callback','beta_bootstrap simulate', ...
         'Enable','on', ...
         'Accelerator','R', ...
         'Tag','SimulateMenu');

   boot_beta.matfilemenu = uimenu('Parent',filemenu, ...
         'Label','Save to m&at-file', ...
         'Separator','on', ...
         'Accelerator','A', ...
         'Enable',full_enable, ...
         'Callback','beta_bootstrap matfile', ...
         'Tag','MatFileMenu');

   boot_beta.summarymenu = uimenu('Parent',filemenu, ...
         'Label','&Simulation Summary', ...
         'Separator','on', ...
         'Callback','beta_bootstrap summary', ...
         'UserData',summary_txt, ...
         'Accelerator','S', ...
         'Enable',summary_enable, ...
         'Tag','SummaryMenu');

   boot_beta.fullmenu = uimenu('Parent',filemenu, ...
         'Label','&Full Simulation', ...
         'Callback','beta_bootstrap full', ...
         'Accelerator','F', ...
         'UserData',full_mat, ...
         'Enable',full_enable, ...
         'Tag','FullMenu');

   if curr_ini.noprint==0;
      boot_beta.output = uimenu('Parent',filemenu, ...
            'Label','Append to &Output', ...
            'Separator','on', ...
            'Callback','beta_bootstrap output', ...
            'Accelerator','O', ...
            'Enable',summary_enable, ...
            'Tag','SummaryMenu');
   end;

   uimenu('Parent',filemenu, ...
         'Label','Center &Window', ...
         'Separator','on', ...
         'Accelerator','W', ...
         'Enable','on', ...
         'Callback','center_figure_fcn', ...
         'Tag','CenterMenu');

   boot_beta.returnmenu = uimenu('Parent',filemenu, ...
         'Label','R&eturn', ...
         'Separator','on', ...
         'Callback','beta_bootstrap done', ...
         'Enable','on', ...
         'Tag','MenuFileReturn');

   boot_beta.filemenu = filemenu;

   %
   % Graph Menu
   %

   graphmenu = uimenu('Parent',beta_boot_gui, ...
      'Label','&Graphics', ...
      'Tag','GraphMenu');

   boot_beta.bootstrapgraphmenu = uimenu('Parent',graphmenu, ...
         'Label','Graph &Bootstrap Sample', ...
         'Callback','beta_bootstrap display_bootstrap', ...
         'Accelerator','B', ...
         'UserData',testfile, ...
         'Enable',boot_enable, ...
         'Tag','BootstrapGraphMenu');

   boot_beta.displaymenu = uimenu('Parent',graphmenu, ...
         'Label','&Graph Distribution', ...
         'Callback','beta_bootstrap display', ...
         'Separator','on', ...
         'Accelerator','G', ...
         'UserData',tm.const_model, ...
         'Enable',view_enable, ...
         'Tag','DisplayMenu');

   boot_beta.histogrammenu = uimenu('Parent',graphmenu, ...
         'Label','&Histogram of Distribution', ...
         'Callback','beta_bootstrap display', ...
         'Accelerator','D', ...
         'Enable',view_enable, ...
         'Tag','HistogramMenu');

   %
   % Help Menu
   %

   helpmenu = uimenu('Parent',beta_boot_gui, ...
      'Label','&Help', ...
      'Tag','HelpMenu');

   boot_beta.helpmenu = uimenu('Parent',helpmenu, ...
         'Label','&Help Topics', ...
         'Callback','help_fcn(''bootstrapping'')', ...
         'Accelerator','H', ...
         'Enable',helpenable, ...
         'Tag','HelpMenu');

   %
   % The toolbar
   %

   boot_beta.toolbar = uitoolbar('Parent',beta_boot_gui, ...
                     'HandleVisibility','off', ...
                     'Interruptible','on', ...
                     'Clipping','on');

   if (iswinxp==0)|(matlabnumber<7);
      xline([1 429 560],[0.5 1]);
   end;

   boot_beta.simulate = uipushtool('Parent',boot_beta.toolbar, ...
                      'TooltipString','Run Bootstrap', ...
                      'CData',button_images.simulate, ...
                      'ClickedCallback','beta_bootstrap simulate', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable','on', ...
                      'UserData',0, ...
                      'Tag','Simulate');


   boot_beta.matfilebutton = uipushtool('Parent',boot_beta.toolbar, ...
                      'TooltipString','Save to mat-file', ...
                      'CData',button_images.matfile, ...
                      'ClickedCallback','beta_bootstrap matfile', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','MatFileButton');

   boot_beta.summary = uipushtool('Parent',boot_beta.toolbar, ...
                      'TooltipString','View Simulation Summary', ...
                      'CData',button_images.sim_summary, ...
                      'ClickedCallback','beta_bootstrap summary', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'UserData',stdbeta, ...
                      'Enable',summary_enable, ...
                      'Tag','SummaryButton');

   boot_beta.full = uipushtool('Parent',boot_beta.toolbar, ...
                      'TooltipString','View Full Simulation', ...
                      'CData',button_images.sim_full, ...
                      'ClickedCallback','beta_bootstrap full', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'UserData',beta_t_dist, ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','FullButton');

   boot_beta.bootstrapgraph = uipushtool('Parent',boot_beta.toolbar, ...
                      'TooltipString','Graph Bootstrap Sample', ...
                      'CData',button_images.bootstrapsmall, ...
                      'ClickedCallback','beta_bootstrap display_bootstrap', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',epsfile, ...
                      'Clipping','on', ...
                      'Enable',boot_enable, ...
                      'Tag','ViewBootstrapButton');

   boot_beta.display = uipushtool('Parent',boot_beta.toolbar, ...
                      'TooltipString','Graph Distribution', ...
                      'CData',button_images.viewdist, ...
                      'ClickedCallback','beta_bootstrap display', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',beta_sorted, ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','ViewDistButton');

   boot_beta.histogram = uipushtool('Parent',boot_beta.toolbar, ...
                      'TooltipString','Histogram of Distribution', ...
                      'CData',button_images.bars, ...
                      'ClickedCallback','beta_bootstrap display', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'UserData',beta_vec_sorted, ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','HistogramButton');

   boot_beta.help = uipushtool('Parent',boot_beta.toolbar, ...
                      'TooltipString','Help Topics', ...
                      'CData',button_images.help, ...
                      'ClickedCallback','help_fcn(''bootstrapping'')', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',helpenable, ...
                      'Tag','HelpButton');

   boot_beta.done = uipushtool('Parent',boot_beta.toolbar, ...
                      'TooltipString','Return', ...
                      'CData',button_images.continue, ...
                      'ClickedCallback','beta_bootstrap done', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'UserData','waiting', ...
                      'Enable','on', ...
                      'Tag','Done');

   axesbox([2 2 558 415],'Beta',25,[0.5 1]);

   %
   % GUI Header
   %

   if curr_ini.sscorrect==1;
      header_txt = ['Bootstrap Beta and F Test (' model_type ' Model)'];
   else;
      header_txt = ['Bootstrap Beta and LR Test (' model_type ' Model)'];
   end;
   desc_txt = 'Select the type of bootstrap you wish to perform, the number of observations and replications. Press the "Run Bootstrap" button when you''re satisfied with your choices and wait for the computations to finish.';
   dialog_header_fcn([16 331 530 70],button_images.bootstrap,header_txt,desc_txt);

   %
   % Options
   %

   axesbox([16 155 155 160],'Options',35,[0.5 1]);

   boot_beta.clock = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 280 130 20], ...
      'Value',1, ...
      'String','Show elapsed time', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'UserData',beta, ...
      'Enable','on', ...
      'Tag','TimeCheck');

   boot_beta.progress = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 260 130 20], ...
      'Value',1, ...
      'String','Show progress dialog', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ProgressCheck');

   boot_beta.save = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 240 130 20], ...
      'Value',1, ...
      'String','Save full simulation', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','SaveCheck');

   boot_beta.parametric = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 220 130 20], ...
      'Value',curr_ini.parametric, ...
      'String','Parametric bootstrap', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'Callback','beta_bootstrap fixobscontrol', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ParametricCheck');


   boot_beta.blocktext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[45 190 100 20], ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Style','text', ...
      'HorizontalAlignment','left', ...
      'String','Block size:', ...
      'Enable','off', ...
      'Tag','BlockText');

   boot_beta.block = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[105 195 50 20], ...
      'Value',1, ...
      'String','1|2|3|4|5|6|7|8|9|10|11|12', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Value',curr_ini.blocksize, ...
      'Enable','off', ...
      'Callback','beta_bootstrap check', ...
      'Tag','BlockPopup');
   
   if curr_ini.parametric==0;
      set(boot_beta.blocktext,'Enable','on');
      set(boot_beta.block,'Enable','on');
   end;

   boot_beta.bootstrap = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 170 130 20], ...
      'Value',curr_ini.reuse_bootstrap, ...
      'String','Reuse/save residuals', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ReuseBootstrapCheck');

   axesbox([185 155 361 160],'Parameters',55,[0.5 1]);

   %
   % number of observations per replication
   %

   boot_beta.obstext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 274 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'HorizontalAlignment','left', ...
      'String','Number of observations:', ...
      'Tag','ObsText');

   boot_beta.obs = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 279 168 20], ...
      'Value',1, ...
      'String',[num2str(my_T) '|100|200|300|400|500|600|700|800|900|1000|1100|1200|1300|1400|1500|1600|1700|1800|1900|2000|2500|3000|4000|5000|6000|7000|8000|9000|10000'], ...
      'Style','popupmenu', ...
      'UserData',my_T, ...
      'Callback','beta_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','ObsPopup');

   if (tm.q1+tm.q0==0)&(isempty(tm.deterfile)==1);
      set(boot_beta.obstext,'Enable','on');
      set(boot_beta.obs,'Enable','on');
   end;

   %
   % number of replications
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 221.5 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of replications:', ...
      'Tag','SimulText');

   boot_beta.rep = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 226.5 168 20], ...
      'Value',nRep_value, ...
      'String','99|999|1,999|2,999|3,999|4,999|9,999|19,999|29,999|39,999|49,999|99,999|199,999|299,999|399,999|499,999|999,999', ...
      'Style','popupmenu', ...
      'Callback','beta_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'UserData',rep,...
      'Enable','on', ...
      'Tag','SimulPopup');

   %
   % Trim beta estimates
   %

   boot_beta.trim_estimatestext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 169 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Trim tails of beta distribution by:', ...
      'Tag','TrimText');

   boot_beta.trim_estimates = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 174 168 20], ...
      'Value',1, ...
      'String','0%|0.05%|0.1%|0.2%|0.3%|0.4%|0.5%|0.6%|0.7%|0.8%|0.9%|1%|2%|3%|4%|5%', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','TrimmingPopup');

   %
   % Select interpolation function
   %

   axesbox([16 16 530 125],'Graphics',45,[0.5 1]);

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 99 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Interpolation function:', ...
      'Tag','InterpolateText');

   boot_beta.interpolate = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 104 168 20], ...
      'Value',tm.interpolate_value, ...
      'String','Nearest neighborhood|Linear|Cubic spline|Cubic|Kernel density normal|Kernel density Epanechnikov|Kernel density rectangular|Kernel density triangular|Kernel density biweight|Kernel density triweight|Kernel density Laplace|Kernel density logistic', ...
      'Callback','beta_bootstrap interpolate', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','InterpolatePopup');

   %
   % Select bootstrap distribution for parameter graphs
   %

   boot_beta.bootdisttext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 64 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Parameter distribution:', ...
      'Tag','BootDistText');

   boot_beta.bootdist = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 69 168 20], ...
      'Value',1, ...
      'String','bootstrapped beta t-statistic|bootstrapped beta', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','BootDistPopup');

   %
   % Number of cells for graphing density functions
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 29 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of cells for histograms:', ...
      'Tag','CellText');

   boot_beta.cells = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 34 168 20], ...
      'Value',1, ...
      'String','20|25|30|35|40|45|50|55|60|65|70|75|80|85|90|95|100', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','CellPopup');

   %
   % Additional options
   %

   boot_beta.cdf = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 107 140 20], ...
      'Value',0, ...
      'String','Cumulative distribution', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','cdfCheckbox');

   boot_beta.threed = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 87 160 20], ...
      'Value',0, ...
      'String','Plot 3D densities for beta', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','cdfCheckbox');

   boot_beta.adaptive = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 67 140 20], ...
      'Value',0, ...
      'String','Adaptive KDE method', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','adaptiveCheckbox');

   boot_beta.bart = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 47 140 20], ...
      'Value',0, ...
      'String','Bartlett corr. bootstrap', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','BartlettCheckbox');

   boot_beta.pq_plot = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 27 140 20], ...
      'Value',0, ...
      'String','P-value plots, etc.', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','PQplotCheckbox');

   if tm.interpolate_value>=5;
      set(boot_beta.adaptive,'Enable','on');
   end;

   if tm.dfbeta==0;
      set(boot_beta.bart,'Enable','off');
      set(boot_beta.pq_plot,'Enable','off');
   end;
   if ((tm.n+tm.q1+tm.dcoint-tm.r)*tm.r)-tm.dfbeta==0;
      set(boot_beta.bootdist,'Enable','off');
      set(boot_beta.trim_estimates,'Enable','off');
      set(boot_beta.bootdisttext,'Enable','off');
      set(boot_beta.trim_estimatestext,'Enable','off');
      set(boot_beta.threed,'Enable','off');
   end;

   set(beta_boot_gui,'UserData',boot_beta,...
         'HandleVisibility','callback');

case 'output'
   if curr_ini.texoutputformat>=2;
      file = strrep(lower(get(boot_beta.summarymenu,'UserData')),'.txt','.ltx');
      txt_str = readtext(file);
      fout = fopen(tm.outputfile,'at');
      fprintf(fout,'\\subsection*{Bootstrap Simulation of $\\beta$} \n\n');
      for i=1:size(txt_str,2);
         fprintf(fout,'%s\n',txt_str{i});
      end;
      fclose(fout);
   else;
      txt_str = readtext(lower(get(boot_beta.summarymenu,'UserData')));
      fout = fopen(tm.outputfile,'at');
      fprintf(fout,'                      Bootstrap Simulation of Beta\n                      ----------------------------\n');
      for i=5:size(txt_str,2)-4;
         fprintf(fout,'%s\n',txt_str{i});
      end;
      fprintf(fout,'\n===============================================================================\n\n');
      fclose(fout);
   end;
case 'display_bootstrap'
   epsfile = get(boot_beta.bootstrapgraph,'UserData');
   testfile = get(boot_beta.bootstrapgraphmenu,'UserData');
   beta_vec_sorted = get(boot_beta.histogram,'UserData');
   my_T = get(boot_beta.obs,'UserData');
   rep = get(boot_beta.rep,'UserData');
   if rep<4999;
      answer = 'Yes';
   else;
      check_txt = ['Your bootstrap setup includes ' num2str(rep) ' draws of the residuals. With ' num2str(tm.n) ' series and ' num2str(my_T) ' observations, this yields ' num2str(rep*tm.n*my_T) ' observations. Are you sure you want to load that much data into memory?'];
      answer = query(check_txt,'warning',120,'Exit',500,'no');
   end;
   if strcmp(answer,'Yes')==1;
      %
      dfc = round((((tm.n+tm.q1+tm.dcoint-tm.r)*tm.r)-tm.dfbeta)/tm.n);
      df = tm.n*(tm.p-1)+tm.r+tm.q1*tm.pe+tm.q0*(tm.pe+1)+tm.d+dfc;
      if tm.dfbeta>0;
         if curr_ini.sscorrect==1;
            txt_str = ['F(' num2str(tm.dfbeta,'%0.0f') ',' num2str(my_T-df,'%0.0f') ') ='];
         else;
            txt_str = ['LR(' num2str(tm.dfbeta,'%0.0f') ') ='];
         end;
      else;
         txt_str = '';
      end;
      %
      % may need to re-estimate
      %
      if (tm.restrict(1,2)==0)|(tm.restrict(1,1)==1);
         [S_00,S_01,S_10,S_11,M_02,M_22,M_12,beta,lambda,trace_test] = mlcointbasic(tm.Z0,tm.Z1,tm.Z2,tm.r);
         unOmega = S_00-S_01*(beta/(beta'*S_11*beta))*beta'*S_10;
         [tm.beta,newlambda,newdfbeta,stdbeta,outputtxt,new_abort] = betarestrict(S_00,S_11,S_01,S_10,beta,tm.T,tm.modelsdir,tm.modelfile,0,tm.dcoint);
         dfc = round((((tm.n+tm.q1+tm.dcoint-tm.r)*tm.r)-newdfbeta)/tm.n);
         df = tm.n*(tm.p-1)+tm.r+tm.q1*tm.pe+tm.q0*(tm.pe+1)+tm.d+dfc;
         %
         % Compute the LR test of the restrictions if there are any
         % overidentifying such
         %
         if newdfbeta>0;
            rOmega = S_00-S_01*(tm.beta/(tm.beta'*S_11*tm.beta))*tm.beta'*S_10;
         else;
            rOmega = unOmega;
         end;
         %
         % recompute all other parameters which will be used to generate bootstrapped data
         %
         tm.alpha = (tm.S_01*tm.beta)/(tm.beta'*tm.S_11*tm.beta);
         if isempty(tm.Z2)==0;
            tm.Psi = (tm.M_02/tm.M_22)-(tm.alpha*tm.beta'*(tm.M_12/tm.M_22));
            tm.epsilon = tm.Z0-(tm.alpha*tm.beta'*tm.Z1)-(tm.Psi*tm.Z2);
         else;
            tm.Psi = [];
            tm.epsilon = tm.Z0-(tm.alpha*tm.beta'*tm.Z1);
         end;
         tm.Omega = rOmega;
      end;
      %
      set(beta_boot_gui,'Visible','off');
      drawnow;
      thisgraph = bootgraphdlg('init',tm,epsfile,testfile,txt_str,tm.beta,rep,my_T,tm.r);
      bootgraph = get(thisgraph,'UserData');
      set(bootgraph.show,'UserData','done');
      killguipid(thisgraph);
      set(beta_boot_gui,'Visible','on');
      drawnow;
   end;
case 'fixobscontrol'
   if get(boot_beta.parametric,'Value')==0;
      T_str = get(boot_beta.obs,'String');
      my_T = mystr2num(strtrim(T_str(get(boot_beta.obs,'Value'),:)));
      set(boot_beta.obs,'Value',1,'UserData',my_T,'Enable','off');
      set(boot_beta.obstext,'Enable','off');
   elseif (tm.q1+tm.q0==0)&(isempty(tm.deterfile)==1);
      set(boot_beta.obs,'Enable','on');
      set(boot_beta.obstext,'Enable','on');
   end;
   beta_bootstrap('check');
case 'interpolate'
   tm.interpolate_value = get(boot_beta.interpolate,'Value');
   interpol_vec = strvcat('nearest','linear','spline','cubic','knorm','kepan','krect','ktria','kbiwe','ktriw','klapl','klogi');
   tm.interpolate = strtrim(interpol_vec(tm.interpolate_value,:));
   if tm.interpolate_value>=5;
      set(boot_beta.adaptive,'Enable','on');
   else;
      set(boot_beta.adaptive,'Enable','off','Value',0);
   end;
case 'matfile'
   beta_sorted = get(boot_beta.display,'UserData');
   beta_vec_sorted = get(boot_beta.histogram,'UserData');
   beta_t_dist = get(boot_beta.full,'UserData');
   beta = get(boot_beta.clock,'UserData');
   stdbeta = get(boot_beta.summary,'UserData');
   rep = get(boot_beta.rep,'UserData');
   my_T = get(boot_beta.obs,'UserData');
   my_const_model = get(boot_beta.displaymenu,'UserData');
   if get(boot_beta.parametric,'Value')==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(get(boot_beta.block,'Value')) '-'];
   end;
   if my_const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-full-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
   elseif my_const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-full-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif my_const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-full-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif my_const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-full-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif my_const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-full-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      my_text = ['The file "' getfilename(full_mat) '" already exists. Are you sure you want to overwrite it?'];
      answer = query(my_text,'question',120,'Save to mat-file',500,'no');
   else;
      answer = 'Yes';
   end;
   if strcmp(answer,'Yes')==1;
      setlogtext('Savings results to mat-files...');
      Number = (1:1:rep)';
      save(full_mat,'beta_sorted','beta_vec_sorted','beta_t_dist','beta','stdbeta');
   end;
case 'check'
   T_str = get(boot_beta.obs,'String');
   my_T = mystr2num(strtrim(T_str(get(boot_beta.obs,'Value'),:)));
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   rep_val = get(boot_beta.rep,'Value');
   rep = repvalues(rep_val);
   set(boot_beta.rep,'UserData',rep);
   set(boot_beta.obs,'UserData',my_T);
   %
   % adjusting the view text buttons
   %
   if get(boot_beta.parametric,'Value')==1;
      bootstyle = '';
      set(boot_beta.blocktext,'Enable','off');
      set(boot_beta.block,'Enable','off','Value',1);
   else;
      if strcmp(get(boot_beta.block,'Enable'),'off')==1;
         set(boot_beta.blocktext,'Enable','on');
         set(boot_beta.block,'Enable','on','Value',curr_ini.blocksize);
      end;
      bootstyle = ['np' num2str(get(boot_beta.block,'Value')) '-'];
   end;
   %
   full_mat = '';
   if tm.const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-full-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
      mod_type = 'noconst';
   elseif tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-full-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
      mod_type = 'resconst';
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-full-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
      mod_type = 'const';
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-full-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
      mod_type = 'restrend';
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-full-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
      mod_type = 'trend';
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      beta_mat = load(full_mat);
      beta_sorted = beta_mat.beta_sorted;
      beta_vec_sorted = beta_mat.beta_vec_sorted;
      if isfield(beta_mat,'beta_t_dist')==1;
         beta_t_dist = beta_mat.beta_t_dist;
         beta = beta_mat.beta;
         stdbeta = beta_mat.stdbeta;
      else;
         beta_t_dist = [];
         beta = [];
         stdbeta = [];
      end;
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
      %
      % adjusting the Graph Distrbution button
      %
      set(boot_beta.display,'Enable','on','UserData',beta_sorted);
      set(boot_beta.histogram,'Enable','on','UserData',beta_vec_sorted);
      set(boot_beta.displaymenu,'Enable','on','UserData',tm.const_model);
      set(boot_beta.full,'UserData',beta_t_dist);
      set(boot_beta.clock,'UserData',beta);
      set(boot_beta.summary,'UserData',stdbeta);
      set(boot_beta.histogrammenu,'Enable','on');
      set(boot_beta.matfilebutton,'Enable','on');
      set(boot_beta.matfilemenu,'Enable','on');
   else;
      full_mat = '';
      full_enable = 'off';
      set(boot_beta.display,'Enable','off','UserData',[]);
      set(boot_beta.displaymenu,'Enable','off','UserData',tm.const_model);
      set(boot_beta.histogram,'Enable','off','UserData',[]);
      set(boot_beta.full,'UserData',[]);
      set(boot_beta.clock,'UserData',[]);
      set(boot_beta.summary,'UserData',[]);
      set(boot_beta.histogrammenu,'Enable','off');
      set(boot_beta.matfilebutton,'Enable','off');
      set(boot_beta.matfilemenu,'Enable','off');
   end;
   %
   % Checking if residuals file exists
   %
   epsfile = [curr_ini.simulatedir tm.modelfile '-' 'beta-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
   testfile = strrep(epsfile,'.mat',['-' 'beta-data.mat']);
   if (fileexist(epsfile)==1)&(fileexist(testfile)==1);
      set(boot_beta.bootstrapgraph,'Enable','on','UserData',epsfile);
      set(boot_beta.bootstrapgraphmenu,'Enable','on','UserData',testfile);
   elseif fileexist(testfile)==1;
      set(boot_beta.bootstrapgraph,'Enable','off','UserData',[]);
      set(boot_beta.bootstrapgraphmenu,'Enable','off','UserData',testfile);
   else;
      set(boot_beta.bootstrapgraph,'Enable','off','UserData',[]);
      set(boot_beta.bootstrapgraphmenu,'Enable','off','UserData','');
   end;
   %
   set(boot_beta.fullmenu,'Enable',full_enable,'UserData',full_mat);
   set(boot_beta.full,'Enable',full_enable);
   summary_txt = '';
   if tm.const_model(1)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-summary-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
   elseif tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-summary-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-summary-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-summary-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-summary-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
   end;
%   if curr_ini.texoutputformat>=2;
%      summary_txt = strrep(summary_txt,'.txt','.ltx');
%   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
   end;
   if curr_ini.noprint==0;
      set(boot_beta.output,'Enable',summary_enable);
   end;
   set(boot_beta.summarymenu,'Enable',summary_enable,'UserData',summary_txt);
   set(boot_beta.summary,'Enable',summary_enable);
   set(beta_boot_gui,'UserData',boot_beta);
case 'summary'
   set(beta_boot_gui,'Visible','off');
   drawnow;
   file = lower(get(boot_beta.summarymenu,'UserData'));
   prtgui = printgui('init',file,'Structural VAR - Beta Bootstrap Simulation Summary',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   myprint = get(prtgui,'UserData');
   set(myprint.print,'UserData','done');
   killguipid(prtgui);
   set(beta_boot_gui,'Visible','on');
   drawnow;
   set(beta_boot_gui,'UserData',boot_beta);
case 'full'
   set(beta_boot_gui,'Visible','off');
   drawnow;
   rep = get(boot_beta.rep,'UserData');
   full_mat = lower(get(boot_beta.fullmenu,'UserData'));
   beta_vec_sorted = get(boot_beta.histogram,'UserData');
   my_T = get(boot_beta.obs,'UserData');
   %
   % not functional yet
   %
   dfc = round((((tm.n+tm.q1+tm.dcoint-tm.r)*tm.r)-tm.dfbeta)/tm.n);
   df = tm.n*(tm.p-1)+tm.r+tm.q1*tm.pe+tm.q0*(tm.pe+1)+tm.d+dfc;
   %
   sp_str = spacestr(curr_ini.decimals-2);
   prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
   my_text = ' Number';
   prt_str = ['%7.0f'];
   if tm.dfbeta>0;
      if curr_ini.sscorrect==1;
         my_text = sprintf(' Number     F(%2.0f,%3.0f)',tm.dfbeta,my_T-df);
      else;
         my_text = sprintf(' Number       LR(%2.0f) ',tm.dfbeta);
      end;
      prt_str = [prt_str '   ' prt_val];
   end;
   for i=1:tm.r;
      for j=1:tm.n+tm.q1+tm.dcoint;
         my_text = [my_text sp_str '  beta(' num2str(i) ',' num2str(j) ')'];
         prt_str = [prt_str '   ' prt_val];
      end;
   end;
   %
   my_text = strvcat(' ',my_text);
   abort = '';
   if rep>=5000;
      input_var.title = ['Progress for ' int2str(rep) ' replications'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.label = 'Replication number:';
      input_var.stop = 0;
      input_var.clock = 1;
      input_var.name = ['Data in ' getname(full_mat)];
      mywait = progressdlg(0,input_var);
%      set(mywait,'Name',['Data in ' getname(full_mat)]);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
      drawnow;
   end;
   beta_mat = load(full_mat);
   my_data = beta_mat.Number;
   if isempty(beta_mat.beta_sorted)==0;
      my_data = [my_data beta_mat.beta_sorted];
   end;
   my_data = [my_data beta_mat.beta_vec_sorted];
   for i=1:size(my_data,1);
      if rep>=5000;
         abort = get(mywait,'UserData');
         if strcmp(abort,'cancel')==1;
            break;
         else;
            progressdlg([(i/rep) i]);
         end;
      end;
      my_text = strvcat(my_text,sprintf(prt_str,my_data(i,:)'));
   end;
   my_text = strvcat(my_text,' ');
   if rep>=5000;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   end;
   if strcmp(abort,'cancel')==0;
      textgui(my_text,'Structural VAR - Beta Bootstrap Simulation',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   end;
   set(beta_boot_gui,'Visible','on');
   drawnow;
   set(beta_boot_gui,'UserData',boot_beta);
case 'display'
   beta_sorted = get(boot_beta.display,'UserData');
   beta_vec_sorted = get(boot_beta.histogram,'UserData');
   beta_t_dist = get(boot_beta.full,'UserData');
   beta_t_vec = [];
   beta = get(boot_beta.clock,'UserData');
   stdbeta = get(boot_beta.summary,'UserData');
   pos = [(tm.realscrsz(3)-600)/2 (tm.realscrsz(4)-400)/2];
   rep = get(boot_beta.rep,'UserData');
   my_T = get(boot_beta.obs,'UserData');
   %
   % trim beta
   %
   trim_val = get(boot_beta.trim_estimates,'Value');
   if trim_val>1;
      trim_str = get(boot_beta.trim_estimates,'String');
      trim_p = strrep(trim_str(trim_val,:),'%','');
      trim_p = mystr2num(trim_p)/200;
      b_val = ceil(trim_p*rep)+1;
      t_val = rep+1-b_val;
   else;
      b_val = 1;
      t_val = rep;
   end;
   %
   % need to fix the rest
   %
   my_const_model = get(boot_beta.displaymenu,'UserData');
   if my_const_model(1)==1;
      this_mod = '(no constant)';
   elseif my_const_model(2)==1;
      this_mod = '(restricted constant)';
   elseif my_const_model(3)==1;
      this_mod = '(constant)';
   elseif my_const_model(4)==1;
      this_mod = '(restricted trend)';
   elseif my_const_model(5)==1;
      this_mod = '(trend)';
   end;
   cell_value = get(boot_beta.cells,'Value');
   cell_vec = [20 25 30 35 40 45 50 55 60 65 70 75 80 85 90 95 100];
   numcells = cell_vec(cell_value);
   my_80 = floor(0.8*rep);
   my_90 = floor(0.9*rep);
   my_95 = floor(0.95*rep);
   my_975 = floor(0.98*rep);
   my_99 = floor(0.99*rep);
   cdf_value = get(boot_beta.cdf,'Value');
   %
   if curr_ini.colors==1;
      col.vec_1 = [0 0 1];
      col.vec_2 = [1 0 0];
      col.vec_3 = [0 0.75 0];
      col.vec_4 = [1 0.5 0];
      col.vec_5 = [0 0.75 0.75];
      col.vec_6 = [0 0 0];
      col.vec_7 = (1/255)*[255 28 28];
      col.vec_8 = [0 1 0];
      col.vec_9 = (1/255)*[255 255 177];
   else;
      col.vec_1 = [0 0 0];
      col.vec_2 = [0.7 0.7 0.7];
      col.vec_3 = [0.6 0.6 0.6];
      col.vec_4 = [0.5 0.5 0.5];
      col.vec_5 = [0.4 0.4 0.4];
      col.vec_6 = [0.3 0.3 0.3];
      col.vec_7 = [0.8 0.8 0.8];
      col.vec_8 = [0.2 0.2 0.2];
      col.vec_9 = col.vec_3;
   end;
   %
   if tm.dfbeta>0;
      dfc = round((((tm.n+tm.q1+tm.dcoint-tm.r)*tm.r)-tm.dfbeta)/tm.n);
      df = tm.n*(tm.p-1)+tm.r+tm.q1*tm.pe+tm.q0*(tm.pe+1)+tm.d+dfc;
      beta_series = [];
      %
      if (gcbo==boot_beta.display)|(gcbo==boot_beta.displaymenu);
         if curr_ini.sscorrect==1;
            df = [tm.dfbeta (my_T-df)];
         else;
            df = tm.dfbeta;
         end;
         [beta_series,beta_quant,beta_table] = asymp_series(df,curr_ini.sscorrect);
         if get(boot_beta.pq_plot,'Value')==1;
            [p_series,pp_series,qq_series] = pq_plot_series(beta_sorted,beta_quant,beta_table,df,curr_ini.sscorrect);
         end;
      end;
      %
      if curr_ini.sscorrect==1;
         add_name = ['F(' num2str(tm.dfbeta,'%0.0f') ',' num2str(my_T-df,'%0.0f') ')'];
      else;
         add_name = ['LR(' num2str(tm.dfbeta,'%0.0f') ')'];
      end;
      %
      if ((gcbo==boot_beta.display)|(gcbo==boot_beta.displaymenu))&(get(boot_beta.pq_plot,'Value')==1);
         [pos,newplot] = pq_plot(pos,'beta-test-pqplot-',['P-value and Quantile Plots for ' add_name ' Test'],['P-value plot of ' add_name],['P-value discrepancy plot of ' add_name],['PP plot of ' add_name],['QQ plot of ' add_name],tm,beta_quant,beta_table,p_series,pp_series,qq_series,col);
      end;
      [pos,thisplot] = dist_plot(pos,'beta-test-plot-',['Density for ' add_name ' Test'],[add_name ' beta test ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(tm.r) ' cointegration vectors'],tm,curr_ini,boot_beta,beta_sorted,beta_series,1,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,df);
   end;
   if ((tm.n+tm.q1+tm.dcoint-tm.r)*tm.r)>tm.dfbeta;
      beta_plot = [];
      create_twodee = 0;
      if get(boot_beta.bootdist,'Value')==2;
         num_row = 1;
         num_col = 1;
         for i=1:size(beta_vec_sorted,2);
            if isalmostequal(min(beta_vec_sorted(:,i)),max(beta_vec_sorted(:,i)))==0;
               %
               % plotting empirical distrbutions for beta_ij
               %
               [pos,bplot] = parm_dist(pos,['beta-' num2str(num_row,'%0.0f') '.' num2str(num_col,'%0.0f') '-plot-'],['Density for beta(' num2str(num_row,'%0.0f') ',' num2str(num_col,'%0.0f') ') parameter (bootstrapped beta)'],['Bootstrapped \beta_{' num2str(num_row,'%0.0f') num2str(num_col,'%0.0f') '} with ' num2str(tm.cbs) '% confidence interval from bootstrapped \beta distribution'],beta(num_col,num_row),beta(num_col,num_row),stdbeta(num_col,num_row),tm,curr_ini,boot_beta,my_T,[],beta_vec_sorted(b_val:t_val,i),1,numcells,col,rep);
               beta_plot = [beta_plot bplot];
               create_twodee = 1;
            end;
            if num_col==tm.n+tm.q1+tm.dcoint;
               num_col = 1;
               num_row = num_row+1;
            else;
               num_col = num_col+1;
            end;
         end;
      else;
         %
         % 2D plots based on t-values
         %
         if isempty(beta_t_dist)==0;
            %
            % construct the asymptotic distribution for beta based on t-value
            %
            if (size(beta_t_dist,2)>0)&(gcbo~=boot_beta.histogram)&(gcbo~=boot_beta.histogrammenu);
               t_series = gauss_dist_series;
            else;
               t_series = [];
            end;
            %
            num_row = 1;
            num_col = 1;
            num_beta = 1;
            for i=1:size(beta_vec_sorted,2);
               if isalmostequal(min(beta_vec_sorted(:,i)),max(beta_vec_sorted(:,i)))==0;
                  %
                  % Plotting the empirical distributions of beta_ij using t-ratios
                  %
                  [pos,bplot] = parm_dist(pos,['beta-' num2str(num_row,'%0.0f') '.' num2str(num_col,'%0.0f') '-plot-'],['Density for beta(' num2str(num_row,'%0.0f') ',' num2str(num_col,'%0.0f') ') parameter (bootstrapped t-value)'],['Bootstrapped \beta_{' num2str(num_row,'%0.0f') num2str(num_col,'%0.0f') '} with ' num2str(tm.cbs) '% confidence interval from bootstrapped t-statistic distribution'],beta(num_col,num_row),beta(num_col,num_row),stdbeta(num_col,num_row),tm,curr_ini,boot_beta,my_T,t_series,beta_t_dist(:,num_beta),1,numcells,col,rep);
                  beta_plot = [beta_plot bplot];
                  create_twodee = 1;
                  num_beta = num_beta+1;
               end;
               if num_col==tm.n+tm.q1+tm.dcoint;
                  num_col = 1;
                  num_row = num_row+1;
               else;
                  num_col = num_col+1;
               end;
            end;
         end;
      end;
      %
      % Create 3D graphs of pairs of beta parameters against density (no histograms)
      %
      c_3dplot = 0;
      if (((tm.n+tm.q1+tm.dcoint-tm.r)*tm.r)-tm.dfbeta>2)&((gcbo==boot_beta.display)|(gcbo==boot_beta.displaymenu))&(get(boot_beta.threed,'Value')==1);
         testfile = get(boot_beta.bootstrapgraphmenu,'UserData');
         if fileexist(testfile)==1;
            beta_data = load(testfile);
            x_col = 1;
            x_row = 1;
            y_col = 2;
            show_wait = 0;
            if get(boot_beta.bootdist,'Value')==2;
               beta_vec = beta_data.beta_vec;
               while x_row<=tm.r;
                  i = x_col+(tm.n+tm.q1+tm.dcoint)*(x_row-1);
                  j = y_col+(tm.n+tm.q1+tm.dcoint)*(x_row-1);
                  if (isalmostequal(min(beta_vec(:,i)),max(beta_vec(:,i)))==0)&(isalmostequal(min(beta_vec(:,j)),max(beta_vec(:,j)))==0);
                     c_3dplot = 1;
                     this_text = strvcat(' ',['Creating 3D density and contour plots for beta(' num2str(x_row) ',' num2str(x_col) ') and beta(' num2str(x_row) ',' num2str(y_col) ').'],' ','Please hold!');
                     if cdf_value==1;
                        this_text = strvcat(' ',['Creating 3D density plots for beta(' num2str(x_row) ',' num2str(x_col) ') and beta(' num2str(x_row) ',' num2str(y_col) ').'],' ','Please hold!');
                     end;
                     if show_wait==0;
                        mywait = waitdlg(this_text,'bootstrap','3D Densities...');
                        waitf = get(mywait,'UserData');
                        show_wait = 1;
                     else;
                        set(waitf.text,'String',this_text);
                     end;
                     %
                     % 3D graph of empirical distribution
                     %
                     if (b_val>1)&(t_val<rep);
                        beta_mat_fixed = sort2d([beta_vec(:,j) beta_vec(:,i)],[beta_vec_sorted(b_val,j) beta_vec_sorted(t_val,j)],[beta_vec_sorted(b_val,i) beta_vec_sorted(t_val,i)]);
                     else;
                        beta_mat_fixed = [beta_vec(:,j) beta_vec(:,i)];
                     end;
                     %
                     [pos,bplot,x_n,y_n,n1] = dist2d_plot(pos,['density-beta-' num2str(x_row,'%0.0f') '.' num2str(x_col,'%0.0f') '-' num2str(x_row,'%0.0f') '.' num2str(y_col,'%0.0f')],['Joint density for beta(' num2str(x_row,'%0.0f') ',' num2str(x_col,'%0.0f') ') and beta(' num2str(x_row,'%0.0f') ',' num2str(y_col,'%0.0f') ') parameters (bootstrapped beta)'],['Bootstrapped density for \beta_{' num2str(x_row,'%0.0f') ',' num2str(x_col,'%0.0f') '} and \beta_{' num2str(x_row,'%0.0f') ',' num2str(y_col,'%0.0f') '} from bootstrapped \beta distribution'],['\beta_{' num2str(x_row,'%0.0f') ',' num2str(x_col,'%0.0f') '}'],['\beta_{' num2str(x_row,'%0.0f') ',' num2str(y_col,'%0.0f') '}'],tm,curr_ini,boot_beta,beta_mat_fixed,[beta_vec_sorted(b_val,i) beta_vec_sorted(t_val,i)],[beta_vec_sorted(b_val,j) beta_vec_sorted(t_val,j)],1,numcells);
                     beta_plot = [beta_plot bplot];
                     %
                     %
                     % create contour plots for density functions
                     %
                     if (cdf_value==0)&(strcmp(tm.interpolate,'nearest')==0);
                        [pos,bplot] = contour_plot(pos,['contour-beta-' num2str(x_row,'%0.0f') '.' num2str(x_col,'%0.0f') '-' num2str(x_row,'%0.0f') '.' num2str(y_col,'%0.0f')],['Confidence contours for beta(' num2str(x_row,'%0.0f') ',' num2str(x_col,'%0.0f') ') and beta(' num2str(x_row,'%0.0f') ',' num2str(y_col,'%0.0f') ') parameters (bootstrapped beta)'],['Confidence regions for \beta_{' num2str(x_row,'%0.0f') ',' num2str(x_col,'%0.0f') '} and \beta_{' num2str(x_row,'%0.0f') ',' num2str(y_col,'%0.0f') '} from bootstrapped \beta distribution'],['\beta_{' num2str(x_row,'%0.0f') ',' num2str(x_col,'%0.0f') '}'],['\beta_{' num2str(x_row,'%0.0f') ',' num2str(y_col,'%0.0f') '}'],tm,curr_ini,beta_mat_fixed,x_n,y_n,n1,1);
                        beta_plot = [beta_plot bplot];
                     end;
                  end;
                  if x_col==tm.n+tm.q1+tm.dcoint-1;
                     x_col = 1;
                     y_col = 2;
                     x_row = x_row+1;
                  elseif y_col==tm.n+tm.q1+tm.dcoint;
                     x_col = x_col+1;
                     y_col = x_col+1;
                  else;
                     y_col = y_col+1;
                  end;
               end;
            else;
               %
               % using beta_t_dist unsorted data
               %
               if isfield(beta_data,'beta_t_dist')==1;
                  beta_t_vec = beta_data.beta_t_dist;
                  x_col = 1;
                  x_row = 1;
                  y_col = 2;
                  ik = 1;
                  jk = 2;
                  made_row_plot = 0;
                  while x_row<=tm.r;
                     i = x_col+(tm.n+tm.q1+tm.dcoint)*(x_row-1);
                     j = y_col+(tm.n+tm.q1+tm.dcoint)*(x_row-1);
                     make_plot = 0;
                     if (isalmostequal(min(beta_vec_sorted(:,i)),max(beta_vec_sorted(:,i)))==0)&(isalmostequal(min(beta_vec_sorted(:,j)),max(beta_vec_sorted(:,j)))==0);
                        c_3dplot = 1;
                        make_plot = 1;
                        made_row_plot = 1;
                        this_text = strvcat(' ',['Creating 3D density and contour plots for beta(' num2str(x_row) ',' num2str(x_col) ') and beta(' num2str(x_row) ',' num2str(y_col) ').'],' ','Please hold!');
                        if cdf_value==1;
                           this_text = strvcat(' ',['Creating 3D density plots for beta(' num2str(x_row) ',' num2str(x_col) ') and beta(' num2str(x_row) ',' num2str(y_col) ').'],' ','Please hold!');
                        end;
                        if show_wait==0;
                           mywait = waitdlg(this_text,'bootstrap','3D Densities...');
                           waitf = get(mywait,'UserData');
                           show_wait = 1;
                        else;
                           set(waitf.text,'String',this_text);
                        end;
                        %
                        % 3D graph of density
                        %
                        beta_mat_fixed = [beta(y_col,x_row)+(beta_t_vec(:,jk)*sqrt(tm.T/my_T)*stdbeta(y_col,x_row)) beta(x_col,x_row)+(beta_t_vec(:,ik)*sqrt(tm.T/my_T)*stdbeta(x_col,x_row))];
                        [pos,bplot,x_n,y_n,n1] = dist2d_plot(pos,['density-beta-t-dist-' num2str(x_row,'%0.0f') '.' num2str(x_col,'%0.0f') '-' num2str(x_row,'%0.0f') '.' num2str(y_col,'%0.0f')],['Joint density for beta(' num2str(x_row,'%0.0f') ',' num2str(x_col,'%0.0f') ') and beta(' num2str(x_row,'%0.0f') ',' num2str(y_col,'%0.0f') ') parameters (bootstrapped t-value)'],['Bootstrapped density for \beta_{' num2str(x_row,'%0.0f') ',' num2str(x_col,'%0.0f') '} and \beta_{' num2str(x_row,'%0.0f') ',' num2str(y_col,'%0.0f') '} from bootstrapped t-statistic distribution'],['\beta_{' num2str(x_row,'%0.0f') ',' num2str(x_col,'%0.0f') '}'],['\beta_{' num2str(x_row,'%0.0f') ',' num2str(y_col,'%0.0f') '}'],tm,curr_ini,boot_beta,beta_mat_fixed,[beta(x_col,x_row)+(beta_t_dist(1,ik)*sqrt(tm.T/my_T)*stdbeta(x_col,x_row)) beta(x_col,x_row)+(beta_t_dist(rep,ik)*sqrt(tm.T/my_T)*stdbeta(x_col,x_row))],[beta(y_col,x_row)+(beta_t_dist(1,jk)*sqrt(tm.T/my_T)*stdbeta(y_col,x_row)) beta(y_col,x_row)+(beta_t_dist(rep,jk)*sqrt(tm.T/my_T)*stdbeta(y_col,x_row))],1,numcells);
                        beta_plot = [beta_plot bplot];
                        %
                        % create contour plots for density functions
                        %
                        if (cdf_value==0)&(strcmp(tm.interpolate,'nearest')==0);
                           [pos,bplot] = contour_plot(pos,['contour-beta-' num2str(x_row,'%0.0f') '.' num2str(x_col,'%0.0f') '-' num2str(x_row,'%0.0f') '.' num2str(y_col,'%0.0f')],['Confidence contours for beta(' num2str(x_row,'%0.0f') ',' num2str(x_col,'%0.0f') ') and beta(' num2str(x_row,'%0.0f') ',' num2str(y_col,'%0.0f') ') parameters (bootstrapped t-value)'],['Confidence regions for \beta_{' num2str(x_row,'%0.0f') ',' num2str(x_col,'%0.0f') '} and \beta_{' num2str(x_row,'%0.0f') ',' num2str(y_col,'%0.0f') '} from bootstrapped t-statistic distribution'],['\beta_{' num2str(x_row,'%0.0f') ',' num2str(x_col,'%0.0f') '}'],['\beta_{' num2str(x_row,'%0.0f') ',' num2str(y_col,'%0.0f') '}'],tm,curr_ini,beta_mat_fixed,x_n,y_n,n1,1);
                           beta_plot = [beta_plot bplot];
                        end;
                     end;
                     if x_col==tm.n+tm.q1+tm.dcoint-1;
                        x_col = 1;
                        y_col = 2;
                        x_row = x_row+1;
                        if made_row_plot==1;
                           ik = jk+1;
                           jk = jk+2;
                        end;
                        made_row_plot = 0;
                     elseif y_col==tm.n+tm.q1+tm.dcoint;
                        x_col = x_col+1;
                        y_col = x_col+1;
                        if make_plot==1;
                           ik = ik+1;
                        end;
                     else;
                        y_col = y_col+1;
                        if make_plot==1;
                           jk = jk+1;
                        end;
                     end;
                  end;
               end;
            end;
            if show_wait==1;
               set(waitf.text,'UserData','done');
               delete(mywait);
               drawnow;
            end;
         end;
      end;
   end;
   if curr_ini.external==0;
      if tm.dfbeta>0;
         if ((gcbo==boot_beta.display)|(gcbo==boot_beta.displaymenu))&(get(boot_beta.pq_plot,'Value')==1);
            set(newplot,'Visible','on');
         end;
         set(thisplot,'Visible','on');
      end;
      if ((tm.n+tm.q1+tm.dcoint-tm.r)*tm.r)>tm.dfbeta;
         if c_3dplot==1;
            for i=1:size(beta_plot,2);
               set(beta_plot(1,i),'Visible','on');
               drawnow;
            end;
         else;
            set(beta_plot,'Visible','on');
         end;
      end;
   else;
      stats = [];
      file_names = '';
      if tm.dfbeta>0;
         this_mod = strrep(this_mod,'(','');
         this_mod = strrep(this_mod,')','');
         this_mod = strtrim(this_mod);
         this_mod = strrep(this_mod,' ','.');
         if (gcbo==boot_beta.histogram)|(gcbo==boot_beta.histogrammenu);
            file = [curr_ini.simulatedir tm.modelfile tm.testtype '-beta-hist-boot-' num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
            file2 = '';
         else;
            file = [curr_ini.simulatedir tm.modelfile tm.testtype '-beta-boot-' num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
            if get(boot_beta.pq_plot,'Value')==1;
               file2 = [curr_ini.simulatedir tm.modelfile tm.testtype '-beta-boot-pqplots-' num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
            else;
               file2 = '';
            end;
         end;
         if strcmp(file2,'')==0;
            set(0,'CurrentFigure',newplot);
            stats = autosavefigure(newplot,file2);
            %
            set(0,'CurrentFigure',thisplot);
            stats = [stats autosavefigure(thisplot,file)];
            file_names = strvcat(file2,file);
         else;
            set(0,'CurrentFigure',thisplot);
            stats = autosavefigure(thisplot,file);
            file_names = file;
         end;
      end;
      num = 1;
      if ((tm.n+tm.q1+tm.dcoint-tm.r)*tm.r)>tm.dfbeta;
         num_row = 1;
         num_col = 1;
         if get(boot_beta.bootdist,'Value')==2;
            for i=1:size(beta_vec_sorted,2);
               if isalmostequal(min(beta_vec_sorted(:,i)),max(beta_vec_sorted(:,i)))==0;
                  file = [curr_ini.simulatedir tm.modelfile '-beta-boot-' num2str(num_row) '.' num2str(num_col) '-' num2str(my_T) '.' num2str(rep) '.' num2str(tm.r)];
                  set(0,'CurrentFigure',beta_plot(num));
                  mstat = autosavefigure(beta_plot(num),file);
                  stats = [stats mstat];
                  file_names = strvcat(file_names,file);
                  num = num+1;
               end;
               if num_col==tm.n+tm.q1+tm.dcoint;
                  num_col = 1;
                  num_row = num_row+1;
               else;
                  num_col = num_col+1;
               end;
            end;
         elseif (create_twodee==1)&(get(boot_beta.bootdist,'Value')==1);
            if isempty(beta_t_dist)==0;
               num_row = 1;
               num_col = 1;
               for i=1:size(beta_vec_sorted,2);
                  if isalmostequal(min(beta_vec_sorted(:,i)),max(beta_vec_sorted(:,i)))==0;
                     file = [curr_ini.simulatedir tm.modelfile '-beta-boot-t-dist-' num2str(num_row) '.' num2str(num_col) '-' num2str(my_T) '.' num2str(rep) '.' num2str(tm.r)];
                     set(0,'CurrentFigure',beta_plot(num));
                     mstat = autosavefigure(beta_plot(num),file);
                     stats = [stats mstat];
                     file_names = strvcat(file_names,file);
                     num = num+1;
                  end;
                  if num_col==tm.n+tm.q1+tm.dcoint;
                     num_col = 1;
                     num_row = num_row+1;
                  else;
                     num_col = num_col+1;
                  end;
               end;
            end;
         end;
      end;
      if c_3dplot==1;
         for i=num:size(beta_plot,2);
            file = [[curr_ini.simulatedir tm.modelfile '-' get(beta_plot(i),'Tag') '-' num2str(my_T) '.' num2str(rep) '.' num2str(tm.r)];];
            set(0,'CurrentFigure',beta_plot(i));
            mstat = autosavefigure(beta_plot(i),file);
            stats = [stats mstat];
            file_names = strvcat(file_names,file);
         end;
      end;
      if isempty(stats)==0;
         for i=1:size(stats,2);
            if stats(i)==0;
               autoshowfigure(strtrim(file_names(i,:)));
            end;
         end;
      end;
   end;
   clear('beta_sorted','beta_vec_sorted','beta_t_dist','beta','stdbeta','beta_t_vec');
   set(beta_boot_gui,'UserData',boot_beta);
   %
   % case simulate
   %
case 'simulate'
   tm.beta_run = 1;
   set(beta_boot_gui,'Visible','off');
   drawnow;
   %
   % check identification
   %
   status = testident(tm.modelsdir,tm.modelfile,tm.r,tm.n,tm.dcoint,tm.q1);
   if sum(status)==tm.r;
      %
      % collect values
      %
      T_str = get(boot_beta.obs,'String');
      my_T = mystr2num(strtrim(T_str(get(boot_beta.obs,'Value'),:)));
      repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
      rep_val = get(boot_beta.rep,'Value');
      rep = repvalues(rep_val);
      set(boot_beta.simulate,'UserData',rep);
      blocksize = get(boot_beta.block,'Value');
      block_txt = '';
      if blocksize>1;
         block_txt = ['Applying block bootstrap with block length ' num2str(blocksize,'%0.0f') '...'];
      end;
      if get(boot_beta.parametric,'Value')==1;
         bootstyle = '';
      else;
         bootstyle = ['np' num2str(get(boot_beta.block,'Value')) '-'];
      end;
      %
      trim_val = get(boot_beta.trim_estimates,'Value');
      if trim_val>1;
         trim_str = get(boot_beta.trim_estimates,'String');
         trim_p = strrep(trim_str(trim_val,:),'%','');
         trim_p = mystr2num(trim_p)/200;
         low_bval = ceil(trim_p*rep)+1;
         high_bval = rep+1-low_bval;
      else;
         low_bval = 1;
         high_bval = rep;
      end;
      %
      % compute the original values if needed, else use those stored in tm structure!
      %
      if (tm.restrict(1,2)==0)|(tm.restrict(1,1)==1)|((size(tm.restrict,2)==3)&(tm.restrict(1,3)==1));
         [S_00,S_01,S_10,S_11,M_02,M_22,M_12,beta,lambda,trace_test] = mlcointbasic(tm.Z0,tm.Z1,tm.Z2,tm.r);
         unOmega = S_00-S_01*(beta/(beta'*S_11*beta))*beta'*S_10;
         [tm.beta,newlambda,tm.dfbeta,tm.stdbeta,outputtxt,new_abort] = betarestrict(S_00,S_11,S_01,S_10,beta,tm.T,tm.modelsdir,tm.modelfile,0,tm.dcoint);
         dfc = round((((tm.n+tm.q1+tm.dcoint-tm.r)*tm.r)-tm.dfbeta)/tm.n);
         df = tm.n*(tm.p-1)+tm.r+tm.q1*tm.pe+tm.q0*(tm.pe+1)+tm.d+dfc;
         %
         % Compute the LR test of the restrictions if there are any
         % overidentifying such
         %
         if tm.dfbeta>0;
            rOmega = S_00-S_01*(tm.beta/(tm.beta'*S_11*tm.beta))*tm.beta'*S_10;
            tm.LRbeta = tm.T*log(det(rOmega)/det(unOmega));
            if curr_ini.sscorrect==1;
               tm.LRbeta = ((tm.T-df)/(tm.T*tm.dfbeta))*tm.LRbeta;
            end;
         else;
            tm.LRbeta = [];
            rOmega = unOmega;
         end;
         %
         % recompute all other parameters which will be used to generate bootstrapped data
         %
         tm.alpha = (tm.S_01*tm.beta)/(tm.beta'*tm.S_11*tm.beta);
         if isempty(tm.Z2)==0;
            tm.Psi = (tm.M_02/tm.M_22)-(tm.alpha*tm.beta'*(tm.M_12/tm.M_22));
            tm.epsilon = tm.Z0-(tm.alpha*tm.beta'*tm.Z1)-(tm.Psi*tm.Z2);
         else;
            tm.Psi = [];
            tm.epsilon = tm.Z0-(tm.alpha*tm.beta'*tm.Z1);
         end;
         tm.Omega = rOmega;
      end;
      %
      % initialize
      %
      if tm.dfbeta>0;
         beta_test = zeros(rep,1);
      else;
         beta_test = [];
      end;
      beta_vec = zeros(rep,size(vec(tm.beta),1));
      if ((tm.n+tm.q1+tm.dcoint-tm.r)*tm.r)>tm.dfbeta;
         beta_t_dist = zeros(rep,size(tm.stdbeta(tm.stdbeta>0),1));
      end;
      if curr_ini.symmetric==0;
         Omega_sig = chol(tm.Omega)';
      else;
         Omega_sig = symm(tm.Omega);
      end;
      abort = '';
      draw = 1;
      showprog = get(boot_beta.progress,'Value');
      if showprog==1;
         input_var.title = ['Progress for ' int2str(rep) ' replications'];
         input_var.facecolor = curr_ini.progress_facecolor;
         input_var.startfacecolor = curr_ini.progress_startfacecolor;
         input_var.edgecolor = curr_ini.progress_edgecolor;
         input_var.bgcolor = curr_ini.progress_bgcolor;
         input_var.clock = get(boot_beta.clock,'Value');
         input_var.label = 'Replication number:';
         input_var.stop = 0;
         mywait = progressdlg(0,input_var);
         set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
      else;
         this_text = strvcat('Bootstrapping. The art of pulling oneself up by the bootstraps. Attempt started at...',' ',['Time: ' datestr(now,14)],' ','Please hold!');
         mywait = waitdlg(this_text,'bootstrap','Beta Bootstrap Simulation');
         waitf = get(mywait,'UserData');
         tic;
      end;
      if tm.const_model(2)==1;
         setlogtext(strvcat(' ','Bootstrapping distributions for beta...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted constant',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
         if showprog==1;
            set(mywait,'Name',['Restricted constant model with ' num2str(my_T,'%0.0f') ' obs']);
            drawnow;
         end;
         mod_type = 'resconst';
      elseif tm.const_model(3)==1;
         setlogtext(strvcat(' ','Bootstrapping distributions for beta...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Unrestricted constant',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
         if showprog==1;
            set(mywait,'Name',['Constant model with ' num2str(my_T,'%0.0f') ' obs']);
            drawnow;
         end;
         mod_type = 'const';
      elseif tm.const_model(4)==1;
         setlogtext(strvcat(' ','Bootstrapping distributions for beta...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted linear trend',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
         if showprog==1;
            set(mywait,'Name',['Restricted trend model with ' num2str(my_T,'%0.0f') ' obs']);
            drawnow;
         end;
         mod_type = 'restrend';
      elseif tm.const_model(5)==1;
         setlogtext(strvcat(' ','Bootstrapping distributions for beta...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Linear trend',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
         if showprog==1;
            set(mywait,'Name',['Linear trend model with ' num2str(my_T,'%0.0f') ' obs']);
            drawnow;
         end;
         mod_type = 'trend';
      end;
      epsfile = [curr_ini.simulatedir tm.modelfile '-' 'beta-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
      if get(boot_beta.bootstrap,'Value')==1;
         %
         % epsilon-file
         %
         if fileexist(epsfile)==1;
            load_eps = 1;
            %
            % load old epsilons
            %
            eps_data = load(epsfile);
         else;
            load_eps = 0;
         end;
      else;
         load_eps = 0;
      end;
      %
      % replicating
      %
      while (draw<=rep);  % should be until rep
         if showprog==1;
            abort = get(mywait,'UserData');
            if strcmp(abort,'cancel')==1;
               break;
            else;
               progressdlg([(draw/rep) draw]);
            end;
         end;
         %
         % check for bootstrap style
         %
         if load_eps==0;
            if get(boot_beta.parametric,'Value')==1;
               %
               % reset the random number generator
               %
               if curr_ini.random_state==2;
                  randn('state',draw);
               elseif curr_ini.random_state==3;
                  randn('state',sum(100*clock));
               elseif curr_ini.random_state==4;
                  randn('state',sum(100*clock)+draw);
               end;
               %
               Epr = randn(tm.n,my_T+50);
               Epr = Epr(:,51:my_T+50);
               %
               % make sure draws in Epr have identity covariance matrix
               %
               Sig = (1/my_T)*Epr*Epr';
               P_sig = chol(Sig)';
               Epr = P_sig\Epr;
               Epr = Omega_sig*Epr;
            else;
               %
               % reset the random number generator
               %
               if curr_ini.random_state==2;
                  rand('state',draw);
               elseif curr_ini.random_state==3;
                  rand('state',sum(100*clock));
               elseif curr_ini.random_state==4;
                  rand('state',sum(100*clock)+draw);
               end;
               %
               % resample from estimated epsilons
               %
               uni_draws = rand([1 my_T+50]);
               uni_draws = uni_draws(1,51:my_T+50);
               Epr = boot_draw(uni_draws,tm.epsilon,blocksize);
            end;
            if get(boot_beta.bootstrap,'Value')==1;
               bootstrap(draw).epsilon = Epr;
            end;
         else;
            Epr = eps_data.bootstrap(draw).epsilon;
         end;
         %
         % create new sample
         %
         boot = bootstrap_sample(tm,tm.beta,Epr);
         %
         % Computing tests
         %
         [S_00,S_01,S_10,S_11,M_02,M_22,M_12,beta,lambda,trace_test] = mlcointbasic(boot.Z0,boot.Z1,boot.Z2,tm.r);
         unOmega = S_00-S_01*(beta/(beta'*S_11*beta))*beta'*S_10;
         [betarest,newlambda,newdfbeta,stdbeta,outputtxt,new_abort] = betarestrict(S_00,S_11,S_01,S_10,beta,my_T,tm.modelsdir,tm.modelfile,0,tm.dcoint);
         %
         dfc = round((((tm.n+tm.q1+tm.dcoint-tm.r)*tm.r)-newdfbeta)/tm.n);
         df = tm.n*(tm.p-1)+tm.r+tm.q1*tm.pe+tm.q0*(tm.pe+1)+tm.d+dfc;
         %
         % Compute the LR test of the restrictions if there are any
         % overidentifying such
         %
         if newdfbeta>0;
            rOmega = S_00-S_01*(betarest/(betarest'*S_11*betarest))*betarest'*S_10;
            LRbeta = my_T*log(det(rOmega)/det(unOmega));
            if curr_ini.sscorrect==1;
               LRbeta = ((my_T-df)/(my_T*newdfbeta))*LRbeta;
            end;
            beta_test(draw,1) = LRbeta;
         end;
         %
         % include beta_t_dist values
         %
         if ((tm.n+tm.q1+tm.dcoint-tm.r)*tm.r)>tm.dfbeta;
            beta_t_dist(draw,:) = ((betarest(tm.stdbeta>0)-tm.beta(tm.stdbeta>0))./stdbeta(tm.stdbeta>0))';
         end;
         %
         beta_vec(draw,:) = vec(betarest)';
         draw = draw+1;
      end;
      %
      % bootstrap has finished
      %
      if showprog==1;
         set(mywait,'UserData','done');
         close(mywait);
         drawnow;
      else;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
         new_time = toc;
         my_hrs = '00';
         my_min = '00';
         my_sec = num2str(new_time,'%0.2f');
         if new_time>=60;
            ch_min = floor(new_time/60);
            my_sec = num2str(new_time-(ch_min*60),'%0.2f');
            my_min = num2str(ch_min,'%0.0f');
            if ch_min>=60;
               ch_hrs = floor(ch_min/60);
               my_min = num2str(ch_min-(ch_hrs*60),'%0.0f');
               my_hrs = num2str(ch_hrs,'%0.0f');
            end;
         end;
         if size(my_sec,2)==4;
            my_sec = ['0' my_sec];
         end;
         if size(my_min,2)==1;
            my_min = ['0' my_min];
         end;
         if size(my_hrs,2)==1;
            my_hrs = ['0' my_hrs];
         end;
         clock_str = [my_hrs ':' my_min ':' my_sec];
         this_text = strvcat('The bootstrapping process took:',' ',['    ' clock_str ' (hrs:min:sec)']);
         about(this_text,'bootstrap','Simulation Time',120,350);
      end;
      %
      % if we don't cancel
      %
      if (strcmp(abort,'cancel')==0)&(isempty(beta_vec)==0);
         this_text = strvcat(' ','Saving bootstrap results to disk...','Please hold!');
         mywait = waitdlg(this_text,'bootstrap','Beta Bootstrap Simulation');
         waitf = get(mywait,'UserData');
         if get(boot_beta.bootstrap,'Value')==1;
            if load_eps==0;
               this_text = strvcat(' ','Saving bootstrapped residuals to disk...','Please hold!');
               set(waitf.text,'String',this_text);
               save(epsfile,'bootstrap');
            end;
            clear('bootstrap');
            set(boot_beta.bootstrapgraph,'Enable','on','UserData',epsfile);
            set(boot_beta.bootstrapgraphmenu,'Enable','on');
         end;
         testfile = strrep(epsfile,'.mat',['-' 'beta-data.mat']);
         test_data = beta_test;
         %
         if ((tm.n+tm.q1+tm.dcoint-tm.r)*tm.r)>tm.dfbeta;
            save(testfile,'test_data','beta_vec','beta_t_dist');
         else;
            save(testfile,'test_data','beta_vec');
         end;
         %
         clear('test_data');
         set(boot_beta.bootstrapgraphmenu,'UserData',testfile);
         %
         setlogtext(['Bootstrap simulation completed at: ' datestr(now,14) '!']);
         %
         % sort the test
         %
         if newdfbeta>0;
            beta_sorted = sort(beta_test);
         else;
            beta_sorted = [];
         end;
         %
         % sort the t-ratios
         %
         if ((tm.n+tm.q1+tm.dcoint-tm.r)*tm.r)>tm.dfbeta;
            for i=1:size(beta_t_dist,2);
               beta_t_dist(:,i) = sort(beta_t_dist(:,i));
            end;
         end;
         clear('beta_test');
         beta_vec_sorted = zeros(size(beta_vec));
         for i=1:size(beta_vec,2);
            beta_vec_sorted(:,i) = sort(beta_vec(:,i));
         end;
         clear('beta_vec');
         set(boot_beta.rep,'UserData',rep);
         set(boot_beta.obs,'UserData',my_T);
         set(boot_beta.displaymenu,'Enable','on','UserData',tm.const_model);
         if tm.const_model(2)==1;
            my_mod = 'Restricted constant';
         elseif tm.const_model(3)==1;
            my_mod = 'Constant';
         elseif tm.const_model(4)==1;
            my_mod = 'Restricted linear trend';
         elseif tm.const_model(5)==1;
            my_mod = 'Linear trend';
         end;
         if curr_ini.sscorrect==1;
            add_test = 'F';
            add_str = [',' num2str(my_T-df,'%0.0f')];
            test_str = ['F(' num2str(newdfbeta,'%0.0f') add_str ')'];
         else;
            add_test = 'LR';
            add_str = '';
            test_str = ['chi-square(' num2str(newdfbeta,'%0.0f') ')'];
         end;
         %
         % save full simulations
         %
         if get(boot_beta.save,'Value')==1;
            this_text = strvcat(' ',['Saving bootstrapped beta estimates and ' add_test ' tests to disk...'],'Please hold!');
            set(waitf.text,'String',this_text);
            setlogtext('Saving results to mat-files...');
            if tm.const_model(1)==1;
               full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-full-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
            elseif tm.const_model(2)==1;
               full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-full-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
            elseif tm.const_model(3)==1;
               full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-full-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
            elseif tm.const_model(4)==1;
               full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-full-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
            elseif tm.const_model(5)==1;
               full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-full-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
            end;
            Number = (1:1:rep)';
            beta = tm.beta;
            stdbeta = tm.stdbeta;
            if ((tm.n+tm.q1+tm.dcoint-tm.r)*tm.r)>tm.dfbeta;
               save(full_mat,'Number','beta_sorted','beta_vec_sorted','beta_t_dist','beta','stdbeta');
            else;
               save(full_mat,'Number','beta_sorted','beta_vec_sorted','beta','stdbeta');
            end;
            set(boot_beta.fullmenu,'Enable','on','UserData',full_mat);
            set(boot_beta.full,'Enable','on');
         end;
         setlogtext('Saving simulation summary to text file...');
         %
         % dealing with the size of the test
         %
         boot_size = [];
         boot_pval = [];
         if newdfbeta>0;
            this_text = strvcat(' ',['Determining the empirical size of the ' add_test ' test...'],'Please hold!');
            set(waitf.text,'String',this_text);
            if curr_ini.sscorrect==1;
               my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],newdfbeta*ones(5,1),(my_T-df)*ones(5,1));
            else;
               my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],newdfbeta*ones(5,1));
            end;
            for i=1:5;
               for j=1:rep;
                  if my_cv(i,1)>=beta_sorted(rep+1-j,1);
                     break;
                  end;
               end;
               if (j<rep)|(my_cv(i,1)>=beta_sorted(1,1));
                  boot_size = [boot_size (rep+1-j)/rep];
               else;
                  boot_size = [boot_size 0];
               end;
            end;
            if tm.T==my_T;
               this_text = strvcat(' ',['Determining the empirical p-value of the ' add_test ' test...'],'Please hold!');
               set(waitf.text,'String',this_text);
               for j=1:rep;
                  if tm.LRbeta>=beta_sorted(rep+1-j);
                     break;
                  end;
               end;
               boot_pval = j/rep;
            end;
         end;
         this_text = strvcat(' ','Writing bootstrap summary information to disk...','Please hold!');
         set(waitf.text,'String',this_text);
         %
         % write summary to file
         %
         my_80 = floor(0.8*rep);
         my_90 = floor(0.9*rep);
         my_95 = floor(0.95*rep);
         my_975 = floor(0.98*rep);
         my_99 = floor(0.99*rep);
         res_str = strvcat(' ','**************************************************************','*                          Results                           *');
         res_str = strvcat(res_str,'**************************************************************',' ',['  Model:                   ' my_mod],['  Endogenous variables:    ' num2str(tm.n,'%0.0f')],['  Cointegration relations: ' num2str(tm.r,'%0.0f')],['  Replications:            ' num2str(rep,'%0.0f')],['  Draws per replication:   ' num2str(my_T,'%0.0f')],' ');
         if blocksize>1;
            res_str = strvcat(res_str,strrep(block_txt,'.',''),' ');
         end;
         sp_str = spacestr(curr_ini.decimals-2);
         prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
         if newdfbeta>0;
            res_str = strvcat(res_str,['                      ' add_test ' test for ' num2str(newdfbeta,'%0.0f') ' restrictions on beta'],'                      ----------------------------------',' ',['     80%   ' sp_str '   90%  ' sp_str '    95%  ' sp_str '    98%   ' sp_str '   99%  ' sp_str '  Mean ' sp_str '  Std. Dev.']);
            max_std = sqrt( (1/rep)*sum( ( beta_sorted - ( (1/rep)*sum(beta_sorted) ) ).*( beta_sorted - ( (1/rep)*sum(beta_sorted) ) ) ) );
            res_str = strvcat(res_str,sprintf([prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],beta_sorted(my_80,1),beta_sorted(my_90,1),beta_sorted(my_95,1),beta_sorted(my_975,1),beta_sorted(my_99,1),(1/rep)*sum(beta_sorted),max_std));
            res_str = strvcat(res_str,['From the ' test_str ' distribution we have the following:']);
            if curr_ini.sscorrect==1;
               res_str = strvcat(res_str,sprintf([prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1)),' ');
            else;
               res_str = strvcat(res_str,sprintf([prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),newdfbeta,sqrt(2*newdfbeta)),' ');
            end;
            %
            res_str = strvcat(res_str,'                      Empirical size','                      --------------',' ','Test level  20%     10%     5%      2%      1%',sprintf('          %6.2f  %6.2f  %6.2f  %6.2f  %6.2f',100*(1-boot_size(1,5)),100*(1-boot_size(1,4)),100*(1-boot_size(1,3)),100*(1-boot_size(1,2)),100*(1-boot_size(1,1))),' ');
            if isempty(boot_pval)==0;
               res_str = strvcat(res_str,'                      Empirical p-value','                      -----------------',' ',[add_test '(' num2str(newdfbeta,'%0.0f') add_str ')  = ' num2str(tm.LRbeta,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],['p-value = ' num2str(boot_pval,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ');
            end;
         end;
         %
         % dealing with beta
         %
         my_cv_min(1,1) = ceil(0.1*rep);
         my_cv_min(2,1) = ceil(0.05*rep);
         my_cv_min(3,1) = ceil(0.025*rep);
         my_cv_min(4,1) = ceil(0.01*rep);
         my_cv_min(5,1) = ceil(0.005*rep);
         my_cv_max(1,1) = floor(0.9*rep);
         my_cv_max(2,1) = floor(0.95*rep);
         my_cv_max(3,1) = floor(0.975*rep);
         my_cv_max(4,1) = floor(0.99*rep);
         my_cv_max(5,1) = floor(0.995*rep);
         row_val = 1;
         col_val = 1;
         check_prt = 0;
         for i=1:size(beta_vec_sorted,2);
            %
            % test if beta coefficient is free
            %
            if isalmostequal(min(beta_vec_sorted(:,i)),max(beta_vec_sorted(:,i)))==0;
               if check_prt==0;
                  res_str = strvcat(res_str,'   Bootstrap statistics for beta parameters','   ----------------------------------------',' ',['Using simulated values from sorted value ' num2str(low_bval,'%0.0f') ' to ' num2str(high_bval,'%0.0f')],' ',['parameter  ML Estimate ' sp_str ' Mean  ' sp_str '   Median ' sp_str '  Std. Dev.' sp_str ' Skewness ' sp_str ' Kurtosis']);
                  check_prt = 1;
               end;
               beta_str = ['beta(' num2str(row_val,'%0.0f') ',' num2str(col_val,'%0.0f') ')'];
               est_val = tm.beta(col_val,row_val);
               mean_val = (1/(high_bval+1-low_bval))*sum(beta_vec_sorted(low_bval:high_bval,i));
               median_val = beta_vec_sorted(ceil(0.5*rep),i);
               std_val = sqrt( (1/(high_bval+1-low_bval))*sum( (beta_vec_sorted(low_bval:high_bval,i)-mean_val).*(beta_vec_sorted(low_bval:high_bval,i)-mean_val) ) );
               norm_beta = (1/std_val)*(beta_vec_sorted(low_bval:high_bval,i)-mean_val);
               skew_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta);
               kurt_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta.*norm_beta);
               %
               res_str = strvcat(res_str,sprintf(['%s  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val],beta_str,est_val,mean_val,median_val,std_val,skew_val,kurt_val));
            end;
            if col_val==tm.n+tm.q1+tm.dcoint;
               row_val = row_val+1;
               col_val = 1;
            else;
               col_val = col_val+1;
            end;
         end;
         if check_prt>0;
            res_str = strvcat(res_str,' ');
         end;
         %
         row_val = 1;
         col_val = 1;
         check_prt = 0;
         for i=1:size(beta_vec_sorted,2);
            %
            % test if beta coefficient is free
            %
            if isalmostequal(min(beta_vec_sorted(:,i)),max(beta_vec_sorted(:,i)))==0;
               if check_prt==0;
                  res_str = strvcat(res_str,'   Bootstrap confidence intervals for beta parameters using bootstrapped beta','   --------------------------------------------------------------------------',' ',['parameter   ' sp_str '       80%        ' sp_str sp_str '          90%         ' sp_str sp_str '         95%         ' sp_str sp_str '         98%        ' sp_str sp_str '          99%']);
                  check_prt = 1;
               end;
               beta_str = ['beta(' num2str(row_val,'%0.0f') ',' num2str(col_val,'%0.0f') ')'];
               res_str = strvcat(res_str,sprintf(['%s  [' prt_val ',' prt_val ']  [' prt_val ',' prt_val ']  [' prt_val ',' prt_val ']  [' prt_val ',' prt_val ']  [' prt_val ',' prt_val ']'],beta_str,vec([beta_vec_sorted(my_cv_min,i) beta_vec_sorted(my_cv_max,i)]')));
            end;
            if col_val==tm.n+tm.q1+tm.dcoint;
               row_val = row_val+1;
               col_val = 1;
            else;
               col_val = col_val+1;
            end;
         end;
         if check_prt>0;
            res_str = strvcat(res_str,' ');
         end;
         row_val = 1;
         col_val = 1;
         check_prt = 0;
         for i=1:size(beta_vec_sorted,2);
            %
            % test if beta coefficient is free
            %
            if isalmostequal(min(beta_vec_sorted(:,i)),max(beta_vec_sorted(:,i)))==0;
               if check_prt==0;
                  res_str = strvcat(res_str,'   Bootstrap confidence intervals for beta parameters using bootstrapped t-values','   ------------------------------------------------------------------------------',' ',['parameter   ' sp_str '       80%        ' sp_str sp_str '          90%         ' sp_str sp_str '         95%         ' sp_str sp_str '         98%        ' sp_str sp_str '          99%']);
                  check_prt = 1;
               end;
               beta_str = ['beta(' num2str(row_val,'%0.0f') ',' num2str(col_val,'%0.0f') ')'];
               b_vals = zeros(2,5);
               for j=1:5;
                  %
                  % notice that upper t-dist is used for lower value and lower t-dist for upper
                  %
                  lower_val = tm.beta(col_val,row_val)-(beta_t_dist(my_cv_max(j,1),check_prt)*sqrt(tm.T/my_T)*tm.stdbeta(col_val,row_val));
                  upper_val = tm.beta(col_val,row_val)-(beta_t_dist(my_cv_min(j,1),check_prt)*sqrt(tm.T/my_T)*tm.stdbeta(col_val,row_val));
                  b_vals(:,j) = [lower_val;upper_val];
               end;
               res_str = strvcat(res_str,sprintf(['%s  [' prt_val ',' prt_val ']  [' prt_val ',' prt_val ']  [' prt_val ',' prt_val ']  [' prt_val ',' prt_val ']  [' prt_val ',' prt_val ']'],beta_str,vec(b_vals)));
               check_prt = check_prt+1;
            end;
            if col_val==tm.n+tm.q1+tm.dcoint;
               row_val = row_val+1;
               col_val = 1;
            else;
               col_val = col_val+1;
            end;
         end;
         if check_prt>0;
            res_str = strvcat(res_str,' ');
         end;
         %
         res_str = strvcat(res_str,'**************************************************************',' ');
         %
         if tm.const_model(1)==1;
            file_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-summary-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
         elseif tm.const_model(2)==1;
            file_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-summary-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
         elseif tm.const_model(3)==1;
            file_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-summary-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
         elseif tm.const_model(4)==1;
            file_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-summary-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
         elseif tm.const_model(5)==1;
            file_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-beta-boot-summary-' bootstyle tm.resalpha num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
         end;
         fid_txt = fopen(file_txt,'wt');
         for i=1:size(res_str,1);
            fprintf(fid_txt,[strrep(res_str(i,:),'%','%%') '\n']);
         end;
         fprintf(fid_txt,['Output created on: ' datestr(now,0) '\n']);
         fclose(fid_txt);
         %
         % write to tex-file
         %
         prt_val = ['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'];
         file_tex = strrep(file_txt,'.txt','.ltx');
         f_id = fopen(file_tex,'wt');
         fprintf(f_id,'\\begin{tabular}{ll}\n');
         fprintf(f_id,['Model: & ' my_mod ' \\\\\n']);
         fprintf(f_id,['\\#Endogenous variables: & ' num2str(tm.n,'%0.0f') ' \\\\\n']);
         fprintf(f_id,['\\#Cointegration relations: & ' num2str(tm.r,'%0.0f') ' \\\\\n']);
         fprintf(f_id,['\\#Replications: & ' num2str(rep,'%0.0f') ' \\\\\n']);
         fprintf(f_id,['\\#Draws per replication: & ' num2str(my_T,'%0.0f') ' \\\\\n']);
         if blocksize>1;
            fprintf(f_id,['Block size length: & ' num2str(blocksize,'%0.0f') ' \\\\\n']);
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
         if newdfbeta>0;
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
            fprintf(f_id,['\\multicolumn{7}{c}{' add_test ' test for ' num2str(newdfbeta,'%0.0f') ' restrictions on $\\beta$} \\\\\n']);
            fprintf(f_id,'80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% & Mean & Std. Dev. \\\\\n');
            max_std = sqrt( (1/rep)*sum( ( beta_sorted - ( (1/rep)*sum(beta_sorted) ) ).*( beta_sorted - ( (1/rep)*sum(beta_sorted) ) ) ) );
            fprintf(f_id,[prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],beta_sorted(my_80,1),beta_sorted(my_90,1),beta_sorted(my_95,1),beta_sorted(my_975,1),beta_sorted(my_99,1),(1/rep)*sum(beta_sorted),max_std);
            fprintf(f_id,['\\multicolumn{7}{c}{From the ' test_str ' distribution we have the following:} \\\\ \n']);
            if curr_ini.sscorrect==1;
               fprintf(f_id,[prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & & \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1));
            else;
               fprintf(f_id,[prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),newdfbeta,sqrt(2*newdfbeta));
            end;
            fprintf(f_id,'\\end{tabular}\n\n');
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
            fprintf(f_id,'\\multicolumn{6}{c}{Empirical size} \\\\\n');
            fprintf(f_id,'Nominal size & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
            fprintf(f_id,' & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',100*(1-boot_size(1,5)),100*(1-boot_size(1,4)),100*(1-boot_size(1,3)),100*(1-boot_size(1,2)),100*(1-boot_size(1,1)));
            fprintf(f_id,'\\end{tabular}\n\n');
            if isempty(boot_pval)==0;
               fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{ll}\n');
               fprintf(f_id,'\\multicolumn{2}{c}{Empirical $p$-value} \\\\\n');
               fprintf(f_id,[' & ' add_test '(%0.0f' add_str ') = ' prt_val ' \\\\ \n'],newdfbeta,tm.LRbeta);
               fprintf(f_id,[' & $p$-value = ' prt_val ' \\\\ \n'],boot_pval);
               fprintf(f_id,'\\end{tabular}\n\n');
            end;
         end;
         row_val = 1;
         col_val = 1;
         check_prt = 0;
         for i=1:size(beta_vec_sorted,2);
            %
            % test if beta coefficient is free
            %
            if isalmostequal(min(beta_vec_sorted(:,i)),max(beta_vec_sorted(:,i)))==0;
               if check_prt==0;
                  fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
                  fprintf(f_id,'\\multicolumn{7}{c}{Bootstrap statistics for $\\beta$ parameters using simulated} \\\\\n');
                  fprintf(f_id,['\\multicolumn{7}{c}{values from sorted value ' num2str(low_bval,'%0.0f') ' to ' num2str(high_bval,'%0.0f') '} \\\\\n']);
                  fprintf(f_id,'parameter & ML Estimate & Mean & Median & Std. Dev. & Skewness & Kurtosis \\\\\n');
                  check_prt = 1;
               end;
               est_val = tm.beta(col_val,row_val);
               mean_val = (1/(high_bval+1-low_bval))*sum(beta_vec_sorted(low_bval:high_bval,i));
               median_val = beta_vec_sorted(ceil(0.5*rep),i);
               std_val = sqrt( (1/(high_bval+1-low_bval))*sum( (beta_vec_sorted(low_bval:high_bval,i)-mean_val).*(beta_vec_sorted(low_bval:high_bval,i)-mean_val) ) );
               norm_beta = (1/std_val)*(beta_vec_sorted(low_bval:high_bval,i)-mean_val);
               skew_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta);
               kurt_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta.*norm_beta);
               fprintf(f_id,['$\\beta_{%0.0f%0.0f}$ & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],row_val,col_val,est_val,mean_val,median_val,std_val,skew_val,kurt_val);
            end;
            if col_val==tm.n+tm.q1+tm.dcoint;
               row_val = row_val+1;
               col_val = 1;
            else;
               col_val = col_val+1;
            end;
         end;
         if check_prt==1;
            fprintf(f_id,'\\end{tabular}\n\n');
         end;
         %
         row_val = 1;
         col_val = 1;
         check_prt = 0;
         for i=1:size(beta_vec_sorted,2);
            %
            % test if beta coefficient is free
            %
            if isalmostequal(min(beta_vec_sorted(:,i)),max(beta_vec_sorted(:,i)))==0;
               if check_prt==0;
                  fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
                  fprintf(f_id,'\\multicolumn{6}{c}{Bootstrap confidence intervals for $\\beta$ parameters using empirical $\\beta$ distribution} \\\\\n');
                  fprintf(f_id,'parameter & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% \\\\\n');
                  check_prt = 1;
               end;
               beta_str = ['$\\beta_{' num2str(row_val,'%0.0f') num2str(col_val,'%0.0f') '}$'];
               for j=1:5;
                  lower_val = beta_vec_sorted(my_cv_min(j,1),i);
                  upper_val = beta_vec_sorted(my_cv_max(j,1),i);
                  beta_str = [beta_str ' & ' num2str(lower_val,prt_val) ',' num2str(upper_val,prt_val)];
               end;
               fprintf(f_id,[beta_str ' \\\\ \n']);
            end;
            if col_val==tm.n+tm.q1+tm.dcoint;
               row_val = row_val+1;
               col_val = 1;
            else;
               col_val = col_val+1;
            end;
         end;
         if check_prt>0;
            fprintf(f_id,'\\end{tabular}\n\n');
         end;
         %
         row_val = 1;
         col_val = 1;
         check_prt = 0;
         for i=1:size(beta_vec_sorted,2);
            %
            % test if beta coefficient is free
            %
            if isalmostequal(min(beta_vec_sorted(:,i)),max(beta_vec_sorted(:,i)))==0;
               if check_prt==0;
                  fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
                  fprintf(f_id,'\\multicolumn{6}{c}{Bootstrap confidence intervals for $\\beta$ parameters using empirical $t$-value distribution} \\\\\n');
                  fprintf(f_id,'parameter & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% \\\\\n');
                  check_prt = 1;
               end;
               beta_str = ['$\\beta_{' num2str(row_val,'%0.0f') num2str(col_val,'%0.0f') '}$'];
               for j=1:5;
                  lower_val = tm.beta(col_val,row_val)-(abs(beta_t_dist(my_cv_min(j,1),check_prt))*sqrt(tm.T/my_T)*tm.stdbeta(col_val,row_val));
                  upper_val = tm.beta(col_val,row_val)+(abs(beta_t_dist(my_cv_max(j,1),check_prt))*sqrt(tm.T/my_T)*tm.stdbeta(col_val,row_val));
                  beta_str = [beta_str ' & ' num2str(lower_val,prt_val) ',' num2str(upper_val,prt_val)];
               end;
               fprintf(f_id,[beta_str ' \\\\\n']);
            end;
            if col_val==tm.n+tm.q1+tm.dcoint;
               row_val = row_val+1;
               col_val = 1;
            else;
               col_val = col_val+1;
            end;
         end;
         if check_prt>0;
            fprintf(f_id,'\\end{tabular}\n\n');
         end;
         %
         fprintf(f_id,'\\ruler\n\n%%*************************************************************\n');
         fclose(f_id);
         %
         set(boot_beta.display,'UserData',beta_sorted);
         set(boot_beta.histogram,'UserData',beta_vec_sorted);
         clear('beta_sorted','beta_vec_sorted');
         if ((tm.n+tm.q1+tm.dcoint-tm.r)*tm.r)>tm.dfbeta;
            set(boot_beta.clock,'UserData',tm.beta);
            set(boot_beta.summary,'UserData',tm.stdbeta);
            set(boot_beta.full,'UserData',beta_t_dist);
            clear('beta_t_dist');
         end;
         %
         if curr_ini.noprint==0;
            set(boot_beta.output,'Enable','on');
         end;
         set(boot_beta.summarymenu,'Enable','on','UserData',file_txt);
         set(boot_beta.summary,'Enable','on');
         if tm.r<tm.n;
            set(boot_beta.display,'Enable','on');
            set(boot_beta.displaymenu,'Enable','on');
            set(boot_beta.histogram,'Enable','on');
            set(boot_beta.histogrammenu,'Enable','on');
         end;
         set(boot_beta.matfilebutton,'Enable','on');
         set(boot_beta.matfilemenu,'Enable','on');
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      else;
         setlogtext('Cancelled...');
      end;
   else;
      unident = '';
      for i=1:tm.r;
         if status(i,1)==0;
            if strcmp(unident,'')==1;
               unident = ['beta(' num2str(i) ')'];
               thisres = 'restriction';
               thisfail = 'fails';
            else;
               unident = [unident ', beta(' num2str(i) ')'];
               thisres = 'restrictions';
               thisfail = 'fail';
            end;
         end;
      end;
      setlogtext(strvcat(' ','ERROR: The restrictions are not identifying...'));
      txt = ['The restrictions you have selected for beta are not identifying. In particular, the ' thisres ' on ' unident ' ' thisfail ' the identification test.'];
      about(txt,'warning','Identification Test Failure',120,500);
   end;
   tm.beta_run = 0;
   set(beta_boot_gui,'Visible','on');
case 'done'
   if tm.beta_run==0;
      set(boot_beta.done,'UserData','done');
      pid = get(boot_beta.filemenu,'UserData');
      if isempty(pid)==1;
         delete(beta_boot_gui);
      else;
         close(beta_boot_gui);
      end;
   end;
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(beta_boot_gui,'Name') ' ' fix_filepath([pwd '\icons\bootstrap.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(boot_beta.filemenu,'UserData',pid);
         set(beta_boot_gui,'CloseRequestFcn','killwinpid');
      end;
   end;
   set(beta_boot_gui,'Visible','on');
   drawnow;
end;

if strcmp(selector,'done')==0;
   curr_ini.models = tm;
   curr_ini.images = button_images;
   set(boot_beta.matfilebutton,'UserData',curr_ini);
end;

if my_exit==1;
   waitfor(boot_beta.done,'UserData','done');
end;

%
% end of beta_bootstrap.m
%
