%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for showing restricted beta         %
%          conditional standard errors, test results             %
%          and require the user to select the new beta           %
%          or not                                                %
%                                                                %
%          Function: betadlg                                     %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       cm: structure with model info            %
%                       infomat: matrix with estimation info     %
%                          regarding number of iterations and    %
%                          value of concergence criterion        %
%                       Psi: nxnq matrix                         %
%                       alpha: nxr matrix                        %
%                                                                %
%          Output:                                               %
%                       h = handle                               %
%                                                                %
%          This version:        July 4, 2006                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function betadlg_handle = betadlg(selector,cm,infomat,Psi,alpha)

if strcmp(selector,'init')==1;
   curr_ini = find_inisettings;
   if curr_ini.lagtest>0;
      lagenable = 'on';
   else;
      lagenable = 'off';
   end;
   if isnumeric(curr_ini.external)==0;
      curr_ini.external = 0;
   end;
   %
   tm = cm;
   tm.restrict = zeros(1,size(tm.restrict,2));
   tm.restrict(1,2) = 1;
   dfc = round((((tm.n+tm.q1+tm.dcoint-tm.r)*tm.r)-tm.dfbeta)/tm.n);
   tm.df = tm.n*(tm.p-1)+tm.r+tm.q1*tm.pe+tm.q0*(tm.pe+1)+tm.d+dfc;
   %
   tm.dfbeta = tm.newdfbeta;
   tm.bZ1t = tm.betarest'*tm.Z1t;
   tm.bR1t = tm.betarest'*tm.R1t;
   tm.Psi = Psi;
   tm.alpha = alpha;
   if tm.dfbeta<((tm.n+tm.q1+tm.dcoint-tm.r)*tm.r);
      betagraph_enable = 'on';
   else;
      betagraph_enable = 'off';
   end;
   %
   % import images
   %
   button_images = read_images;
   %
   tm.myrun = 0;
   tm.beta = tm.betarest;
   currbeta = showbeta(tm.betarest,tm.evars,strtrim([tm.xvars1 ' ' tm.restvec]));
   currstdbeta = showbeta(tm.stdbeta,tm.evars,strtrim([tm.xvars1 ' ' tm.restvec]));
   tm.myuserestrict = 0;
   thisexit = 0;
   %
   add_height = 0;
   if isempty(infomat)==0;
      tm.model_info.header = 'Number of iterations for the switching algorithm:';
      tm.model_info.info = num2str(infomat(1,1),'%0.0f');
      if curr_ini.betagrad==1;
         tm.model_info.header = strvcat(tm.model_info.header,'Value of convergence criterion (max|dlnL/dbeta|):');
         tm.model_info.info = strvcat(tm.model_info.info,num2str(infomat(1,2)));
      else;
         tm.model_info.header = strvcat(tm.model_info.header,'Value of convergence criterion (|(lnL(i)-lnL(i-1))/lnL(i-1)|):');
         tm.model_info.info = strvcat(tm.model_info.info,num2str(infomat(1,2)));
      end;
      add_height = 60;
   else;
      tm.model_info.header = '';
      tm.model_info.info = '';
   end;
   tm.model_info.header = strvcat(tm.model_info.header,'Largest non-unit eigenvalue of the companion matrix:');
   tm.model_info.info = strvcat(tm.model_info.info,num2str(tm.evalue,'%0.4f'));
   if tm.dfbeta>0;
      add_s = '';
      if tm.dfbeta>1;
         add_s = 's';
      end;
      if curr_ini.sscorrect==0;
         tm.model_info.header = strvcat(tm.model_info.header,['LR-test of ' num2str(tm.dfbeta) ' beta restriction' add_s ':'],'p-value:');
      else;
         tm.model_info.header = strvcat(tm.model_info.header,['F-test of (' num2str(tm.dfbeta) ',' num2str(tm.T-tm.df,'%0.0f') ') beta restriction' add_s ':'],'p-value:');
      end;
   end;
   tm.model_info.info = strvcat(tm.model_info.info,num2str(tm.LRbeta,'%0.4f'),num2str(1-tm.pval,'%0.4f'));
   %
   if tm.evalue>=1;
      mypermcompenable = 'off';
   else;
      mypermcompenable = 'on';
   end;
   cmatenable = mypermcompenable;
   weakexoenable = 'on';
   if tm.r==tm.n;
      weakexoenable = 'off';
   end;
   if (tm.n==1)&(tm.q1+tm.q0==0);
      gcenable = 'off';
   else;
      gcenable = 'on';
   end;
else;
   thisexit = 1;
%   betadlggui = get(0,'CurrentFigure');
   betadlggui = findobj('Type','figure','Tag','BetaDLG')';
   betar = get(betadlggui,'UserData');
   curr_ini = get(betar.viewdata,'UserData');
   button_images = curr_ini.images;
   tm = curr_ini.models;
end;

%
% Set screen size directly instead of using
% get(0,'ScreenSize')!
%

scrsz = [1 1 1024 768];
realscrsz = get(0,'ScreenSize');

switch selector;
   case 'init';
      betadlggui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','betadlg.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(realscrsz(3)-scrsz(3)/2)/2-50 (realscrsz(4)-375-add_height)/2 scrsz(3)/2+100 375+add_height], ...
         'Tag','BetaDLG', ...
         'Resize','off', ...
         'Name','Restrictions on Beta - Results', ...
         'NumberTitle','off', ...
         'Visible','off', ...
         'CloseRequestFcn','betadlg wayout', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(betadlggui,'DockControl','off');
      end;

      %
      % File menu
      %

      filemenu = uimenu('Parent',betadlggui, ...
         'Label','&File', ...
         'Tag','FileMenu');

      %
      % Objects on File menu
      %

      betar.viewdata = uimenu('Parent',filemenu, ...
         'Label','View &Data...', ...
         'Callback','betadlg viewdata', ...
         'Enable','on', ...
         'Tag','ViewData');

      betar.savecoint = uimenu('Parent',filemenu, ...
         'Label','Save &Cointegration Relations...', ...
         'Callback','betadlg savecoint', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','SaveResid');

      betar.savetc = uimenu('Parent',filemenu, ...
         'Label','Save &Transitory Components...', ...
         'Callback','betadlg savetc', ...
         'Accelerator','T', ...
         'Enable',mypermcompenable, ...
         'Tag','SaveTC');

      betar.saveresid = uimenu('Parent',filemenu, ...
         'Label','Save &Residuals...', ...
         'Callback','betadlg saveresid', ...
         'Accelerator','D', ...
         'Enable','on', ...
         'Tag','SaveCoint');

      uimenu('Parent',filemenu, ...
         'Label','Center &Window', ...
         'Separator','on', ...
         'Accelerator','W', ...
         'Enable','on', ...
         'Callback','center_figure_fcn', ...
         'Tag','CenterMenu');

      betar.menuuse = uimenu('Parent',filemenu, ...
         'Label','&Use New Beta', ...
         'Callback','betadlg use', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','MenuFileUse');

      betar.menuskip = uimenu('Parent',filemenu, ...
         'Label','R&ecycle New Beta', ...
         'Callback','betadlg skip', ...
         'Enable','off', ...
         'Tag','MenuFileSkip');

      betar.menucontinue = uimenu('Parent',filemenu, ...
         'Label','C&ontinue', ...
         'Separator','on', ...
         'Callback','betadlg done', ...
         'Accelerator','C', ...
         'Enable','on', ...
         'Tag','MenuFileContinue');

      %
      % Tools menu
      %

      testmenu = uimenu('Parent',betadlggui, ...
         'Label','&Tools', ...
         'Tag','TestMenu');

      %
      % Objects on Tools menu
      %

      betar.corrtest = uimenu('Parent',testmenu, ...
         'Label','&Serial Correlation...', ...
         'Callback','betadlg corrtest', ...
         'Enable','on', ...
         'Accelerator','S', ...
         'Tag','CorrTest');

      betar.archtest = uimenu('Parent',testmenu, ...
         'Label','&ARCH...', ...
         'Callback','betadlg archtest', ...
         'Accelerator','A', ...
         'Enable','on', ...
         'Tag','ArchTest');

      betar.normalitytest = uimenu('Parent',testmenu, ...
         'Label','&Normality...', ...
         'Callback','betadlg normalitytest', ...
         'Enable','on', ...
         'Accelerator','N', ...
         'Tag','NormalityTest');

      betar.constancytest = uimenu('Parent',testmenu, ...
         'Label','&Parameter Constancy...', ...
         'Callback','betadlg constancytest', ...
         'Accelerator','P', ...
         'Enable','on', ...
         'Tag','ConstancyTest');

      betar.lagorder = uimenu('Parent',testmenu, ...
         'Label','&Lag Order...', ...
         'Callback','betadlg lagorder', ...
         'Accelerator','L', ...
         'Separator','on', ...
         'Enable',lagenable, ...
         'Tag','LagOrder');

      betar.weakexo = uimenu('Parent',testmenu, ...
         'Label','&Weak Exogeneity...', ...
         'Callback','betadlg weakexo', ...
         'Enable',weakexoenable, ...
         'Tag','WeakExogeneity');

      betar.gctest = uimenu('Parent',testmenu, ...
         'Label','&Granger Causality...', ...
         'Callback','betadlg gctest', ...
         'Accelerator','G', ...
         'Enable',gcenable, ...
         'Tag','GrangerCausality');

      if tm.n>2;
         betar.multigctest = uimenu('Parent',testmenu, ...
            'Label','M&ulti-Step Granger Causality...', ...
            'Callback','betadlg multigctest', ...
            'Enable','on', ...
            'Tag','MultiGrangerCausality');
      end;

      if ((tm.p>1)&(tm.n>2))|(tm.q0>0)|((tm.q1>0)&(tm.pe>0));
         betar.exclude = uimenu('Parent',testmenu, ...
            'Label','&Exclusion', ...
            'Separator','on', ...
            'Enable','on', ...
            'Tag','ExclusionMenu');
         
         betar.firstdiffs = uimenu('Parent',betar.exclude, ...
            'Label','&First Differences', ...
            'Callback','betadlg firstdiffs', ...
            'Enable','on', ...
            'Tag','FirstDiffMenu');
      end;

      if (tm.p>1)&(tm.r<tm.n);
         betar.common_cycles = uimenu('Parent',testmenu, ...
            'Label','Co&mmon Cycles...', ...
            'Callback','betadlg common_cycles', ...
            'Separator','on', ...
            'Enable','on', ...
            'Tag','ShowCommonCycles');
      end;

      if tm.datad>0;
         betar.dummy = uimenu('Parent',testmenu, ...
            'Label','&Deterministic Variables', ...
            'Separator','on', ...
            'Enable','on', ...
            'Tag','DummyVarMenu');

         betar.dummyexclusion = uimenu('Parent',betar.dummy, ...
            'Label','&Exclusion...', ...
            'Callback','betadlg dummyexclusion', ...
            'Enable','on', ...
            'Tag','DummyExclusionMenu');

         betar.dummylongrun = uimenu('Parent',betar.dummy, ...
            'Label','&Long Run...', ...
            'Callback','betadlg dummylongrun', ...
            'Enable',weakexoenable, ...
            'Tag','DummyLongRunMenu');

         if tm.datad>1;
            betar.propdummy = uimenu('Parent',betar.dummy, ...
            'Label','&Proportionality...', ...
            'Callback','betadlg dummyprop', ...
            'Enable','on', ...
            'Tag','DummyPropMenu');
         end;

      end;


      betar.cmat = uimenu('Parent',testmenu, ...
         'Label','&C-Matrix...', ...
         'Callback','betadlg cmat', ...
         'Separator','on', ...
         'Accelerator','M', ...
         'Enable',cmatenable, ...
         'Tag','CMatrix');

      betar.longrun_gir = uimenu('Parent',testmenu, ...
         'Label','L&ong Run GIRs...', ...
         'Callback','betadlg longrun_gir', ...
         'Separator','off', ...
         'Enable',cmatenable, ...
         'Tag','LongRunGIRsMenu');

      betar.residanalysis = uimenu('Parent',testmenu, ...
         'Label','&Residual Analysis...', ...
         'Callback','betadlg residanalysis', ...
         'Accelerator','R', ...
         'Enable','on', ...
         'Tag','ResidAnalysis');

      betar.shortdyn = uimenu('Parent',testmenu, ...
         'Label','S&hort Run Dynamics...', ...
         'Callback','betadlg shortdyn', ...
         'Accelerator','Y', ...
         'Enable','on', ...
         'Tag','ShortDyn');

      betar.distribution = uimenu('Parent',testmenu, ...
         'Label','Distri&bution...', ...
         'Callback','betadlg distribution', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','DistributionMenu');

      %
      % Graphics menu
      %

      graphmenu = uimenu('Parent',betadlggui, ...
         'Label','&Graphics', ...
         'Tag','GraphicsMenu');

      betar.menugraph = uimenu('Parent',graphmenu, ...
         'Label','&Cointegration Relations...', ...
         'Callback','betadlg graphs', ...
         'Enable','on', ...
         'Tag','MenuGraph');

      betar.menupermcomp = uimenu('Parent',graphmenu, ...
         'Label','&Permanent and Transitory Components...', ...
         'Callback','betadlg permcomp', ...
         'Accelerator','E', ...
         'Enable',mypermcompenable, ...
         'Tag','MenuPermComp');

      betar.menuresiduals = uimenu('Parent',graphmenu, ...
         'Label','&Residuals...', ...
         'Callback','betadlg residuals', ...
         'Accelerator','I', ...
         'Enable','on', ...
         'Tag','MenuResiduals');

      betar.menufitted = uimenu('Parent',graphmenu, ...
         'Label','Fitted &Terms...', ...
         'Callback','betadlg fitted', ...
         'Enable','on', ...
         'Tag','MenuFitted');

      betar.forecast = uimenu('Parent',graphmenu, ...
         'Label','Forec&asting...', ...
         'Callback','betadlg forecast', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','MenuForecast');

      betar.varforecast = uimenu('Parent',graphmenu, ...
         'Label','Forecast &Variable Transformations...', ...
         'Callback','betadlg varforecast', ...
         'Enable','on', ...
         'Tag','MenuVARForecast');

      if tm.q1+tm.q0>0;
         set(betar.forecast,'Enable','off');
         set(betar.varforecast,'Enable','off');
      end;

      betar.menuchow = uimenu('Parent',graphmenu, ...
         'Label','Recursive Ch&ow Tests', ...
         'Callback','betadlg chow', ...
         'Separator','on', ...
         'Accelerator','O', ...
         'Enable','on', ...
         'Tag','MenuChow');

      betar.menuploberger = uimenu('Parent',graphmenu, ...
         'Label','Recursive &Fluctuation Test', ...
         'Callback','betadlg ploberger', ...
         'Accelerator','F', ...
         'Enable','on', ...
         'Tag','MenuPloberger');

      betar.genimpulse = uimenu('Parent',graphmenu, ...
         'Label','&Generalized Impulse Responses...', ...
         'Callback','betadlg genimpulse', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','MenuGeneralizedImpulse');

%      if (isempty(tm.isdummy)==0)&(max(tm.isdummy)==1);
      if tm.datad>0;
         betar.dummyimpulse = uimenu('Parent',graphmenu, ...
            'Label','&Dummy Impulse Responses...', ...
            'Callback','betadlg dummyimpulse', ...
            'Enable','on', ...
            'Tag','MenuDummyImpulse');
      end;

      betar.betagraph = uimenu('Parent',graphmenu, ...
         'Label','&Log-likelihood and Beta...', ...
         'Callback','betadlg betagraph', ...
         'Separator','on', ...
         'Accelerator','K', ...
         'Enable',betagraph_enable, ...
         'Tag','MenuBetaGraph');

      betar.companion = uimenu('Parent',graphmenu, ...
         'Label','Eigenvalues of Companion &Matrix', ...
         'Callback','betadlg companion', ...
         'Enable','on', ...
         'Tag','MenuCompanion');

      %
      % Help menu
      %

      helpmenu = uimenu('Parent',betadlggui, ...
         'Label','&Help', ...
         'Tag','HelpMenu');

      betar.beta_help = uimenu('Parent',helpmenu, ...
            'Label','&Restrictions on Beta', ...
            'Callback','help_fcn(''RestrictionsonBeta'');', ...
            'Accelerator','H', ...
            'Separator','off', ...
            'Enable','on', ...
            'Tag','MenuBetaHelp');

      %
      % Horizontal lines for toolbar
      %

%      xline([1 scrsz(4)/2+51 (scrsz(3)/2)+40],[0.5 1]);

      xline([1 374+add_height (scrsz(3)/2)+100],[0.5 1]);

      betar.toolbar = uitoolbar('Parent',betadlggui, ...
                        'HandleVisibility','off', ...
                        'Interruptible','on', ...
                        'Clipping','on');

      %
      %  Use button
      %

      betar.use = uipushtool('Parent',betar.toolbar, ...
                         'TooltipString','Use New Beta', ...
                         'CData',button_images.pickbeta, ...
                         'ClickedCallback','betadlg use', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','UseButton');

      betar.skip = uipushtool('Parent',betar.toolbar, ...
                         'TooltipString','Recycle New Beta', ...
                         'CData',button_images.skipbeta, ...
                         'ClickedCallback','betadlg skip', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','off', ...
                         'Tag','SkipButton');

      %
      %  Done button
      %

      betar.done = uipushtool('Parent',betar.toolbar, ...
                         'TooltipString','Continue', ...
                         'CData',button_images.continue, ...
                         'ClickedCallback','betadlg done', ...
                         'Separator','on', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'UserData','waiting', ...
                         'Tag','DoneButton');

      %
      % Graphics button
      %

      betar.graphs = uipushtool('Parent',betar.toolbar, ...
                         'TooltipString','Cointegration Relations', ...
                         'CData',button_images.graph, ...
                         'ClickedCallback','betadlg graphs', ...
                         'Separator','on', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'UserData','working', ...
                         'Enable','on', ...
                         'Tag','Graphics');

      betar.permcomp = uipushtool('Parent',betar.toolbar, ...
                         'TooltipString','Permanent and Transitory Components', ...
                         'CData',button_images.permcomp, ...
                         'ClickedCallback','betadlg permcomp', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable',mypermcompenable, ...
                         'Tag','PermCompGraphics');

      betar.residgraph = uipushtool('Parent',betar.toolbar, ...
                         'TooltipString','Residuals', ...
                         'CData',button_images.histogram, ...
                         'ClickedCallback','betadlg residuals', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','ResidGraphics');

      %
      % Forecast button
      %

      betar.forecast_button = uipushtool('Parent',betar.toolbar, ...
                         'TooltipString','Forecasting', ...
                         'CData',button_images.forecast, ...
                         'ClickedCallback','betadlg forecast', ...
                         'Separator','on', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','ForecastGraph');

      if tm.q1+tm.q0>0;
         set(betar.forecast_button,'Enable','off');
      end;

      %
      % Chow test button
      %

      betar.chow = uipushtool('Parent',betar.toolbar, ...
                         'TooltipString','Recursive Chow Tests', ...
                         'CData',button_images.chow, ...
                         'ClickedCallback','betadlg chow', ...
                         'Separator','on', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','RecChowGraph');

      betar.ploberger = uipushtool('Parent',betar.toolbar, ...
                         'TooltipString','Recursive Fluctuation Test', ...
                         'CData',button_images.fluctest, ...
                         'ClickedCallback','betadlg ploberger', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','RecPlobGraph');

      %
      % Outer axis
      %

      axesbox([2 2 (scrsz(3)/2)+98 360+add_height],'Maximum Likelihood Results',135,[0.5 1]);

      %
      % Outer axis for showing beta
      %

      axesbox([14 78+add_height scrsz(3)/2+72 268],'Current Beta Matrix and Conditional Standard Errors',242,[0.5 1]);

      %
      % Outer axis for additional info
      %

      axesbox([14 14 scrsz(3)/2+72 50+add_height],'Estimation Information',105,[0.5 1]);

      %
      % Listbox for showing estimated beta
      %

      betar.betamat = uicontrol('Units','pixels', ...
         'BackgroundColor','white', ...
         'Position',[30 220+add_height scrsz(3)/2+40 110], ...
         'Style','listbox', ...
         'FontSize',10, ...
         'FontName','FixedWidth', ...
         'Max',2, ...
         'Value',[], ...
         'String',currbeta, ...
         'Enable','inactive', ...
         'UserData',tm.myuserestrict, ...
         'HorizontalAlignment','center', ...
         'Tag','BetaListbox');

      %
      % Listbox for showing estimated conditional standard
      % errors for beta
      %

      betar.stdmat = uicontrol('Units','pixels', ...
         'BackgroundColor','white', ...
         'Position',[30 94+add_height scrsz(3)/2+40 110], ...
         'Style','listbox', ...
         'FontSize',10, ...
         'FontName','FixedWidth', ...
         'Max',2, ...
         'Value',[], ...
         'String',currstdbeta, ...
         'Enable','inactive', ...
         'UserData','working', ...
         'HorizontalAlignment','center', ...
         'Tag','BetaStdListbox');

      %
      % Show output text
      %

      betar.model_header = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 30 412 20+add_height], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'ForegroundColor',curr_ini.gui_foreground_color, ...
         'String',tm.model_info.header, ...
         'Tag','OutputText');

      head_ext = get(betar.model_header,'Extent');
      if head_ext(1,4)<=20+add_height;
         new_pos = [30 30+(20+add_height-head_ext(1,4))/2 head_ext(1,3:4)];
      else;
         new_pos = [30 30 head_ext(1,3) 20+add_height];
      end;
      set(betar.model_header,'Position',new_pos);

      betar.model_info = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[35+new_pos(1,3) new_pos(1,2) scrsz(3)/2+35-new_pos(1,3) new_pos(1,4)], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String',tm.model_info.info, ...
         'ForegroundColor',curr_ini.gui_foreground_color, ...
         'HorizontalAlignment','left', ...
         'Tag','ModelInfoText');

      set(betadlggui,'UserData',betar,...
         'HandleVisibility','callback');

   case 'betagraph'
      if tm.myrun==0;
         tm.myrun = 1;
         %
         % Find the free parameters of beta
         %
         bH = [];
         for i=1:tm.r;
            file = strcat(tm.modelsdir,'H_',num2str(i),'-',num2str(tm.n),'x',num2str(tm.r),'x',num2str(tm.dcoint+tm.q1),'-',tm.modelfile,'.rest');
            if fileexist(file)==1;
               h = loaddata(file);
               if i==1;
                  bH = h;
               else;
                  bH = [[bH zeros(size(bH,1),size(h,2))];[zeros(size(h,1),size(bH,2)) h]];
               end;
            end;
         end;
         thisR = null(bH','r');
         file = strcat(tm.modelsdir,'normalize-',num2str(tm.n),'x',num2str(tm.r),'x',num2str(tm.dcoint+tm.q1),'-',tm.modelfile,'.norm');
         h = loaddata(file);
         for i=1:tm.r;
            thisvec = zeros(size(bH,1),1);
            thisvec(h(i,1)+(i-1)*size(tm.beta,1),1) = 1;
            thisR = [thisR thisvec];
         end;
         R_orth = null(thisR');
         for i=1:size(R_orth,2);
            if max(R_orth(:,i))>0;
               R_orth(:,i) = (1/max(R_orth(:,i)))*R_orth(:,i);
            else;
               R_orth(:,i) = (1/min(R_orth(:,i)))*R_orth(:,i);
            end;
         end;
         tm.R_orth = round(R_orth);
         %
         % The matrix R_orth shows the free parameters of vec(tm.beta)
         %
         set(betadlggui,'Visible','off');
         drawnow;
         mybetagraphgui = betagraphdlg('init',tm);
         graphbeta = get(mybetagraphgui,'UserData');
         set(graphbeta.graph,'UserData','done');
         killguipid(mybetagraphgui);
         set(betadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'residanalysis'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_residual_analysis(betadlggui,tm,ind);
         tm.myrun = 0;
      end;
   case 'fitted'
      if tm.myrun==0;
         tm.myrun = 1;
         set(betadlggui,'Visible','off');
         drawnow;
         thisgraph = fittedterms('init',tm,[tm.Psi tm.alpha],tm.beta);
         fitted = get(thisgraph,'UserData');
         set(fitted.show,'UserData','done');
         killguipid(thisgraph);
         set(betadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'companion'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_companion(tm.beta,tm.alpha,tm.Psi,tm,curr_ini,ind,0);
         tm.myrun = 0;
      end;
   case 'distribution'
      if tm.myrun==0;
         tm.myrun = 1;
         set(betadlggui,'Visible','off');
         drawnow;
         %
         thisgraph = distdlg('init',tm.cbs);
         killguipid(thisgraph);
         %
         set(betadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'common_cycles'
      if tm.myrun==0;
         tm.myrun = 1;
         set(betadlggui,'Visible','off');
         drawnow;
         show_common_cycles(tm,curr_ini,tm.alpha,tm.Psi,tm.beta);
         set(betadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'dummyprop'
      if tm.myrun==0;
         tm.myrun = 1;
         set(betadlggui,'Visible','off');
         drawnow;
         proportionality_dummies_dlg('init',tm,curr_ini);
         set(betadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'dummylongrun'
      if tm.myrun==0;
         tm.myrun = 1;
         show_longrun_dummies(betadlggui,tm,curr_ini);
         tm.myrun = 0;
      end;
   case 'dummyexclusion'
      if tm.myrun==0;
         tm.myrun = 1;
         show_exclude_dummies(betadlggui,tm,curr_ini);
         tm.myrun = 0;
      end;
   case 'dummyimpulse'
      if tm.myrun==0;
         tm.myrun = 1;
         set(betadlggui,'Visible','off');
         drawnow;
         Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
         alpha = tm.alpha;
         beta = tm.beta;
         Psi = tm.Psi;
         Sigma_theta = [];
         %
         txt = 'Would you like to impose restrictions on the dummy variables?';
         if (tm.datad>1)|((tm.r<tm.n)&(tm.r>0));
            answer = query(txt,'question',120,'Structural VAR - Dummy Restrictions',300,'no');
         else;
            answer = 'No';
         end;
         if strcmp(answer,'Yes')==1;
            %
            % open a select restrictions dialog
            %
            cm = restrict_dummies_dlg('init',tm,curr_ini);
            if strcmp(cm.action,'cancel')==0;
               %
               % check if we should use new estimated
               %
               if (isfield(cm,'applied')==1)&(isempty(cm.applied)==0)&(ischar(cm.applied)==1)&(strcmp(cm.applied,'applied')==1);
                  if isfield(cm,'dm')==1;
                     txt = 'Are you sure you want to use the restricted estimates for the dummy impulse responses?';
                     answer = query(txt,'question',120,'Structural VAR - Dummy Restrictions',300,'yes');
                     if strcmp(answer,'Yes')==1;
                        alpha = cm.dm.alpha;
                        beta = cm.dm.beta;
                        Psi = cm.dm.Psi;
                        Omega = cm.dm.Omega;
                        Sigma_theta = cm.dm.Sigma_theta;
                     end;
                  end;
               end;
            else;
               %
               % no dummy impulses
               %
               set(betadlggui,'Visible','on');
               drawnow;
               return;
            end;
         end;
         %
         setlogtext(strvcat(['Computing impulse responses for dummies up to period ' num2str(tm.h)],['with asymptotic ' num2str(tm.c) ' % confidence bands...']));
         abort = '';
         %
         [tm.duir,tm.duir_std,tm.buir,tm.buir_std,abort] = dummy_impulses_fcn(tm,alpha,beta,Psi,Omega,Sigma_theta,1);
         %
         if strcmp(abort,'cancel')==0;
            %
            % get the value from the normal distribution corresponding to the
            % chosen levels of significance c
            %
            c_val = norm_inv((100+tm.c)/200);
            for i=1:size(tm.duir,2);
               for j=1:tm.n*tm.datad;
                  if abs(tm.duir_std(j,i))<1.0e-008;
                     tm.duir_std(j,i) = 0;
                  end;
               end;
            end;
            tm.duir_upper = tm.duir+(c_val*tm.duir_std);
            tm.duir_lower = tm.duir-(c_val*tm.duir_std);
            %
            if isempty(tm.buir)==0;
               for i=1:size(tm.buir,2);
                  for j=1:tm.r*tm.datad;
                     if abs(tm.buir_std(j,i))<1.0e-008;
                        tm.buir_std(j,i) = 0;
                     end;
                  end;
               end;
               tm.buir_upper = tm.buir+(c_val*tm.buir_std);
               tm.buir_lower = tm.buir-(c_val*tm.buir_std);
            else;
               tm.buir_upper = [];
               tm.buir_lower = [];
            end;
            %
            thisgraph = duir_graphdlg('init',tm);
            ir_graph = get(thisgraph,'UserData');
            set(ir_graph.show,'UserData','done');
            killguipid(thisgraph);
         end;
         %
         set(betadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'genimpulse'
      if tm.myrun==0;
         tm.myrun = 1;
         set(betadlggui,'Visible','off');
         drawnow;
         setlogtext(strvcat(['Computing generalized impulse responses up to period ' num2str(tm.h)],['with asymptotic ' num2str(tm.c) ' % confidence bands...']));
         abort = '';
         %
         Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
         [tm.gir,tm.gir_std,tm.bir,tm.bir_std,abort] = generalized_impulses_fcn(tm,tm.alpha,tm.beta,tm.Psi,Omega,[],1);
         if strcmp(abort,'cancel')==0;
            %
            % get the value from the normal distribution corresponding to the
            % chosen levels of significance c
            %
            c_val = norm_inv((100+tm.c)/200);
            for i=1:size(tm.gir,2);
               for j=1:tm.n*tm.n;
                  if abs(tm.gir_std(j,i))<1.0e-008;
                     tm.gir_std(j,i) = 0;
                  end;
               end;
            end;
            tm.gir_upper = tm.gir+(c_val*tm.gir_std);
            tm.gir_lower = tm.gir-(c_val*tm.gir_std);
            if isempty(tm.bir)==0;
               for i=1:size(tm.bir,2);
                  for j=1:tm.r*tm.n;
                     if abs(tm.bir_std(j,i))<1.0e-008;
                        tm.bir_std(j,i) = 0;
                     end;
                  end;
               end;
               tm.bir_upper = tm.bir+(c_val*tm.bir_std);
               tm.bir_lower = tm.bir-(c_val*tm.bir_std);
            else;
               tm.bir_upper = [];
               tm.bir_lower = [];
            end;
            thisgraph = gir_graphdlg('init',tm);
            ir_graph = get(thisgraph,'UserData');
            set(ir_graph.show,'UserData','done');
            killguipid(thisgraph);
         end;
         %
         set(betadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'corrtest'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_corrtest(betadlggui,tm,curr_ini,ind);
         tm.myrun = 0;
      end;
   case 'archtest'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_archtest(betadlggui,tm,curr_ini,ind);
         tm.myrun = 0;
      end;
   case 'normalitytest'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_normalitytest(betadlggui,tm,curr_ini,ind);
         tm.myrun = 0;
      end;
   case 'constancytest'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_constancytest(betadlggui,tm.beta,tm,curr_ini,ind,0,0);
         tm.myrun = 0;
      end;
   case 'weakexo'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_weakexo(betadlggui,tm.beta,tm.alpha,[],tm,curr_ini,ind,0);
         tm.myrun = 0;
      end;
   case 'longrun_gir'
      if tm.myrun==0;
         tm.myrun = 1;
         set(betadlggui,'Visible','off');
         drawnow;
         %
         Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
         [lr_gir,lr_gir_std] = longrun_gir_fcn(tm.alpha,tm.beta,tm.Psi,Omega,[],tm.epsilon,tm.Z1,tm.Z2,tm.p,tm.d);
         %
         addrest = ' restricted';
         if tm.dfbeta==0;
            addrest = '';
         end;
         ctext = strvcat(' ',['LONG RUN GENERALIZED IMPULSE RESPONSES (for' addrest ' rank=' num2str(tm.r,'%1.0f') ')']);
         numchar = size(ctext,2);
         addcorr = '';
         for i=1:numchar;
            addcorr = strcat(addcorr,'=');
         end;
         ctext = strvcat(ctext,addcorr,' ');
         ctext = strvcat(ctext,showc(lr_gir,tm.myvars),' ');
         ctext = strvcat(ctext,'Estimated asymptotic standard errors:',' ',showc(lr_gir_std,tm.myvars),' ','t-ratios:',' ',showc(inf2nan(lr_gir./lr_gir_std),tm.myvars),' ');
         drawnow;
         textgui(ctext,'Long Run GIRs',[(realscrsz(3)-700)/2 (realscrsz(4)-500)/2 700 500],'Results',38);
         %
         set(betadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'cmat'
      if tm.myrun==0;
         tm.myrun = 1;
         addrest = ' restricted';
         if tm.dfbeta==0;
            addrest = '';
         end;
         if tm.r<tm.n;
            C = cmat(tm.Psi,tm.alpha,tm.beta,tm.epsilon,tm.Z1,tm.Z2,tm.p,tm.d,1);
         else;
            C = cmat_stat(tm.Psi,tm.alpha,tm.beta,tm.epsilon,tm.Z1,tm.Z2,tm.p,tm.d,1);
         end;
         ctext = strvcat(' ',['THE C-MATRIX (for' addrest ' rank=' num2str(tm.r,'%1.0f') ')']);
         numchar = size(ctext,2);
         addcorr = '';
         for i=1:numchar;
            addcorr = strcat(addcorr,'=');
         end;
         ctext = strvcat(ctext,addcorr,' ');
         ctext = strvcat(ctext,showc(C(:,1:tm.n),tm.myvars),' ');
         ctext = strvcat(ctext,'Estimated asymptotic standard errors:',' ',showc(C(:,tm.n+1:2*tm.n),tm.myvars),' ','t-ratios:',' ',showc(inf2nan(C(:,1:tm.n)./C(:,tm.n+1:2*tm.n)),tm.myvars),' ');
         set(betadlggui,'Visible','off');
         drawnow;
         textgui(ctext,'C-Matrix',[(realscrsz(3)-700)/2 (realscrsz(4)-500)/2 700 500],'Results',38);
         set(betadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'lagorder'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_lagordertest(betadlggui,tm.beta,tm.alpha,tm.Psi,[],tm,curr_ini,ind,0);
         tm.myrun = 0;
      end;
   case 'firstdiffs'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_firstdiffstests(betadlggui,tm.beta,tm.alpha,tm.Psi,[],tm,curr_ini,ind,0);
         tm.myrun = 0;
      end;
   case 'gctest'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_gctest(betadlggui,tm.beta,tm.alpha,tm.Psi,[],tm,curr_ini,ind,0);
         tm.myrun = 0;
      end;
   case 'multigctest'
      if tm.myrun==0;
         tm.myrun = 1;
         set(betadlggui,'Visible','off');
         drawnow;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         this_graph = select_mgc('init',tm,tm.beta,[],0,ind,0);
         mgc = get(this_graph,'UserData');
         set(mgc.show,'UserData','done');
         killguipid(this_graph);
         set(betadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'shortdyn'
      if tm.myrun==0;
         tm.myrun = 1;
         Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
         shortstr = shortrun(tm.alpha,tm.Psi,Omega,tm.beta,tm.Z1,tm.Z2,tm.p,tm.pe,tm.d,tm.deterselect,tm.q0,tm.q1,tm.evars,tm.xvars0,tm.xvars1,tm.deter,tm.restvec,1,tm.outputfile,1);
         if tm.dfbeta>0;
            myshortstr = shortstr(2,:);
            oldsize = size(myshortstr,2);
            myshortstr = strrep(myshortstr,'for rank=','for restricted rank=');
            newsize = size(myshortstr,2);
            myshortstr = myshortstr(1,1:newsize-11);
            kind = findstr(myshortstr,')');
            if isempty(kind)==0;
               shortstr(2,:) = myshortstr;
               shortstr(3,:) = strrep(shortstr(3,:),'=           ','============');
            end;
         end;
         set(betadlggui,'Visible','off');
         drawnow;
         textgui(shortstr,'Short Run Dynamics',[(realscrsz(3)-800)/2 (realscrsz(4)-500)/2 800 500],'Results',38);
         set(betadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'graphs'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 0;
         if tm.dfbeta>0;
            ind = 1;
         end;
         set(betadlggui,'Visible','off');
         drawnow;
         thisgraph = cointgraphdlg('init',tm,tm.bZ1t,tm.bR1t,ind);
         graph = get(thisgraph,'UserData');
         set(graph.show,'UserData','done');
         killguipid(thisgraph);
         set(betadlggui,'Visible','on');
         drawnow;
         set(betadlggui,'UserData',betar);
         tm.myrun = 0;
      end;
   case 'ploberger'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 0;
         if tm.dfbeta>0;
            ind = 1;
         end;
         show_ploberger(betadlggui,tm.beta,tm,curr_ini,ind,0);
         tm.myrun = 0;
      end;
   case 'chow'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 0;
         if tm.dfbeta>0;
            ind = 1;
         end;
         show_chow(betadlggui,tm.beta,tm,curr_ini,ind,0);
         tm.myrun = 0;
      end;
   case 'permcomp'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 0;
         if tm.dfbeta>0;
            ind = 1;
         end;
         [y_t,perm_y,trans_y] = permcomp(tm.Psi,tm.alpha,tm.beta,tm.epsilon,tm.x0,tm.x1,tm.x1_r,tm.x2,tm.d,tm.dcoint,tm.p,tm.pe,tm.q1,tm.q0);
         set(betadlggui,'Visible','off');
         drawnow;
         thisgraph = pctcdlg('init',tm,y_t,perm_y,trans_y,ind);
         pctc = get(thisgraph,'UserData');
         set(pctc.show,'UserData','done');
         killguipid(thisgraph);
         set(betadlggui,'Visible','on');
         drawnow;
         set(betadlggui,'UserData',betar);
         tm.myrun = 0;
      end;
   case 'varforecast'
      if tm.myrun==0;
         tm.myrun = 1;
         set(betadlggui,'Visible','off');
         drawnow;
         thisgraph = var_forecastdlg('init',tm,[0 1]);
         f_cast = get(thisgraph,'UserData');
         set(f_cast.show,'UserData','done');
         killguipid(thisgraph);
         set(betadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'forecast'
      if tm.myrun==0;
         tm.myrun = 1;
         set(betadlggui,'Visible','off');
         drawnow;
         thisgraph = forecastdlg('init',tm,[0 1]);
         f_cast = get(thisgraph,'UserData');
         set(f_cast.show,'UserData','done');
         killguipid(thisgraph);
         set(betadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'residuals'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 0;
         if tm.dfbeta>0;
            ind = 1;
         end;
         set(betadlggui,'Visible','off');
         drawnow;
         thisgraph = epsilondlg('init',tm,ind);
         epsi = get(thisgraph,'UserData');
         set(epsi.show,'UserData','done');
         killguipid(thisgraph);
         set(betadlggui,'Visible','on');
         drawnow;
         set(betadlggui,'UserData',betar);
         tm.myrun = 0;
      end;
   case 'viewdata'
      if tm.myrun==0;
         tm.myrun = 1;
         if matlabnumber>=6.0;
            myfile = {'*.txt;*.data;*.wk1;*.xls;*.mat;*.csv', 'Data Files (*.txt, *.data, *.wk1, *.xls, *.mat, *.csv)'; ...
                    '*.txt;*.data', 'Text Files (*.txt, *.data)'; ...
                    '*.mat', 'MatLab MAT Files (*.mat)'; ...
                    '*.wk1', 'Lotus 1-2-3 Spreadsheets (*.wk1)'; ...
                    '*.xls', 'Excel Spreadsheets (*.xls)'; ...
                    '*.csv', 'Comma Separated Value Files (*.csv)'; ...
                    '*.*', 'All Files (*.*)'};
         else;
            if (iscompiled==1)&(iswinnt==1)&(curr_ini.opendialog==1);
               fix_fig = findobj('Tag','StructuralVAR');
               model = get(fix_fig,'UserData');
               afile = get(model.endogenous,'String');
               basedir = getpath(strtrim(afile));
               file_fltr = 'Data Files (*.txt, *.data, *.wk1, *.mat, *.csv)|*.txt;*.data;*.wk1;*.mat;*.csv|Text Files (*.txt, *.data)|*.txt;*.data|MatLab MAT Files (*.mat)|*.mat|Lotus 1-2-3 Spreadsheets (*.wk1)|*.wk1|Comma Separated Value Files (*.csv)|*.csv|All Files (*.*)|*.*|';
               best_pos = 1;
               title_txt = 'Open';
            else;
               fix_fig = findobj('Tag','StructuralVAR');
               model = get(fix_fig,'UserData');
               afile = get(model.endogenous,'String');
               afile = strtrim(afile);
               if fileexist(afile)==1;
                  adir = getpath(afile);
                  if ispc==1;
                     if strcmp(adir(1,size(adir,2)),'\')==0;
                        adir = [adir '\'];
                     end;
                  else;
                     if strcmp(adir(1,size(adir,2)),'/')==0;
                        adir = [adir '/'];
                     end;
                  end;
               else;
                  adir = tm.outputdir;
               end;
               myfile = [adir '*.txt;*.data;*.wk1;*.mat;*.csv'];
            end;
         end;
         if (iscompiled==1)&(iswinnt==1)&(curr_ini.opendialog==1);
            [openfile,openpath] = fileopen(basedir,file_fltr,1,title_txt);
         else;
            if matlabnumber>=6;
               [openfile,openpath] = uigetfile(myfile,'Open',getpath(tm.endofile));
            else;
               [openfile,openpath] = uigetfile(myfile,'Open');
            end;
         end;
         drawnow;
         if isnumeric(openfile)==0;
            openfile = strcat(openpath,openfile);
            set(betadlggui,'Visible','off');
            drawnow;
            textgui(openfile,['View Data - ' openfile],[(realscrsz(3)-(realscrsz(4)-80))/2 1 realscrsz(4)-80 realscrsz(4)-54],'Data',25);
            set(betadlggui,'Visible','on');
            drawnow;
         end;
         tm.myrun = 0;
      end;
   case 'savecoint'
      if tm.myrun==0;
         tm.myrun = 1;
         addrest = 'rest-';
         if tm.dfbeta==0;
            addrest = '';
         end;
         myfile = [tm.outputdir 'coint-' addrest num2str(tm.r,'%1.0f') '.data'];
         [savefile,savepath] = uiputfile(myfile,'Save As');
         drawnow;
         if isnumeric(savefile)==0;
            [myR myT] = size(tm.bZ1t);
            myt = '';
            for i=1:myT;
               myt = strvcat(myt,getdate(tm.samplebeg,tm.sampleend,tm.freq,i/myT));
            end;
            setlogtext(['Saving cointegration relations to ' savefile '...']);
            savefile = strcat(savepath,savefile);
            fid = fopen(savefile,'wt');
            myprintstr = '';
            firststr = ' DATE  ';
            prt_str = ['%' num2str(2*(curr_ini.exportdata+3),'%0.0f') '.' num2str(curr_ini.exportdata+3,'%0.0f') 'f'];
            for i=1:myR;
               myprintstr = [myprintstr '   ' prt_str];
               firststr = [firststr '               ci_' num2str(i,'%1.0f')];
            end;
            fprintf(fid,[firststr '\n']);
            for i=1:myT;
               fprintf(fid,['%s ' myprintstr '\n'],myt(i,:),tm.bZ1t(:,i)');
            end;
            fclose(fid);
         end;
         tm.myrun = 0;
      end;
   case 'savetc'
      if tm.myrun==0;
         tm.myrun = 1;
         addrest = 'rest-';
         if tm.dfbeta==0;
            addrest = '';
         end;
         [y_t,perm_y,trans_y] = permcomp(tm.Psi,tm.alpha,tm.beta,tm.epsilon,tm.x0,tm.x1,tm.x1_r,tm.x2,tm.d,tm.dcoint,tm.p,tm.pe,tm.q1,tm.q0);
         myfile = [tm.outputdir 'trans.comp-' addrest num2str(tm.r,'%1.0f') '.data'];
         [savefile,savepath] = uiputfile(myfile,'Save As');
         drawnow;
         if isnumeric(savefile)==0;
            [myN myT] = size(trans_y);
            myt = '';
            for i=1:myT;
               myt = strvcat(myt,getdate(tm.samplebeg,tm.sampleend,tm.freq,i/myT));
            end;
            setlogtext(['Saving transitory components to ' savefile '...']);
            savefile = strcat(savepath,savefile);
            fid = fopen(savefile,'wt');
            myprintstr = '';
            firststr = ' DATE  ';
            prt_str = ['%' num2str(2*(curr_ini.exportdata+3),'%0.0f') '.' num2str(curr_ini.exportdata+3,'%0.0f') 'f'];
            for i=1:myN;
               myprintstr = [myprintstr '   ' prt_str];
               firststr = [firststr '              tc_' tm.myvars(i,:)];
            end;
            fprintf(fid,[firststr '\n']);
            for i=1:myT;
               fprintf(fid,['%s ' myprintstr '\n'],myt(i,:),trans_y(:,i)');
            end;
            fclose(fid);
         end;
         tm.myrun = 0;
      end;
   case 'saveresid'
      if tm.myrun==0;
         tm.myrun = 1;
         addrest = 'rest-';
         if tm.dfbeta==0;
            addrest = '';
         end;
         myfile = [tm.outputdir 'epsilon-' addrest num2str(tm.r,'%1.0f') '.data'];
         [savefile,savepath] = uiputfile(myfile,'Save As');
         drawnow;
         if isnumeric(savefile)==0;
            [myN myT] = size(tm.epsilon);
            myt = '';
            for i=1:myT;
               myt = strvcat(myt,getdate(tm.samplebeg,tm.sampleend,tm.freq,i/myT));
            end;
            setlogtext(['Saving residuals to ' savefile '...']);
            savefile = strcat(savepath,savefile);
            fid = fopen(savefile,'wt');
            myprintstr = '';
            firststr = ' DATE  ';
            prt_str = ['%' num2str(2*(curr_ini.exportdata+3),'%0.0f') '.' num2str(curr_ini.exportdata+3,'%0.0f') 'f'];
            for i=1:myN;
               myprintstr = [myprintstr '   ' prt_str];
               firststr = [firststr '             eps_' tm.myvars(i,:)];
            end;
            fprintf(fid,[firststr '\n']);
            for i=1:myT;
               fprintf(fid,['%s ' myprintstr '\n'],myt(i,:),tm.epsilon(:,i)');
            end;
            fclose(fid);
         end;
         tm.myrun = 0;
      end;
   case 'use'
      if tm.myrun==0;
         tm.myrun = 1;
         tm.myuserestrict = 1;
         set(betar.use,'Enable','off');
         set(betar.menuuse,'Enable','off');
         set(betar.skip,'Enable','on');
         set(betar.menuskip,'Enable','on');
         set(betar.betamat,'UserData',tm.myuserestrict);
         set(betadlggui,'UserData',betar);
         tm.myrun = 0;
      end;
   case 'skip'
      if tm.myrun==0;
         tm.myrun = 1;
         tm.myuserestrict = 0;
         set(betar.use,'Enable','on');
         set(betar.menuuse,'Enable','on');
         set(betar.skip,'Enable','off');
         set(betar.menuskip,'Enable','off');
         set(betar.betamat,'UserData',tm.myuserestrict);
         set(betadlggui,'UserData',betar);
         tm.myrun = 0;
      end;
   case 'done'
      if tm.myrun==0;
         tm.myrun = 1;
         set(betar.done,'UserData','done');
         set(betadlggui,'UserData',betar);
         tm.myrun = 0;
      end;
   case 'wayout'
      set(betar.betamat,'UserData',tm.myuserestrict);
      set(betar.done,'UserData','done');
      if strcmp(get(betar.stdmat,'UserData'),'done')==1;
         delete(betadlggui);
      end;
end;

if strcmp(selector,'init')==1;
   set(betadlggui,'Visible','on');
end;

if nargout==1;
   betadlg_handle = betadlggui;
end;

if strcmp(selector,'wayout')==0;
   curr_ini.images = button_images;
   curr_ini.models = tm;
   set(betar.viewdata,'UserData',curr_ini);
end;

if thisexit==0;
   waitfor(betar.done,'UserData','done');
end;

%
% end of betadlg.m
%
