%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for displaying graphs of            %
%          cointegration relations                               %
%                                                                %
%          Function: cointgraphdlg                               %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       c_mod: structure with model info         %
%                       datafile: rxT matrix                     %
%                       corrdatafile: rxT matrix                 %
%                       restricted: 0-1 integer indicating if    %
%                           the beta vectors are restricted      %
%                                                                %
%          Output:                                               %
%                       h: handle                                %
%                                                                %
%          This version:        May 3, 2006                      %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = cointgraphdlg(selector,c_mod,datafile,corrdatafile,restricted)

if strcmp(selector,'init')==1;
   t_m = c_mod;
   thisexit = 0;
   t_m.mydatafile = datafile;
   t_m.mycorrdatafile = corrdatafile;
   listnumbers = '1';
   i = 2;
   while i<=t_m.r;
      listnumbers = strcat(listnumbers,'|',num2str(i));
      i = i+1;
   end;
   curr_ini = find_inisettings;
   if isnumeric(curr_ini.external)==0;
      curr_ini.external = 0;
   end;
   %
   % setting up the actual sample period
   %
   [t_m.dataindex,t_m.samplebeg,t_m.sampleend,add] = make_dataindex(t_m.freq,t_m.samplebeg,t_m.sampleend);
   t_m.dataindexfix = [t_m.samplebeg-3*add;t_m.samplebeg-2*add;t_m.samplebeg-add;t_m.dataindex];
   checkyear = floor(t_m.samplebeg);
   checkperiod = t_m.samplebeg-checkyear;
   t_m.subbeginyear = num2str(checkyear);
   if strcmp(t_m.freq,'q')==1;
      checkperiod = 4*(checkperiod+(1/8));
      t_m.subbeginperiod = num2str(round(checkperiod));
   elseif strcmp(t_m.freq,'m')==1;
      checkperiod = 12*(checkperiod+(1/24));
      t_m.subbeginperiod = num2str(round(checkperiod));
   end;
   t_m.restricted = restricted;
else;
   thisexit = 1;
   cointgraphgui = get(0,'CurrentFigure');
   graph = get(cointgraphgui,'UserData');
   curr_ini = get(graph.popup,'UserData');
   t_m = curr_ini.models;
end;

%
% Set screen size directly instead of using
% get(0,'ScreenSize')!
%

realscrsz = get(0,'ScreenSize');

switch selector;
   case 'init';
      cointgraphgui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','cointgraphdlg.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(realscrsz(3)-341)/2 (realscrsz(4)-140)/2 341 140], ...
         'Tag','FigParent', ...
         'Resize','off', ...
         'Visible','off', ...
         'Name','Graph Cointegration Relations', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','cointgraphdlg done', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(cointgraphgui,'DockControl','off');
      end;

      %
      % Outer axis
      %

      axesbox([2 2 339 130],'Graphics',45,[0.5 1]);

      imageaxes = axes('Units','pixels', ...
         'Box','on', ...
         'TickLength',[0 0], ...
         'CameraUpVector',[0 1 0], ...
         'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 80 39 39], ...
         'XTickLabelMode','manual', ...
         'YTickLabelMode','manual', ...
         'Tag','AxisLogo', ...
         'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

      mycons = getstoredimages;
      if curr_ini.use_toolbar_bgcolor==1;
         bgcolor = (1/255)*(round(255*get(0,'defaultuicontrolbackgroundcolor'))-[8 4 8]);
         bgcolor(1) = max(0,bgcolor(1));
         bgcolor(2) = max(0,bgcolor(2));
         bgcolor(3) = max(0,bgcolor(3));
      else;
         bgcolor = get(0,'defaultuicontrolbackgroundcolor');
      end;
      %
      image('CData',mirrorimage(maketrans(mycons.cointbig_image,[160 160 164],bgcolor)),'Clipping','off','Parent',imageaxes);

      graph.icon = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 50 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String',['Estimation Sample:    ' t_m.subbeginyear ':' t_m.subbeginperiod ' - ' t_m.subendyear ':' t_m.subendperiod], ...
         'HorizontalAlignment','left', ...
         'Tag','SampleText');

      %
      % Select variable
      %

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 16 120 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String','Select Relation Number:', ...
         'HorizontalAlignment','left', ...
         'Tag','VariableText');

      graph.popup = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[144 20 60 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'String',listnumbers, ...
         'Tag','GraphListbox',...
         'Value',1);

      %
      % Create graph button
      %

      graph.show = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[236 55 90 20], ...
         'String','Display', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','cointgraphdlg showgraph', ...
         'UserData','working', ...
         'Enable','on', ...
         'Tag','Done');

      %
      %  Done button
      %

      graph.done = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[236 20 90 20], ...
         'String','Done', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','cointgraphdlg done', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','Done');

      set(cointgraphgui,'UserData',graph,...
         'HandleVisibility','callback');
   case 'showgraph'
      series = get(graph.popup,'Value');
      newvalue = series+1;
      if newvalue>t_m.r;
         set(graph.popup,'Value',1);
      else;
         set(graph.popup,'Value',newvalue);
      end;
      if curr_ini.colors==1;
         colorstr = 'b';
      else;
         colorstr = 'k';
      end;
      y = t_m.mydatafile(series,:)';
      dy = t_m.mycorrdatafile(series,:)';
      thisplot = figure('Units','pixels', ...
         'Position',[(realscrsz(3)-512)/2 (realscrsz(4)-384)/2 512 384], ...
         'Menubar','none', ...
         'Toolbar','none', ...
         'NumberTitle','off', ...
         'Visible','off', ...
         'Name',['Time Series Plot of Cointegration Relation no. ' num2str(series)]);
      %
      % default figure properties
      %
      setfigureproperties(thisplot);
      %
      plot(t_m.dataindex,y,'-','LineWidth',1,'Color',colorstr,'Tag',['coint(' num2str(series) ')']);
      set(gca,'XLim',[t_m.dataindex(1,1) t_m.dataindex(size(t_m.dataindex,1),1)]);
      y_lim = get(gca,'YLim');
      if (y_lim(1,1)<0)&(y_lim(1,2)>0);
         %
         % plot a zero line
         %
         hold('on');
         plot([t_m.dataindex(1,1) t_m.dataindex(size(t_m.dataindex,1),1)],[0 0],'-','LineWidth',1,'Color','k');
      end;
      setaxesfonts('Title',['Cointegration relation no. ' num2str(series)]);
      toolbar_fcn(gca);
      nextplot = figure('Units','pixels', ...
         'Position',[(realscrsz(3)-512)/2+22 (realscrsz(4)-384)/2-22 512 384], ...
         'Menubar','none', ...
         'Toolbar','none', ...
         'NumberTitle','off', ...
         'Visible','off', ...
         'Name',['Time Series Plot of Cointegration Relation no. ' num2str(series) ' - Corrected']);
      %
      % default figure properties
      %
      setfigureproperties(nextplot);
      %
      plot(t_m.dataindex,dy,'-','LineWidth',1,'Color',colorstr,'Tag',['corr-coint(' num2str(series) ')']);
      hold('on');
      plot(t_m.dataindexfix,zeros(size(dy,1)+3,1),'-','LineWidth',1,'Color','k');
      set(gca,'XLim',[t_m.dataindexfix(1,1) t_m.dataindexfix(size(t_m.dataindexfix,1),1)]);
      setaxesfonts('Title',['Corrected cointegration relation no. ' num2str(series)]);
      toolbar_fcn(gca);
%      hold('off');
      if t_m.restricted==0;
         variable = strcat('coint-',num2str(series));
      else;
         variable = strcat('rest-coint-',num2str(series));
      end;
      if curr_ini.external==0;
         set(thisplot,'Visible','on');
         set(nextplot,'Visible','on');
      else;
         file1 = [t_m.outputdir variable];
         file2 = [t_m.outputdir 'corr-' variable];
         mstat1 = autosavefigure(thisplot,file1);
         mstat2 = autosavefigure(nextplot,file2);
         if mstat1==0;
            autoshowfigure(file1);
         end;
         if mstat2==0;
            autoshowfigure(file2);
         end;
      end;
      set(cointgraphgui,'UserData',graph);
   case 'done'
      set(graph.done,'UserData','done');
end;

if nargout==1;
   h = cointgraphgui;
end;

if strcmp(selector,'done')==0;
   curr_ini.models = t_m;
   set(graph.popup,'UserData',curr_ini);
   set(cointgraphgui,'UserData',graph);
end;

if thisexit==0;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(cointgraphgui,'Name') ' ' fix_filepath([pwd '\icons\coint.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(graph.icon,'UserData',pid);
      end;
   end;
   %
   set(cointgraphgui,'Visible','on');
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(cointgraphgui,'Name') ' 1'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(graph.done);
   end;
   waitfor(graph.done,'UserData','done');
end;

%
% end of cointgraphdlg.m
%
