%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for bootstrapping the fluctuation   %
%          tests for the non-zero eigenvalues                    %
%                                                                %
%          Function: eigen_bootstrap                             %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       cm: structure with model info            %
%                                                                %
%          Output:                                               %
%                                                                %
%          This version:        July 10, 2006                    %
%          Written by:          Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function eigen_bootstrap(varargin)

%
% GUI for bootstrapping the non-zero eigenvalue fluctuation test
%

selector = varargin{1};
if (nargin==0)|(strcmp(selector,'init')==1);
   tm = varargin{2};
   %
   % toolbar images
   %
   button_images = read_images;
   %
   % more initialization
   %
   selector = 'init';
   my_exit = 1;
   tm.const_model = [0 0 0 0 0];
   if tm.deterselect(1)==1;
      tm.const_model(3) = 1;
   elseif tm.deterselect(2)==1
      tm.const_model(2) = 1;
   elseif tm.deterselect(3)==1;
      tm.const_model(5) = 1;
   else;
      tm.const_model(4) = 1;
   end;
   %
   % Set screen size directly instead of using
   % get(0,'ScreenSize')!
   %
   tm.realscrsz = get(0,'ScreenSize');
   tm.eigen_run = 0;
   %
   % read var.in
   %
   curr_ini = find_inisettings;
   if curr_ini.transeig==1;
      tm.transeig = 'transeig-';
   else;
      tm.transeig = '';
   end;
   my_T = tm.T;
   rep = curr_ini.nRep;
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   nRep_value = 1;
   for i=1:size(repvalues,2);
      if curr_ini.nRep==repvalues(1,i);
         nRep_value = i;
         break;
      end;
   end;
   if direxist(curr_ini.simulatedir)==0;
      mystatus = makedirs(curr_ini.simulatedir);
   else;
      mystatus = 2;
   end;
   if mystatus==0;
      curr_ini.simulatedir = pwd;
      if ispc==1;
         curr_ini.simulatedir = [curr_ini.simulatedir '\'];
      end;
   end;
   if isnumeric(curr_ini.external)==0;
      curr_ini.external = 0;
   end;
   %
   if curr_ini.fullrec==1;
      tm.updating = 'fixed-';
   else;
      tm.updating = 'updated-';
   end;
   %
   if curr_ini.parametric==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(curr_ini.blocksize) '-'];
   end;
   full_mat = '';
   if tm.const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-full-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
   elseif tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-full-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-full-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-full-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-full-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
      view_enable = 'on';
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      eigen_mat = load(full_mat);
      eigen_test_sorted = eigen_mat.eigen_test_sorted;
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
   else;
      view_enable = 'off';
      eigen_test_sorted = [];
      full_mat = '';
      full_enable = 'off';
   end;
   summary_txt = '';
   if tm.const_model(1)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-summary-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
      mod_type = 'noconst';
      model_type = 'No Constant';
   elseif tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-summary-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
      mod_type = 'resconst';
      model_type = 'Restricted Constant';
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-summary-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
      mod_type = 'const';
      model_type = 'Constant';
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-summary-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
      mod_type = 'restrend';
      model_type = 'Restricted Linear Trend';
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-summary-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
      mod_type = 'trend';
      model_type = 'Linear Trend';
   end;
%   if curr_ini.texoutputformat>=2;
%      summary_txt = strrep(summary_txt,'.txt','.ltx');
%   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
   end;
   %
   % check if file with bootstrapped residuals exists
   %
   epsfile = [curr_ini.simulatedir tm.modelfile '-' 'eigen-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
   testfile = strrep(epsfile,'.mat',['-' 'eigen-data.mat']);
   if fileexist(epsfile)==1;
      boot_enable = 'on';;
   else;
      epsfile = '';
      testfile = '';
      boot_enable = 'off';
   end;
   %
   tm.interpolate = curr_ini.interpolate;
   if strcmp(tm.interpolate,'nearest')==1;
      tm.interpolate_value = 1;
   elseif strcmp(tm.interpolate,'linear')==1;
      tm.interpolate_value = 2;
   elseif strcmp(tm.interpolate,'spline')==1;
      tm.interpolate_value = 3;
   elseif strcmp(tm.interpolate,'cubic')==1;
      tm.interpolate_value = 4;
   elseif strcmp(tm.interpolate,'knorm')==1;
      tm.interpolate_value = 5;
   elseif strcmp(tm.interpolate,'kepan')==1;
      tm.interpolate_value = 6;
   elseif strcmp(tm.interpolate,'krect')==1;
      tm.interpolate_value = 7;
   elseif strcmp(tm.interpolate,'ktria')==1;
      tm.interpolate_value = 8;
   elseif strcmp(tm.interpolate,'kbiwe')==1;
      tm.interpolate_value = 9;
   elseif strcmp(tm.interpolate,'ktriw')==1;
      tm.interpolate_value = 10;
   elseif strcmp(tm.interpolate,'klapl')==1;
      tm.interpolate_value = 11;
   elseif strcmp(tm.interpolate,'klogi')==1;
      tm.interpolate_value = 12;
   end;
else;
   my_exit = 0;
   eigen_boot_gui = findobj('Type','figure','Tag','EigenBoot')';
   boot_eigen = get(eigen_boot_gui,'UserData');
   curr_ini = get(boot_eigen.matfilebutton,'UserData');
   tm = curr_ini.models;
   button_images = curr_ini.images;
end;

switch selector
case 'init'
   eigen_boot_gui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','eigen_bootstrap.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(tm.realscrsz(3)-560)/2 (tm.realscrsz(4)-405)/2 560 405], ...
         'Tag','EigenBoot', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name','Bootstrap Distributions for Eigenvalue Fluctuation Tests', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','eigen_bootstrap done', ...
         'ToolBar','none');

   if matlabnumber>=7.0;
      set(eigen_boot_gui,'DockControl','off');
   end;

   if strcmp(curr_ini.helpexe,'')==1;
      helpenable = 'off';
   else;
      helpenable = 'on';
   end;

   %
   % File menu
   %

   filemenu = uimenu('Parent',eigen_boot_gui, ...
      'Label','&File', ...
      'Tag','FileMenu');

   boot_eigen.simulatemenu = uimenu('Parent',filemenu, ...
         'Label','&Run Bootstrap', ...
         'Callback','eigen_bootstrap simulate', ...
         'Enable','on', ...
         'Accelerator','R', ...
         'Tag','SimulateMenu');

   boot_eigen.matfilemenu = uimenu('Parent',filemenu, ...
         'Label','Save to m&at-file', ...
         'Separator','on', ...
         'Accelerator','A', ...
         'Enable',full_enable, ...
         'Callback','eigen_bootstrap matfile', ...
         'Tag','MatFileMenu');

   boot_eigen.summarymenu = uimenu('Parent',filemenu, ...
         'Label','&Simulation Summary', ...
         'Separator','on', ...
         'Callback','eigen_bootstrap summary', ...
         'UserData',summary_txt, ...
         'Accelerator','S', ...
         'Enable',summary_enable, ...
         'Tag','SummaryMenu');

   boot_eigen.fullmenu = uimenu('Parent',filemenu, ...
         'Label','&Full Simulation', ...
         'Callback','eigen_bootstrap full', ...
         'Accelerator','F', ...
         'UserData',full_mat, ...
         'Enable',full_enable, ...
         'Tag','FullMenu');

   if curr_ini.noprint==0;
      boot_eigen.output = uimenu('Parent',filemenu, ...
            'Label','Append to &Output', ...
            'Separator','on', ...
            'Callback','eigen_bootstrap output', ...
            'Accelerator','O', ...
            'Enable',summary_enable, ...
            'Tag','SummaryMenu');
   end;

   uimenu('Parent',filemenu, ...
         'Label','Center &Window', ...
         'Separator','on', ...
         'Accelerator','W', ...
         'Enable','on', ...
         'Callback','center_figure_fcn', ...
         'Tag','CenterMenu');

   boot_eigen.returnmenu = uimenu('Parent',filemenu, ...
         'Label','R&eturn', ...
         'Separator','on', ...
         'Callback','eigen_bootstrap done', ...
         'Enable','on', ...
         'Tag','MenuFileReturn');

   boot_eigen.filemenu = filemenu;

   %
   % Graph Menu
   %

   graphmenu = uimenu('Parent',eigen_boot_gui, ...
      'Label','&Graphics', ...
      'Tag','GraphMenu');

   boot_eigen.bootstrapgraphmenu = uimenu('Parent',graphmenu, ...
         'Label','Graph &Bootstrap Sample', ...
         'Callback','eigen_bootstrap display_bootstrap', ...
         'Accelerator','B', ...
         'UserData',testfile, ...
         'Enable',boot_enable, ...
         'Tag','BootstrapGraphMenu');

   boot_eigen.displaymenu = uimenu('Parent',graphmenu, ...
         'Label','&Graph Distribution', ...
         'Callback','eigen_bootstrap display', ...
         'Separator','on', ...
         'Accelerator','G', ...
         'UserData',tm.const_model, ...
         'Enable',view_enable, ...
         'Tag','DisplayMenu');

   boot_eigen.histogrammenu = uimenu('Parent',graphmenu, ...
         'Label','&Histogram of Distribution', ...
         'Callback','eigen_bootstrap display', ...
         'Accelerator','D', ...
         'Enable',view_enable, ...
         'Tag','HistogramMenu');

   %
   % Help Menu
   %

   helpmenu = uimenu('Parent',eigen_boot_gui, ...
      'Label','&Help', ...
      'Tag','HelpMenu');

   boot_eigen.helpmenu = uimenu('Parent',helpmenu, ...
         'Label','&Help Topics', ...
         'Callback','help_fcn(''bootstrapping'')', ...
         'Accelerator','H', ...
         'Enable',helpenable, ...
         'Tag','HelpMenu');

   %
   % The toolbar
   %

   boot_eigen.toolbar = uitoolbar('Parent',eigen_boot_gui, ...
                     'HandleVisibility','off', ...
                     'Interruptible','on', ...
                     'Clipping','on');

   if (iswinxp==0)|(matlabnumber<7);
      xline([1 404 560],[0.5 1]);
   end;

   boot_eigen.simulate = uipushtool('Parent',boot_eigen.toolbar, ...
                      'TooltipString','Run Bootstrap', ...
                      'CData',button_images.simulate, ...
                      'ClickedCallback','eigen_bootstrap simulate', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable','on', ...
                      'UserData',0, ...
                      'Tag','Simulate');


   boot_eigen.matfilebutton = uipushtool('Parent',boot_eigen.toolbar, ...
                      'TooltipString','Save to mat-file', ...
                      'CData',button_images.matfile, ...
                      'ClickedCallback','eigen_bootstrap matfile', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','MatFileButton');

   boot_eigen.summary = uipushtool('Parent',boot_eigen.toolbar, ...
                      'TooltipString','View Simulation Summary', ...
                      'CData',button_images.sim_summary, ...
                      'ClickedCallback','eigen_bootstrap summary', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',summary_enable, ...
                      'Tag','SummaryButton');

   boot_eigen.full = uipushtool('Parent',boot_eigen.toolbar, ...
                      'TooltipString','View Full Simulation', ...
                      'CData',button_images.sim_full, ...
                      'ClickedCallback','eigen_bootstrap full', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','FullButton');

   boot_eigen.bootstrapgraph = uipushtool('Parent',boot_eigen.toolbar, ...
                      'TooltipString','Graph Bootstrap Sample', ...
                      'CData',button_images.bootstrapsmall, ...
                      'ClickedCallback','eigen_bootstrap display_bootstrap', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',epsfile, ...
                      'Clipping','on', ...
                      'Enable',boot_enable, ...
                      'Tag','ViewBootstrapButton');

   boot_eigen.display = uipushtool('Parent',boot_eigen.toolbar, ...
                      'TooltipString','Graph Distribution', ...
                      'CData',button_images.viewdist, ...
                      'ClickedCallback','eigen_bootstrap display', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',eigen_test_sorted, ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','ViewDistButton');

   boot_eigen.histogram = uipushtool('Parent',boot_eigen.toolbar, ...
                      'TooltipString','Histogram of Distribution', ...
                      'CData',button_images.bars, ...
                      'ClickedCallback','eigen_bootstrap display', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','HistogramButton');

   boot_eigen.help = uipushtool('Parent',boot_eigen.toolbar, ...
                      'TooltipString','Help Topics', ...
                      'CData',button_images.help, ...
                      'ClickedCallback','help_fcn(''bootstrapping'')', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',helpenable, ...
                      'Tag','HelpButton');

   boot_eigen.done = uipushtool('Parent',boot_eigen.toolbar, ...
                      'TooltipString','Return', ...
                      'CData',button_images.continue, ...
                      'ClickedCallback','eigen_bootstrap done', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'UserData','waiting', ...
                      'Enable','on', ...
                      'Tag','Done');

   axesbox([2 2 558 390],'Eigenvalue Fluctuation Test',135,[0.5 1]);

   %
   % GUI Header
   %

   header_txt = ['Hansen-Johansen Fluctuation Test (' model_type ' Model)'];
   desc_txt = 'Select the type of bootstrap you wish to perform, the number of observations and replications. Press the "Run Bootstrap" button when you''re satisfied with your choices and wait for the computations to finish.';
   dialog_header_fcn([16 306 530 70],button_images.bootstrap,header_txt,desc_txt);

   %
   % Options
   %

   axesbox([16 130 155 160],'Options',35,[0.5 1]);

   boot_eigen.clock = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 255 130 20], ...
      'Value',1, ...
      'String','Show elapsed time', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','TimeCheck');

   boot_eigen.progress = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 235 130 20], ...
      'Value',1, ...
      'String','Show progress dialog', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ProgressCheck');

   boot_eigen.save = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 215 130 20], ...
      'Value',1, ...
      'String','Save full simulation', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','SaveCheck');

   boot_eigen.parametric = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 195 130 20], ...
      'Value',curr_ini.parametric, ...
      'String','Parametric bootstrap', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'Callback','eigen_bootstrap fixobscontrol', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ParametricCheck');


   boot_eigen.blocktext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[45 165 100 20], ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Style','text', ...
      'HorizontalAlignment','left', ...
      'String','Block size:', ...
      'Enable','off', ...
      'Tag','BlockText');

   boot_eigen.block = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[105 170 50 20], ...
      'Value',1, ...
      'String','1|2|3|4|5|6|7|8|9|10|11|12', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Value',curr_ini.blocksize, ...
      'Enable','off', ...
      'Callback','eigen_bootstrap check', ...
      'Tag','BlockPopup');
   
   if curr_ini.parametric==0;
      set(boot_eigen.blocktext,'Enable','on');
      set(boot_eigen.block,'Enable','on');
   end;

   boot_eigen.bootstrap = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 145 130 20], ...
      'Value',curr_ini.reuse_bootstrap, ...
      'String','Reuse/save residuals', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ReuseBootstrapCheck');

   axesbox([185 130 361 160],'Parameters',55,[0.5 1]);

   %
   % number of observations per replication
   %

   boot_eigen.obstext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 249 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'HorizontalAlignment','left', ...
      'String','Number of observations:', ...
      'Tag','ObsText');

   boot_eigen.obs = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 254 168 20], ...
      'Value',1, ...
      'String',[num2str(my_T) '|100|200|300|400|500|600|700|800|900|1000|1100|1200|1300|1400|1500|1600|1700|1800|1900|2000|2500|3000|4000|5000|6000|7000|8000|9000|10000'], ...
      'Style','popupmenu', ...
      'UserData',my_T, ...
      'Callback','eigen_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','ObsPopup');

   if (tm.q1+tm.q0==0)&(isempty(tm.deterfile)==1);
      set(boot_eigen.obstext,'Enable','on');
      set(boot_eigen.obs,'Enable','on');
   end;

   %
   % number of replications
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 196.5 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of replications:', ...
      'Tag','SimulText');

   boot_eigen.rep = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 201.5 168 20], ...
      'Value',nRep_value, ...
      'String','99|999|1,999|2,999|3,999|4,999|9,999|19,999|29,999|39,999|49,999|99,999|199,999|299,999|399,999|499,999|999,999', ...
      'Style','popupmenu', ...
      'Callback','eigen_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'UserData',rep,...
      'Enable','on', ...
      'Tag','SimulPopup');

   %
   % number of cointegration relations
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 144 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'HorizontalAlignment','left', ...
      'String','Number of cointegration relations:', ...
      'Tag','CointText');

   r_str = '1';
   for i=2:tm.n;
      r_str = [r_str '|' num2str(i)];
   end;

   boot_eigen.my_r = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 149 168 20], ...
      'Value',tm.r, ...
      'String',r_str, ...
      'UserData',tm.r, ...
      'Style','popupmenu', ...
      'Callback','eigen_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','CointPopup');

   %
   % Select interpolation function
   %

   axesbox([16 16 530 100],'Graphics',45,[0.5 1]);

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 74 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Interpolation function:', ...
      'Tag','InterpolateText');

   boot_eigen.interpolate = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 79 168 20], ...
      'Value',tm.interpolate_value, ...
      'String','Nearest neighborhood|Linear|Cubic spline|Cubic|Kernel density normal|Kernel density Epanechnikov|Kernel density rectangular|Kernel density triangular|Kernel density biweight|Kernel density triweight|Kernel density Laplace|Kernel density logistic', ...
      'Callback','eigen_bootstrap interpolate', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','InterpolatePopup');

   %
   % Number of cells for graphing density functions
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 29 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of cells for histograms:', ...
      'Tag','CellText');

   boot_eigen.cells = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 34 168 20], ...
      'Value',1, ...
      'String','20|25|30|35|40|45|50|55|60|65|70|75|80|85|90|95|100', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','CellPopup');

   boot_eigen.cdf = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 84.5 140 20], ...
      'Value',0, ...
      'String','Cumulative distribution', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','cdfCheckbox');

   boot_eigen.adaptive = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 64.5 140 20], ...
      'Value',0, ...
      'String','Adaptive KDE method', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','adaptiveCheckbox');

   boot_eigen.bart = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 44.5 140 20], ...
      'Value',0, ...
      'String','Bartlett corr. bootstrap', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','BartlettCheckbox');

   boot_eigen.pqplot = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 24.5 140 20], ...
      'Value',0, ...
      'String','P-value plots, etc.', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','PQPlotCheckbox');

   if tm.interpolate_value>=5;
      set(boot_eigen.adaptive,'Enable','on');
   end;

   set(eigen_boot_gui,'UserData',boot_eigen,...
         'HandleVisibility','callback');

case 'output'
   if curr_ini.texoutputformat>=2;
      file = strrep(lower(get(boot_eigen.summarymenu,'UserData')),'.txt','.ltx');
      txt_str = readtext(file);
      fout = fopen(tm.outputfile,'at');
      fprintf(fout,'\\subsection*{Bootstrap Simulation of Hansen-Johansen Fluctuation Tests} \n\n');
      for i=1:size(txt_str,2);
         fprintf(fout,'%s\n',txt_str{i});
      end;
      fclose(fout);
   else;
      txt_str = readtext(lower(get(boot_eigen.summarymenu,'UserData')));
      fout = fopen(tm.outputfile,'at');
      fprintf(fout,'            Bootstrap Simulation of Hansen-Johansen Fluctuation Tests\n            ---------------------------------------------------------\n');
      for i=5:size(txt_str,2)-4;
         fprintf(fout,'%s\n',txt_str{i});
      end;
      fprintf(fout,'\n===============================================================================\n\n');
      fclose(fout);
   end;
case 'display_bootstrap'
   epsfile = get(boot_eigen.bootstrapgraph,'UserData');
   testfile = get(boot_eigen.bootstrapgraphmenu,'UserData');
   my_T = get(boot_eigen.obs,'UserData');
   rep = get(boot_eigen.rep,'UserData');
   if rep<4999;
      answer = 'Yes';
   else;
      check_txt = ['Your bootstrap setup includes ' num2str(rep) ' draws of the residuals. With ' num2str(tm.n) ' series and ' num2str(my_T) ' observations, this yields ' num2str(rep*tm.n*my_T) ' observations. Are you sure you want to load that much data into memory?'];
      answer = query(check_txt,'warning',120,'Exit',500,'no');
   end;
   if strcmp(answer,'Yes')==1;
      %
      %
      txt_str = '';
      for i=1:tm.r;
         txt_str = strvcat(txt_str,['sup tau(eig(' num2str(i,'%0.0f') ')) =']);
      end;
      if tm.r>1;
         txt_str = strvcat(txt_str,['sup tau(sum eig(i)) =']);
      end;
      %
      set(eigen_boot_gui,'Visible','off');
      drawnow;
      thisgraph = bootgraphdlg('init',tm,epsfile,testfile,txt_str,tm.beta(:,1:tm.r),rep,my_T,tm.r);
      bootgraph = get(thisgraph,'UserData');
      set(bootgraph.show,'UserData','done');
      killguipid(thisgraph);
      set(eigen_boot_gui,'Visible','on');
      drawnow;
   end;
case 'fixobscontrol'
   if get(boot_eigen.parametric,'Value')==0;
      T_str = get(boot_eigen.obs,'String');
      my_T = mystr2num(strtrim(T_str(get(boot_eigen.obs,'Value'),:)));
      set(boot_eigen.obs,'Value',1,'UserData',my_T,'Enable','off');
      set(boot_eigen.obstext,'Enable','off');
   elseif (tm.q1+tm.q0==0)&(isempty(tm.deterfile)==1);
      set(boot_eigen.obs,'Enable','on');
      set(boot_eigen.obstext,'Enable','on');
   end;
   eigen_bootstrap('check');
case 'interpolate'
   tm.interpolate_value = get(boot_eigen.interpolate,'Value');
   interpol_vec = strvcat('nearest','linear','spline','cubic','knorm','kepan','krect','ktria','kbiwe','ktriw','klapl','klogi');
   tm.interpolate = strtrim(interpol_vec(tm.interpolate_value,:));
   if tm.interpolate_value>=5;
      set(boot_eigen.adaptive,'Enable','on');
   else;
      set(boot_eigen.adaptive,'Enable','off','Value',0);
   end;
case 'matfile'
   eigen_test_sorted = get(boot_eigen.display,'UserData');
   rep = get(boot_eigen.rep,'UserData');
   my_T = get(boot_eigen.obs,'UserData');
   my_const_model = get(boot_eigen.displaymenu,'UserData');
   if get(boot_eigen.parametric,'Value')==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(get(boot_eigen.block,'Value')) '-'];
   end;
   if my_const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-full-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
   elseif my_const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-full-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif my_const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-full-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif my_const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-full-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif my_const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-full-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      my_text = ['The file "' getfilename(full_mat) '" already exists. Are you sure you want to overwrite it?'];
      answer = query(my_text,'question',120,'Save to mat-file',500,'no');
   else;
      answer = 'Yes';
   end;
   if strcmp(answer,'Yes')==1;
      setlogtext('Savings results to mat-files...');
      Number = (1:1:rep)';
      save(full_mat,'eigen_test_sorted');
   end;
case 'check'
   T_str = get(boot_eigen.obs,'String');
   my_T = mystr2num(strtrim(T_str(get(boot_eigen.obs,'Value'),:)));
   if strcmp(get(boot_eigen.my_r,'Enable'),'on')==1;
      tm.r = get(boot_eigen.my_r,'Value');
      %
      % make sure the largest non-zero eigenvalue is less than unity
      %
      eigenvalues = companion(tm.Z0,tm.Z1,tm.Z2,tm.r,tm.p,tm.n,tm.q1,tm.q0,tm.d,tm.T);
      eigenvalues = abs(sort(eigenvalues));
      i = size(eigenvalues,1);
      while i>=1;
         tm.evalue = eigenvalues(i,1);
         if strcmp(num2str(tm.evalue,'%1.10f'),'1.0000000000')==1;
            i = i-1;
         else;
            i = 0;
         end;
      end;
      if tm.evalue>1;
         some_txt = ['For the cointegration rank ' num2str(tm.r,'%0.0f') ' the largest non-unit eigenvalue is ' num2str(tm.evalue,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) '. Explosive systems should not be studied with the Hansen-Johansen fluctuation test.'];
         about(some_txt,'warning','Explosive Model...',120,400);
         tm.r = get(boot_eigen.my_r,'UserData');
         set(boot_eigen.my_r,'Value',tm.r);
      else;
         tm.alpha = (tm.S_01*tm.beta(:,1:tm.r))/(tm.beta(:,1:tm.r)'*tm.S_11*tm.beta(:,1:tm.r));
         if isempty(tm.Z2)==0;
            tm.Psi = (tm.M_02/tm.M_22)-(tm.alpha*tm.beta(:,1:tm.r)'*(tm.M_12/tm.M_22));
            tm.epsilon = tm.Z0-(tm.alpha*tm.beta(:,1:tm.r)'*tm.Z1)-(tm.Psi*tm.Z2);
         else;
            tm.Psi = [];
            tm.epsilon = tm.Z0-(tm.alpha*tm.beta(:,1:tm.r)'*tm.Z1);
         end;
         tm.Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
         set(boot_eigen.my_r,'UserData',tm.r);
      end;
   end;
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   rep_val = get(boot_eigen.rep,'Value');
   rep = repvalues(rep_val);
   set(boot_eigen.rep,'UserData',rep);
   set(boot_eigen.obs,'UserData',my_T);
   %
   % adjusting the view text buttons
   %
   if get(boot_eigen.parametric,'Value')==1;
      bootstyle = '';
      set(boot_eigen.blocktext,'Enable','off');
      set(boot_eigen.block,'Enable','off','Value',1);
   else;
      if strcmp(get(boot_eigen.block,'Enable'),'off')==1;
         set(boot_eigen.blocktext,'Enable','on');
         set(boot_eigen.block,'Enable','on','Value',curr_ini.blocksize);
      end;
      bootstyle = ['np' num2str(get(boot_eigen.block,'Value')) '-'];
   end;
   full_mat = '';
   if tm.const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-full-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
      mod_type = 'noconst';
   elseif tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-full-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
      mod_type = 'resconst';
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-full-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
      mod_type = 'const';
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-full-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
      mod_type = 'restrend';
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-full-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
      mod_type = 'trend';
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      eigen_mat = load(full_mat);
      eigen_test_sorted = eigen_mat.eigen_test_sorted;
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
      %
      % adjusting the Graph Distrbution button
      %
      set(boot_eigen.display,'Enable','on','UserData',eigen_test_sorted);
      set(boot_eigen.displaymenu,'Enable','on','UserData',tm.const_model);
      set(boot_eigen.histogram,'Enable','on');
      set(boot_eigen.histogrammenu,'Enable','on');
      set(boot_eigen.matfilebutton,'Enable','on');
      set(boot_eigen.matfilemenu,'Enable','on');
   else;
      full_mat = '';
      full_enable = 'off';
      set(boot_eigen.display,'Enable','off','UserData',[]);
      set(boot_eigen.displaymenu,'Enable','off','UserData',tm.const_model);
      set(boot_eigen.histogram,'Enable','off');
      set(boot_eigen.histogrammenu,'Enable','off');
      set(boot_eigen.matfilebutton,'Enable','off');
      set(boot_eigen.matfilemenu,'Enable','off');
   end;
   %
   % Checking if residuals file exists
   %
   epsfile = [curr_ini.simulatedir tm.modelfile '-' 'eigen-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
   testfile = strrep(epsfile,'.mat',['-' 'eigen-data.mat']);
   %
   if (fileexist(epsfile)==1)&(fileexist(testfile)==1);
      set(boot_eigen.bootstrapgraph,'Enable','on','UserData',epsfile);
      set(boot_eigen.bootstrapgraphmenu,'Enable','on','UserData',testfile);
   else;
      set(boot_eigen.bootstrapgraph,'Enable','off','UserData',[]);
      set(boot_eigen.bootstrapgraphmenu,'Enable','off','UserData','');
   end;
   %
   set(boot_eigen.fullmenu,'Enable',full_enable,'UserData',full_mat);
   set(boot_eigen.full,'Enable',full_enable);
   summary_txt = '';
   if tm.const_model(1)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-summary-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
   elseif tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-summary-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-summary-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-summary-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-summary-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
   end;
%   if curr_ini.texoutputformat>=2;
%      summary_txt = strrep(summary_txt,'.txt','.ltx');
%   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
   end;
   if curr_ini.noprint==0;
      set(boot_eigen.output,'Enable',summary_enable);
   end;
   set(boot_eigen.summarymenu,'Enable',summary_enable,'UserData',summary_txt);
   set(boot_eigen.summary,'Enable',summary_enable);
   set(eigen_boot_gui,'UserData',boot_eigen);
case 'summary'
   set(eigen_boot_gui,'Visible','off');
   drawnow;
   file = lower(get(boot_eigen.summarymenu,'UserData'));
   prtgui = printgui('init',file,'Structural VAR - Fluctuation Tests Bootstrap Simulation Summary',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   myprint = get(prtgui,'UserData');
   set(myprint.print,'UserData','done');
   killguipid(prtgui);
   set(eigen_boot_gui,'Visible','on');
   drawnow;
   set(eigen_boot_gui,'UserData',boot_eigen);
case 'full'
   set(eigen_boot_gui,'Visible','off');
   drawnow;
   rep = get(boot_eigen.rep,'UserData');
   full_mat = lower(get(boot_eigen.fullmenu,'UserData'));
   my_T = get(boot_eigen.obs,'UserData');
   %
   % not functional yet
   %
   prt_str = '%7.0f     ';
   sp_str = spacestr(curr_ini.decimals-2);
   prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
   head_txt = ' Number      ';
   for i=1:tm.r;
      prt_str = [prt_str prt_val '   '];
      head_txt = sprintf([head_txt 'eig(%2.0f)    ' sp_str],i);
   end;
   if tm.r>1;
      prt_str = [prt_str prt_val];
      head_txt = [head_txt 'sum(eig(i))'];
   end;
   %
   my_text = strvcat(' ',head_txt);
   abort = '';
   if rep>=5000;
      input_var.title = ['Progress for ' int2str(rep) ' replications'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.label = 'Replication number:';
      input_var.stop = 0;
      input_var.clock = 1;
      input_var.name = ['Data in ' getname(full_mat)];
      mywait = progressdlg(0,input_var);
%      set(mywait,'Name',['Data in ' getname(full_mat)]);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
      drawnow;
   end;
   eigen_mat = load(full_mat);
   my_data = [eigen_mat.Number eigen_mat.eigen_test_sorted];
   for i=1:size(my_data,1);
      if rep>=5000;
         abort = get(mywait,'UserData');
         if strcmp(abort,'cancel')==1;
            break;
         else;
            progressdlg([(i/rep) i]);
         end;
      end;
      out = sprintf(prt_str,my_data(i,:)');
      my_text = strvcat(my_text,out);
   end;
   my_text = strvcat(my_text,' ');
   if rep>=5000;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   end;
   if strcmp(abort,'cancel')==0;
      textgui(my_text,'Structural VAR - Fluctuation Tests Bootstrap Simulation',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   end;
   set(eigen_boot_gui,'Visible','on');
   drawnow;
   set(eigen_boot_gui,'UserData',boot_eigen);
case 'display'
   eigen_test_sorted = get(boot_eigen.display,'UserData');
   pos = [(tm.realscrsz(3)-600)/2 (tm.realscrsz(4)-400)/2];
   rep = get(boot_eigen.rep,'UserData');
   my_T = get(boot_eigen.obs,'UserData');
   %
   % need to fix the rest
   %
   my_const_model = get(boot_eigen.displaymenu,'UserData');
   if my_const_model(1)==1;
      this_mod = '(no constant)';
   elseif my_const_model(2)==1;
      this_mod = '(restricted constant)';
   elseif my_const_model(3)==1;
      this_mod = '(constant)';
   elseif my_const_model(4)==1;
      this_mod = '(restricted trend)';
   elseif my_const_model(5)==1;
      this_mod = '(trend)';
   end;
   cell_value = get(boot_eigen.cells,'Value');
   cell_vec = [20 25 30 35 40 45 50 55 60 65 70 75 80 85 90 95 100];
   numcells = cell_vec(cell_value);
   my_80 = floor(0.8*rep);
   my_90 = floor(0.9*rep);
   my_95 = floor(0.95*rep);
   my_975 = floor(0.98*rep);
   my_99 = floor(0.99*rep);
   %
   if curr_ini.colors==1;
      col.vec_1 = [0 0 1];
      col.vec_2 = [1 0 0];
      col.vec_3 = [0 0.75 0];
      col.vec_4 = [1 0.5 0];
      col.vec_5 = [0 0.75 0.75];
      col.vec_6 = [0 0 0];
      col.vec_7 = (1/255)*[255 28 28];
      col.vec_8 = [0 1 0];
   else;
      col.vec_1 = [0 0 0];
      col.vec_2 = [0.7 0.7 0.7];
      col.vec_3 = [0.6 0.6 0.6];
      col.vec_4 = [0.5 0.5 0.5];
      col.vec_5 = [0.4 0.4 0.4];
      col.vec_6 = [0.3 0.3 0.3];
      col.vec_7 = [0.8 0.8 0.8];
      col.vec_8 = [0.2 0.2 0.2];
   end;
   %
   eigen_series = [];
   eigen_plots = [];
   if curr_ini.fullrec==1;
      [lambdaT,lambdastd,sigmastd,tauT,nyblomT,nyblomcorr,xisumT,xistdT,evaluet,tT,abort] = reclambda(tm.Z0,tm.Z1,tm.Z2,tm.r,tm.p,tm.d,curr_ini.T0,tm.df,tm.deterselect,0);
   else;
      [lambdaT,lambdastd,sigmastd,tauT,nyblomT,nyblomcorr,xisumT,xistdT,evaluet,tT,abort] = rectlambda(tm.Z0,tm.Z1,tm.Z2,tm.r,tm.p,tm.d,curr_ini.T0,tm.df,tm.deterselect,0);
   end;
   tm.eigen_test = max(tauT');
   t1 = size(xisumT,2);
   tauxisumT = xisumT-(xisumT(1,t1)*ones(1,t1));
   tm.eigen_test = [tm.eigen_test max(abs(tT.*(tauxisumT./(sqrt(xistdT(1,t1))*ones(1,t1)))))];
   %
   if (gcbo==boot_eigen.display)|(gcbo==boot_eigen.displaymenu);
      if ispc==1;
         file = [pwd '\mat\ploberger.mat'];
      else;
         file = [pwd '/mat/ploberger.mat'];
      end;
      if fileexist(file)==1;
         rand('state',sum(100*clock));
         %
         new_eigen = rand(10000+50,1);
         new_eigen = sort(new_eigen(51:10000+50,:));
         eigen_quant = quantiles_fcn;
         eigentab = load(file);
         eigen_table = eigentab.quantiles(:,1);
         eigen_series = zeros(10000,1);
         for i=1:10000;
            for j=1:220;
               if new_eigen(i,1)<=eigen_quant(j,1);
                  eigen_series(i,1) = eigen_table(j,1);
                  break;
               elseif j==220;
                  eigen_series(i,1) = eigen_table(221,1);
               end;
            end;
         end;
         [t1,t2] = hist(eigen_series,numcells);
         t1 = t1/10000;
      end;
   end;
   %
   num_eig = 1;
   if tm.r>1;
      num_eig = tm.r+1;
   end;
   for i=1:num_eig;
      if i<tm.r+1;
         if curr_ini.transeig==1;
            p_title = ['Fluctuation test for log[\lambda_{' num2str(i,'%0.0f') '}/(1-\lambda_{(' num2str(i,'%0.0f') '}] ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(tm.r) ' cointegration vectors'];
            add_name = ['log[\lambda_{' num2str(i,'%0.0f') '}/(1-\lambda_{(' num2str(i,'%0.0f') '}]'];
         else;
            p_title = ['Fluctuation test for \lambda_{' num2str(i,'%0.0f') '} ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(tm.r) ' cointegration vectors'];
            add_name = ['\lambda_{' num2str(i,'%0.0f') '}'];
         end;
         fig_name = ['Density for Hansen-Johansen Fluctuation Test for eig(' num2str(i,'%0.0f') ')'];
         fig_tag = ['hansen-johansen-fluctest-' num2str(i,'%0.0f') '-'];
      else;
         p_title = ['Fluctuation test for \Sigma_{i=1}^{' num2str(tm.r,'%0.0f') '}log[\lambda_{i}/(1-\lambda_{i})] ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(tm.r) ' cointegration vectors'];
         fig_name = 'Density for Hansen-Johansen Fluctuation Test for sum(eig(i))';
         fig_tag = 'hansen-johansen-fluctest-sum-';
         add_name = ['\Sigma_{i=1}^{' num2str(tm.r,'%0.0f') '}log[\lambda_{i}/(1-\lambda_{i})]'];
      end;
      %
      if ((gcbo==boot_eigen.display)|(gcbo==boot_eigen.displaymenu))&(get(boot_eigen.pqplot,'Value')==1);
         [p_series,pp_series,qq_series] = pq_pkk_series(eigen_test_sorted(:,i),eigen_quant,eigen_table,1);
         [pos,newplot] = pq_plot(pos,[fig_tag 'pqplot-'],['P-value and Quantile Plots for Hansen-Johansen Test'],['P-value plot of ' add_name],['P-value discrepancy plot of ' add_name],['PP plot of ' add_name],['QQ plot of ' add_name],tm,eigen_quant,eigen_table,p_series,pp_series,qq_series,col);
         eigen_plots = [eigen_plots newplot];
      end;
      %
      if isempty(eigen_series)==0;
         mean_eigen_series = (1/10000)*sum(eigen_series);
         bart_c = (mean_eigen_series*size(eigen_test_sorted(:,i),1)/sum(eigen_test_sorted(:,i)));
      else;
         bart_c = [];
      end;
      %
      [pos,thisplot] = dist_plot(pos,fig_tag,fig_name,p_title,tm,curr_ini,boot_eigen,eigen_test_sorted(:,i),eigen_series,1,1,0,col,my_80,my_90,my_95,my_975,my_99,numcells,1,bart_c);
      eigen_plots = [eigen_plots thisplot];
      %
   end;
   if curr_ini.external==0;
      set(eigen_plots,'Visible','on');
   else;
      stats = [];
      file_names = '';
      this_mod = strrep(this_mod,'(','');
      this_mod = strrep(this_mod,')','');
      this_mod = strtrim(this_mod);
      this_mod = strrep(this_mod,' ','.');
      stats = [];
      file_names = '';
      for i=1:size(eigen_plots,2);
         if (gcbo==boot_eigen.histogram)|(gcbo==boot_eigen.histogrammenu);
            file = [curr_ini.simulatedir tm.modelfile '-hist-boot-' get(eigen_plots(1,i),'Tag') tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
         else;
            file = [curr_ini.simulatedir tm.modelfile '-boot-' get(eigen_plots(1,i),'Tag') tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
         end;
         set(0,'CurrentFigure',eigen_plots(1,i));
         stats = [stats autosavefigure(eigen_plots(1,i),file)];
         file_names = strvcat(file_names,file);
      end;
      if isempty(stats)==0;
         for i=1:size(stats,2);
            if stats(i)==0;
               autoshowfigure(strtrim(file_names(i,:)));
            end;
         end;
      end;
   end;
   set(eigen_boot_gui,'UserData',boot_eigen);
   %
   % case simulate
   %
case 'simulate'
   tm.eigen_run = 1;
   set(eigen_boot_gui,'Visible','off');
   drawnow;
   %
   % collect values
   %
   T_str = get(boot_eigen.obs,'String');
   my_T = mystr2num(strtrim(T_str(get(boot_eigen.obs,'Value'),:)));
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   rep_val = get(boot_eigen.rep,'Value');
   rep = repvalues(rep_val);
   set(boot_eigen.simulate,'UserData',rep);
   blocksize = get(boot_eigen.block,'Value');
   block_txt = '';
   if blocksize>1;
      block_txt = ['Applying block bootstrap with block length ' num2str(blocksize,'%0.0f') '...'];
   end;
   if get(boot_eigen.parametric,'Value')==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(get(boot_eigen.block,'Value')) '-'];
   end;
   %
   % initialize
   %
   if curr_ini.fullrec==1;
      [lambdaT,lambdastd,sigmastd,tauT,nyblomT,nyblomcorr,xisumT,xistdT,evaluet,tT,abort] = reclambda(tm.Z0,tm.Z1,tm.Z2,tm.r,tm.p,tm.d,curr_ini.T0,tm.df,tm.deterselect,0);
   else;
      [lambdaT,lambdastd,sigmastd,tauT,nyblomT,nyblomcorr,xisumT,xistdT,evaluet,tT,abort] = rectlambda(tm.Z0,tm.Z1,tm.Z2,tm.r,tm.p,tm.d,curr_ini.T0,tm.df,tm.deterselect,0);
   end;
   tm.eigen_test = max(tauT');
   t1 = size(xisumT,2);
   tauxisumT = xisumT-(xisumT(1,t1)*ones(1,t1));
   tm.eigen_test = [tm.eigen_test max(abs(tT.*(tauxisumT./(sqrt(xistdT(1,t1))*ones(1,t1)))))];
   eigen_test = zeros(rep,size(tm.eigen_test,2));
   if curr_ini.symmetric==0;
      Omega_sig = chol(tm.Omega)';
   else;
      Omega_sig = symm(tm.Omega);
   end;
   abort = '';
   draw = 1;
   est_status = 0;
   showprog = get(boot_eigen.progress,'Value');
   if showprog==1;
      input_var.title = ['Progress for ' int2str(rep) ' replications'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.clock = get(boot_eigen.clock,'Value');
      input_var.label = 'Replication number:';
      input_var.stop = 0;
      mywait = progressdlg(0,input_var);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
   else;
      this_text = strvcat('Bootstrapping. The art of pulling oneself up by the bootstraps. Attempt started at...',' ',['Time: ' datestr(now,14)],' ','Please hold!');
      mywait = waitdlg(this_text,'bootstrap','Beta Bootstrap Simulation');
      waitf = get(mywait,'UserData');
      tic;
   end;
   if tm.const_model(2)==1;
      setlogtext(strvcat(' ','Bootstrapping distributions for Hansen-Johansen','fluctuation test...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted constant',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Restricted constant model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'resconst';
   elseif tm.const_model(3)==1;
      setlogtext(strvcat(' ','Bootstrapping distributions for Hansen-Johansen','fluctuation test...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Unrestricted constant',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Constant model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'const';
   elseif tm.const_model(4)==1;
      setlogtext(strvcat(' ','Bootstrapping distributions for Hansen-Johansen','fluctuation test...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted linear trend',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Restricted trend model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'restrend';
   elseif tm.const_model(5)==1;
      setlogtext(strvcat(' ','Bootstrapping distributions for Hansen-Johansen','fluctuation test...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Linear trend',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Linear trend model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'trend';
   end;
   if get(boot_eigen.bootstrap,'Value')==1;
      %
      % epsilon-file
      %
      epsfile = [curr_ini.simulatedir tm.modelfile '-' 'eigen-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
      if fileexist(epsfile)==1;
         load_eps = 1;
         %
         % load old epsilons
         %
         eps_data = load(epsfile);
      else;
         load_eps = 0;
      end;
   else;
      load_eps = 0;
   end;
   %
   % replicating
   %
   while (draw<=rep);  % should be until rep
      if showprog==1;
         abort = get(mywait,'UserData');
         if strcmp(abort,'cancel')==1;
            break;
         else;
            progressdlg([(draw/rep) draw]);
         end;
      end;
      %
      % check for bootstrap style
      %
      if load_eps==0;
         if get(boot_eigen.parametric,'Value')==1;
            %
            % reset the random number generator
            %
            if (curr_ini.random_state==2)&(est_status==0);
               randn('state',draw);
            elseif curr_ini.random_state==3;
               randn('state',sum(100*clock));
            else;
               randn('state',sum(100*clock)+draw);
            end;
            %
            Epr = randn(tm.n,my_T+50);
            Epr = Epr(:,51:my_T+50);
            %
            % make sure draws in Epr have identity covariance matrix
            %
            Sig = (1/my_T)*Epr*Epr';
            P_sig = chol(Sig)';
            Epr = P_sig\Epr;
            Epr = Omega_sig*Epr;
         else;
            %
            % reset the random number generator
            %
            if (curr_ini.random_state==2)&(est_status==0);
               rand('state',draw);
            elseif curr_ini.random_state==3;
               rand('state',sum(100*clock));
            else;
               rand('state',sum(100*clock)+draw);
            end;
            %
            % resample from estimated epsilons
            %
            uni_draws = rand([1 my_T+50]);
            uni_draws = uni_draws(1,51:my_T+50);
            Epr = boot_draw(uni_draws,tm.epsilon,blocksize);
         end;
         if get(boot_eigen.bootstrap,'Value')==1;
            bootstrap(draw).epsilon = Epr;
         end;
      else;
         Epr = eps_data.bootstrap(draw).epsilon;
      end;
      %
      % create new sample
      %
      boot = bootstrap_sample(tm,tm.beta(:,1:tm.r),Epr);
      if curr_ini.fullrec==1;
         [tauT,xisumT,xistdT,est_status,tT] = receigen(boot.Z0,boot.Z1,boot.Z2,tm.r,tm.p,tm.d,curr_ini.T0,tm.df,tm.deterselect,min(tm.T,my_T));
      else;
         [tauT,xisumT,xistdT,est_status,tT] = recteigen(boot.Z0,boot.Z1,boot.Z2,tm.r,tm.p,tm.d,curr_ini.T0,tm.df,tm.deterselect,min(tm.T,my_T));
      end;
      if est_status==0;
         tauT = max(tauT')';
         t1 = size(xisumT,2);
         tauxisumT = xisumT-(xisumT(1,t1)*ones(1,t1));
         tauxisumT = max(abs(tT.*(tauxisumT./(sqrt(xistdT(1,t1))*ones(1,t1)))));
         eigen_test(draw,:) = [tauT' tauxisumT];
         draw = draw+1;
      end;
   end;
   %
   % bootstrap has finished
   %
   if showprog==1;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   else;
      set(waitf.text,'UserData','done');
      delete(mywait);
      drawnow;
      new_time = toc;
      my_hrs = '00';
      my_min = '00';
      my_sec = num2str(new_time,'%0.2f');
      if new_time>=60;
         ch_min = floor(new_time/60);
         my_sec = num2str(new_time-(ch_min*60),'%0.2f');
         my_min = num2str(ch_min,'%0.0f');
         if ch_min>=60;
            ch_hrs = floor(ch_min/60);
            my_min = num2str(ch_min-(ch_hrs*60),'%0.0f');
            my_hrs = num2str(ch_hrs,'%0.0f');
         end;
      end;
      if size(my_sec,2)==4;
         my_sec = ['0' my_sec];
      end;
      if size(my_min,2)==1;
         my_min = ['0' my_min];
      end;
      if size(my_hrs,2)==1;
         my_hrs = ['0' my_hrs];
      end;
      clock_str = [my_hrs ':' my_min ':' my_sec];
      this_text = strvcat('The bootstrapping process took:',' ',['    ' clock_str ' (hrs:min:sec)']);
      about(this_text,'bootstrap','Simulation Time',120,350);
   end;
   %
   % if we don't cancel
   %
   if (strcmp(abort,'cancel')==0)&(isempty(eigen_test)==0);
      this_text = strvcat(' ','Saving bootstrap results to disk...','Please hold!');
      mywait = waitdlg(this_text,'bootstrap','Eigenvalue Fluctuation Test Bootstrap Simulation');
      waitf = get(mywait,'UserData');
      if get(boot_eigen.bootstrap,'Value')==1;
         if load_eps==0;
            this_text = strvcat(' ','Saving bootstrapped residuals to disk...','Please hold!');
            set(waitf.text,'String',this_text);
            save(epsfile,'bootstrap');
         end;
         clear('bootstrap');
         testfile = strrep(epsfile,'.mat',['-' 'eigen-data.mat']);
         test_data = eigen_test;
         save(testfile,'test_data');
         clear('test_data');
         set(boot_eigen.bootstrapgraph,'Enable','on','UserData',epsfile);
         set(boot_eigen.bootstrapgraphmenu,'Enable','on','UserData',testfile);
      end;
      setlogtext(['Bootstrap simulation completed at: ' datestr(now,14) '!']);
      %
      % sort the tests
      %
      eigen_test_sorted = [];
      for i=1:tm.r+1;
         eigen_test_sorted = [eigen_test_sorted sort(eigen_test(:,i))];
      end;
      clear('eigen_test');
      set(boot_eigen.rep,'UserData',rep);
      set(boot_eigen.obs,'UserData',my_T);
      set(boot_eigen.displaymenu,'Enable','on','UserData',tm.const_model);
      if tm.const_model(2)==1;
         my_mod = 'Restricted constant';
      elseif tm.const_model(3)==1;
         my_mod = 'Constant';
      elseif tm.const_model(4)==1;
         my_mod = 'Restricted linear trend';
      elseif tm.const_model(5)==1;
         my_mod = 'Linear trend';
      end;
      %
      % save full simulations
      %
      if get(boot_eigen.save,'Value')==1;
         this_text = strvcat(' ','Saving bootstrapped Hansen-Johansen fluctuation tests to disk...','Please hold!');
         set(waitf.text,'String',this_text);
         setlogtext('Saving results to mat-files...');
         if tm.const_model(1)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-full-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
         elseif tm.const_model(2)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-full-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
         elseif tm.const_model(3)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-full-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
         elseif tm.const_model(4)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-full-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
         elseif tm.const_model(5)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-full-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
         end;
         Number = (1:1:rep)';
         save(full_mat,'Number','eigen_test_sorted');
         set(boot_eigen.fullmenu,'Enable','on','UserData',full_mat);
         set(boot_eigen.full,'Enable','on');
      end;
      setlogtext('Saving simulation summary to text file...');
      %
      % dealing with the size of the test
      %
      boot_size = [];
      boot_pval = [];
      this_text = strvcat(' ','Determining the empirical size of the Hansen-Johansen fluctuation tests...','Please hold!');
      set(waitf.text,'String',this_text);
      my_cv = [];
      for i=1:5;
         if i==1;
            c = 0.99;
         elseif i==2;
            c = 0.98;
         elseif i==3;
            c = 0.95;
         elseif i==4;
            c = 0.9;
         elseif i==5;
            c = 0.8;
         end;
         my_cv = [my_cv;plobinv(c,1,0)];
      end;
      for i=1:5;
         boot_size_new = [];
         for i1=1:tm.r+1;
            for j=1:rep;
               if my_cv(i,1)>=eigen_test_sorted(rep+1-j,i1);
                  break;
               end;
            end;
            if (j<rep)|(my_cv(i,1)>=eigen_test_sorted(1,i1));
               boot_size_new = [boot_size_new (rep+1-j)/rep];
            else;
               boot_size_new = [boot_size_new 0];
            end;
         end;
         boot_size = [boot_size;boot_size_new];
      end;
      if tm.T==my_T;
         this_text = strvcat(' ','Determining the empirical p-value of the Hansen-Johansen fluctuation tests...','Please hold!');
         set(waitf.text,'String',this_text);
         for i1=1:tm.r+1;
            for j=1:rep;
               if tm.eigen_test(1,i1)>=eigen_test_sorted(rep+1-j,i1);
                  break;
               end;
            end;
            boot_pval = [boot_pval j/rep];
         end;
      end;
      this_text = strvcat(' ','Writing bootstrap summary information to disk...','Please hold!');
      set(waitf.text,'String',this_text);
      %
      % write summary to file
      %
      sp_str = spacestr(curr_ini.decimals-2);
      prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
      my_80 = floor(0.8*rep);
      my_90 = floor(0.9*rep);
      my_95 = floor(0.95*rep);
      my_975 = floor(0.98*rep);
      my_99 = floor(0.99*rep);
      res_str = strvcat(' ','**************************************************************','*                          Results                           *');
      res_str = strvcat(res_str,'**************************************************************',' ',['  Model:                   ' my_mod],['  Endogenous variables:    ' num2str(tm.n,'%0.0f')],['  Cointegration relations: ' num2str(tm.r,'%0.0f')],['  Replications:            ' num2str(rep,'%0.0f')],['  Draws per replication:   ' num2str(my_T,'%0.0f')],' ');
      if blocksize>1;
         res_str = strvcat(res_str,strrep(block_txt,'.',''),' ');
      end;
      res_str = strvcat(res_str,['            Hansen-Johansen Fluctuation tests for ' num2str(tm.r,'%0.0f') ' eigenvalues'],'            ---------------------------------------------------',' ',['Eigenvalue     80%   ' sp_str '   90%   ' sp_str '   95%   ' sp_str '   98%   ' sp_str '   99%   ' sp_str '   Mean ' sp_str ' Std. Dev.']);
      for i=1:tm.r;
         max_std = sqrt( (1/rep)*sum( ( eigen_test_sorted(:,i) - ( (1/rep)*sum(eigen_test_sorted(:,i)) ) ).*( eigen_test_sorted(:,i) - ( (1/rep)*sum(eigen_test_sorted(:,i)) ) ) ) );
         res_str = strvcat(res_str,sprintf(['    %2.0f     ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],i,eigen_test_sorted(my_80,i),eigen_test_sorted(my_90,i),eigen_test_sorted(my_95,i),eigen_test_sorted(my_975,i),eigen_test_sorted(my_99,i),(1/rep)*sum(eigen_test_sorted(:,i)),max_std));
      end;
      if tm.r>1;
         max_std = sqrt( (1/rep)*sum( ( eigen_test_sorted(:,tm.r+1) - ( (1/rep)*sum(eigen_test_sorted(:,tm.r+1)) ) ).*( eigen_test_sorted(:,tm.r+1) - ( (1/rep)*sum(eigen_test_sorted(:,tm.r+1)) ) ) ) );
         res_str = strvcat(res_str,sprintf(['   sum     ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],eigen_test_sorted(my_80,tm.r+1),eigen_test_sorted(my_90,tm.r+1),eigen_test_sorted(my_95,tm.r+1),eigen_test_sorted(my_975,tm.r+1),eigen_test_sorted(my_99,tm.r+1),(1/rep)*sum(eigen_test_sorted(:,tm.r+1)),max_std));
      end;
      res_str = strvcat(res_str,'From the asymptotic distribution we have the following quantile values:',sprintf(['           ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1)),' ');
      res_str = strvcat(res_str,'                      Empirical size','                      --------------',' ','Eigenvalue    20%    10%     5%     2%     1%');
      for i=1:tm.r;
         res_str = strvcat(res_str,sprintf('    %2.0f      %6.2f %6.2f %6.2f %6.2f %6.2f',i,100*(1-boot_size(5,i)),100*(1-boot_size(4,i)),100*(1-boot_size(3,i)),100*(1-boot_size(2,i)),100*(1-boot_size(1,i))));
      end;
      if tm.r>1;
         res_str = strvcat(res_str,sprintf('   sum      %6.2f %6.2f %6.2f %6.2f %6.2f',100*(1-boot_size(5,tm.r+1)),100*(1-boot_size(4,tm.r+1)),100*(1-boot_size(3,tm.r+1)),100*(1-boot_size(2,tm.r+1)),100*(1-boot_size(1,tm.r+1))));
      end;
      if isempty(boot_pval)==0;
         if tm.r>1;
            res_str = strvcat(res_str,' ','                      Empirical p-values','                      ------------------',' ');
         else;
            res_str = strvcat(res_str,' ','                      Empirical p-value','                      -----------------',' ');
         end;
         for i=1:tm.r;
            if curr_ini.transeig==1;
               res_str = strvcat(res_str,sprintf(['    sup tau(log[eig(%0.0f)/(1-eig(%0.0f))]) = ' prt_val ',  p-value = %0.' num2str(curr_ini.decimals,'%0.0f') 'f'],i,i,tm.eigen_test(1,i),boot_pval(1,i)));
            else;
               res_str = strvcat(res_str,sprintf(['                    sup tau(eig(%0.0f)) = ' prt_val ',  p-value = %0.' num2str(curr_ini.decimals,'%0.0f') 'f'],i,tm.eigen_test(1,i),boot_pval(1,i)));
            end;
         end;
         if tm.r>1;
            res_str = strvcat(res_str,sprintf(['sup tau(sum log[eig(i)/(1-eig(i))]) = ' prt_val ',  p-value = %0.' num2str(curr_ini.decimals,'%0.0f') 'f'],tm.eigen_test(1,tm.r+1),boot_pval(1,tm.r+1)));
         end;
      end;
      res_str = strvcat(res_str,' ');
      %
      res_str = strvcat(res_str,'**************************************************************',' ');
      %
      if tm.const_model(1)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-summary-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
      elseif tm.const_model(2)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-summary-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
      elseif tm.const_model(3)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-summary-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
      elseif tm.const_model(4)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-summary-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
      elseif tm.const_model(5)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-eigen-boot-summary-' bootstyle tm.transeig tm.updating num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
      end;
      fid_txt = fopen(file_txt,'wt');
      for i=1:size(res_str,1);
         fprintf(fid_txt,[strrep(res_str(i,:),'%','%%') '\n']);
      end;
      fprintf(fid_txt,['Output created on: ' datestr(now,0) '\n']);
      fclose(fid_txt);
      %
      % write to tex file
      %
      prt_val = ['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'];
      file_tex = strrep(file_txt,'.txt','.ltx');
      f_id = fopen(file_tex,'wt');
      fprintf(f_id,'\\begin{tabular}{ll}\n');
      fprintf(f_id,['Model: & ' my_mod ' \\\\\n']);
      fprintf(f_id,['\\#Endogenous variables: & ' num2str(tm.n,'%0.0f') ' \\\\\n']);
      fprintf(f_id,['\\#Cointegration relations: & ' num2str(tm.r,'%0.0f') ' \\\\\n']);
      fprintf(f_id,['\\#Replications: & ' num2str(rep,'%0.0f') ' \\\\\n']);
      fprintf(f_id,['\\#Draws per replication: & ' num2str(my_T,'%0.0f') ' \\\\\n']);
      if blocksize>1;
         fprintf(f_id,['Block size length: & ' num2str(blocksize,'%0.0f') ' \\\\\n']);
      end;
      fprintf(f_id,'\\end{tabular}\n\n');
      fprintf(f_id,'\\begin{tabular}{rrrrrrrr}\n');
      fprintf(f_id,['\\multicolumn{8}{c}{Hansen-Johansen Fluctuation tests for ' num2str(tm.r,'%0.0f') ' eigenvalues} \\\\\n']);
      fprintf(f_id,'Eigenvalue & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% & Mean & Std. Dev. \\\\\n');
      for i=1:tm.r;
         max_std = sqrt( (1/rep)*sum( ( eigen_test_sorted(:,i) - ( (1/rep)*sum(eigen_test_sorted(:,i)) ) ).*( eigen_test_sorted(:,i) - ( (1/rep)*sum(eigen_test_sorted(:,i)) ) ) ) );
         fprintf(f_id,['%0.0f & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],i,eigen_test_sorted(my_80,i),eigen_test_sorted(my_90,i),eigen_test_sorted(my_95,i),eigen_test_sorted(my_975,i),eigen_test_sorted(my_99,i),(1/rep)*sum(eigen_test_sorted(:,i)),max_std);
      end;
      if tm.r>1;
         max_std = sqrt( (1/rep)*sum( ( eigen_test_sorted(:,tm.r+1) - ( (1/rep)*sum(eigen_test_sorted(:,tm.r+1)) ) ).*( eigen_test_sorted(:,tm.r+1) - ( (1/rep)*sum(eigen_test_sorted(:,tm.r+1)) ) ) ) );
         fprintf(f_id,'\\multicolumn{8}{c}{ } \\\\\n');
         fprintf(f_id,['$\\sum_{i=1}^{%0.0f} \\xi_i$ & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],tm.r,eigen_test_sorted(my_80,tm.r+1),eigen_test_sorted(my_90,tm.r+1),eigen_test_sorted(my_95,tm.r+1),eigen_test_sorted(my_975,tm.r+1),eigen_test_sorted(my_99,tm.r+1),(1/rep)*sum(eigen_test_sorted(:,tm.r+1)),max_std);
      end;
      fprintf(f_id,'\\multicolumn{8}{c}{ } \\\\\n');
      fprintf(f_id,'\\multicolumn{8}{c}{From the asymptotic distribution we have the following quantile values:} \\\\\n');
      fprintf(f_id,[' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' &  &  \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1));
      fprintf(f_id,'\\end{tabular}\n\n');
      fprintf(f_id,'\\vspace*{2mm}\n\n\\begin{tabular}{rrrrrr}\n');
      fprintf(f_id,'\\multicolumn{6}{c}{Empirical size} \\\\\n');
      fprintf(f_id,'Eigenvalue & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
      for i=1:tm.r;
         fprintf(f_id,'%0.0f & %0.2f & %0.2f & %0.2f & %0.2f & %0.2f \\\\\n',i,100*(1-boot_size(5,i)),100*(1-boot_size(4,i)),100*(1-boot_size(3,i)),100*(1-boot_size(2,i)),100*(1-boot_size(1,i)));
      end;
      if tm.r>1;
         fprintf(f_id,'\\multicolumn{6}{c}{ } \\\\\n');
         fprintf(f_id,'$\\sum_{i=1}^{%0.0f} \\xi_i$ & %0.2f & %0.2f & %0.2f & %0.2f & %0.2f \\\\\n',tm.r,100*(1-boot_size(5,tm.r+1)),100*(1-boot_size(4,tm.r+1)),100*(1-boot_size(3,tm.r+1)),100*(1-boot_size(2,tm.r+1)),100*(1-boot_size(1,tm.r+1)));
      end;
      fprintf(f_id,'\\end{tabular}\n\n');
      if isempty(boot_pval)==0;
         fprintf(f_id,'\\vspace*{2mm}\n\n\\begin{tabular}{lll}\n');
         fprintf(f_id,'\\multicolumn{3}{c}{Empirical $p$-values} \\\\\n');
         if curr_ini.transeig==1;
            fprintf(f_id,'Eigenvalue & $\\sup \\tau_{t|T} (\\xi_i )$ & $p$-value \\\\\n');
         else;
            fprintf(f_id,'Eigenvalue & $\\sup \\tau_{t|T} (\\lambda_i )$ & $p$-value \\\\\n');
         end;
         for i=1:tm.r;
            fprintf(f_id,['%0.0f & ' prt_val ' & ' prt_val ' \\\\ \n'],i,tm.eigen_test(1,i),boot_pval(1,i));
         end;
         if tm.r>1;
            fprintf(f_id,'\\multicolumn{3}{c}{ } \\\\\n');
            fprintf(f_id,' & $\\sup \\tau_{t|T} (\\sum_{i=1}^{%0.0f} \\xi_i )$ & $p$-value \\\\\n',tm.r);
            fprintf(f_id,[' & ' prt_val ' & ' prt_val ' \\\\ \n'],tm.eigen_test(1,tm.r+1),boot_pval(1,tm.r+1));
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
      end;
      fprintf(f_id,'\\ruler\n\n%%*************************************************************\n');
      fclose(f_id);
      %
      set(boot_eigen.display,'UserData',eigen_test_sorted);
      clear('eigen_test_sorted');
      %
      if curr_ini.noprint==0;
         set(boot_eigen.output,'Enable','on');
      end;
      set(boot_eigen.summarymenu,'Enable','on','UserData',file_txt);
      set(boot_eigen.summary,'Enable','on');
      set(boot_eigen.display,'Enable','on');
      set(boot_eigen.displaymenu,'Enable','on');
      set(boot_eigen.histogram,'Enable','on');
      set(boot_eigen.histogrammenu,'Enable','on');
      set(boot_eigen.matfilebutton,'Enable','on');
      set(boot_eigen.matfilemenu,'Enable','on');
      set(waitf.text,'UserData','done');
      delete(mywait);
      drawnow;
   else;
      setlogtext('Cancelled...');
   end;
   tm.eigen_run = 0;
   set(eigen_boot_gui,'Visible','on');
case 'done'
   if tm.eigen_run==0;
      set(boot_eigen.done,'UserData','done');
      pid = get(boot_eigen.filemenu,'UserData');
      if isempty(pid)==1;
         delete(eigen_boot_gui);
      else;
         close(eigen_boot_gui);
      end;
   end;
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(eigen_boot_gui,'Name') ' ' fix_filepath([pwd '\icons\bootstrap.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(boot_eigen.filemenu,'UserData',pid);
         set(eigen_boot_gui,'CloseRequestFcn','killwinpid');
      end;
   end;
   set(eigen_boot_gui,'Visible','on');
end;

if strcmp(selector,'done')==0;
   curr_ini.models = tm;
   curr_ini.images = button_images;
   set(boot_eigen.matfilebutton,'UserData',curr_ini);
end;

if my_exit==1;
   waitfor(boot_eigen.done,'UserData','done');
end;

%
% end of eigen_bootstrap.m
%
