%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab function for determining the sample            %
%                                                                %
%          Function: getsample                                   %
%                                                                %
%          Input:                                                %
%          	            curr_model: structure with model info    %
%                       file: datafile                           %
%                       sheet: name of sheet (xls files only)    %
%                                                                %
%          Output:                                               %
%                       curr_model: structure with revised       %
%                          model info                            %
%                                                                %
%          This version:        June 1, 2004                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2004          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function curr_model = getsample(curr_model,file,sheet)

curr_model.beginyear = strrep(curr_model.beginyear,' ','');
curr_model.beginperiod = strrep(curr_model.beginperiod,' ','');
curr_model.endyear = strrep(curr_model.endyear,' ','');
curr_model.endperiod = strrep(curr_model.endperiod,' ','');
curr_model.subbeginyear = strrep(curr_model.subbeginyear,' ','');
curr_model.subbeginperiod = strrep(curr_model.subbeginperiod,' ','');
curr_model.subendyear = strrep(curr_model.subendyear,' ','');
curr_model.subendperiod = strrep(curr_model.subendperiod,' ','');

A = loaddata(file,sheet);
if isempty(A)==1;
   curr_model.fp = [];
   curr_model.lp = [];
   curr_model.freq = '';
   curr_model.samplebeg = [];
   curr_model.sampleend = [];
   return;
end;

[n T] = size(A);

if n>T;
   [n T] = size(A');
end;

curr_model.fp = 1;
curr_model.lp = T;

curr_model.samplebeg = 0;
curr_model.sampleend = 0;

curr_model.freq = '';

%
% if there are no valid inputs for curr_model.beginyear and curr_model.endyear, assume
% yearly data and return
%

if (isempty(mystr2num(curr_model.beginyear))==1)|(isempty(mystr2num(curr_model.endyear))==1);
   curr_model.fp = 1;
   curr_model.lp = T;
   curr_model.samplebeg = 1;
   curr_model.sampleend = T;
%   curr_model.freq = 'y';
   curr_model.beginperiod = '1';
   curr_model.endperiod = '1';
   curr_model.subbeginyear = '1';
   curr_model.subbeginperiod = '1';
   curr_model.subendyear = num2str(T);
   curr_model.subendperiod = '1';
   return;
end;

%
% check which frequency the actual sample matches is any
%

beg = mystr2num(curr_model.beginyear);

n1 = mystr2num(curr_model.beginperiod);
if isempty(n1)==1;
   n1 = 1;
end;
n1 = n1/4;
beg = beg+n1;

endp = mystr2num(curr_model.endyear);
if endp<=mystr2num(curr_model.beginyear);
   curr_model.fp = [];
   curr_model.lp = [];
   curr_model.freq = '';
   curr_model.samplebeg = [];
   curr_model.sampleend = [];
   return;
end;
n1 = mystr2num(curr_model.endperiod);
if isempty(n1)==1;
   n1 = 1;
end;
n1 = n1/4;
endp = endp+n1;

start = beg;
count = 0;
while start<=endp;
   start = start+(1/4);
   count = count+1;
end;

if count==T;
   curr_model.freq = 'q';
else;
   %
   % check if monthly
   %
   beg = mystr2num(curr_model.beginyear);
   n1 = mystr2num(curr_model.beginperiod);
   if isempty(n1)==1;
      n1 = 1;
   end;
   n1 = n1/12;
   beg = beg+n1;

   endp = mystr2num(curr_model.endyear);
   n1 = mystr2num(curr_model.endperiod);
   if isempty(n1)==1;
      n1 = 1;
   end;
   n1 = n1/12;
   endp = endp+n1;

   start = beg;
   count1 = 0;
   while start<=endp;
      start = start+(1/12);
      count1 = count1+1;
   end;

   if count1==T;
      curr_model.freq = 'm';
   else;
      %
      % check if yearly
      %
      beg = mystr2num(curr_model.beginyear);
      endp = mystr2num(curr_model.endyear);

      start = beg;
      count2 = 0;
      while start<=endp;
         start = start+1;
         count2 = count2+1;
      end;

      if count2==T;
         curr_model.freq = 'y';
      end;
   end;
end;

if strcmp(curr_model.freq,'')==1;
   curr_model.fp = [];
   curr_model.lp = [];
   curr_model.freq = '';
   curr_model.samplebeg = [];
   curr_model.sampleend = [];
   return;
end;

%
% Determine base curr_model.samplebeg and curr_model.sampleend
%

curr_model.samplebeg = mystr2num(curr_model.beginyear);
add = mystr2num(curr_model.beginperiod);
if isempty(add)==1;
   add = 1;
   curr_model.beginperiod = '1';
end;
curr_model.sampleend = mystr2num(curr_model.endyear);
add2 = mystr2num(curr_model.endperiod);
if isempty(add2)==1;
   add2 = 1;
   curr_model.endperiod = '1';
end;
if strcmp(curr_model.freq,'q')==1;
   add = add/4;
   add2 = add2/4;
elseif strcmp(curr_model.freq,'m')==1;
   add = add/12;
   add2 = add2/12;
else;
   add = 0;
   add2 = 0;
end;
oldsamplebeg = curr_model.samplebeg;
curr_model.samplebeg = curr_model.samplebeg+add;
oldsampleend = curr_model.sampleend;
curr_model.sampleend = curr_model.sampleend+add2;

%
% Checking subsample beginning
%

beg = mystr2num(curr_model.subbeginyear);
add = mystr2num(curr_model.subbeginperiod);

if isempty(add)==1;
   add = 1;
   curr_model.subbeginperiod = '1';
end;

if strcmp(curr_model.freq,'q')==1;
   if add>4;
      add = 4;
      curr_model.subbeginperiod = '4';
   end;
   add = add/4;
elseif strcmp(curr_model.freq,'m')==1;
   if add>12;
      add = 12;
      curr_model.subbeginperiod = '12';
   end;
   add = add/12;
else;
   add = 0;
   curr_model.subbeginperiod = '1';
end;

if isempty(beg)==1;
   beg = oldsamplebeg;
   curr_model.subbeginyear = curr_model.beginyear;
elseif beg<oldsamplebeg;
   beg = oldsamplebeg;
   curr_model.subbeginyear = curr_model.beginyear;
elseif beg==oldsamplebeg;
   if (beg+add)<curr_model.samplebeg;
      beg = oldsamplebeg;
      curr_model.subbeginyear = curr_model.beginyear;
      curr_model.subbeginperiod = curr_model.beginperiod;
   end;
elseif beg>=oldsampleend;
   beg = oldsamplebeg;
   curr_model.subbeginyear = curr_model.beginyear;
end;

newsamplebeg = beg+add;

if newsamplebeg<curr_model.samplebeg;
   newsamplebeg = curr_model.samplebeg;
   curr_model.subbeginyear = curr_model.beginyear;
   curr_model.subbeginperiod = curr_model.beginperiod;
end;

%
% Checking subsample end
%

endp = mystr2num(curr_model.subendyear);
add2 = mystr2num(curr_model.subendperiod);

if isempty(add2)==1;
   add2 = mystr2num(curr_model.endperiod);
   curr_model.subendperiod = curr_model.endperiod;
end;

if isempty(add2)==1;
   add2 = 1;
   curr_model.subendperiod = '1';
end;

if strcmp(curr_model.freq,'q')==1;
   if add2>4;
      add2 = 4;
      curr_model.subendperiod = '4';
   end;
   add2 = add2/4;
elseif strcmp(curr_model.freq,'m')==1;
   if add2>12;
      add2 = 12;
      curr_model.subendperiod = '12';
   end;
   add2 = add2/12;
else;
   add2 = 0;
   curr_model.subendperiod = '1';
end;

if isempty(endp)==1;
   endp = oldsampleend;
   curr_model.subendyear = curr_model.endyear;
elseif endp>oldsampleend;
   endp = oldsampleend;
   curr_model.subendyear = curr_model.endyear;
elseif endp==oldsampleend;
   if (endp+add2)>curr_model.sampleend;
      endp = oldsampleend;
      curr_model.subendyear = curr_model.endyear;
      curr_model.subendperiod = curr_model.endperiod;
   end;
elseif endp<=beg;
   endp = oldsampleend;
   curr_model.subendyear = curr_model.endyear;
end;

newsampleend = endp+add2;

if newsampleend>curr_model.sampleend;
   newsampleend = curr_model.sampleend;
   curr_model.subendyear = curr_model.endyear;
   curr_model.subendperiod = curr_model.endperiod;
end;

%
% determining new curr_model.fp and curr_model.lp
%

if strcmp(curr_model.freq,'q')==1;
   add = 1/4;
elseif strcmp(curr_model.freq,'m')==1;
   add = 1/12;
else;
   add = 1;
end;

count = 1;
start = curr_model.samplebeg;

while start<=curr_model.sampleend;
   if strcmp(num2str(start,'%1.4f'),num2str(newsamplebeg,'%1.4f'))==1;
      curr_model.fp = count;
   elseif strcmp(num2str(start,'%1.4f'),num2str(newsampleend,'%1.4f'))==1;
      curr_model.lp = count;
   end;
   start = start+add;
   count = count+1;
end;

curr_model.samplebeg = newsamplebeg;
curr_model.sampleend = newsampleend;

%
% end of getsample.m
%