%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI for determining the restrictions on alpha  %
%                                                                %
%          Function: gmatdlg                                     %
%                                                                %
%          Input:                                                %
%                        selector: case switch function          %
%                        cm: structure with model info           %
%                                                                %
%          Output:                                               %
%                        h: handle                               %
%                        and gmat to G-modelfile.rest            %
%                                                                %
%          This version:        May 18, 2006                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = gmatdlg(selector,cm)

if strcmp(selector,'init')==1;
   tm = cm;
   curr_ini = find_inisettings;
   myvars = vecstr(tm.evars);
   thisexit = 0;
   %
   % Determining the number of restrictions (default value)
   % and the maximum number of parameters per restriction
   %
   tm.oldG = tm.G;
   tm.numres = size(tm.G,1);
   tm.numelem = floor(size(tm.G,2)/3);
   if size(tm.G)==[1 6];
      if tm.G==zeros(1,6);
         myclear = 'off';
      else;
         myclear = 'on';
      end;
   else;
      myclear = 'on';
   end;
   %
   % Setting the screensize, height and width
   %
   realscrsz = get(0,'ScreenSize');
   heightf = tm.numres*20+(tm.numres-1)*2+46;
   widthf = 210+(tm.numelem-1)*115;
   if widthf<357;
      widthf = 357;
   elseif widthf+28>realscrsz(3);
      widthf = realscrsz(3)-28;
   end;
   if heightf>realscrsz(4)-200;
      heightf = realscrsz(4)-200;
   end;
   height = heightf+150;
   width = widthf+28;
   thiselem = floor((realscrsz(3)-123)/115);
   %
   numresstr = '1';
   for i=2:tm.n*tm.r;
      numresstr = [numresstr '|' num2str(i)];
   end;
   numelemstr = '1';
   for i=2:min([tm.n*tm.r thiselem]);
      numelemstr = [numelemstr '|' num2str(i)];
   end;
   if tm.numelem>min([(tm.n-1)*tm.r thiselem]);
      tm.numelem = min([(tm.n-1)*tm.r thiselem]);
      tm.G = [tm.G(:,1:2+3*(tm.numelem-1)) tm.G(:,size(tm.G,2))];
   end;
else;
   thisexit = 1;
   gmatgui = get(0,'CurrentFigure');
   gmat = get(gmatgui,'UserData');
   curr_ini = get(gmat.undo,'UserData');
   tm = curr_ini.models;
end;

switch selector;
   case 'init';
      
      fix_height = 0;
      if height>realscrsz(4)-154;
         height = realscrsz(4)-154;
         heightf = height-150;
         fix_height = 1;
         header_height = heightf+98;
         if (widthf)-(210+((tm.numelem-1)*115))<20;
            widthf = 230+((tm.numelem-1)*115);
            width = widthf+28;
         end;
      end;
      
      gmatgui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','gmatdlg.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(realscrsz(3)-width)/2 (realscrsz(4)-height-100)/2 width height+100], ...
         'Tag','FigParent', ...
         'Resize','off', ...
         'Name','Restrictions on Alpha', ...
         'NumberTitle','off', ...
         'Visible','off', ...
         'CloseRequestFcn','gmatdlg exit', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(gmatgui,'DockControl','off');
      end;

      %
      % Outer axis
      %

      axesbox([2 2 width-2 height+90],['Select Alpha Restrictions - Alpha is ' num2str(tm.n) 'x' num2str(tm.r)],195,[0.5 1]);

      %
      % GUI Header
      %

      mycons = getstoredimages;
      header_txt = 'Alpha Restrictions';
      desc_txt = 'Select the number of overidentifying restrictions you''d like to impose, the maximum number of parameters per restriction, and enter the restrictions. Press "Done" to finish or "Cancel" to cancel.';
      dialog_header_fcn([14 height-5 widthf 82],mirrorimage(maketrans(mycons.alpharestbig_image,[160 160 164],[1 1 1])),header_txt,desc_txt);

      %
      % Outer axis for G matrix
      %

      axesbox([14 128 widthf heightf],'Restrictions',60,[0.5 1]);
      
      %
      % Outer axis for restrictions parameter controls
      %

      axesbox([14 14 width-130 100],'Restriction Parameters',110,[0.5 1]);

      %
      % Edit control for element (i,j) in Gmat
      %
      
      gmat.editcontrols = [];
      gmat.restcontrols = [];

      for i=1:tm.numres;

         s1 = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[26 140+(i-1)*22 70 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','text', ...
            'HorizontalAlignment','right', ...
            'String',['Restriction ' num2str(tm.numres-i+1) ':'], ...
            'Tag',['RestText_1_' int2str(i)]);

         s2 = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[100 140+(i-1)*22 5 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','text', ...
            'HorizontalAlignment','center', ...
            'String','(', ...
            'Tag',['RestText_2_' int2str(i)]);

         gmat.editbox1 = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[105 142+(i-1)*22 30 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','edit', ...
            'HorizontalAlignment','left', ...
            'String',num2str(tm.G(tm.numres-i+1,1)), ...
            'Enable','on', ...
            'Callback','gmatdlg checkelement', ...
            'UserData',[tm.numres-i+1 1 tm.G(tm.numres-i+1,1)], ...
            'Tag',['EditBox_' int2str(tm.numres-i+1) '_' int2str(1)]);

         s3 = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[135 140+(i-1)*22 5 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','text', ...
            'HorizontalAlignment','center', ...
            'String',',', ...
            'Tag',['RestText_3_' int2str(i)]);

         gmat.editbox2 = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[140 142+(i-1)*22 30 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','edit', ...
            'HorizontalAlignment','left', ...
            'String',num2str(tm.G(tm.numres-i+1,2)), ...
            'Enable','on', ...
            'Callback','gmatdlg checkelement', ...
            'UserData',[tm.numres-i+1 2 tm.G(tm.numres-i+1,2)], ...
            'Tag',['EditBox_' int2str(tm.numres-i+1) '_' int2str(2)]);

         s4 = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[170 140+(i-1)*22 5 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','text', ...
            'HorizontalAlignment','center', ...
            'String',')', ...
            'Tag',['RestText_4_' int2str(i)]);

         if i==tm.numres;

            s5 = uicontrol('Units','pixels', ...
               'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
               'Position',[105 140+tm.numres*22 65 20], ...
               'FontSize',curr_ini.gui_fontsize, ...
               'FontName',curr_ini.gui_fontname, ...
               'FontWeight',curr_ini.gui_fontweight, ...
               'FontAngle',curr_ini.gui_fontangle, ...
               'Style','text', ...
               'HorizontalAlignment','center', ...
               'String','Row,Column', ...
               'Tag','RowCol_1');
            
         else;
            s5 = [];
         end;
         
         new_controls = [];
         s10_controls = [];
         rest_controls = [];
         
         for j=1:tm.numelem-1;

            s6 = uicontrol('Units','pixels', ...
               'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
               'Position',[175+(j-1)*115 140+(i-1)*22 5 20], ...
               'FontSize',curr_ini.gui_fontsize, ...
               'FontName',curr_ini.gui_fontname, ...
               'FontWeight',curr_ini.gui_fontweight, ...
               'FontAngle',curr_ini.gui_fontangle, ...
               'Style','text', ...
               'HorizontalAlignment','center', ...
               'String','+', ...
               'Tag',['RestText_5_' int2str(i)]);

            gmat.editbox3 = uicontrol('Units','pixels', ...
               'BackgroundColor',[0.6 1 1], ...
               'Position',[180+(j-1)*115 142+(i-1)*22 30 20], ...
               'FontSize',curr_ini.gui_fontsize, ...
               'FontName',curr_ini.gui_fontname, ...
               'FontWeight',curr_ini.gui_fontweight, ...
               'FontAngle',curr_ini.gui_fontangle, ...
               'Style','edit', ...
               'HorizontalAlignment','left', ...
               'String',num2str(tm.G(tm.numres-i+1,3+3*(j-1))), ...
               'Enable','on', ...
               'Callback','gmatdlg checkelement', ...
               'UserData',[tm.numres-i+1 3+3*(j-1) tm.G(tm.numres-i+1,3+3*(j-1))], ...
               'Tag',['EditBox_' int2str(tm.numres-i+1) '_' int2str(3+3*(j-1))]);

            s7 = uicontrol('Units','pixels', ...
               'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
               'Position',[210+(j-1)*115 140+(i-1)*22 10 20], ...
               'FontSize',curr_ini.gui_fontsize, ...
               'FontName',curr_ini.gui_fontname, ...
               'FontWeight',curr_ini.gui_fontweight, ...
               'FontAngle',curr_ini.gui_fontangle, ...
               'Style','text', ...
               'HorizontalAlignment','center', ...
               'String','x(', ...
               'Tag',['RestText_6_' int2str(i)]);

            gmat.editbox4 = uicontrol('Units','pixels', ...
               'BackgroundColor',[1 1 1], ...
               'Position',[220+(j-1)*115 142+(i-1)*22 30 20], ...
               'FontSize',curr_ini.gui_fontsize, ...
               'FontName',curr_ini.gui_fontname, ...
               'FontWeight',curr_ini.gui_fontweight, ...
               'FontAngle',curr_ini.gui_fontangle, ...
               'Style','edit', ...
               'HorizontalAlignment','left', ...
               'String',num2str(tm.G(tm.numres-i+1,4+3*(j-1))), ...
               'Enable','on', ...
               'Callback','gmatdlg checkelement', ...
               'UserData',[tm.numres-i+1 4+3*(j-1) tm.G(tm.numres-i+1,4+3*(j-1))], ...
               'Tag',['EditBox_' int2str(tm.numres-i+1) '_' int2str(4+3*(j-1))]);

            s8 = uicontrol('Units','pixels', ...
               'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
               'Position',[250+(j-1)*115 140+(i-1)*22 5 20], ...
               'FontSize',curr_ini.gui_fontsize, ...
               'FontName',curr_ini.gui_fontname, ...
               'FontWeight',curr_ini.gui_fontweight, ...
               'FontAngle',curr_ini.gui_fontangle, ...
               'Style','text', ...
               'HorizontalAlignment','center', ...
               'String',',', ...
               'Tag',['RestText_7_' int2str(i)]);

            gmat.editbox5 = uicontrol('Units','pixels', ...
               'BackgroundColor',[1 1 1], ...
               'Position',[255+(j-1)*115 142+(i-1)*22 30 20], ...
               'FontSize',curr_ini.gui_fontsize, ...
               'FontName',curr_ini.gui_fontname, ...
               'FontWeight',curr_ini.gui_fontweight, ...
               'FontAngle',curr_ini.gui_fontangle, ...
               'Style','edit', ...
               'HorizontalAlignment','left', ...
               'String',num2str(tm.G(tm.numres-i+1,5+3*(j-1))), ...
               'Enable','on', ...
               'Callback','gmatdlg checkelement', ...
               'UserData',[tm.numres-i+1 5+3*(j-1) tm.G(tm.numres-i+1,5+3*(j-1))], ...
               'Tag',['EditBox_' int2str(tm.numres-i+1) '_' int2str(5+3*(j-1))]);

            s9 = uicontrol('Units','pixels', ...
               'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
               'Position',[285+(j-1)*115 140+(i-1)*22 5 20], ...
               'FontSize',curr_ini.gui_fontsize, ...
               'FontName',curr_ini.gui_fontname, ...
               'FontWeight',curr_ini.gui_fontweight, ...
               'FontAngle',curr_ini.gui_fontangle, ...
               'Style','text', ...
               'HorizontalAlignment','center', ...
               'String',')', ...
               'Tag',['RestText_8_' int2str(i)]);

            if i==tm.numres;

               s10 = uicontrol('Units','pixels', ...
                  'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
                  'Position',[220+(j-1)*115 140+tm.numres*22 65 20], ...
                  'FontSize',curr_ini.gui_fontsize, ...
                  'FontName',curr_ini.gui_fontname, ...
                  'FontWeight',curr_ini.gui_fontweight, ...
                  'FontAngle',curr_ini.gui_fontangle, ...
                  'Style','text', ...
                  'HorizontalAlignment','center', ...
                  'String','Row,Column', ...
                  'Tag',['RowCol_' int2str(j+1)]);

            else;
               s10 = [];
            end;
            
            new_controls = [new_controls s6 gmat.editbox3 s7 gmat.editbox4 s8 gmat.editbox5 s9];
            s10_controls = [s10_controls s10];
            rest_controls = [rest_controls gmat.editbox3 gmat.editbox4 gmat.editbox5];
            
         end;

         s11 = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[175+(tm.numelem-1)*115 140+(i-1)*22 5 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','text', ...
            'HorizontalAlignment','center', ...
            'String','=', ...
            'Tag',['RestText_9_' int2str(i)]);

         gmat.editbox6 = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 0.6], ...
            'Position',[180+(tm.numelem-1)*115 142+(i-1)*22 30 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','edit', ...
            'HorizontalAlignment','left', ...
            'String',num2str(tm.G(tm.numres-i+1,tm.numelem*3)), ...
            'Enable','on', ...
            'Callback','gmatdlg checkelement', ...
            'UserData',[tm.numres-i+1 tm.numelem*3 tm.G(tm.numres-i+1,tm.numelem*3)], ...
            'Tag',['EditBox_' int2str(tm.numres-i+1) '_' int2str(tm.numelem*3)]);

         gmat.editcontrols = [[s1 s2 gmat.editbox1 s3 gmat.editbox2 s4 new_controls s11 gmat.editbox6];gmat.editcontrols];
         gmat.restcontrols = [[s1 gmat.editbox1 gmat.editbox2 rest_controls gmat.editbox6];gmat.restcontrols];

      end;
      
      gmat.headercontrols = [s5 s10_controls];
      
      %
      % fix positions of controls if need by and add sliders
      %
      
      if fix_height==1;
         for i=1:size(gmat.headercontrols,2);
            pos = get(gmat.headercontrols(1,i),'Position');
            pos(2) = header_height;
            set(gmat.headercontrols(1,i),'Position',pos);
         end;
         hpos = header_height-22;
         c_rows = 0;
         gmat.vpositions = [];;
         for i=1:size(gmat.editcontrols,1);
            if hpos>=140;
               gmat.vpositions = [gmat.vpositions;hpos];
               for j=1:size(gmat.editcontrols,2);
                  pos = get(gmat.editcontrols(i,j),'Position');
                  if strcmp(get(gmat.editcontrols(i,j),'Style'),'text')==1;
                     pos(2) = hpos;
                  elseif strcmp(get(gmat.editcontrols(i,j),'Style'),'edit')==1;
                     pos(2) = hpos+2;
                  end;
                  set(gmat.editcontrols(i,j),'Position',pos);
               end;
               last_pos = hpos;
               hpos = hpos-22;
               c_rows = c_rows+1;
            else;
               hpos = 0;
               for j=1:size(gmat.editcontrols,2);
                  pos = get(gmat.editcontrols(i,j),'Position');
                  pos(2) = 0;
                  set(gmat.editcontrols(i,j),'Position',pos,'Visible','off');
               end;
            end;
         end;
         gmat.c_rows = c_rows;
         %
         % add a vertical slider
         %
         slider_pos = [pos(1)+30 last_pos 20 header_height-last_pos];
         %
         gmat.vslider = uicontrol('Units','pixels', ...
            'BackgroundColor',(get(0,'defaultuicontrolbackgroundcolor')+[1 1 1])/2, ...
            'Position',slider_pos, ...
            'Style','slider', ...
            'Min',gmat.c_rows, ...
            'Max',size(gmat.editcontrols,1), ...
            'Value',size(gmat.editcontrols,1), ...
            'Callback','gmatdlg vslider', ...
            'Enable','on', ...
            'Tag','VerticalSlider');

         if 2/(size(gmat.editcontrols,1)-gmat.c_rows)<=1;
            set(gmat.vslider,'SliderStep',[1/(size(gmat.editcontrols,1)-gmat.c_rows) 2/(size(gmat.editcontrols,1)-gmat.c_rows)]);
         else;
            set(gmat.vslider,'SliderStep',[0.9 1.0],'UserData',1);
         end;

      end;

      %
      % Number of restrictions control
      %

      gmat.text = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 70 120 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','left', ...
         'UserData',tm.G, ...
         'String','Number of restrictions:', ...
         'Tag','NumResText');


      gmat.numres = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[width-175 75 45 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Value',tm.numres, ...
         'String',numresstr, ...
         'UserData','done', ...
         'CallBack','gmatdlg changeGmat', ...
         'Tag','NumResPopup');

      %
      % Number of parameters control
      %

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 30 180 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','left', ...
         'String','Maximum #parameters per restriction:', ...
         'Tag','NumParmText');

      gmat.numelem = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[width-175 35 45 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Value',tm.numelem, ...
         'String',numelemstr, ...
         'CallBack','gmatdlg changeGmat', ...
         'UserData','working', ...
         'Tag','NumElemPopup');

      %
      % Undo button
      %

      gmat.undo = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-100 95 85 20], ...
         'String','Undo', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','gmatdlg undo', ...
         'Enable','off', ...
         'Tag','UndoButton');

      %
      % Clear button
      %

      gmat.clear = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-100 70 85 20], ...
         'String','Clear', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','gmatdlg clear', ...
         'Enable',myclear, ...
         'Tag','ClearButton');

      %
      % Done button
      %

      gmat.continue = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-100 45 85 20], ...
         'String','Done', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','gmatdlg exit', ...
         'UserData','waiting', ...
         'Enable','on', ...
         'Tag','ContinueButton');

      %
      %  Cancel button
      %

      gmat.cancel = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-100 20 85 20], ...
         'String','Cancel', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','gmatdlg cancel', ...
         'Enable','on', ...
         'UserData',0, ...
         'Tag','CancelButton');

      set(gmatgui,'UserData',gmat,...
         'HandleVisibility','callback');

   case 'vslider'
      slider_val = get(gmat.vslider,'Value');
      if isempty(get(gmat.vslider,'UserData'))==0;
         if isequal(slider_val,round(slider_val))==0;
            slider_val = round(slider_val);
            set(gmat.vslider,'Value',slider_val);
         end;
      end;
      if isint(slider_val)==0;
         slider_val = round(slider_val);
      end;
      set(gmat.restcontrols,'Visible','off');
      first_con = size(gmat.restcontrols,1)-slider_val+1;
      last_con = first_con+gmat.c_rows-1;
      num = 1;
      for i=first_con:last_con;
         for j=1:size(gmat.restcontrols,2);
            pos = get(gmat.restcontrols(i,j),'Position');
            if j==1;
               pos(1,2) = gmat.vpositions(num,1);
            else;
               pos(1,2) = gmat.vpositions(num,1)+2;
            end;
            set(gmat.restcontrols(i,j),'Position',pos,'Visible','on');
         end;
         num = num+1;
      end;
   case 'undo'
      set(gmat.text,'UserData',tm.oldG);
      set(gmat.numres,'UserData','redraw');
      set(gmatgui,'UserData',gmat);
      gmatdlg('exit');
   case 'changeGmat'
      newnumres = get(gmat.numres,'Value');
      newnumelem = get(gmat.numelem,'Value');
      change = 0;
      if newnumres>tm.numres;
         tm.G = [tm.G;zeros(newnumres-tm.numres,3*tm.numelem)];
         tm.numres = newnumres;
         change = 1;
      elseif newnumres<tm.numres;
         tm.G = tm.G(1:newnumres,:);
         tm.numres = newnumres;
         change = 1;
      end;
      if newnumelem>tm.numelem;
         tm.G = [tm.G(:,1:size(tm.G,2)-1) zeros(size(tm.G,1),(newnumelem-tm.numelem)*3) tm.G(:,size(tm.G,2))];
         change = 1;
      elseif newnumelem<tm.numelem;
         tm.G = [tm.G(:,1:2+3*(newnumelem-1)) tm.G(:,size(tm.G,2))];
         change = 1;
      end;
      if change==1;
         set(gmat.text,'UserData',tm.G);
         set(gmat.numres,'UserData','redraw');
         set(gmatgui,'UserData',gmat);
         gmatdlg('exit');
      else;
      end;
   case 'checkelement'
      whichelem = gcbo;
      currelem = get(whichelem,'Userdata');
      if isempty(currelem)==0;
         currvalue = get(whichelem,'String');
         currvalue = strrep(currvalue,',','.');
         currvalue = mystr2num(currvalue);
         if isempty(currvalue)==0;
            %
            % check if value is row or col and adjust it
            % if necessary (i.e. row,col must be an integer
            % and row =1,...,n   col=1,...,r
            %
            type_var = 0;
            if floor(currelem(1,2)/3)<(currelem(1,2)/3);
               for i=1:tm.numelem;
                  for j=1:2;
                     k=j+3*(i-1);
                     if round(k)==round(currelem(1,2));
                        type_var = j;
                        j = 3;
                        i = tm.numelem+1;
                     end;
                  end;
               end;
               currvalue = floor(currvalue);
               if type_var==1;
                  if (currvalue<1)|(currvalue>tm.n);
                     currvalue = 0;
                  end;
               else;
                  if (currvalue<1)|(currvalue>tm.r);
                     currvalue = 0;
                  end;
               end;
            end;
            tm.G(currelem(1,1),currelem(1,2)) = currvalue(1,1);
            set(whichelem,'UserData',[currelem(1,1:2) currvalue(1,1)]);
            set(whichelem,'String',num2str(currvalue(1,1)));
            if get(whichelem,'BackgroundColor')==[1 1 1];
               set(whichelem,'BackgroundColor',[1 0.75 0.75]);
            elseif get(whichelem,'BackgroundColor')==[0.6 1 1];
               set(whichelem,'BackgroundColor',[0.2 1 1]);
            elseif get(whichelem,'BackgroundColor')==[1 1 0.6];
               set(whichelem,'BackgroundColor',[1 1 0.2]);
            end;
            set(gmat.undo,'Enable','on');
            if strcmp(get(gmat.clear,'Enable'),'off')==1;
               set(gmat.clear,'Enable','on');
            end;
         else;
            set(whichelem,'String',num2str(currelem(1,3)));
         end;
      end;
   case 'exit'
      cancel = get(gmat.cancel,'UserData');
      if cancel==1;
         closeexit = 1;
      else;
         closeexit = 1;
         if strcmp(get(gmat.numres,'UserData'),'redraw')==0;
            if strcmp(get(gmat.continue,'UserData'),'done')==0;
               [Rmat,rvec] = rmatrix(tm.G,tm.n,tm.r);
               if rank(Rmat)==size(tm.G,1);
                  checkalpha = null(Rmat,'r');
                  checkalpha = checkalpha*randn(size(checkalpha,2),1);
                  checkalpha = checkalpha+((Rmat'/(Rmat*Rmat'))*rvec);
                  checkalpha = vecinv(checkalpha,tm.n);
                  if rank(checkalpha)==tm.r;
                     file = strcat(tm.modelsdir,'G-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
                     myprintstr = '%2.4f';
                     for i=2:size(tm.G,2);
                        myprintstr = [myprintstr ' %2.4f'];
                     end;
                     myprintstr = [myprintstr '\n'];
                     fid = fopen(file,'wt');
                     fprintf(fid,myprintstr,tm.G');
                     fclose(fid);
                  else;
                     closeexit = 0;
                     txt = ['The restrictions you have specified implies that alpha has rank ' num2str(rank(checkalpha)) ', i.e. less than the number of cointegration vectors. Please respecify or select ''Cancel''!'];
                     about(txt,'warning',['Restrictions on Alpha - Information'],130,500);
                  end;
               else;
                  closeexit = 0;
                  if tm.numres>1;
                     txt = ['The ' num2str(tm.numres) ' restrictions you have specified for alpha are linearly dependent, i.e. the rank of the restrictions matrix is ' num2str(rank(Rmat)) '. Please respecify or select ''Cancel''!'];
                  else;
                     txt = 'You haven''t specified a proper restriction for alpha. Please respecify or select ''Cancel''!';
                  end;
                  about(txt,'warning',['Restrictions on Alpha - Information'],130,500);
               end;
            end;
         end;
      end;
      if closeexit==1;
         set(gmatgui,'Visible','off');
         drawnow;
         set(gmat.continue,'UserData','done');
         if strcmp(get(gmat.numelem,'UserData'),'done')==1;
%            delete(gmatgui);
         end;
      end;
   case 'clear'
      if curr_ini.sillyq==0;
         txt = 'Are you sure you want to empty the set of restrictions?';
         answer = query(txt,'question',120,'Clear Restrictions',350,'no');
      else;
         answer = 'Yes';
      end;
      if strcmp(answer,'Yes')==1;
         set(gmat.text,'UserData',zeros(1,6));
         set(gmat.numres,'UserData','redraw');
         set(gmatgui,'UserData',gmat);
         gmatdlg('exit');
      end;
   case 'cancel'
      set(gmat.cancel,'UserData',1);
      set(gmatgui,'UserData',gmat);
      gmatdlg('exit');
end;


if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(gmatgui,'Name') ' ' fix_filepath([pwd '\icons\alpharest.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(gmat.clear,'UserData',pid);
      end;
   end;
   set(gmatgui,'Visible','on');
   drawnow;
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(gmatgui,'Name') ' 1'];
      dos(prog);
      drawnow;
   elseif matlabnumber>7;
      uicontrol(gmat.cancel);
   end;
end;

if nargout==1;
   h = gmatgui;
end;

curr_ini.models = tm;
set(gmat.undo,'UserData',curr_ini);

if thisexit==0;
   waitfor(gmat.continue,'UserData','done');
end;

%
% end of gmatdlg.m
%
