function [ir,stdvec,betair,betair_std,abort,outvd] = impulses_vlaar_fcn(mm,type_var,B_0,Sigma_B0,gamma,C,dC_theta,h,S,R_mat,R_l,Psi,alpha,beta,Sigma_theta,waitbar,name_bool)

betair = [];
betair_std = [];

if nargin<17;
   name_bool = 0;
end;

r = size(alpha,2);
if r>0;
   Pi = alpha*beta(1:mm.n,:)';
else;
   Pi = zeros(mm.n,mm.n);
end;
if mm.p>=2;
   Phi = Psi(:,mm.d+1:mm.d+mm.n*(mm.p-1));
end;

ip = zeros(mm.p,mm.p);
for i=1:mm.p;
   for j=1:mm.p;
      if j>=i;
         ip(j,i)=1;
      end;
   end;
end;

%
% Computing levels VAR coefficients from
% VECM coefficients
%

ip = kron(ip,eye(mm.n));
J = eye(mm.n);
if mm.p>=2;
   M = [(Pi+eye(mm.n)) -Phi];
   M = M/ip;
   M = [M;[eye(mm.n*(mm.p-1)) zeros(mm.n*(mm.p-1),mm.n)]];
   J = [J zeros(mm.n,mm.n*(mm.p-1))];
else;
   M = (Pi+eye(mm.n))/ip;
end;

ir = [vec(B_0) zeros(mm.n*mm.n,h)];

for i=1:h;
   if i==1;
      M_i = M;
   else;
      M_i = M_i*M;
   end;
   B_i = J*M_i*J'*B_0;
   ir(:,i+1) = vec(B_i);
end;

if r>0;
   bir = kron(eye(mm.n),beta(1:mm.n,:)')*ir;
end;

if strcmp(type_var,'short_run')==0;
   %
   % computing dvec(B)/dtheta' through a number of steps
   %
   %
   % 1. computing dvec(R)/dvec(C)'
   %
   dR_C = dr_c(R_l,mm.n);
   %
   % 2. computing dvec(S)/dvec(R)'
   %
   dS_R = ds_r(S,R_mat);
   %
   % 3. computing dvec(Omega)/dgamma'
   %
   dO_g = do_g(B_0,S);
   %
   % 4. computing dvec(Omega)/vec(R)'
   %
   dO_R = do_r(B_0,R_mat);
   %
   % 5. computing dgamma/dvec(R)'
   %
   dg_R = dg_r(dO_R,dO_g);
   %
   % 6. computing dvec(B)/dvec(R)'
   %
   dB_R = db_r(dS_R,dg_R,gamma,S,mm.n);
   %
   % 7. computing dvec(B)/dvec(theta)'
   %
   dB_theta = dB_R*dR_C*dC_theta;
else;
   if size(Sigma_theta,1)>(mm.n*mm.d);
      dB_theta = zeros(mm.n*mm.n,size(Sigma_theta,1)-(mm.n*mm.d));
   end;
end;

%
% Now we can compute dvec(C_i)/dtheta'
% and                dvec(C_i)/dvec(B)'
% to obtain the asymptotic covariance matrices
% of vec(C_i) for i=1,...,h.
%


%
% Computing partials for contemporaneous response
%

D_2 = eye(mm.n*mm.n);
if size(Sigma_theta,1)>(mm.n*mm.d);
   D_3 = dB_theta;
   J_gamma = j_gamma(mm.n,mm.p,mm.pe,r,mm.d,mm.q1,mm.q0);
   J_alpha = j_alpha(mm.n,mm.p,mm.pe,r,mm.d,mm.q1,mm.q0);
   J_fix = [J_gamma;J_alpha];
   J_fix = kron(J_fix,eye(mm.n));
   Sigma_theta = J_fix*Sigma_theta*J_fix';
   CovB_j = (D_3*Sigma_theta*D_3')+Sigma_B0;
else;
   D_3 = [];
   Sigma_theta = [];
   CovB_j = Sigma_B0;
end;
stdvec = [sqrt(abs(diag(CovB_j))) zeros(mm.n*mm.n,h)];
if r>0;
   betair_vcv = kron(eye(mm.n),beta(1:mm.n,:)')*CovB_j*kron(eye(mm.n),beta(1:mm.n,:));
   betair_std = [sqrt(abs(diag(betair_vcv))) zeros(r*mm.n,mm.h)];
end;
vd.Sigma_theta = Sigma_theta;
vd.Sigma_B0 = Sigma_B0;
vd.partial(1).theta = D_3;
vd.partial(1).B_0 = eye(size(Sigma_B0,2));

%
% Create the W matrix, needed to compute D_1
%

if mm.p>1;
   ip = inverse(ip);
   ip(1:mm.n,mm.n*(mm.p-1)+1:mm.n*mm.p) = eye(mm.n);
   ip(mm.n*(mm.p-1)+1:mm.n*mm.p,mm.n*(mm.p-1)+1:mm.n*mm.p) = zeros(mm.n,mm.n);
end;
if r>0;
   if mm.p==1;
      W = beta(1:mm.n,:);
   else;
      W = [[eye(mm.n*(mm.p-1)) zeros(mm.n*(mm.p-1),r)];[zeros(mm.n,mm.n*(mm.p-1)) beta(1:mm.n,:)]];
   end;
   W = ip*W;
else;
   if mm.p==1;
      W = [];   % need to remember this case
   else;
      W = [eye(mm.n*(mm.p-1));zeros(mm.n,mm.n*(mm.p-1))];
      W = ip*W;
   end;
end;

abort = '';
if isempty(W)==0;
   %
   % set up a progress-bar if called for
   %
   if waitbar==1;
      curr_ini = find_inisettings;
      realscrsz = get(0,'ScreenSize');
      if name_bool==0;
         input_var.title = ['Progress for ' int2str(h) ' impulse responses'];
      else;
         input_var.title = ['Progress for ' int2str(h) ' variance decompositions'];
      end;
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.label = 'Response number:';
      input_var.stop = 0;
      input_var.clock = 0;
      if name_bool==0;
         input_var.name = 'Impulse Response Functions';
%         set(mywait,'Name','Impulse Response Functions');
      else;
         input_var.name = 'Variance Decompositions';
%         set(mywait,'Name','Variance Decompositions');
      end;
      mywait = progressdlg(0,input_var);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
      drawnow;
   end;
   %
   M_j = eye(mm.n*mm.p);
   for j=1:h;
      if waitbar==1;
         if j==1;
            drawnow;
            progressdlg([(1/h) 1]);
         else;
            abort = get(mywait,'UserData');
            if strcmp(abort,'cancel')==1;
               break;
            else;
               progressdlg([(j/h) j]);
            end;
         end;
      end;
      %
      M_j = M_j*M;
      %
      % Using the notation from Vlaar (1998):
      %
      % Computing the partials: D(2,j) = dvec(B_j)/dvec(B_0)'
      %
      D_2j = J*M_j*J';
      D_2j = kron(eye(mm.n),D_2j);
      %
      % Computing the partials: D(3,j) = (dvec(B_j)/dvec(B_0)')*(dvec(B_0)/dtheta')
      % conditional on C_j, where B_j = C_j*B_0
      %
      D_3j = D_2j*D_3;
      D_1j = zeros(mm.n*mm.n,mm.n*(mm.n*(mm.p-1)+r));
      for i=0:j-1;
         if i==0;
            M_2 = eye(mm.n*mm.p);
         else;
            M_2 = M_2*M;
         end;
         M_1 = eye(mm.n*mm.p);
         for i1=1:j-1-i;
            M_1 = M_1*M';
         end;
         d_11 = B_0'*J*M_1*W;
         d_12 = J*M_2*J';
         %
         % Computing the partials D(1,j) = dvec(B_j)/dtheta' conditional on B_0
         %
         D_1j = D_1j+kron(d_11,d_12);
      end;
      %
      % Computing the partials: dvec(B_j)/dtheta'
      %
      D_thetaj = D_1j+D_3j;
      %
      % Computing the asymptotic covariance matrix for B_j
      %
      CovB_j = (D_thetaj*Sigma_theta*D_thetaj')+(D_2j*Sigma_B0*D_2j');
      vd.partial(j+1).theta = D_thetaj;
      vd.partial(j+1).B_0 = D_2j;
      stdvec(:,j+1) = sqrt(abs(diag(CovB_j)));
      if r>0;
         betair_vcv = kron(eye(mm.n),beta(1:mm.n,:)')*CovB_j*kron(eye(mm.n),beta(1:mm.n,:));
         betair_std(:,j+1) = sqrt(abs(diag(betair_vcv)));
      end;
   end;
   %
   % delete the progress dialog if it was opened
   %
   if waitbar==1;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   end;
else;
   stdvec = stdvec(:,1)*ones(1,h+1);
   if r>0;
      betair_std = betair_std(:,1)*ones(1,h+1);
   end;
end;

if nargout==6;
   outvd = vd;
end;

%
% end of impulses_vlaar_fcn.m
%
