function rec_marg_like = marginal_likelihood_rank(tm,file)

%
% open a wait dialog
%

mywait = waitdlg(strvcat(' ','Initializing...','Please wait!'),'bootstrap','Recursive Marginal Likelihoods',450,124);
waitf = get(mywait,'UserData');


if tm.amat_type==1;
   if tm.amat_lag==1;
      A = tm.rank(tm.n+1).Omega;
   else;
      A = tm.amat_val;
   end;
   q = tm.n+2;
else;
   A = tm.lambda_a*eye(tm.n);
   q = tm.q_parm;
end;
if (tm.prior_inf_shortrun==2)&(tm.prior_inf_deter==2);
   %
   % improper priors on delta and Gamma
   %
   if isempty(tm.Z2)==0;
      Z = tm.Z2;
      z = det(Z*Z');
      N = eye(tm.T)-Z'*inverse(Z*Z')*Z;
      num_z = size(tm.Z2,1);
   else;
      z = 1;
      N = eye(tm.T);
      num_z = 0;
   end;
elseif (tm.prior_inf_shortrun==1)&(tm.prior_inf_deter==2);
   %
   % improper prior on delta
   %
   if isempty(tm.Z2)==0;
      if tm.d>0;
         D = tm.Z2(1:tm.d,:);
         M_D = eye(tm.T)-(D'*inverse(D*D')*D);
      else;
         D = 1;
         M_D = eye(tm.T);
      end;
      if size(tm.Z2,1)>tm.d;
         Z2 = tm.Z2(tm.d+1:size(tm.Z2,1),:);
         G_sigma = tm.prior.shortrun.sigma;
         N = M_D-(M_D*Z2'*inverse(((Z2*M_D*Z2')+inverse(G_sigma)))*Z2*M_D);
         z = det(G_sigma)*det(D*D')*det(((Z2*M_D*Z2')+inverse(G_sigma)));
      else;
         N = M_D;
         z = det(D*D');
      end;
   else;
      N = eye(tm.T);
      z = 1;
   end;
   num_z = tm.d;
elseif (tm.prior_inf_shortrun==2)&(tm.prior_inf_deter==1);
   %
   % improper prior on Gamma
   %
   if isempty(tm.Z2)==0;
      if tm.d>0;
         D_sigma = tm.prior.deter.sigma;
         D = tm.Z2(1:tm.d,:);
         if size(tm.Z2)>tm.d;
            Z2 = tm.Z2(tm.d+1:size(tm.Z2,1),:);
            M_Z2 = eye(tm.T)-(Z2'*inverse(Z2*Z2')*Z2);
            N = M_Z2-(M_Z2*D'*inverse(((D*M_Z2*D')+inverse(D_sigma)))*D*M_Z2);
            z = det(D_sigma)*det(Z2*Z2')*det(((D*M_Z2*D')+inverse(D_sigma)));
            num_z = size(Z2,1);
         else;
            N = eye(tm.T)-D'*inverse(((D*D')+inverse(D_sigma)))*D;
            z = det(D_sigma)*det(((D*D')+inverse(D_sigma)));
            num_z = 0;
         end;
      else;
         Z2 = tm.Z2;
         M_Z2 = eye(tm.T)-(Z2'*inverse(Z2*Z2')*Z2);
         N = M_Z2;
         z = det(Z2*Z2');
         num_z = size(Z2,1);
      end;
   else;
      N = eye(tm.T);
      z = 1;
      num_z = 0;
   end;
else;
   %
   % proper priors on delta and Gamma
   %
   if isempty(tm.Z2)==0;
      D_sigma = tm.prior.deter.sigma;
      G_sigma = tm.prior.shortrun.sigma;
      Z = tm.Z2;
      if tm.d>0;
         if size(tm.Z2)>tm.d;
            F_sigma = [[D_sigma zeros(tm.d,size(G_sigma,1))];[zeros(size(G_sigma,1),tm.d) G_sigma]];
         else;
            F_sigma = D_sigma;
         end;
      else;
         F_sigma = G_sigma;
      end;
      N = eye(tm.T)-(Z'*inverse(((Z*Z')+inverse(F_sigma)))*Z);
      z = det(F_sigma)*det(((Z*Z')+inverse(F_sigma)));
   else;
      N = eye(tm.T);
      z = 1;
   end;
   num_z = 0;
end;

C_1 = (tm.Z1*N*tm.Z1')+((1/(tm.lambda_alpha^2))*eye(tm.n));
S = A+(tm.Z0*N*tm.Z0')-(tm.Z0*N*tm.Z1'*inverse(C_1)*tm.Z1*N*tm.Z0');

log_k1 = ((q/2)*log(det(A)))-( ((tm.T-num_z)*(tm.n/2)*log(pi)) + ((tm.n/2)*log(z)) + gamma_product(tm.n,q) );

%
% first compute log marginal likelihoods for r=0 and r=n
%

rec_marg_like(1).log_marg_like = log_k1 + gamma_product(tm.n,tm.T+q-num_z) - ( ((tm.T+q-num_z)/2)*log(det(A+(tm.Z0*N*tm.Z0'))) );
rec_marg_like(1).nse_marglike = 0;
rec_marg_like(tm.n+1).log_marg_like = log_k1 + gamma_product(tm.n,tm.T+q-num_z) - ((tm.n*tm.n)*log(tm.lambda_alpha)) - ((tm.n/2)*log(det(C_1))) - (((tm.T+q-num_z)/2)*log(det(S)));
rec_marg_like(tm.n+1).nse_marglike = 0;

for r=1:tm.n-1;
   txt = strvcat(' ',['Computing the marginal likelihood recursively over all saved draws from 200 draws until ' num2str(tm.save_draws,'%0.0f') ' draws for cointegration rank ' num2str(r,'%0.0f') '...'],'Please wait.');
   set(waitf.text,'String',txt);
   drawnow;
   %
   % load the correct file
   %
   r_file = strrep(file,['rank-gibbs-' num2str(tm.scale_endo,'%0.4f')],['rank-' num2str(r,'%0.0f') '-' num2str(tm.scale_endo,'%0.4f') '-gibbs']);
   f = load(r_file);
   alpha = f.results.posterior_mode.alpha;
   beta = f.results.posterior_mode.beta;
   c_mat = tm.rank(r+1).c_mat;
   c_mat_orth = tm.rank(r+1).c_mat_orth;
   %
   % Now we compute the initial parts for determining ther marginal likelihood
   %
   % Step 1: The numerator
   %
   W = tm.Z0-(alpha*beta'*tm.Z1);
   Q = A+((1/(tm.lambda_alpha^2))*alpha*beta'*beta*alpha')+(W*N*W');
   log_numerator = log_k1 + gamma_product(tm.n,tm.T+q+r-num_z) + gamma_product(r,tm.n,r) - ((( ((2*tm.n)-r)*r)/2)*log(pi)) - ((tm.n*r)*log(tm.lambda_alpha)) - (((tm.T+q+r-num_z)/2)*log(det(Q)));
   %
   % Step 2: The marginal conditional distribution of the free beta parameters conditional on alpha and the data
   %
   Psi = inverse(c_mat_orth'*c_mat_orth)*c_mat_orth'*beta;
   %
   % compute the moments for the matrix t and the degrees of freedom
   %
   df = tm.T+q+r-tm.n-num_z;
   K = [c_mat*inverse(c_mat'*c_mat) c_mat_orth*inverse(c_mat_orth'*c_mat_orth)]';
   Pi_hat = tm.Z0*N*tm.Z1'*inverse(C_1);
   beta_hat = K*Pi_hat'*inverse(S)*alpha*inverse(alpha'*inverse(S)*alpha);
   beta_hat_1 = beta_hat(1:r,1:r);
   beta_hat_2 = beta_hat(r+1:tm.n,1:r);
   G = (K*inverse(C_1)*K')+(K*Pi_hat'*inverse(S)*Pi_hat*K')-(beta_hat*alpha'*inverse(S)*alpha*beta_hat');
   G_1 = G(1:r,1:r);
   G_2 = G(1:r,r+1:tm.n);
   G_3 = G(r+1:tm.n,r+1:tm.n);
   beta_dev = eye(r)-beta_hat_1;
   Psi_hat = beta_hat_2+(G_2'*inverse(G_1)*beta_dev);
   C_3 = (beta_dev'*inverse(G_1)*beta_dev)+inverse(alpha'*inverse(S)*alpha);
   G_adj = inverse(G_3-(G_2'*inverse(G_1)*G_2));
   log_beta_marg_like = matrix_t_density(Psi_hat,G_adj,C_3,df,Psi);
   %
   % Step 3: The marginal distribution of alpha conditional on the data
   %
   tm.rankfilenames = f.rankfilenames;
   clear('f');
   %
   draw_file = strtrim(tm.rankfilenames(r+1,:));
   %
   % load gibbs draws
   %
   gibbs_output = load(draw_file);
   alpha_marg_like = 0;
   df = df-r;
   check_beta = isfield(gibbs_output.gibbs_results.posterior(1),'beta_n');
   c_alpha_dens = zeros(tm.save_draws,1);
   rec_marg_like(r+1).log_marg_like = zeros(1,tm.save_draws);
   rec_marg_like(r+1).nse_marglike = zeros(1,tm.save_draws);
   for i=1:tm.save_draws;
      if check_beta==1;
         beta_hat = gibbs_output.gibbs_results.posterior(i).beta_n;
      else;
         beta_hat = gibbs_output.gibbs_results.posterior(i).beta;
      end;
      alpha_hat = tm.Z0*N*tm.Z1'*beta_hat*inverse(beta_hat'*C_1*beta_hat);
      W = tm.Z0-(alpha_hat*beta_hat'*tm.Z1);
      P_mat = inverse(A+(tm.Z0*N*W'));
      Q_mat = inverse(beta_hat'*C_1*beta_hat);
      c_alpha_dens(i,1) = matrix_t_exp_density(alpha_hat,P_mat,Q_mat,df,alpha);
      alpha_marg_like = alpha_marg_like+((1/tm.save_draws)*c_alpha_dens(i,1));
      if i>=200;
         log_alpha_marg_like = log(alpha_marg_like)+gamma_product(r,df+tm.n+r,df+r)-(((tm.n*r)/2)*log(pi));
         rec_marg_like(r+1).log_marg_like(1,i) = log_numerator-log_beta_marg_like-log_alpha_marg_like;
         temp_c_alpha_dens = c_alpha_dens(1:i,1)-alpha_marg_like;
         auto_cov_alpha = auto_corr_fcn(temp_c_alpha_dens,0.01);
         rec_marg_like(r+1).nse_marglike(1,i) = sqrt(newey_west_fcn(auto_cov_alpha,i))/alpha_marg_like;
      end;
      drawnow;
   end;
   clear('gibbs_output');
end;

%
% shut down the wait dialog
%

set(waitf.text,'UserData','done');
delete(mywait);
drawnow;

%
% end of marginal_likelihood_rank.m
%
