%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for bootstrapping the supTS test    %
%          for 1 versus 2 regimes when the regime process is a   %
%          2-state Markov switching process                      %
%                                                                %
%          Function: markov_bootstrap                            %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       cm: structure with model info            %
%                                                                %
%          Output:                                               %
%                                                                %
%          This version:        July 10, 2006                    %
%          Written by:          Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function markov_bootstrap(varargin)

%
% GUI for bootstrapping the Markov switching regimes test due to Carrasco, Hu and Ploberger
%

selector = varargin{1};
if (nargin==0)|(strcmp(selector,'init')==1);
   tm = varargin{2};
   %
   % initialize information structure about MS tests
   %
   if tm.restrict(1,2)==0;
      for i=0:tm.n;
         for j=1:7;
            tm.rank(i+1).mstest_type(j).initialized = '';
         end;
      end;
   else;
      for j=1:7;
         tm.mstest_type(j).initialized = '';
      end;
   end;
   %
   % toolbar images
   %
   button_images = read_images;
   %
   % more initialization
   %
   selector = 'init';
   my_exit = 1;
   tm.const_model = [0 0 0 0 0];
   if tm.deterselect(1)==1;
      tm.const_model(3) = 1;
   elseif tm.deterselect(2)==1
      tm.const_model(2) = 1;
   elseif tm.deterselect(3)==1;
      tm.const_model(5) = 1;
   else;
      tm.const_model(4) = 1;
   end;
   %
   % Set screen size directly instead of using
   % get(0,'ScreenSize')!
   %
   tm.realscrsz = get(0,'ScreenSize');
   tm.markov_run = 0;
   %
   % read var.in
   %
   curr_ini = find_inisettings;
   my_T = tm.T;
   rep = curr_ini.nRep;
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   nRep_value = 1;
   for i=1:size(repvalues,2);
      if curr_ini.nRep==repvalues(1,i);
         nRep_value = i;
         break;
      end;
   end;
   if direxist(curr_ini.simulatedir)==0;
      mystatus = makedirs(curr_ini.simulatedir);
   else;
      mystatus = 2;
   end;
   if mystatus==0;
      curr_ini.simulatedir = pwd;
      if ispc==1;
         curr_ini.simulatedir = [curr_ini.simulatedir '\'];
      end;
   end;
   if isnumeric(curr_ini.external)==0;
      curr_ini.external = 0;
   end;
   %
   tm.ms_model = '1-';
   %
   if curr_ini.parametric==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(curr_ini.blocksize) '-'];
   end;
   if tm.restrict(1,2)==0;
      tm.beta_rest = '';
   else;
      tm.beta_rest = 'beta-';
   end;
   tm.hvec = '1-';
   full_mat = '';
   tm.mp_ud = '20-';
   tm.ul_ud = '20-';
   if tm.const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-markov-boot-full-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
   elseif tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-markov-boot-full-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-markov-boot-full-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-markov-boot-full-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-markov-boot-full-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
      view_enable = 'on';
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      markov_mat = load(full_mat);
      markov_test_sorted = markov_mat.markov_test_sorted;
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
   else;
      view_enable = 'off';
      markov_test_sorted = [];
      full_mat = '';
      full_enable = 'off';
   end;
   summary_txt = '';
   if tm.const_model(1)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-markov-boot-summary-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
      mod_type = 'noconst';
      model_type = 'No Constant';
   elseif tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-markov-boot-summary-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
      mod_type = 'resconst';
      model_type = 'Restricted Constant';
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-markov-boot-summary-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
      mod_type = 'const';
      model_type = 'Constant';
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-markov-boot-summary-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
      mod_type = 'restrend';
      model_type = 'Restricted Linear Trend';
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-markov-boot-summary-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
      mod_type = 'trend';
      model_type = 'Linear Trend';
   end;
%   if curr_ini.texoutputformat>=2;
%      summary_txt = strrep(summary_txt,'.txt','.ltx');
%   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
   end;
   %
   % check if file with bootstrapped residuals exists
   %
   epsfile = [curr_ini.simulatedir tm.modelfile '-' 'markov-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
   testfile = strrep(epsfile,'.mat',['-' 'markov-data.mat']);
   if fileexist(epsfile)==1;
      boot_enable = 'on';;
   else;
      epsfile = '';
      testfile = '';
      boot_enable = 'off';
   end;
   %
   tm.interpolate = curr_ini.interpolate;
   if strcmp(tm.interpolate,'nearest')==1;
      tm.interpolate_value = 1;
   elseif strcmp(tm.interpolate,'linear')==1;
      tm.interpolate_value = 2;
   elseif strcmp(tm.interpolate,'spline')==1;
      tm.interpolate_value = 3;
   elseif strcmp(tm.interpolate,'cubic')==1;
      tm.interpolate_value = 4;
   elseif strcmp(tm.interpolate,'knorm')==1;
      tm.interpolate_value = 5;
   elseif strcmp(tm.interpolate,'kepan')==1;
      tm.interpolate_value = 6;
   elseif strcmp(tm.interpolate,'krect')==1;
      tm.interpolate_value = 7;
   elseif strcmp(tm.interpolate,'ktria')==1;
      tm.interpolate_value = 8;
   elseif strcmp(tm.interpolate,'kbiwe')==1;
      tm.interpolate_value = 9;
   elseif strcmp(tm.interpolate,'ktriw')==1;
      tm.interpolate_value = 10;
   elseif strcmp(tm.interpolate,'klapl')==1;
      tm.interpolate_value = 11;
   elseif strcmp(tm.interpolate,'klogi')==1;
      tm.interpolate_value = 12;
   end;
else;
   my_exit = 0;
   markov_boot_gui = findobj('Type','figure','Tag','MarkovBoot')';
   boot_markov = get(markov_boot_gui,'UserData');
   curr_ini = get(boot_markov.matfilebutton,'UserData');
   tm = curr_ini.models;
   button_images = curr_ini.images;
end;

switch selector
case 'init'
   markov_boot_gui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','markov_bootstrap.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(tm.realscrsz(3)-560)/2 (tm.realscrsz(4)-460)/2 560 460], ...
         'Tag','MarkovBoot', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name','Bootstrap Distributions for Markov Switching Test', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','markov_bootstrap done', ...
         'ToolBar','none');

   if matlabnumber>=7.0;
      set(markov_boot_gui,'DockControl','off');
   end;

   if strcmp(curr_ini.helpexe,'')==1;
      helpenable = 'off';
   else;
      helpenable = 'on';
   end;

   %
   % File menu
   %

   filemenu = uimenu('Parent',markov_boot_gui, ...
      'Label','&File', ...
      'Tag','FileMenu');

   boot_markov.runtestmenu = uimenu('Parent',filemenu, ...
         'Label','&Compute Test', ...
         'Callback','markov_bootstrap runtest', ...
         'Enable','on', ...
         'Accelerator','T', ...
         'Tag','RunTestMenu');

   boot_markov.simulatemenu = uimenu('Parent',filemenu, ...
         'Label','&Run Bootstrap', ...
         'Callback','markov_bootstrap simulate', ...
         'Enable','on', ...
         'Separator','on', ...
         'Accelerator','R', ...
         'Tag','SimulateMenu');

   boot_markov.matfilemenu = uimenu('Parent',filemenu, ...
         'Label','Save to m&at-file', ...
         'Separator','on', ...
         'Accelerator','A', ...
         'Enable',full_enable, ...
         'Callback','markov_bootstrap matfile', ...
         'Tag','MatFileMenu');

   boot_markov.summarymenu = uimenu('Parent',filemenu, ...
         'Label','&Simulation Summary', ...
         'Separator','on', ...
         'Callback','markov_bootstrap summary', ...
         'UserData',summary_txt, ...
         'Accelerator','S', ...
         'Enable',summary_enable, ...
         'Tag','SummaryMenu');

   boot_markov.fullmenu = uimenu('Parent',filemenu, ...
         'Label','&Full Simulation', ...
         'Callback','markov_bootstrap full', ...
         'Accelerator','F', ...
         'UserData',full_mat, ...
         'Enable',full_enable, ...
         'Tag','FullMenu');

   if curr_ini.noprint==0;
      boot_markov.output = uimenu('Parent',filemenu, ...
            'Label','Append to &Output', ...
            'Separator','on', ...
            'Callback','markov_bootstrap output', ...
            'Accelerator','O', ...
            'Enable',summary_enable, ...
            'Tag','SummaryMenu');
   end;

   uimenu('Parent',filemenu, ...
         'Label','Center &Window', ...
         'Separator','on', ...
         'Accelerator','W', ...
         'Enable','on', ...
         'Callback','center_figure_fcn', ...
         'Tag','CenterMenu');

   boot_markov.returnmenu = uimenu('Parent',filemenu, ...
         'Label','R&eturn', ...
         'Separator','on', ...
         'Callback','markov_bootstrap done', ...
         'Enable','on', ...
         'Tag','MenuFileReturn');

   boot_markov.filemenu = filemenu;

   %
   % Graph Menu
   %

   graphmenu = uimenu('Parent',markov_boot_gui, ...
      'Label','&Graphics', ...
      'Tag','GraphMenu');

   boot_markov.bootstrapgraphmenu = uimenu('Parent',graphmenu, ...
         'Label','Graph &Bootstrap Sample', ...
         'Callback','markov_bootstrap display_bootstrap', ...
         'Accelerator','B', ...
         'UserData',testfile, ...
         'Enable',boot_enable, ...
         'Tag','BootstrapGraphMenu');

   boot_markov.displaymenu = uimenu('Parent',graphmenu, ...
         'Label','&Graph Distribution', ...
         'Callback','markov_bootstrap display', ...
         'Separator','on', ...
         'Accelerator','G', ...
         'UserData',tm.const_model, ...
         'Enable',view_enable, ...
         'Tag','DisplayMenu');

   boot_markov.histogrammenu = uimenu('Parent',graphmenu, ...
         'Label','&Histogram of Distribution', ...
         'Callback','markov_bootstrap display', ...
         'Accelerator','D', ...
         'Enable',view_enable, ...
         'Tag','HistogramMenu');

   %
   % Help Menu
   %

   helpmenu = uimenu('Parent',markov_boot_gui, ...
      'Label','&Help', ...
      'Tag','HelpMenu');

   boot_markov.helpmenu = uimenu('Parent',helpmenu, ...
         'Label','&Help Topics', ...
         'Callback','help_fcn(''bootstrapping'')', ...
         'Accelerator','H', ...
         'Enable',helpenable, ...
         'Tag','HelpMenu');

   %
   % The toolbar
   %

   boot_markov.toolbar = uitoolbar('Parent',markov_boot_gui, ...
                     'HandleVisibility','off', ...
                     'Interruptible','on', ...
                     'Clipping','on');

   if (iswinxp==0)|(matlabnumber<7);
      xline([1 459 560],[0.5 1]);
   end;

   boot_markov.runtest = uipushtool('Parent',boot_markov.toolbar, ...
                      'TooltipString','Compute Test', ...
                      'CData',button_images.estimate, ...
                      'ClickedCallback','markov_bootstrap runtest', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable','on', ...
                      'Tag','RunTest');

   boot_markov.simulate = uipushtool('Parent',boot_markov.toolbar, ...
                      'TooltipString','Run Bootstrap', ...
                      'CData',button_images.simulate, ...
                      'ClickedCallback','markov_bootstrap simulate', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable','on', ...
                      'UserData',0, ...
                      'Tag','Simulate');


   boot_markov.matfilebutton = uipushtool('Parent',boot_markov.toolbar, ...
                      'TooltipString','Save to mat-file', ...
                      'CData',button_images.matfile, ...
                      'ClickedCallback','markov_bootstrap matfile', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','MatFileButton');

   boot_markov.summary = uipushtool('Parent',boot_markov.toolbar, ...
                      'TooltipString','View Simulation Summary', ...
                      'CData',button_images.sim_summary, ...
                      'ClickedCallback','markov_bootstrap summary', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',summary_enable, ...
                      'Tag','SummaryButton');

   boot_markov.full = uipushtool('Parent',boot_markov.toolbar, ...
                      'TooltipString','View Full Simulation', ...
                      'CData',button_images.sim_full, ...
                      'ClickedCallback','markov_bootstrap full', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','FullButton');

   boot_markov.bootstrapgraph = uipushtool('Parent',boot_markov.toolbar, ...
                      'TooltipString','Graph Bootstrap Sample', ...
                      'CData',button_images.bootstrapsmall, ...
                      'ClickedCallback','markov_bootstrap display_bootstrap', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',epsfile, ...
                      'Clipping','on', ...
                      'Enable',boot_enable, ...
                      'Tag','ViewBootstrapButton');

   boot_markov.display = uipushtool('Parent',boot_markov.toolbar, ...
                      'TooltipString','Graph Distribution', ...
                      'CData',button_images.viewdist, ...
                      'ClickedCallback','markov_bootstrap display', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',markov_test_sorted, ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','ViewDistButton');

   boot_markov.histogram = uipushtool('Parent',boot_markov.toolbar, ...
                      'TooltipString','Histogram of Distribution', ...
                      'CData',button_images.bars, ...
                      'ClickedCallback','markov_bootstrap display', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','HistogramButton');

   boot_markov.help = uipushtool('Parent',boot_markov.toolbar, ...
                      'TooltipString','Help Topics', ...
                      'CData',button_images.help, ...
                      'ClickedCallback','help_fcn(''bootstrapping'')', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',helpenable, ...
                      'Tag','HelpButton');

   boot_markov.done = uipushtool('Parent',boot_markov.toolbar, ...
                      'TooltipString','Return', ...
                      'CData',button_images.continue, ...
                      'ClickedCallback','markov_bootstrap done', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'UserData','waiting', ...
                      'Enable','on', ...
                      'Tag','Done');

   axesbox([2 2 558 445],'Markov Switching Test',110,[0.5 1]);

   %
   % GUI Header
   %

   header_txt = ['Markov Switching Test (' model_type ' Model)'];
   desc_txt = 'Select the type of bootstrap you wish to perform, the number of observations and replications. Press the "Run Bootstrap" button when you''re satisfied with your choices and wait for the computations to finish.';
   dialog_header_fcn([16 361 530 70],button_images.bootstrap,header_txt,desc_txt);

   %
   % Options
   %

   axesbox([16 130 155 215],'Options',35,[0.5 1]);

   boot_markov.clock = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 307.5 130 20], ...
      'Value',1, ...
      'String','Show elapsed time', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','TimeCheck');

   boot_markov.progress = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 275 130 20], ...
      'Value',1, ...
      'String','Show progress dialog', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ProgressCheck');

   boot_markov.save = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 242.5 130 20], ...
      'Value',1, ...
      'String','Save full simulation', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','SaveCheck');

   boot_markov.parametric = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 210 130 20], ...
      'Value',curr_ini.parametric, ...
      'String','Parametric bootstrap', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'Callback','markov_bootstrap fixobscontrol', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ParametricCheck');


   boot_markov.blocktext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[45 180 100 20], ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Style','text', ...
      'HorizontalAlignment','left', ...
      'String','Block size:', ...
      'Enable','off', ...
      'Tag','BlockText');

   boot_markov.block = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[105 185 50 20], ...
      'Value',1, ...
      'String','1|2|3|4|5|6|7|8|9|10|11|12', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Value',curr_ini.blocksize, ...
      'Enable','off', ...
      'Callback','markov_bootstrap check', ...
      'Tag','BlockPopup');
   
   if curr_ini.parametric==0;
      set(boot_markov.blocktext,'Enable','on');
      set(boot_markov.block,'Enable','on');
   end;

   boot_markov.bootstrap = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 147.5 130 20], ...
      'Value',curr_ini.reuse_bootstrap, ...
      'String','Reuse/save residuals', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ReuseBootstrapCheck');

   axesbox([185 130 361 215],'Parameters',55,[0.5 1]);

   %
   % number of observations per replication
   %

   boot_markov.obstext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 304 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'HorizontalAlignment','left', ...
      'String','Number of observations:', ...
      'Tag','ObsText');

   boot_markov.obs = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 309 168 20], ...
      'Value',1, ...
      'String',[num2str(my_T) '|100|200|300|400|500|600|700|800|900|1000|1100|1200|1300|1400|1500|1600|1700|1800|1900|2000|2500|3000|4000|5000|6000|7000|8000|9000|10000'], ...
      'Style','popupmenu', ...
      'UserData',my_T, ...
      'Callback','markov_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','ObsPopup');

   if (tm.q1+tm.q0==0)&(isempty(tm.deterfile)==1);
      set(boot_markov.obstext,'Enable','on');
      set(boot_markov.obs,'Enable','on');
   end;

   %
   % number of replications
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 276.5 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of replications:', ...
      'Tag','SimulText');

   boot_markov.rep = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 281.5 168 20], ...
      'Value',nRep_value, ...
      'String','99|999|1,999|2,999|3,999|4,999|9,999|19,999|29,999|39,999|49,999|99,999|199,999|299,999|399,999|499,999|999,999', ...
      'Style','popupmenu', ...
      'Callback','markov_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'UserData',rep,...
      'Enable','on', ...
      'Tag','SimulPopup');

   %
   % number of cointegration relations
   %

   boot_markov.my_rtext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 249 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'HorizontalAlignment','left', ...
      'String','Number of cointegration relations:', ...
      'Tag','CointText');

   r_str = '0';
   for i=1:tm.n;
      r_str = [r_str '|' num2str(i)];
   end;

   boot_markov.my_r = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 254 168 20], ...
      'Value',tm.r+1, ...
      'String',r_str, ...
      'UserData',tm.r, ...
      'Style','popupmenu', ...
      'Callback','markov_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','CointPopup');

   if tm.restrict(1,2)==1;
      set(boot_markov.my_r,'Enable','off');
      set(boot_markov.my_rtext,'Enable','off');
   end;

   %
   % parameters to vary under the alternative
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 221.5 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'HorizontalAlignment','left', ...
      'String','Regime model under alternative:', ...
      'Tag','ModelText');

   boot_markov.ms_model = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 226.5 168 20], ...
      'Value',2, ...
      'String','All parameters but beta|Delta|Alpha & Gamma|Omega|Delta, Alpha & Gamma |Delta & Omega|Alpha, Gamma & Omega', ...
      'Style','popupmenu', ...
      'Callback','markov_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ModelPopup');


   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 194 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'HorizontalAlignment','left', ...
      'String','Number of random h vectors:', ...
      'Tag','hvecText');

   boot_markov.hvector = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 199 168 20], ...
      'Value',1, ...
      'String','None - numerical optimization|50|100|150|200|250|300|350|400|450|500|550|600|650|700|750|800|850|900|950|1000|1100|1200|1300|1400|1500|1600|1700|1800|1900|2000|2100|2200|2300|2400|2500|2600|2700|2800|2900|3000|3100|3200|3300|3400|3500|3600|3700|3800|3900|4000|4100|4200|4300|4400|4500|4600|4700|4800|4900|5000|5500|6000|6500|7000|7500|8000|8500|9000|9500|10000', ...
      'Style','popupmenu', ...
      'Callback','markov_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','hvecPopup');

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 166.5 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'HorizontalAlignment','left', ...
      'String','Range for regime correlation:', ...
      'Tag','CorrText');

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[362 166.5 80 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'HorizontalAlignment','center', ...
      'String','mid-point', ...
      'Tag','midpointText');

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[450 166.5 80 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'HorizontalAlignment','center', ...
      'String','upper-lower', ...
      'Tag','upperlowerText');

   boot_markov.mid_point = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 149 80 20], ...
      'Value',20, ...
      'String','-0.95|-0.90|-0.85|-0.80|-0.75|-0.70|-0.65|-0.60|-0.55|-0.50|-0.45|-0.40|-0.35|-0.30|-0.25|-0.20|-0.15|-0.10|-0.05|0|0.05|0.10|0.15|0.20|0.25|0.30|0.35|0.40|0.45|0.50|0.55|0.60|0.65|0.70|0.75|0.80|0.85|0.90|0.95', ...
      'Style','popupmenu', ...
      'Callback','markov_bootstrap check_range', ...
      'UserData',20, ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','midpointPopup');

   boot_markov.upper_lower = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[450 149 80 20], ...
      'Value',20, ...
      'String','+/-0.000|+/-0.025|+/-0.050|+/-0.100|+/-0.150|+/-0.200|+/-0.250|+/-0.300|+/-0.350|+/-0.400|+/-0.450|+/-0.500|+/-0.550|+/-0.600|+/-0.650|+/-0.700|+/-0.750|+/-0.800|+/-0.850|+/-0.900|+/-0.950', ...
      'Style','popupmenu', ...
      'Callback','markov_bootstrap check_range', ...
      'UserData',20, ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','midpointPopup');

   %
   % Select interpolation function
   %

   axesbox([16 16 530 100],'Graphics',45,[0.5 1]);

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 74 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Interpolation function:', ...
      'Tag','InterpolateText');

   boot_markov.interpolate = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 79 168 20], ...
      'Value',tm.interpolate_value, ...
      'String','Nearest neighborhood|Linear|Cubic spline|Cubic|Kernel density normal|Kernel density Epanechnikov|Kernel density rectangular|Kernel density triangular|Kernel density biweight|Kernel density triweight|Kernel density Laplace|Kernel density logistic', ...
      'Callback','markov_bootstrap interpolate', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','InterpolatePopup');

   %
   % Number of cells for graphing density functions
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 29 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of cells for histograms:', ...
      'Tag','CellText');

   boot_markov.cells = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 34 168 20], ...
      'Value',1, ...
      'String','20|25|30|35|40|45|50|55|60|65|70|75|80|85|90|95|100', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','CellPopup');

   boot_markov.cdf = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 84.5 140 20], ...
      'Value',0, ...
      'String','Cumulative distribution', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','cdfCheckbox');

   boot_markov.adaptive = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 64.5 140 20], ...
      'Value',0, ...
      'String','Adaptive KDE method', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','adaptiveCheckbox');

   boot_markov.bart = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 44.5 140 20], ...
      'Value',0, ...
      'String','Bartlett corr. bootstrap', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','BartlettCheckbox');

   boot_markov.pqplot = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 24.5 140 20], ...
      'Value',0, ...
      'String','P-value plots, etc.', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','PQPlotCheckbox');

   if tm.interpolate_value>=5;
      set(boot_markov.adaptive,'Enable','on');
   end;

   set(markov_boot_gui,'UserData',boot_markov,...
         'HandleVisibility','callback');

case 'output'
   if curr_ini.texoutputformat>=2;
      file = strrep(lower(get(boot_markov.summarymenu,'UserData')),'.txt','.ltx');
      txt_str = readtext(file);
      fout = fopen(tm.outputfile,'at');
      fprintf(fout,'\\subsection*{Bootstrap Simulation of the Carrarsco-Hu-Ploberger Markov Switching Test} \n\n');
      for i=1:size(txt_str,2);
         fprintf(fout,'%s\n',txt_str{i});
      end;
      fclose(fout);
   else;
      txt_str = readtext(lower(get(boot_markov.summarymenu,'UserData')));
      fout = fopen(tm.outputfile,'at');
      fprintf(fout,'            Bootstrap Simulation of the Carrasco-Hu-Ploberger Markov Switching Test\n            -----------------------------------------------------------------------\n');
      for i=5:size(txt_str,2)-4;
         fprintf(fout,'%s\n',txt_str{i});
      end;
      fprintf(fout,'\n===============================================================================\n\n');
      fclose(fout);
   end;
case 'display_bootstrap'
   epsfile = get(boot_markov.bootstrapgraph,'UserData');
   testfile = get(boot_markov.bootstrapgraphmenu,'UserData');
   my_T = get(boot_markov.obs,'UserData');
   rep = get(boot_markov.rep,'UserData');
   if rep<4999;
      answer = 'Yes';
   else;
      check_txt = ['Your bootstrap setup includes ' num2str(rep) ' draws of the residuals. With ' num2str(tm.n) ' series and ' num2str(my_T) ' observations, this yields ' num2str(rep*tm.n*my_T) ' observations. Are you sure you want to load that much data into memory?'];
      answer = query(check_txt,'warning',120,'Exit',500,'no');
   end;
   if strcmp(answer,'Yes')==1;
      %
      %
      txt_str = 'sup TS =';
      %
      set(markov_boot_gui,'Visible','off');
      drawnow;
      thisgraph = bootgraphdlg('init',tm,epsfile,testfile,txt_str,tm.beta(:,1:tm.r),rep,my_T,tm.r);
      bootgraph = get(thisgraph,'UserData');
      set(bootgraph.show,'UserData','done');
      killguipid(thisgraph);
      set(markov_boot_gui,'Visible','on');
      drawnow;
   end;
case 'fixobscontrol'
   if get(boot_markov.parametric,'Value')==0;
      T_str = get(boot_markov.obs,'String');
      my_T = mystr2num(strtrim(T_str(get(boot_markov.obs,'Value'),:)));
      set(boot_markov.obs,'Value',1,'UserData',my_T,'Enable','off');
      set(boot_markov.obstext,'Enable','off');
   elseif (tm.q1+tm.q0==0)&(isempty(tm.deterfile)==1);
      set(boot_markov.obs,'Enable','on');
      set(boot_markov.obstext,'Enable','on');
   end;
   markov_bootstrap('check');
case 'interpolate'
   tm.interpolate_value = get(boot_markov.interpolate,'Value');
   interpol_vec = strvcat('nearest','linear','spline','cubic','knorm','kepan','krect','ktria','kbiwe','ktriw','klapl','klogi');
   tm.interpolate = strtrim(interpol_vec(tm.interpolate_value,:));
   if tm.interpolate_value>=5;
      set(boot_markov.adaptive,'Enable','on');
   else;
      set(boot_markov.adaptive,'Enable','off','Value',0);
   end;
case 'matfile'
   markov_test_sorted = get(boot_markov.display,'UserData');
   rep = get(boot_markov.rep,'UserData');
   my_T = get(boot_markov.obs,'UserData');
   my_const_model = get(boot_markov.displaymenu,'UserData');
   if get(boot_markov.parametric,'Value')==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(get(boot_markov.block,'Value')) '-'];
   end;
   if my_const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-markov-boot-full-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
   elseif my_const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-markov-boot-full-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif my_const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-markov-boot-full-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif my_const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-markov-boot-full-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif my_const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-markov-boot-full-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      my_text = ['The file "' getfilename(full_mat) '" already exists. Are you sure you want to overwrite it?'];
      answer = query(my_text,'question',120,'Save to mat-file',500,'no');
   else;
      answer = 'Yes';
   end;
   if strcmp(answer,'Yes')==1;
      setlogtext('Savings results to mat-files...');
      Number = (1:1:rep)';
      save(full_mat,'markov_test_sorted');
   end;
case 'check_range'
   mp_val = get(boot_markov.mid_point,'Value');
   mp_str = get(boot_markov.mid_point,'String');
   mid_point = mystr2num(strtrim(mp_str(mp_val,:)));
   ul_val = get(boot_markov.upper_lower,'Value');
   ul_str = get(boot_markov.upper_lower,'String');
   upper_lower = mystr2num(strtrim(strrep(ul_str(ul_val,:),'+/-','')));
   %
   % check if the interval is contained within -1,1
   %
   u_val = mid_point+upper_lower;
   l_val = mid_point-upper_lower;
   if (u_val<1)&(l_val>-1);
      set(boot_markov.mid_point,'UserData',mp_val);
      set(boot_markov.upper_lower,'UserData',ul_val);
      markov_bootstrap('check');
   else;
      set(boot_markov.mid_point,'Value',get(boot_markov.mid_point,'UserData'));
      set(boot_markov.upper_lower,'Value',get(boot_markov.upper_lower,'UserData'));
   end;
   tm.mp_ud = [num2str(get(boot_markov.mid_point,'UserData'),'%0.0f') '-'];
   tm.ul_ud = [num2str(get(boot_markov.upper_lower,'UserData'),'%0.0f') '-'];
case 'check'
   T_str = get(boot_markov.obs,'String');
   my_T = mystr2num(strtrim(T_str(get(boot_markov.obs,'Value'),:)));
   tm.ms_model = [num2str(get(boot_markov.ms_model,'Value'),'%0.0f') '-'];
   h_val = get(boot_markov.hvector,'Value');
   h_str = get(boot_markov.hvector,'String');
   if h_val>1;
      tm.hvec = [strtrim(h_str(h_val,:)) '-'];
   else;
      tm.hvec = '1-';
   end;
   tm.mp_ud = [num2str(get(boot_markov.mid_point,'UserData'),'%0.0f') '-'];
   tm.ul_ud = [num2str(get(boot_markov.upper_lower,'UserData'),'%0.0f') '-'];
   if strcmp(get(boot_markov.my_r,'Enable'),'on')==1;
      tm.r = get(boot_markov.my_r,'Value')-1;
      %
      % make sure the largest non-zero eigenvalue is less than unity
      %
      eigenvalues = companion(tm.Z0,tm.Z1,tm.Z2,tm.r,tm.p,tm.n,tm.q1,tm.q0,tm.d,tm.T);
      eigenvalues = abs(sort(eigenvalues));
      i = size(eigenvalues,1);
      while i>=1;
         tm.evalue = eigenvalues(i,1);
         if strcmp(num2str(tm.evalue,'%1.10f'),'1.0000000000')==1;
            i = i-1;
         else;
            i = 0;
         end;
      end;
      if tm.evalue>1;
         some_txt = ['For the cointegration rank ' num2str(tm.r,'%0.0f') ' the largest non-unit eigenvalue is ' num2str(tm.evalue,'%0.4f') '. Explosive systems should not be bootstrapped.'];
         about(some_txt,'warning','Explosive Model...',120,350);
         tm.r = get(boot_markov.my_r,'UserData');
         set(boot_markov.my_r,'Value',tm.r);
      else;
         tm.alpha = (tm.S_01*tm.beta(:,1:tm.r))/(tm.beta(:,1:tm.r)'*tm.S_11*tm.beta(:,1:tm.r));
         if isempty(tm.Z2)==0;
            tm.Psi = (tm.M_02/tm.M_22)-(tm.alpha*tm.beta(:,1:tm.r)'*(tm.M_12/tm.M_22));
            tm.epsilon = tm.Z0-(tm.alpha*tm.beta(:,1:tm.r)'*tm.Z1)-(tm.Psi*tm.Z2);
         else;
            tm.Psi = [];
            tm.epsilon = tm.Z0-(tm.alpha*tm.beta(:,1:tm.r)'*tm.Z1);
         end;
         tm.Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
         set(boot_markov.my_r,'UserData',tm.r);
      end;
   end;
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   rep_val = get(boot_markov.rep,'Value');
   rep = repvalues(rep_val);
   set(boot_markov.rep,'UserData',rep);
   set(boot_markov.obs,'UserData',my_T);
   %
   % adjusting the view text buttons
   %
   if get(boot_markov.parametric,'Value')==1;
      bootstyle = '';
      set(boot_markov.blocktext,'Enable','off');
      set(boot_markov.block,'Enable','off','Value',1);
   else;
      if strcmp(get(boot_markov.block,'Enable'),'off')==1;
         set(boot_markov.blocktext,'Enable','on');
         set(boot_markov.block,'Enable','on','Value',curr_ini.blocksize);
      end;
      bootstyle = ['np' num2str(get(boot_markov.block,'Value')) '-'];
   end;
   full_mat = '';
   if tm.const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-markov-boot-full-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
      mod_type = 'noconst';
   elseif tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-markov-boot-full-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
      mod_type = 'resconst';
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-markov-boot-full-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
      mod_type = 'const';
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-markov-boot-full-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
      mod_type = 'restrend';
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-markov-boot-full-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
      mod_type = 'trend';
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      markov_mat = load(full_mat);
      markov_test_sorted = markov_mat.markov_test_sorted;
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
      %
      % adjusting the Graph Distrbution button
      %
      set(boot_markov.display,'Enable','on','UserData',markov_test_sorted);
      set(boot_markov.displaymenu,'Enable','on','UserData',tm.const_model);
      set(boot_markov.histogram,'Enable','on');
      set(boot_markov.histogrammenu,'Enable','on');
      set(boot_markov.matfilebutton,'Enable','on');
      set(boot_markov.matfilemenu,'Enable','on');
   else;
      full_mat = '';
      full_enable = 'off';
      set(boot_markov.display,'Enable','off','UserData',[]);
      set(boot_markov.displaymenu,'Enable','off','UserData',tm.const_model);
      set(boot_markov.histogram,'Enable','off');
      set(boot_markov.histogrammenu,'Enable','off');
      set(boot_markov.matfilebutton,'Enable','off');
      set(boot_markov.matfilemenu,'Enable','off');
   end;
   %
   % Checking if residuals file exists
   %
   epsfile = [curr_ini.simulatedir tm.modelfile '-' 'markov-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
   testfile = strrep(epsfile,'.mat',['-' 'markov-data.mat']);
   %
   if (fileexist(epsfile)==1)&(fileexist(testfile)==1);
      set(boot_markov.bootstrapgraph,'Enable','on','UserData',epsfile);
      set(boot_markov.bootstrapgraphmenu,'Enable','on','UserData',testfile);
   else;
      set(boot_markov.bootstrapgraph,'Enable','off','UserData',[]);
      set(boot_markov.bootstrapgraphmenu,'Enable','off','UserData','');
   end;
   %
   set(boot_markov.fullmenu,'Enable',full_enable,'UserData',full_mat);
   set(boot_markov.full,'Enable',full_enable);
   summary_txt = '';
   if tm.const_model(1)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-markov-boot-summary-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
   elseif tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-markov-boot-summary-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-markov-boot-summary-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-markov-boot-summary-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-markov-boot-summary-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
   end;
%   if curr_ini.texoutputformat>=2;
%      summary_txt = strrep(summary_txt,'.txt','.ltx');
%   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
   end;
   if curr_ini.noprint==0;
      set(boot_markov.output,'Enable',summary_enable);
   end;
   set(boot_markov.summarymenu,'Enable',summary_enable,'UserData',summary_txt);
   set(boot_markov.summary,'Enable',summary_enable);
   set(markov_boot_gui,'UserData',boot_markov);
case 'summary'
   set(markov_boot_gui,'Visible','off');
   drawnow;
   file = lower(get(boot_markov.summarymenu,'UserData'));
   prtgui = printgui('init',file,'Structural VAR - Markov Switching Test Bootstrap Simulation Summary',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   myprint = get(prtgui,'UserData');
   set(myprint.print,'UserData','done');
   killguipid(prtgui);
   set(markov_boot_gui,'Visible','on');
   drawnow;
   set(markov_boot_gui,'UserData',boot_markov);
case 'full'
   set(markov_boot_gui,'Visible','off');
   drawnow;
   rep = get(boot_markov.rep,'UserData');
   full_mat = lower(get(boot_markov.fullmenu,'UserData'));
   my_T = get(boot_markov.obs,'UserData');
   %
   % not functional yet
   %
   my_text = ' Number       sup TS';
   prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
   my_text = strvcat(' ',my_text,' ');
   abort = '';
   if rep>=5000;
      input_var.title = ['Progress for ' int2str(rep) ' replications'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.label = 'Replication number:';
      input_var.stop = 0;
      input_var.clock = 1;
      input_var.name = ['Data in ' getname(full_mat)];
      mywait = progressdlg(0,input_var);
%      set(mywait,'Name',['Data in ' getname(full_mat)]);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
      drawnow;
   end;
   markov_mat = load(full_mat);
   my_data = [markov_mat.Number markov_mat.markov_test_sorted];
   for i=1:size(my_data,1);
      if rep>=5000;
         abort = get(mywait,'UserData');
         if strcmp(abort,'cancel')==1;
            break;
         else;
            progressdlg([(i/rep) i]);
         end;
      end;
      my_text = strvcat(my_text,sprintf(['%7.0f     ' prt_val],my_data(i,:)'));
   end;
   my_text = strvcat(my_text,' ');
   if rep>=5000;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   end;
   if strcmp(abort,'cancel')==0;
      textgui(my_text,'Structural VAR - Markov Switching Test Bootstrap Simulation',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   end;
   set(markov_boot_gui,'Visible','on');
   drawnow;
   set(markov_boot_gui,'UserData',boot_markov);
case 'display'
   markov_test_sorted = get(boot_markov.display,'UserData');
   pos = [(tm.realscrsz(3)-600)/2 (tm.realscrsz(4)-400)/2];
   rep = get(boot_markov.rep,'UserData');
   my_T = get(boot_markov.obs,'UserData');
   %
   % need to fix the rest
   %
   my_const_model = get(boot_markov.displaymenu,'UserData');
   if my_const_model(1)==1;
      this_mod = '(no constant)';
   elseif my_const_model(2)==1;
      this_mod = '(restricted constant)';
   elseif my_const_model(3)==1;
      this_mod = '(constant)';
   elseif my_const_model(4)==1;
      this_mod = '(restricted trend)';
   elseif my_const_model(5)==1;
      this_mod = '(trend)';
   end;
   cell_value = get(boot_markov.cells,'Value');
   cell_vec = [20 25 30 35 40 45 50 55 60 65 70 75 80 85 90 95 100];
   numcells = cell_vec(cell_value);
   my_80 = floor(0.8*rep);
   my_90 = floor(0.9*rep);
   my_95 = floor(0.95*rep);
   my_975 = floor(0.98*rep);
   my_99 = floor(0.99*rep);
   %
   if curr_ini.colors==1;
      col.vec_1 = [0 0 1];
      col.vec_2 = [1 0 0];
      col.vec_3 = [0 0.75 0];
      col.vec_4 = [1 0.5 0];
      col.vec_5 = [0 0.75 0.75];
      col.vec_6 = [0 0 0];
      col.vec_7 = (1/255)*[255 28 28];
      col.vec_8 = [0 1 0];
   else;
      col.vec_1 = [0 0 0];
      col.vec_2 = [0.7 0.7 0.7];
      col.vec_3 = [0.6 0.6 0.6];
      col.vec_4 = [0.5 0.5 0.5];
      col.vec_5 = [0.4 0.4 0.4];
      col.vec_6 = [0.3 0.3 0.3];
      col.vec_7 = [0.8 0.8 0.8];
      col.vec_8 = [0.2 0.2 0.2];
   end;
   %
   [pos,markov_plot] = dist_plot(pos,['markov-test-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest],'Markov switching test','Carrasco-Hu-Ploberger Markov switching test',tm,curr_ini,boot_markov,markov_test_sorted,[],1,1,0,col,my_80,my_90,my_95,my_975,my_99,numcells,1);

   if curr_ini.external==0;
      set(markov_plot,'Visible','on');
   else;
      this_mod = strrep(this_mod,'(','');
      this_mod = strrep(this_mod,')','');
      this_mod = strtrim(this_mod);
      this_mod = strrep(this_mod,' ','.');
      if (gcbo==boot_markov.histogram)|(gcbo==boot_markov.histogrammenu);
         file = [curr_ini.simulatedir tm.modelfile '-hist-boot-' get(markov_plot,'Tag') num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
      else;
         file = [curr_ini.simulatedir tm.modelfile '-boot-' get(markov_plot,'Tag') num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
      end;
      set(0,'CurrentFigure',markov_plot);
      stat = autosavefigure(markov_plot,file);
      if isempty(stat)==0;
         if stat==0;
            autoshowfigure(strtrim(file));
         end;
      end;
   end;
   set(markov_boot_gui,'UserData',boot_markov);
case 'runtest'
   set(markov_boot_gui,'Visible','off');
   drawnow;
   %
   % compute the test for the actual data and store in tm.rank(r+1).mstest_type(value).ms_test
   %
   theta = [tm.Psi tm.alpha];
   Omega = tm.Omega;
   Y = tm.Z0;
   if tm.r>0;
      if tm.restrict(1,2)==0;
         X = [tm.Z2;tm.beta(:,1:tm.r)'*tm.Z1];
      else;
         X = [tm.Z2;tm.beta'*tm.Z1];
      end;
   else;
      X = tm.Z2;
   end;
   %
   % set ut the alternative model
   %
   vary_parm = get(boot_markov.ms_model,'String');
   vary_val = get(boot_markov.ms_model,'Value');
   vary_parm = strtrim(vary_parm(vary_val,:));
   parm_vec = [tm.n*tm.d (size(X,1)-tm.d)*tm.n tm.n*(tm.n+1)/2];
   do_run = 1;
   if get(boot_markov.ms_model,'Value')==1;
      alt_model = [1 1 1];
   elseif get(boot_markov.ms_model,'Value')==2;
      alt_model = [1 0 0];
      if parm_vec(1,1)==0;
         do_run = 0;
      end;
   elseif get(boot_markov.ms_model,'Value')==3;
      alt_model = [0 1 0];
      if parm_vec(1,2)==0;
         do_run = 0;
      end;
   elseif get(boot_markov.ms_model,'Value')==4;
      alt_model = [0 0 1];
   elseif get(boot_markov.ms_model,'Value')==5;
      alt_model = [1 1 0];
      if (parm_vec(1,1)+parm_vec(1,2))==0;
         do_run = 0;
      end;
   elseif get(boot_markov.ms_model,'Value')==6;
      alt_model = [1 0 1];
   else;
      alt_model = [0 1 1];
   end;
   h_val = mystr2num(strrep(tm.hvec,'-',''));
   %
   mp_val = get(boot_markov.mid_point,'UserData');
   mp_str = get(boot_markov.mid_point,'String');
   mid_point = mystr2num(strtrim(mp_str(mp_val,:)));
   ul_val = get(boot_markov.upper_lower,'UserData');
   ul_str = get(boot_markov.upper_lower,'String');
   upper_lower = mystr2num(strtrim(strrep(ul_str(ul_val,:),'+/-','')));
   %
   rho_low = mid_point-upper_lower;
   rho_upp = mid_point+upper_lower;
   if rho_low<rho_upp;
      rho_size = size((rho_low:0.025:rho_upp),2);
   else;
      rho_size = 1;
   end;
   %
   % check if we can compute the test
   %
   if do_run==0;
      txt = 'There are no parameters that can vary with the Markov regimes under the alternative model you have selected. The supTS test will not be computed. Please select another alternative model.';
      about(txt,'information','Bad Alternative Model',120,450);
      %
      set(markov_boot_gui,'Visible','on');
      drawnow;
      return;
   end;
   %
   % notice that X can be empty if r=0, restricted constant, and p=1
   %
   [res,abort,res_mat,h_init] = ms_test(Y,X,theta,Omega,alt_model,parm_vec,h_val,rho_low,rho_upp,rho_size,[],get(boot_markov.progress,'Value'),get(boot_markov.clock,'Value'),1);
   if strcmp(abort,'cancel')==0;
      sp_str = spacestr(curr_ini.decimals-2);
      prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
      res_str = strvcat(' ',['MARKOV SWITCHING TEST (for rank = ' num2str(tm.r,'%0.0f') ')'],'====================================',' ');
      res_str = strvcat(res_str,'   Null Hypothesis:        No Markov regimes','   Alternative Hypothesis: At least 2 Markov regimes',' ');
      res_str = strvcat(res_str,['Parameters that can vary under the alternative: ' vary_parm],' ');
      res_str = strvcat(res_str,['supTS = ' sprintf(prt_val,res)],' ',['correlation ' sp_str ' test-value']);
      for i=1:size(res_mat,1);
         r_str = sprintf([prt_val '    ' prt_val],res_mat(i,1),res_mat(i,2));
         res_str = strvcat(res_str,r_str);
      end;
      res_str = strvcat(res_str,' ','NOTE: Run bootstrap exercise to generate the empirical distribution','      of the test as well as p-values.',' ');
      file = [curr_ini.tempdir 'ms-test.txt'];
      fid = fopen(file,'wt');
      for i=1:size(res_str,1);
         fprintf(fid,'%s\n',res_str(i,:));
      end;
      fclose(fid);
      prtgui = printgui('init',file,'Structural VAR - Markov Switching test',[(tm.realscrsz(3)-750)/2 (tm.realscrsz(4)-500)/2 750 500],'Results',40);
      myprint = get(prtgui,'UserData');
      set(myprint.print,'UserData','done');
      killguipid(prtgui);
      %
      delete_file_fcn(file);
      if tm.restrict(1,2)==0;
         tm.rank(tm.r+1).mstest_type(vary_val).ms_test = res;
         tm.rank(tm.r+1).mstest_type(vary_val).h_init = h_init;
      else;
         tm.mstest_type(vary_val).ms_test = res;
         tm.mstest_type(vary_val).h_init = h_init;
      end;
   end;
   %
   set(markov_boot_gui,'Visible','on');
   drawnow;
   %
   % case simulate
   %
case 'simulate'
   tm.markov_run = 1;
   set(markov_boot_gui,'Visible','off');
   drawnow;
   %
   % collect values
   %
   T_str = get(boot_markov.obs,'String');
   my_T = mystr2num(strtrim(T_str(get(boot_markov.obs,'Value'),:)));
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   rep_val = get(boot_markov.rep,'Value');
   rep = repvalues(rep_val);
   set(boot_markov.simulate,'UserData',rep);
   blocksize = get(boot_markov.block,'Value');
   block_txt = '';
   if blocksize>1;
      block_txt = ['Applying block bootstrap with block length ' num2str(blocksize,'%0.0f') '...'];
   end;
   if get(boot_markov.parametric,'Value')==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(get(boot_markov.block,'Value')) '-'];
   end;
   %
   % check if we need to compute the test
   %
   ms_test_value = [];
   vary_val = get(boot_markov.ms_model,'Value');
   %
   % set ut the alternative model
   %
   vary_parm = get(boot_markov.ms_model,'String');
   vary_parm = strtrim(vary_parm(vary_val,:));
   parm_vec = [tm.n*tm.d (size(tm.Z2,1)+tm.r-tm.d)*tm.n tm.n*(tm.n+1)/2];
   do_run = 1;
   h_start = [];
   if get(boot_markov.ms_model,'Value')==1;
      alt_model = [1 1 1];
   elseif get(boot_markov.ms_model,'Value')==2;
      alt_model = [1 0 0];
      if parm_vec(1,1)==0;
         do_run = 0;
      end;
   elseif get(boot_markov.ms_model,'Value')==3;
      alt_model = [0 1 0];
      if parm_vec(1,2)==0;
         do_run = 0;
      end;
   elseif get(boot_markov.ms_model,'Value')==4;
      alt_model = [0 0 1];
   elseif get(boot_markov.ms_model,'Value')==5;
      alt_model = [1 1 0];
      if (parm_vec(1,1)+parm_vec(1,2))==0;
         do_run = 0;
      end;
   elseif get(boot_markov.ms_model,'Value')==6;
      alt_model = [1 0 1];
   else;
      alt_model = [0 1 1];
   end;
   h_val = mystr2num(strrep(tm.hvec,'-',''));
   %
   mp_val = get(boot_markov.mid_point,'UserData');
   mp_str = get(boot_markov.mid_point,'String');
   mid_point = mystr2num(strtrim(mp_str(mp_val,:)));
   ul_val = get(boot_markov.upper_lower,'UserData');
   ul_str = get(boot_markov.upper_lower,'String');
   upper_lower = mystr2num(strtrim(strrep(ul_str(ul_val,:),'+/-','')));
   %
   rho_low = mid_point-upper_lower;
   rho_upp = mid_point+upper_lower;
   if rho_low<rho_upp;
      rho_size = size((rho_low:0.025:rho_upp),2);
   else;
      rho_size = 1;
   end;
   %
   % check if we can compute the test
   %
   if do_run==0;
      txt = 'There are no parameters that can vary with the Markov regimes under the alternative model you have selected. The supTS test will not be computed. Please select another alternative model.';
      about(txt,'information','Bad Alternative Model',120,450);
      %
      set(markov_boot_gui,'Visible','on');
      drawnow;
      return;
   end;
   %
   % see if we can find a value for the test on the actual data
   %
   if tm.restrict(1,2)==0;
      if isfield(tm.rank(tm.r+1).mstest_type(vary_val),'ms_test')==1;
         ms_test_value = tm.rank(tm.r+1).mstest_type(vary_val).ms_test;
      end;
   else;
      if isfield(tm.mstest_type(vary_val),'ms_test')==1;
         ms_test_value = tm.mstest_type(vary_val).ms_test;
      end;
   end;
   %
   if isempty(ms_test_value)==1;
      %
      % compute the test for the actual data and store in tm.rank(r+1).mstest_type(value).ms_test
      %
      theta = [tm.Psi tm.alpha];
      Omega = tm.Omega;
      Y = tm.Z0;
      if tm.r>0;
         if tm.restrict(1,2)==0;
            X = [tm.Z2;tm.beta(:,1:tm.r)'*tm.Z1];
         else;
            X = [tm.Z2;tm.beta'*tm.Z1];
         end;
      else;
         X = tm.Z2;
      end;
      %
      % notice that X can be empty if r=0, restricted constant, and p=1
      %
      [res,abort,res_mat,h_init] = ms_test(Y,X,theta,Omega,alt_model,parm_vec,h_val,rho_low,rho_upp,rho_size,[],get(boot_markov.progress,'Value'),get(boot_markov.clock,'Value'),1);
      if strcmp(abort,'cancel')==0;
         if tm.restrict(1,2)==0;
            tm.rank(tm.r+1).mstest_type(vary_val).ms_test = res;
            tm.rank(tm.r+1).mstest_type(vary_val).h_init = h_init;
         else;
            tm.mstest_type(vary_val).ms_test = res;
            tm.mstest_type(vary_val).h_init = h_init;
         end;
         h_start = h_init;
         ms_test_value = res;
         curr_ini.models = tm;
         set(boot_markov.matfilebutton,'UserData',curr_ini);
      else;
         tm.markov_run = 0;
         set(markov_boot_gui,'Visible','on');
         drawnow;
         return;
      end;
   else;
      if tm.restrict(1,2)==0;
         h_start = tm.rank(tm.r+1).mstest_type(vary_val).h_init;
      else;
         h_start = tm.mstest_type(vary_val).h_init;
      end;
   end;
   %
   % initializing the bootstrap
   %
   markov_test = zeros(rep,1);
   if curr_ini.symmetric==0;
      Omega_sig = chol(tm.Omega)';
   else;
      Omega_sig = symm(tm.Omega);
   end;
   abort = '';
   draw = 1;
   est_status = 0;
   showprog = get(boot_markov.progress,'Value');
   if showprog==1;
      input_var.title = ['Progress for ' int2str(rep) ' replications'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.clock = get(boot_markov.clock,'Value');
      input_var.label = 'Replication number:';
      input_var.stop = 0;
      mywait = progressdlg(0,input_var);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
   else;
      this_text = strvcat('Bootstrapping. The art of pulling oneself up by the bootstraps. Attempt started at...',' ',['Time: ' datestr(now,14)],' ','Please hold!');
      mywait = waitdlg(this_text,'bootstrap','Beta Bootstrap Simulation');
      waitf = get(mywait,'UserData');
      tic;
   end;
   if tm.const_model(2)==1;
      setlogtext(strvcat(' ','Bootstrapping distribution for Carrasco-Hu-Ploberger','Markov switching test...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted constant',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications'],'Alternative:',['       ' vary_parm],'       subject to 2 regimes'));
      if showprog==1;
         set(mywait,'Name',['Restricted constant model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'resconst';
   elseif tm.const_model(3)==1;
      setlogtext(strvcat(' ','Bootstrapping distribution for Carrasco-Hu-Ploberger','Markov switching test...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Unrestricted constant',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications'],'Alternative:',['       ' vary_parm],'       subject to 2 regimes'));
      if showprog==1;
         set(mywait,'Name',['Constant model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'const';
   elseif tm.const_model(4)==1;
      setlogtext(strvcat(' ','Bootstrapping distribution for Carrasco-Hu-Ploberger','Markov switching test...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted linear trend',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications'],'Alternative:',['       ' vary_parm],'       subject to 2 regimes'));
      if showprog==1;
         set(mywait,'Name',['Restricted trend model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'restrend';
   elseif tm.const_model(5)==1;
      setlogtext(strvcat(' ','Bootstrapping distribution for Carrasco-Hu-Ploberger','Markov switching test...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Linear trend',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications'],'Alternative:',['       ' vary_parm],'       subject to 2 regimes'));
      if showprog==1;
         set(mywait,'Name',['Linear trend model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'trend';
   end;
   if get(boot_markov.bootstrap,'Value')==1;
      %
      % epsilon-file
      %
      epsfile = [curr_ini.simulatedir tm.modelfile '-' 'markov-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
      if fileexist(epsfile)==1;
         load_eps = 1;
         %
         % load old epsilons
         %
         eps_data = load(epsfile);
      else;
         load_eps = 0;
      end;
   else;
      load_eps = 0;
   end;
   %
   % replicating
   %
   while (draw<=rep);  % should be until rep
      if showprog==1;
         abort = get(mywait,'UserData');
         if strcmp(abort,'cancel')==1;
            break;
         else;
            progressdlg([(draw/rep) draw]);
         end;
      end;
      setlogtext(['   Draw ' num2str(draw,'%0.0f') ' started at: ' datestr(now,14)]);
      %
      % check for bootstrap style
      %
      if load_eps==0;
         if get(boot_markov.parametric,'Value')==1;
            %
            % reset the random number generator
            %
            if (curr_ini.random_state==2)&(est_status==0);
               randn('state',draw);
            elseif curr_ini.random_state==3;
               randn('state',sum(100*clock));
            else;
               randn('state',sum(100*clock)+draw);
            end;
            %
            Epr = randn(tm.n,my_T+50);
            Epr = Epr(:,51:my_T+50);
            %
            % make sure draws in Epr have identity covariance matrix
            %
            Sig = (1/my_T)*Epr*Epr';
            P_sig = chol(Sig)';
            Epr = P_sig\Epr;
            Epr = Omega_sig*Epr;
         else;
            %
            % reset the random number generator
            %
            if (curr_ini.random_state==2)&(est_status==0);
               rand('state',draw);
            elseif curr_ini.random_state==3;
               rand('state',sum(100*clock));
            else;
               rand('state',sum(100*clock)+draw);
            end;
            %
            % resample from estimated epsilons
            %
            uni_draws = rand([1 my_T+50]);
            uni_draws = uni_draws(1,51:my_T+50);
            Epr = boot_draw(uni_draws,tm.epsilon,blocksize);
         end;
         if get(boot_markov.bootstrap,'Value')==1;
            bootstrap(draw).epsilon = Epr;
         end;
      else;
         Epr = eps_data.bootstrap(draw).epsilon;
      end;
      %
      % create new sample
      %
      boot = bootstrap_sample(tm,tm.beta(:,1:tm.r),Epr);
      %
      % estimate the model under the null
      %
      [S_00,S_01,S_10,S_11,M_02,M_22,M_12,beta,lambda,trace_test] = mlcointbasic(boot.Z0,boot.Z1,boot.Z2,tm.r);
      if tm.restrict(1,2)==1;
         [beta,newlambda,newdfbeta,stdbeta,outputtxt,new_abort] = betarestrict(S_00,S_11,S_01,S_10,beta,my_T,tm.modelsdir,tm.modelfile,0,tm.dcoint);
      end;
      %
      % compute alpha, Psi, and epsilon
      %
      if tm.r>0;
         alpha = (S_01*beta)/(beta'*S_11*beta);
         if isempty(boot.Z2)==0;
            Psi = (M_02/M_22)-(alpha*beta'*(M_12/M_22));
            X = [boot.Z2;beta'*boot.Z1];
         else;
            Psi = [];
            X = beta'*boot.Z1;
         end;
         Theta = [Psi alpha];
         epsilon = boot.Z0-(Theta*X);
      else;
         if isempty(boot.Z2)==0;
            Theta = M_02/M_22;
            X = boot.Z2;
            epsilon = boot.Z0-(Theta*X);
         else;
            Theta = [];
            X = [];
            epsilon = boot.Z0;
         end;
      end;
      Omega = (1/my_T)*epsilon*epsilon';
      %
      % construct input for the Markov switching test function
      %
      Y = boot.Z0;
      %
      % compute the Markov switching test
      %
      [res,new_abort] = ms_test(Y,X,Theta,Omega,alt_model,parm_vec,h_val,rho_low,rho_upp,rho_size,h_start,0,0,0);
      %
      % save results and continue with draws
      %
      markov_test(draw,:) = res;
      draw = draw+1;
   end;
   %
   % bootstrap has finished
   %
   if showprog==1;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   else;
      set(waitf.text,'UserData','done');
      delete(mywait);
      drawnow;
      new_time = toc;
      my_hrs = '00';
      my_min = '00';
      my_sec = num2str(new_time,'%0.2f');
      if new_time>=60;
         ch_min = floor(new_time/60);
         my_sec = num2str(new_time-(ch_min*60),'%0.2f');
         my_min = num2str(ch_min,'%0.0f');
         if ch_min>=60;
            ch_hrs = floor(ch_min/60);
            my_min = num2str(ch_min-(ch_hrs*60),'%0.0f');
            my_hrs = num2str(ch_hrs,'%0.0f');
         end;
      end;
      if size(my_sec,2)==4;
         my_sec = ['0' my_sec];
      end;
      if size(my_min,2)==1;
         my_min = ['0' my_min];
      end;
      if size(my_hrs,2)==1;
         my_hrs = ['0' my_hrs];
      end;
      clock_str = [my_hrs ':' my_min ':' my_sec];
      this_text = strvcat('The bootstrapping process took:',' ',['    ' clock_str ' (hrs:min:sec)']);
      about(this_text,'bootstrap','Simulation Time',120,350);
   end;
   %
   % if we don't cancel
   %
   if (strcmp(abort,'cancel')==0)&(isempty(markov_test)==0);
      this_text = strvcat(' ','Saving bootstrap results to disk...','Please hold!');
      mywait = waitdlg(this_text,'bootstrap','Markov Switching Test Bootstrap Simulation');
      waitf = get(mywait,'UserData');
      if get(boot_markov.bootstrap,'Value')==1;
         if load_eps==0;
            this_text = strvcat(' ','Saving bootstrapped residuals to disk...','Please hold!');
            set(waitf.text,'String',this_text);
            save(epsfile,'bootstrap');
         end;
         clear('bootstrap');
         testfile = strrep(epsfile,'.mat',['-' 'markov-data.mat']);
         test_data = markov_test;
         save(testfile,'test_data');
         clear('test_data');
         set(boot_markov.bootstrapgraph,'Enable','on','UserData',epsfile);
         set(boot_markov.bootstrapgraphmenu,'Enable','on','UserData',testfile);
      end;
      setlogtext(['Bootstrap simulation completed at: ' datestr(now,14) '!']);
      %
      % sort the tests
      %
      markov_test_sorted = sort(markov_test);
      clear('markov_test');
      set(boot_markov.rep,'UserData',rep);
      set(boot_markov.obs,'UserData',my_T);
      set(boot_markov.displaymenu,'Enable','on','UserData',tm.const_model);
      if tm.const_model(2)==1;
         my_mod = 'Restricted constant';
      elseif tm.const_model(3)==1;
         my_mod = 'Constant';
      elseif tm.const_model(4)==1;
         my_mod = 'Restricted linear trend';
      elseif tm.const_model(5)==1;
         my_mod = 'Linear trend';
      end;
      %
      % save full simulations
      %
      if get(boot_markov.save,'Value')==1;
         this_text = strvcat(' ','Saving bootstrapped Markov Switching tests to disk...','Please hold!');
         set(waitf.text,'String',this_text);
         setlogtext('Saving results to mat-files...');
         if tm.const_model(1)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-markov-boot-full-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
         elseif tm.const_model(2)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-markov-boot-full-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
         elseif tm.const_model(3)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-markov-boot-full-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
         elseif tm.const_model(4)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-markov-boot-full-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
         elseif tm.const_model(5)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-markov-boot-full-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
         end;
         Number = (1:1:rep)';
         save(full_mat,'Number','markov_test_sorted');
         set(boot_markov.fullmenu,'Enable','on','UserData',full_mat);
         set(boot_markov.full,'Enable','on');
      end;
      setlogtext('Saving simulation summary to text file...');
      %
      % dealing with the size of the test
      %
      boot_pval = [];
      if tm.T==my_T;
         this_text = strvcat(' ','Determining the empirical p-value of the Carrasco-Hu-Ploberger Markov switching tests...','Please hold!');
         set(waitf.text,'String',this_text);
         boot_pval = size(markov_test_sorted(markov_test_sorted>ms_test_value),1)/rep;
      end;
      this_text = strvcat(' ','Writing bootstrap summary information to disk...','Please hold!');
      set(waitf.text,'String',this_text);
      %
      % write summary to file
      %
      my_80 = floor(0.8*rep);
      my_90 = floor(0.9*rep);
      my_95 = floor(0.95*rep);
      my_975 = floor(0.98*rep);
      my_99 = floor(0.99*rep);
      sp_str = spacestr(curr_ini.decimals-2);
      prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
      prt_tex = ['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'];
      res_str = strvcat(' ','**************************************************************','*                          Results                           *');
      res_str = strvcat(res_str,'**************************************************************',' ',['  Model:                   ' my_mod],['  Endogenous variables:    ' num2str(tm.n,'%0.0f')],['  Cointegration relations: ' num2str(tm.r,'%0.0f')],['  Replications:            ' num2str(rep,'%0.0f')],['  Draws per replication:   ' num2str(my_T,'%0.0f')],' ',['Alternative Model: ' vary_parm],'                   subject to 2 Markov regimes',' ');
      if blocksize>1;
         res_str = strvcat(res_str,strrep(block_txt,'.',''),' ');
      end;
      res_str = strvcat(res_str,'            Carrasco-Hu-Ploberger Markov switching tests','            --------------------------------------------',' ',['    80%   ' sp_str '     90%   ' sp_str '     95%   ' sp_str '     98%   ' sp_str '     99%   ' sp_str '     Mean  ' sp_str '  Std. Dev.']);
      max_std = sqrt( (1/rep)*sum( ( markov_test_sorted - ( (1/rep)*sum(markov_test_sorted) ) ).*( markov_test_sorted - ( (1/rep)*sum(markov_test_sorted) ) ) ) );
      res_str = strvcat(res_str,sprintf([prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],markov_test_sorted(my_80,1),markov_test_sorted(my_90,1),markov_test_sorted(my_95,1),markov_test_sorted(my_975,1),markov_test_sorted(my_99,1),(1/rep)*sum(markov_test_sorted),max_std));
      if isempty(boot_pval)==0;
         res_str = strvcat(res_str,' ','                      Empirical p-value','                      -----------------',' ');
         res_str = strvcat(res_str,['             sup TS = ' num2str(ms_test_value,prt_tex) '    p-value = ' num2str(boot_pval,prt_tex)]);
      end;
      res_str = strvcat(res_str,' ');
      %
      res_str = strvcat(res_str,'**************************************************************',' ');
      %
      if tm.const_model(1)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-markov-boot-summary-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
      elseif tm.const_model(2)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-markov-boot-summary-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
      elseif tm.const_model(3)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-markov-boot-summary-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
      elseif tm.const_model(4)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-markov-boot-summary-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
      elseif tm.const_model(5)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-markov-boot-summary-' bootstyle tm.ms_model tm.hvec tm.mp_ud tm.ul_ud tm.beta_rest num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
      end;
      fid_txt = fopen(file_txt,'wt');
      for i=1:size(res_str,1);
         fprintf(fid_txt,[strrep(res_str(i,:),'%','%%') '\n']);
      end;
      fprintf(fid_txt,['Output created on: ' datestr(now,0) '\n']);
      fclose(fid_txt);
      %
      % write to tex file
      %
      file_tex = strrep(file_txt,'.txt','.ltx');
      f_id = fopen(file_tex,'wt');
      fprintf(f_id,'\\begin{tabular}{ll}\n');
      fprintf(f_id,['Model: & ' my_mod ' \\\\\n']);
      fprintf(f_id,['\\#Endogenous variables: & ' num2str(tm.n,'%0.0f') ' \\\\\n']);
      fprintf(f_id,['\\#Cointegration relations: & ' num2str(tm.r,'%0.0f') ' \\\\\n']);
      fprintf(f_id,['\\#Replications: & ' num2str(rep,'%0.0f') ' \\\\\n']);
      fprintf(f_id,['\\#Draws per replication: & ' num2str(my_T,'%0.0f') ' \\\\\n']);
      fprintf(f_id,['Alternative Model: & ' vary_parm ' \\\\\n']);
      fprintf(f_id,' & subject to 2 Markov regimes \\\\\n');
      if blocksize>1;
         fprintf(f_id,['Block size length: & ' num2str(blocksize,'%0.0f') ' \\\\\n']);
      end;
      fprintf(f_id,'\\end{tabular}\n\n');
      fprintf(f_id,'\\begin{tabular}{rrrrrrr}\n');
      fprintf(f_id,['\\multicolumn{7}{c}{Carrasco-Hu-Ploberger test for Markov regimes} \\\\\n']);
      fprintf(f_id,'80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% & Mean & Std. Dev. \\\\\n');
      fprintf(f_id,[prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],markov_test_sorted(my_80,1),markov_test_sorted(my_90,1),markov_test_sorted(my_95,1),markov_test_sorted(my_975,1),markov_test_sorted(my_99,1),(1/rep)*sum(markov_test_sorted),max_std);
      fprintf(f_id,'\\end{tabular}\n\n');
      if isempty(boot_pval)==0;
         fprintf(f_id,'\\vspace*{2mm}\n\n\\begin{tabular}{ll}\n');
         fprintf(f_id,'\\multicolumn{2}{c}{Empirical $p$-value} \\\\\n');
         fprintf(f_id,'$\\sup {\\rm TS}$ & $p$-value \\\\\n');
         fprintf(f_id,[prt_tex ' & ' prt_tex ' \\\\ \n'],ms_test_value,boot_pval);
         fprintf(f_id,'\\end{tabular}\n\n');
      end;
      fprintf(f_id,'\\ruler\n\n%%*************************************************************\n');
      fclose(f_id);
      %
      set(boot_markov.display,'UserData',markov_test_sorted);
      clear('markov_test_sorted');
      %
      if curr_ini.noprint==0;
         set(boot_markov.output,'Enable','on');
      end;
      set(boot_markov.summarymenu,'Enable','on','UserData',file_txt);
      set(boot_markov.summary,'Enable','on');
      set(boot_markov.display,'Enable','on');
      set(boot_markov.displaymenu,'Enable','on');
      set(boot_markov.histogram,'Enable','on');
      set(boot_markov.histogrammenu,'Enable','on');
      set(boot_markov.matfilebutton,'Enable','on');
      set(boot_markov.matfilemenu,'Enable','on');
      set(waitf.text,'UserData','done');
      delete(mywait);
      drawnow;
   else;
      setlogtext('Cancelled...');
   end;
   tm.markov_run = 0;
   set(markov_boot_gui,'Visible','on');
case 'done'
   if tm.markov_run==0;
      set(boot_markov.done,'UserData','done');
      pid = get(boot_markov.filemenu,'UserData');
      if isempty(pid)==1;
         delete(markov_boot_gui);
      else;
         close(markov_boot_gui);
      end;
   end;
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(markov_boot_gui,'Name') ' ' fix_filepath([pwd '\icons\bootstrap.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(boot_markov.filemenu,'UserData',pid);
         set(markov_boot_gui,'CloseRequestFcn','killwinpid');
      end;
   end;
   set(markov_boot_gui,'Visible','on');
end;

if strcmp(selector,'done')==0;
   curr_ini.models = tm;
   curr_ini.images = button_images;
   set(boot_markov.matfilebutton,'UserData',curr_ini);
end;

if my_exit==1;
   waitfor(boot_markov.done,'UserData','done');
end;

%
% end of markov_bootstrap.m
%
