function model_select(cm,curr_ini,maingui)

%
% make sure the Output tab is displayed when option is selected
%
if curr_ini.logtab==1;
   cf = findobj('Type','figure','Tag','StructuralVAR');
   if (isempty(cf)==0)&(ishandle(cf)==1);
      mod = get(cf,'UserData');
      h_log = mod.tab2;
      set(cf,'CurrentObject',h_log);
      maindlg('tab');
   end;
end;
%
% Display wait dialogue
%
txt = strvcat(' ','Initializing...','Reading data.','Please hold!');
mywait = waitdlg(txt,'information');
waitf = get(mywait,'UserData');

%
% get sample information
%

cm = getsample(cm,cm.endofile,cm.endosheet);

if isempty(cm.fp)==1;
   set(waitf.text,'UserData','done');
   delete(mywait);
   drawnow;
   txt = ['ERROR: Unable to read data from ' fix_path(getfilename(cm.endofile)) '.'];
   about(txt,'error','Bad data...',120,350);
   return;
end;

model = get(maingui,'UserData');
if strcmp(get(model.scale_1,'Check'),'on')==1;
   cm.scale_endo = 0.0001;
elseif strcmp(get(model.scale_2,'Check'),'on')==1;
   cm.scale_endo = 0.001;
elseif strcmp(get(model.scale_3,'Check'),'on')==1;
   cm.scale_endo = 0.01;
elseif strcmp(get(model.scale_4,'Check'),'on')==1;
   cm.scale_endo = 0.1;
elseif strcmp(get(model.scale_5,'Check'),'on')==1;
   cm.scale_endo = 1;
elseif strcmp(get(model.scale_6,'Check'),'on')==1;
   cm.scale_endo = 10;
elseif strcmp(get(model.scale_7,'Check'),'on')==1;
   cm.scale_endo = 100;
elseif strcmp(get(model.scale_8,'Check'),'on')==1;
   cm.scale_endo = 1000;
elseif strcmp(get(model.scale_9,'Check'),'on')==1;
   cm.scale_endo = 10000;
else;
   cm.scale_endo = 1;
end;

%
% checking if we should place an upper bound on cm.maxp
%

if (isfield(cm,'maxp')==0)|(curr_ini.ms_maxlag<cm.maxp);
   cm.maxp = curr_ini.ms_maxlag;
end;
if (cm.maxp==0)|(isfield(cm,'maxp')==0);
   cm.maxp = 12;
end;
%
%    Loading data
%

cm.x0 = loaddata(cm.endofile,cm.endosheet);

%
% Setting up deterministic component
%

if cm.deterselect(1,1)==1;
   cm.x1 = ones(size(cm.x0,1),1);
   cm.x1_r = [];
   cm.constvec = 'const';
   cm.restvec = '';
elseif cm.deterselect(1,2)==1;
   cm.x1 = [];
   cm.x1_r = ones(size(cm.x0,1),1);
   cm.constvec = '';
   cm.restvec = 'const';
elseif cm.deterselect(1,3)==1;
   cm.x1 = [ones(size(cm.x0,1),1) (1:size(cm.x0,1))'-cm.maxp];
   cm.x1_r = [];
   cm.constvec = 'const trend';
   cm.restvec = '';
elseif cm.deterselect(1,4)==1;
   cm.x1 = ones(size(cm.x0,1),1);
   cm.x1_r = (1:size(cm.x0,1))'-cm.maxp;
   cm.constvec = 'const';
   cm.restvec = 'trend';
end;

cm.dcoint = 0;
if strcmp(cm.restvec,'')==0;
   cm.dcoint = 1;
end;

cm.ds = 0;
if cm.seasonal(1,1)==1;
   if strcmp(cm.freq,'')==0;
      [seamat,seastring] = seasonal_fcn(cm.freq,size(cm.x0,1));
      cm.x1 = [cm.x1 seamat];
      if strcmp(cm.constvec,'')==1;
         cm.constvec = seastring;
      else;
         cm.constvec = [cm.constvec ' ' seastring];
      end;
   end;
   cm.ds = size(seamat,2);
end;

%
% determining the number of automatically created deterministic variables
%
cm.ad = size(cm.x1,2);
cm.datad = 0;
if strcmp(cm.deterfile,'')==0;
   if fileexist(cm.deterfile)==1;
      dummyfile = loaddata(cm.deterfile,cm.detersheet);
      if isempty(dummyfile)==1;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
         txt = ['ERROR: Unable to read data from ' fix_path(getfilename(cm.deterfile)) '.'];
         about(txt,'error','Bad data...',120,350);
         return;
      end;
      if size(dummyfile,1)==size(cm.x1,1);
         cm.x1 = [cm.x1 dummyfile];
      elseif isempty(cm.x1)==1;
         cm.x1 = dummyfile;
      end;
      cm.datad = size(cm.x1,2)-cm.ad;
   end;
end;

if strcmp(cm.exo1file,'')==0;
   if fileexist(cm.exo1file)==1;
      cm.x2 = loaddata(cm.exo1file,cm.exo1sheet);
      if isempty(cm.x2)==1;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
         txt = ['ERROR: Unable to read data from ' fix_path(getfilename(cm.exo1file)) '.'];
         about(txt,'error','Bad data...',120,350);
         return;
      end;
   else;
      cm.x2 = [];
   end;
else;
   cm.x2 = [];
end;
if strcmp(cm.exo0file,'')==0;
   if fileexist(cm.exo0file)==1;
      cm.x3 = loaddata(cm.exo0file,cm.exo0sheet);
      if isempty(cm.x3)==1;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
         txt = ['ERROR: Unable to read data from ' fix_path(getfilename(cm.exo0file)) '.'];
         about(txt,'error','Bad data...',120,350);
         return;
      end;
   else;
      cm.x3 = [];
   end;
else;
   cm.x3 = [];
end;

if size(cm.x0,2)>size(cm.x0,1);
   cm.x0 = cm.x0';
end;

if size(cm.x1,2)>size(cm.x1,1);
   cm.x1 = cm.x1';
end;

if size(cm.x2,2)>size(cm.x2,1);
   cm.x2 = cm.x2';
end;

if size(cm.x3,2)>size(cm.x3,1);
   cm.x3 = cm.x3';
end;

if isempty(cm.x2)==0;
   origq1 = size(cm.x2,2);
else;
   origq1 = 0;
end;

extrai0 = 0;
if (isempty(cm.x3)==0)&(curr_ini.rahbek==1);
   if (size(cm.x2,1)==size(cm.x3,1))|(isempty(cm.x2)==1);
      extrai0 = size(cm.x3,2);
      cm.x3 = cumsum(cm.x3);
      cm.x2 = [cm.x2 cm.x3];
      cm.x3 = [];
   end;
end;

%
% Setting up the exogenous variables into the cm.x2 matrix
% and determining the number of I(1) variables
%

if isempty(cm.x3)==0;
   if size(cm.x2,1)==size(cm.x3,1);
      cm.q1 = size(cm.x2,2);
      cm.x2 = [cm.x2 cm.x3];
   else;
      cm.q1 = 0;
      cm.x2 = cm.x3;
   end;
else;
   if isempty(cm.x2)==0;
      cm.q1 = size(cm.x2,2);
   else;
      cm.q1 = 0;
   end;
end;

%
% setting up subsample
%

if size(cm.x1,2)>0;
   if cm.lp<=size(cm.x1,1);
      cm.x1 = cm.x1(cm.fp:cm.lp,:);
   else;
      set(waitf.text,'UserData','done');
      delete(mywait);
      drawnow;
      txt = ['ERROR: Unable to match observations in ' fix_path(getfilename(cm.deterfile)) ' with those in ' fix_path(getfilename(cm.endofile)) '. Please make sure that the observations match in all your data-files'];
      about(txt,'error','Data mismatch...',120,400);
      return;
   end;
end;
if size(cm.x2,1)>1;
   if cm.lp<=size(cm.x2,1);
      cm.x2 = cm.scale_endo*cm.x2(cm.fp:cm.lp,:);
   else;
      set(waitf.text,'UserData','done');
      delete(mywait);
      drawnow;
      if (strcmp(strtrim(cm.exo1file),'')==0)&(strcmp(strtrim(cm.exo0file),'')==1);
         txt = ['ERROR: Unable to match observations in ' fix_path(getfilename(cm.exo1file)) ' with those in ' fix_path(getfilename(cm.endofile)) '. Please make sure that the observations match in all your data-files'];
      elseif (strcmp(strtrim(cm.exo1file),'')==1)&(strcmp(strtrim(cm.exo0file),'')==0);
         txt = ['ERROR: Unable to match observations in ' fix_path(getfilename(cm.exo0file)) ' with those in ' fix_path(getfilename(cm.endofile)) '. Please make sure that the observations match in all your data-files'];
      else;
         txt = ['ERROR: Unable to match observations in ' fix_path(getfilename(cm.exo0file)) ' and in ' fix_path(getfilename(cm.exo1file)) ' with those in ' fix_path(getfilename(cm.endofile)) '. Please make sure that the observations match in all your data-files'];
      end;
      about(txt,'error','Data mismatch...',120,400);
      return;
   end;
end;
if isempty(cm.x1_r)==0;
   cm.x1_r = cm.x1_r(cm.fp:cm.lp,:);
end;
cm.x0 = cm.scale_endo*cm.x0(cm.fp:cm.lp,:);

%
% Checking names of variables and creating ones for the missing
% entries
%

if strcmp(cm.evars,'')==1;
   cm.n = size(cm.x0,2);
   i = 1;
   while i<=cm.n;
      if i==1;
         cm.evars = 'y_1';
      else;
         cm.evars = [cm.evars ' y_' num2str(i)];
      end;
      i = i+1;
   end;
end;

cm.dummies = 0;
cm.d = size(cm.x1,2);
if strcmp(cm.deterfile,'')==0;
   cm.dummies = 1;
   if strcmp(cm.deter,'')==1;
      if cm.deterselect(1,1)==1;
         fixed = 1;
      elseif cm.deterselect(1,2)==1;
         fixed = 0;
      elseif cm.deterselect(1,3)==1;
         fixed = 2;
      elseif cm.deterselect(1,4)==1;
         fixed = 1;
      end;
      for i=1:cm.d-fixed;
         if i==1;
            cm.deter = 'd_1';
         else;
            cm.deter = [cm.deter ' d_' num2str(i)];
         end;
      end;
   end;
end;

if strcmp(cm.constvec,'')==0;
   cm.deter = [cm.constvec ' ' cm.deter];
end;

[cm.x1,cm.deter,cm.deterdel] = checkdeter(cm.x1,cm.x1_r,cm.deter);
cm.d = size(cm.x1,2);
if cm.deterselect(1,3)==1;
   cm.dd = cm.d-1;
else;
   cm.dd = cm.d;
end;

if strcmp(cm.xvars1,'')==1;
   i = 1;
   while i<=origq1;
      if i==1;
         cm.xvars1 = 'x1_1';
      else;
         cm.xvars1 = [cm.xvars1 ' x1_' num2str(i)];
      end;
      i = i+1;
   end;
end;

if strcmp(cm.xvars0,'')==1;
   i = 1;
   cm.q = size(cm.x2,2);
   while i<=cm.q-cm.q1;
      if i==1;
         cm.xvars0 = 'x0_1';
      else;
         cm.xvars0 = [cm.xvars0 ' x0_' num2str(i)];
      end;
      i = i+1;
   end;
end;

%
% extra check in case cm.x3 moved to cm.x2 (Rahbek&Mosconi fix)
%

if strcmp(cm.xvars0,'')==1;
   if extrai0>0;
      for i=1:extrai0;
         if i==1;
            cm.xvars0 = 'x0_1';
         else;
            cm.xvars0 = [cm.xvars0 ' x0_' num2str(i)];
         end;
      end;
   end;
end;

if (curr_ini.rahbek==1)&(isempty(cm.x2)==0);
   if strcmp(cm.xvars0,'')==0;
      cm.xvars0 = stradd(cm.xvars0,'cum');
      if strcmp(cm.xvars1,'')==1;
         cm.xvars1 = cm.xvars0;
      else;
         cm.xvars1 = [cm.xvars1 ' ' cm.xvars0];
      end;
      cm.xvars0 = '';
   end;
end;

%
% Creating data matrices in VECM form
%

check_maxp = 0;

while check_maxp==0;
   %
   %
   %
   txt = strvcat(' ','Checking maximum lag length.',['Current value = ' num2str(cm.maxp,'%0.0f')],'Please hold!');
   set(waitf.text,'String',txt);
   if isempty(cm.x2)==1;
      [cm.Z0,cm.Z1,cm.Z2,cm.Z1t]=vecmdata(cm.x0,cm.maxp,cm.x1);
      cm.q = 0;
      cm.q1 = 0;
      cm.q0 = 0;
      exo = 0;
   else;
      [cm.Z0,cm.Z1,cm.Z2,cm.Z1t]=vecmdata(cm.x0,cm.maxp,cm.x1,cm.x2,cm.q1,cm.maxp);
      cm.q = size(cm.x2,2);
      cm.q0 = cm.q-cm.q1;
      exo = 1;
   end;
   %
   if isempty(cm.x1_r)==0;
      num = size(cm.x1_r,1);
      cm.Z1 = [cm.Z1;cm.x1_r(cm.maxp+1:num,:)'];
      cm.Z1t = [cm.Z1t;cm.x1_r(cm.maxp+1:num,:)'];
   end;
   [cm.n cm.T] = size(cm.Z0);
   nq1 = size(cm.Z1,1);
   nz2 = size(cm.Z2,1);
   if cm.T<nq1+nz2+cm.n;
      cm.maxp = cm.maxp-1;
   else;
      check_maxp = 1;
   end;
   if cm.maxp==0;
      if isempty(mywait)==0;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
      txt = ['The general model you have specified has ' num2str(nq1+nz2,'%0.0f') ' parameters per equation for 1 lag and only ' num2str(cm.T,'%0.0f') ' observations. Hence the maximum lag length is 0 and Structural VAR requires at least 1 lag. You must respecify the model before it can be estimated.'];
      about(txt,'warning','Warning - Too many parameters',120,400);
      check_maxp = 1;
      return,
   end;
end;

%
% check if we can invert the product moment matrices
%
M00 = (1/cm.T)*cm.Z0*cm.Z0';
M11 = (1/cm.T)*cm.Z1*cm.Z1';
if isempty(cm.Z2)==0;
   M22 = (1/cm.T)*cm.Z2*cm.Z2';
   M33 = (1/cm.T)*[cm.Z2;cm.Z1]*[cm.Z2;cm.Z1]';
else;
   M22 = 1;
   M33 = [];
end;
if (max(max(isnan(M00)))==1)|(max(max(isnan(M11)))==1)|(max(max(isnan(M22)))==1);
   if isempty(mywait)==0;
      set(waitf.text,'UserData','done');
      delete(mywait);
      drawnow;
   end;
   txt = 'There has been some errors reading your data. NaN''s were detected in the product moments matrices. Please try running the estimation routine again or check your data.';
   about(txt,'warning','Warning - NaNs Detected',120,400);
   return;
end;
%
checks = zeros(1,3);
if max(size(M00))>rank(M00);
   checks(1,1) = 1;
end;
if max(size(M11))>rank(M11);
   checks(1,2) = 1;
end;
if max(size(M22))>rank(M22);
   checks(1,3) = 1;
end;
check3 = 0;
if isempty(M33)==0;
   if (max(size(M33))>rank(M33))&(max(size(M33))>rank(M33,eps));
      check3 = 1;
   elseif (max(size(M33))>rank(M33))&(max(size(M33))==rank(M33,eps));
      check3 = 2;
   end;
end;
if check3==1;
   if isempty(mywait)==0;
      set(waitf.text,'UserData','done');
      delete(mywait);
      drawnow;
   end;
   txt = 'The model you have specified cannot be estimated. Structural VAR has found multicollinearity among the regressors.';
   about(txt,'warning','Warning - Linear Dependence',120,400);
   return;
elseif check3==2;
   if isempty(mywait)==0;
      set(waitf.text,'UserData','done');
      delete(mywait);
      drawnow;
   end;
   txt ='Structural VAR has found bad scaling among the variabels. The model you have specified will not be estimated on your data since numerical precision will be extremely poor.';
   about(txt,'warning','Warning - Bad Scaling',120,400);
   return;
else;
   if sum(checks)>0;
      if isempty(mywait)==0;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
      txt = strvcat('The model you have specified cannot be estimated. The following product moment matrices are non-invertible:',' ');
      if checks(1,1)==1;
         txt = strvcat(txt,'          * First differences of endogenous variables');
      end;
      if checks(1,2)==1;
         txt = strvcat(txt,'          * Lagged endogenous variables in levels');
      end;
      if checks(1,3)==1;
         txt = strvcat(txt,'          * Lagged first differences and deterministics');
      end;
      txt = strvcat(txt,' ','Your data thus contains linearly dependent variables. Please make sure to remove the redundant variables.');
      about(txt,'warning','Warning - Linear Dependence',120+((sum(checks)-1)*10)+(max((sum(checks)-2)*5,0)),600);
      return;
   end;
end;

%
% now we create data for each lag i having the same number of observations
%

results_mat = [];

for i=1:cm.maxp;
   if cm.cointvalue==1;
      txt = strvcat(' ','Model:',['   lag length:              ' num2str(i,'%4.0f')],['   cointegration rank: ' num2str(cm.n,'%4.0f')]);
   else;
      txt = strvcat(' ','Model:',['   lag length: ' num2str(i,'%4.0f')]);
   end;
   set(waitf.text,'String',txt);
   ss_beg = cm.maxp-i+1;
   ss_end = size(cm.x0,1);
   if isempty(cm.x2)==1;
      if isempty(cm.x1)==0;
         [cm.Z0,cm.Z1,cm.Z2,cm.Z1t]=vecmdata(cm.x0(ss_beg:ss_end,:),i,cm.x1(ss_beg:ss_end,:));
      else;
         [cm.Z0,cm.Z1,cm.Z2,cm.Z1t]=vecmdata(cm.x0(ss_beg:ss_end,:),i,[]);
      end;
      cm.q = 0;
      cm.q1 = 0;
      cm.q0 = 0;
      exo = 0;
   else;
      if isempty(cm.x1)==0;
         [cm.Z0,cm.Z1,cm.Z2,cm.Z1t]=vecmdata(cm.x0(ss_beg:ss_end,:),i,cm.x1(ss_beg:ss_end,:),cm.x2(ss_beg:ss_end,:),cm.q1,i);
      else;
         [cm.Z0,cm.Z1,cm.Z2,cm.Z1t]=vecmdata(cm.x0(ss_beg:ss_end,:),i,[],cm.x2(ss_beg:ss_end,:),cm.q1,i);
      end;
      cm.q = size(cm.x2,2);
      cm.q0 = cm.q-cm.q1;
      exo = 1;
   end;
   %
   if isempty(cm.x1_r)==0;
      num = size(cm.x1_r,1);
      cm.Z1 = [cm.Z1;cm.x1_r(cm.maxp+1:num,:)'];
      cm.Z1t = [cm.Z1t;cm.x1_r(cm.maxp+1:num,:)'];
   end;
   %
   % Estimate the cointegration space
   %
   [cm.S_00,cm.S_01,cm.S_10,cm.S_11,cm.M_02,cm.M_22,cm.M_12,cm.beta,cm.lambda,cm.trace] = mlcointbasic(cm.Z0,cm.Z1,cm.Z2,cm.n);
   %
   % and the other parameters
   %
   cm.alpha = (cm.S_01*cm.beta)/(cm.beta'*cm.S_11*cm.beta);
   if isempty(cm.Z2)==0;
      cm.Psi = (cm.M_02/cm.M_22)-(cm.alpha*cm.beta'*(cm.M_12/cm.M_22));
      cm.epsilon = cm.Z0-(cm.alpha*cm.beta'*cm.Z1)-(cm.Psi*cm.Z2);
   else;
      cm.Psi = [];
      cm.epsilon = cm.Z0-(cm.alpha*cm.beta'*cm.Z1);
   end;
   cm.Omega = (1/cm.T)*cm.epsilon*cm.epsilon';
   cm.df = cm.n*i+cm.q1*(i+1)+cm.q0*(i+1)+cm.d+cm.dcoint;
   %
   % compute the information criteria
   %
   [aic,fpe,hq,sc] = infocrit(cm.epsilon,cm.df);
   m = (cm.n*cm.maxp)+(cm.n+cm.dcoint+cm.q1)+cm.d+(cm.q0*(cm.maxp+1))+(cm.q1*cm.maxp);
   fml = fml_crit(cm.epsilon,m,cm.T-cm.df,cm.n+size(cm.Z1,1)+size(cm.Z2,1)-cm.df);
   %
   % check that all information criteria are real (could be a problem for long lags
   %
   check_val = 0;
   if abs(aic)~=abs(real(aic));
      check_val = 1;
   elseif abs(fpe)~=abs(real(fpe));
      check_val = 1;
   elseif abs(hq)~=abs(real(hq));
      check_val = 1;
   elseif abs(sc)~=abs(real(sc));
      check_val = 1;
   elseif abs(fml)~=abs(real(fml));
      check_val = 1;
   end;
   %
   if (cm.cointvalue==1)&(check_val==0);
      %
      % vary the cointegration rank
      %
      results_mat = [results_mat;[i cm.n aic fpe hq sc fml]];
      for j=1:cm.n;
         r = cm.n-j;
         txt = strvcat(' ','Model:',['   lag length:              ' num2str(i,'%4.0f')],['   cointegration rank: ' num2str(r,'%4.0f')]);
         set(waitf.text,'String',txt);
         if r>0;
            beta = cm.beta(:,1:r);
            cm.alpha = (cm.S_01*beta)/(beta'*cm.S_11*beta);
            if isempty(cm.Z2)==0;
               cm.Psi = (cm.M_02/cm.M_22)-(cm.alpha*beta'*(cm.M_12/cm.M_22));
               cm.epsilon = cm.Z0-(cm.alpha*beta'*cm.Z1)-(cm.Psi*cm.Z2);
            else;
               cm.Psi = [];
               cm.epsilon = cm.Z0-(cm.alpha*beta'*cm.Z1);
            end;
         else;
            if isempty(cm.Z2)==0;
               cm.Psi = (cm.M_02/cm.M_22);
               cm.epsilon = cm.Z0-(cm.Psi*cm.Z2);
            else;
               cm.Psi = [];
               cm.epsilon = cm.Z0;
            end;
         end;
         cm.Omega = (1/cm.T)*cm.epsilon*cm.epsilon';
         dfc = round(((cm.n+cm.q1+cm.dcoint-r)*r)/cm.n);
         cm.df = cm.n*(i-1)+r+cm.q1*i+cm.q0*(i+1)+cm.d+dfc;
         %
         % computing information criteria
         %
         [aic,fpe,hq,sc] = infocrit(cm.epsilon,cm.df);
         fml = fml_crit(cm.epsilon,m,cm.T-cm.df,cm.n+size(cm.Z1,1)+size(cm.Z2,1)-cm.df);
         %
         % check that all information criteria are real (could be a problem for long lags
         %
         check_val = 0;
         if abs(aic)~=abs(real(aic));
            check_val = 1;
         elseif abs(fpe)~=abs(real(fpe));
            check_val = 1;
         elseif abs(hq)~=abs(real(hq));
            check_val = 1;
         elseif abs(sc)~=abs(real(sc));
            check_val = 1;
         elseif abs(fml)~=abs(real(fml));
            check_val = 1;
         end;
         if check_val==0;
            results_mat = [results_mat;[i r aic fpe hq sc fml]];
         end;
      end;
   elseif check_val==0;
      results_mat = [results_mat;[i aic fpe hq sc fml]];
   end;
end;

%
% create a temporary file with the results
%

sp_str = spacestr(curr_ini.decimals-2);
file = [curr_ini.tempdir 'svar-tempfile.txt'];
fid = fopen(file,'wt');
if cm.cointvalue==1;
   header_str = ['   Lags    Rank      AIC   ' sp_str '  log(FPE)  ' sp_str '    HQ    ' sp_str '    SC    ' sp_str '   FML'];
   underline_str = '';
   for i=1:size(header_str,2);
      underline_str = [underline_str '-'];
   end;
   fprintf(fid,'\n%s \n%s \n',header_str,underline_str);
   prt_str = ['    %2.0f      %2.0f    %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f%s    %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f%s    %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f%s   %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f%s   %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f%s \n'];
   for i=1:size(results_mat,1);
      if min(results_mat(:,3))==results_mat(i,3);
         aic_min = '*';
      else;
         aic_min = ' ';
      end;
      if min(results_mat(:,4))==results_mat(i,4);
         fpe_min = '*';
      else;
         fpe_min = ' ';
      end;
      if min(results_mat(:,5))==results_mat(i,5);
         hq_min = '*';
      else;
         hq_min = ' ';
      end;
      if min(results_mat(:,6))==results_mat(i,6);
         sc_min = '*';
      else;
         sc_min = ' ';
      end;
      if min(results_mat(:,7))==results_mat(i,7);
         fml_min = '*';
      else;
         fml_min = ' ';
      end;
      fprintf(fid,prt_str,results_mat(i,1),results_mat(i,2),results_mat(i,3),aic_min,results_mat(i,4),fpe_min,results_mat(i,5),hq_min,results_mat(i,6),sc_min,results_mat(i,7),fml_min);
   end;
   fprintf(fid,'------------------------------------------------------------------------------\n\n');
else;
   header_str = ['   Lags      AIC   ' sp_str '  log(FPE)  ' sp_str '    HQ    ' sp_str '    SC    ' sp_str '   FML'];
   underline_str = '';
   for i=1:size(header_str,2);
      underline_str = [underline_str '-'];
   end;
   fprintf(fid,'\n%s \n%s \n',header_str,underline_str);
   prt_str = ['    %2.0f    %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f%s    %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f%s    %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f%s   %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f%s   %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f%s \n'];
   %
   for i=1:size(results_mat,1);
      if min(results_mat(:,2))==results_mat(i,2);
         aic_min = '*';
      else;
         aic_min = ' ';
      end;
      if min(results_mat(:,3))==results_mat(i,3);
         fpe_min = '*';
      else;
         fpe_min = ' ';
      end;
      if min(results_mat(:,4))==results_mat(i,4);
         hq_min = '*';
      else;
         hq_min = ' ';
      end;
      if min(results_mat(:,5))==results_mat(i,5);
         sc_min = '*';
      else;
         sc_min = ' ';
      end;
      if min(results_mat(:,6))==results_mat(i,6);
         fml_min = '*';
      else;
         fml_min = ' ';
      end;
      fprintf(fid,prt_str,results_mat(i,1),results_mat(i,2),aic_min,results_mat(i,3),fpe_min,results_mat(i,4),hq_min,results_mat(i,5),sc_min,results_mat(i,6),fml_min);
   end;
   fprintf(fid,'---------------------------------------------------------\n\n');
end;
fprintf(fid,'NOTE: Minimum values are represented by an asterisk.\n      AIC: Akaike Information Criterion\n      FPE: Final Prediction Error\n      HQ:  Hannan-Quinn Information Criterion\n      SC:  Schwarz Information Criterion\n      FML: Fractional Marginal Likelihood Criterion\n');
fclose(fid);

%
% Close wait dialogue
%
set(waitf.text,'UserData','done');
delete(mywait);
drawnow;

%
% display the results
%

realscrsz = get(0,'ScreenSize');
prtgui = printgui('init',file,['Model Selection - ' cm.modelfile '.var'],[(realscrsz(3)-700)/2 (realscrsz(4)-500)/2 700 500],'Results',40);
myprint = get(prtgui,'UserData');
set(myprint.print,'UserData','done');
killguipid(prtgui);

if fileexist(file)==1;
   delete_file_fcn(file);
end;

%
% end of model_select.m
%
