%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for selecting normalizing variables %
%          for cointegration rank determination under the        %
%          Bayesian analysis                                     %
%                                                                %
%          Function: normalize_beta_dlg                          %
%                                                                %
%          Input:                                                %
%                       selector: case value string              %
%                       cm: current model structure              %
%                       curr_ini: var.ini settings               %
%                                                                %
%          Output:                                               %
%          	            h: handle                                %
%                                                                %
%          This version:        May 18, 2006                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = normalize_beta_dlg(selector,cm,curr_ini)

if strcmp(selector,'init')==1;
   tm = cm;
   tm.ini = curr_ini;
   tm.realscrsz = get(0,'ScreenSize');
   %
   % calculate width and height
   %
   width = (70*tm.n)+(10*(tm.n-1))+90;
   if width<500;
      width = 500;
   end;
   height = (20*(tm.n-1))+100;
   if tm.n>2;
      height = height+(5*(tm.n-2));
   end;
else;
   norm_beta_gui = findobj('Type','figure','Tag','PropDlg');
   norm_beta_gui_graph = get(norm_beta_gui,'UserData');
   tm = get(norm_beta_gui_graph.cancel,'UserData');
   curr_ini = tm.ini;
end;

switch selector;
   case 'init';
      norm_beta_gui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','normalize_beta_dlg.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(tm.realscrsz(3)-width)/2 (tm.realscrsz(4)-height)/2 width height], ...
         'Tag','PropDlg', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name','Beta Rank Restrictions', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','normalize_beta_dlg done', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(norm_beta_gui,'DockControl','off');
      end;

      axesbox([2 2 width-2 height-10],'Selection',45,[0.5 1]);

      norm_beta_gui_graph.icon = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[20 height-40 40 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String','Rank', ...
         'HorizontalAlignment','left', ...
         'Tag','RankTextHeader');

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[60 height-40 (tm.n*70)+(10*(tm.n-1)) 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String','Normalize beta on the variables', ...
         'HorizontalAlignment','center', ...
         'Tag','NormTextHeader');

      norm_beta_gui_graph.controls = zeros(tm.n-1,tm.n);
      num = 0;
      for i=1:tm.n-1;
         %
         % text controls
         %
         uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[20 50+num 10 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','text', ...
            'String',num2str(tm.n-i,'%0.0f'), ...
            'HorizontalAlignment','right', ...
            'Tag','RankText');
         w_add = 0;
         for j=1:tm.n;
            %
            % checkboxes
            %
            norm_beta_gui_graph.controls(tm.n-i,j) = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[70+w_add 50+num 70 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','checkbox', ...
            'String',strtrim(tm.myvars(j,:)), ...
            'HorizontalAlignment','left', ...
            'Value',tm.rank_norm_data(tm.n-i,j), ...
            'Tag','CheckText');
            w_add = w_add+80;
         end;
         num = num+25;
      end;


      norm_beta_gui_graph.ok = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-310 20 90 20], ...
         'String','OK', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','normalize_beta_dlg done', ...
         'Enable','on', ...
         'Tag','Done');

      norm_beta_gui_graph.cancel = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-210 20 90 20], ...
         'String','Cancel', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','normalize_beta_dlg cancel', ...
         'Enable','off', ...
         'UserData',tm, ...
         'Tag','Done');

      norm_beta_gui_graph.apply = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-110 20 90 20], ...
         'String','Apply', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','normalize_beta_dlg apply', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','Done');

      set(norm_beta_gui,'UserData',norm_beta_gui_graph,...
         'HandleVisibility','callback');

   case 'cancel'
      for i=1:tm.n-1;
         for j=1:tm.n;
            set(norm_beta_gui_graph.controls(i,j),'Value',tm.rank_norm_data(i,j));
         end;
      end;
      %
      % fix the norm file
      %
      file = [tm.modelsdir tm.modelfile '-ranknorm-' num2str(tm.n,'%0.0f') '.norm'];
      fid = fopen(file,'wt');
      prt_str = '%2.0f';
      for i=1:tm.n-1;
         prt_str = [prt_str ' %2.0f'];
      end;
      prt_str = [prt_str '\n'];
      for i=1:tm.n-1;
         fprintf(fid,prt_str,tm.rank_norm_data(i,:));
      end;
      fclose(fid);
      %
      %
      set(norm_beta_gui_graph.cancel,'Enable','off');
   case 'apply'
      %
      % collect the data from the checkbox controls
      %
      rank_norm_data = zeros(tm.n-1,tm.n);
      for i=1:tm.n-1;
         for j=1:tm.n;
            rank_norm_data(i,j) = get(norm_beta_gui_graph.controls(i,j),'Value');
         end;
      end;
      ch_data = sum(rank_norm_data,2);
      if sum(ch_data==(1:1:tm.n-1)')==tm.n-1;
         file = [tm.modelsdir tm.modelfile '-ranknorm-' num2str(tm.n,'%0.0f') '.norm'];
         fid = fopen(file,'wt');
         prt_str = '%2.0f';
         for i=1:tm.n-1;
            prt_str = [prt_str ' %2.0f'];
         end;
         prt_str = [prt_str '\n'];
         for i=1:tm.n-1;
            fprintf(fid,prt_str,rank_norm_data(i,:));
         end;
         fclose(fid);
         set(norm_beta_gui_graph.cancel,'Enable','on');
      else;
         txt = 'The number of check marked variables for each rank must match the rank. Please change your selections.';
         about(txt,'error','Normalization Error...',120,450);
      end;
   case 'done'
      set(norm_beta_gui_graph.apply,'UserData','done');
end;

if nargout==1;
   h = norm_beta_gui;
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(norm_beta_gui,'Name') ' ' fix_filepath([pwd '\icons\var_rankfile.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(norm_beta_gui_graph.icon,'UserData',pid);
      end;
   end;
   %
   set(norm_beta_gui,'Visible','on');
   drawnow;
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(norm_beta_gui,'Name') ' 3'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(norm_beta_gui_graph.ok);
   end;
   waitfor(norm_beta_gui_graph.apply,'UserData','done');
end;

%
% end of normalize_beta_dlg.m
%
