%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for selecting restrictions on alpha %
%                                                                %
%          Function: openalpharestgui                            %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       cm: structure with model info            %
%                       modelsdir_: text string with path to the %
%                           G-x.rest files with restrictions     %
%                           (can be a string with a space)       %
%                       modelfile_: name of model                %
%                       n_: number of endogenous variables       %
%                       r_: number of cointegration relations    %
%                                                                %
%          Output:                                               %
%                       h = handle                               %
%                                                                %
%          This version:        May 18, 2006                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = openalpharestgui(selector,cm)

if strcmp(selector,'init')==1;
   tm = cm;
   curr_ini = find_inisettings;
   thisexit = 0;
   mycons = getstoredimages;
   bgcolor = get(0,'defaultuicontrolbackgroundcolor');
   mybrowse = maketrans(mycons.browse_image,[160 160 164],bgcolor);
   tm.restfile = tm.modelsdir;
else;
   thisexit = 1;
%   openalpharestdlg = get(0,'CurrentFigure');
   openalpharestdlg = findobj('Type','figure','Tag','OpenRestAlpha');
   openalpharest = get(openalpharestdlg,'UserData');
   curr_ini = get(openalpharest.restfile,'UserData');
   tm = curr_ini.models;
end;

%
% Set screen size directly instead of using
% get(0,'ScreenSize')!
%

scrsz = [1 1 1024 768];
realscrsz = get(0,'ScreenSize');

switch selector;
   case 'init';
      openalpharestdlg = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','openalpharestgui.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(realscrsz(3)-512)/2 (realscrsz(4)-395)/2 512 395], ...
         'Tag','OpenRestAlpha', ...
         'Resize','off', ...
         'Name','Open Alpha Restrictions', ...
         'NumberTitle','off', ...
         'Visible','off', ...
         'CloseRequestFcn','openalpharestgui exit', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(openalpharestdlg,'DockControl','off');
      end;

      %
      % Outer axis
      %

      axesbox([2 2 510 385],'Restrictions on Alpha',105,[0.5 1]);

      %
      % GUI Header
      %

      mycons = getstoredimages;
      header_txt = 'Select Alpha Restrictions File';
      desc_txt = 'Open a restrictions file (*.rest) by pressing on the "Browse" button and view its content in the display. When you''re satisfied it''s the one you wish to use, press "Apply" to make setting permanent. Press "Done" to finish.';
      dialog_header_fcn([14 300 484 72],mirrorimage(maketrans(mycons.openalphabig_image,[160 160 164],[1 1 1])),header_txt,desc_txt);

      %
      % Outer axis for showing restrictions file
      %

      axesbox([14 100 484 182],'The Restrictions',80,[0.5 1]);

      %
      % Outer axis for restrictions file
      %

      axesbox([14 14 380 73],'Restrictions Selection',105,[0.5 1]);

      %
      % Listbox to show restrictions on alpha
      %

      openalpharest.gmat = uicontrol('Units','pixels', ...
         'BackgroundColor','white', ...
         'Position',[30 116 452 150], ...
         'Style','listbox', ...
         'FontSize',10, ...
         'FontName','FixedWidth', ...
         'Max',2, ...
         'Value',[], ...
         'String','', ...
         'Enable','inactive', ...
         'UserData','working', ...
         'HorizontalAlignment','center', ...
         'Tag','BetaListbox');

      %
      % Show restrictions file
      %

      openalpharest.icon = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[30 50 150 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','text', ...
         'HorizontalAlignment','left', ...
      	 'String','Restrictions file:', ...
      	 'Tag','ShowRest');

      openalpharest.restfile = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[30 30 295 22], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','edit', ...
         'HorizontalAlignment','left', ...
         'String',tm.modelsdir, ...
         'Callback','openalpharestgui checkrest', ...
         'Enable','on', ...
         'Tag','RestFile');

      %
      % Button for selecting output file
      %

      openalpharest.restbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[330 30 50 22], ...
         'TooltipString','Browse', ...
         'CData',mybrowse, ...
         'Callback','openalpharestgui openrest', ...
         'Enable','on', ...
         'Tag','RestButton');

      %
      % Use Restrictions button
      %

      openalpharest.use = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[408 48 90 20], ...
         'String','Apply', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','openalpharestgui use', ...
         'Enable','off', ...
         'UserData','waiting', ...
         'Tag','UseButton');

      %
      %  Done button
      %

      openalpharest.done = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[408 14 90 20], ...
         'String','Done', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','openalpharestgui done', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','DoneButton');

      set(openalpharestdlg,'UserData',openalpharest,...
         'HandleVisibility','callback');
   case 'openrest'
      if (iscompiled==1)&(iswinnt==1)&(curr_ini.opendialog==1)&(matlabnumber<6.0);
         newrestfile = get(openalpharest.restfile,'String');
         basedir = getpath(newrestfile);
         file_fltr = 'VAR Restrictions Files (*.rest)|*.rest|';
         best_pos = 1;
         title_txt = 'Select file or enter filename';
         [newrestfile,restpath] = fileopen(basedir,file_fltr,best_pos,title_txt);
      else;
         newrestfile = get(openalpharest.restfile,'String');
         newrestfile = getpath(newrestfile);
         newrestfile = strcat(newrestfile,'*.rest');
         [newrestfile,restpath] = uigetfile(newrestfile, 'Select file or enter filename');
      end;
      drawnow;
      if isnumeric(newrestfile)==0;
         newrestfile = strcat(restpath,newrestfile);
         if fileexist(newrestfile)==1;
            gvar = loaddata(newrestfile);
            [gv1 gv2] = size(gvar);
            [Rmat,rvec] = rmatrix(gvar,tm.n,tm.r);
            Rmat = Rmat(1:size(Rmat,1),1:tm.n*tm.r);
            if rank(Rmat)==gv1;
               checkalpha = null(Rmat,'r');
               checkalpha = checkalpha*randn(size(checkalpha,2),1);
               checkalpha = checkalpha+(Rmat'*inverse(Rmat*Rmat')*rvec);
               checkalpha = vecinv(checkalpha,tm.n);
               if rank(checkalpha)==tm.r;
                  %
                  % load restrictions into gui
                  %
                  tm.restfile = newrestfile;
                  set(openalpharest.restfile,'String',tm.restfile);
                  set(openalpharest.use,'Enable','on');
                  myrest = ' ';
                  for i=1:gv1;
                     thisrest = '';
                     k = 1;
                     l = 1;
                     for j=1:tm.n*tm.r;
                        if abs(Rmat(i,j))>0;
                           if Rmat(i,j)==1;
                              if strcmp(thisrest,'')==1;
                                 thisrest = ['   alpha(' num2str(l) ',' num2str(k) ')'];
                              else;
                                 thisrest = [thisrest ' + alpha(' num2str(l) ',' num2str(k) ')'];
                              end;
                           elseif Rmat(i,j)==-1;
                              if strcmp(thisrest,'')==1;
                                 thisrest = ['   - alpha(' num2str(l) ',' num2str(k) ')'];
                              else;
                                 thisrest = [thisrest ' - alpha(' num2str(l) ',' num2str(k) ')'];
                              end;
                           else;
                              if Rmat(i,j)>0;
                                 if strcmp(thisrest,'')==1;
                                    thisrest = ['   ' num2str(Rmat(i,j),'%1.2f') '*alpha(' num2str(l) ',' num2str(k) ')'];
                                 else;
                                    thisrest = [thisrest ' + ' num2str(Rmat(i,j),'%1.2f') '*alpha(' num2str(l) ',' num2str(k) ')'];
                                 end;
                              else;
                                 if strcmp(thisrest,'')==1;
                                    thisrest = ['   - ' num2str(abs(Rmat(i,j)),'%1.2f') '*alpha(' num2str(l) ',' num2str(k) ')'];
                                 else;
                                    thisrest = [thisrest ' - ' num2str(abs(Rmat(i,j)),'%1.2f') '*alpha(' num2str(l) ',' num2str(k) ')'];
                                 end;
                              end;
                           end
                        end;
                        if k==floor(j/tm.n);
                           k = k+1;
                           l = 1;
                        else;
                           l=l+1;
                        end;
                     end;
                     if abs(rvec(i,1))==0;
                        thisrest = [thisrest ' = 0'];
                     else;
                        thisrest = [thisrest ' = ' num2str(rvec(i,1),'%1.2f')];
                     end;
                     myrest = strvcat(myrest,thisrest);
                     set(openalpharest.gmat,'String',myrest);
                  end;
               else;
                  txt = ['The file you selected implies that alpha has rank ' num2str(rank(checkalpha)) ', i.e. less than the number of cointegration vectors. Please select another file!'];
                  about(txt,'warning',['Restrictions on Alpha - Information'],120,350);
               end;
            else;
               if rank(Rmat)>=1;
                  txt = ['The ' num2str(gv1) ' restrictions you have selected for alpha are linearly dependent, i.e. the rank of the restrictions matrix is ' num2str(rank(Rmat)) '. Please select another file'];
               else;
                  txt = ['The file you selected, ' getname(newrestfile) ', doesn''t contain any restrictions. Please select another file!'];
               end;
               about(txt,'warning',['Restrictions on Alpha - Information'],120,350);
            end;
         else;
            set(openalpharest.restfile,'String',tm.restfile);
            if fileexist(tm.restfile)==1;
               set(openalpharest.use,'Enable','on');
            else;
               set(openalpharest.use,'Enable','off');
            end;
         end;
      else;
         set(openalpharest.restfile,'String',tm.restfile);
         if fileexist(tm.restfile)==1; 
            set(openalpharest.use,'Enable','on');
         else;
            set(openalpharest.use,'Enable','off');
         end;
      end;
      set(openalpharestdlg,'UserData',openalpharest);
   case 'checkrest'
      newrestfile = get(openalpharest.restfile,'String');
      if fileexist(newrestfile)==0;
         set(openalpharest.restfile,'String',tm.restfile);
         if fileexist(tm.restfile)==1;
            set(openalpharest.use,'Enable','on');
         else;
            set(openalpharest.use,'Enable','off');
         end;
      else;
         gvar = loaddata(newrestfile);
         [gv1 gv2] = size(gvar);
         [Rmat,rvec] = rmatrix(gvar,tm.n,tm.r);
         Rmat = Rmat(1:size(Rmat,1),1:tm.n*tm.r);
         if rank(Rmat)==gv1;
            checkalpha = null(Rmat,'r');
            checkalpha = checkalpha*randn(size(checkalpha,2),1);
            checkalpha = checkalpha+(Rmat'*inverse(Rmat*Rmat')*rvec);
            checkalpha = vecinv(checkalpha,tm.n);
            if rank(checkalpha)==tm.r;
               %
               % load restrictions into gui
               %
               tm.restfile = newrestfile;
               set(openalpharest.restfile,'String',tm.restfile);
               set(openalpharest.use,'Enable','on');
               myrest = ' ';
               for i=1:gv1;
                  thisrest = '';
                  k = 1;
                  l = 1;
                  for j=1:tm.n*tm.r;
                     if abs(Rmat(i,j))>0;
                        if Rmat(i,j)==1;
                           if strcmp(thisrest,'')==1;
                              thisrest = ['   alpha(' num2str(l) ',' num2str(k) ')'];
                           else;
                              thisrest = [thisrest ' + alpha(' num2str(l) ',' num2str(k) ')'];
                           end;
                        elseif Rmat(i,j)==-1;
                           if strcmp(thisrest,'')==1;
                              thisrest = ['   - alpha(' num2str(l) ',' num2str(k) ')'];
                           else;
                              thisrest = [thisrest ' - alpha(' num2str(l) ',' num2str(k) ')'];
                           end;
                        else;
                           if Rmat(i,j)>0;
                              if strcmp(thisrest,'')==1;
                                 thisrest = ['   ' num2str(Rmat(i,j),'%1.2f') '*alpha(' num2str(l) ',' num2str(k) ')'];
                              else;
                                 thisrest = [thisrest ' + ' num2str(Rmat(i,j),'%1.2f') '*alpha(' num2str(l) ',' num2str(k) ')'];
                              end;
                           else;
                              if strcmp(thisrest,'')==1;
                                 thisrest = ['   - ' num2str(abs(Rmat(i,j)),'%1.2f') '*alpha(' num2str(l) ',' num2str(k) ')'];
                              else;
                                 thisrest = [thisrest ' - ' num2str(abs(Rmat(i,j)),'%1.2f') '*alpha(' num2str(l) ',' num2str(k) ')'];
                              end;
                           end;
                        end
                     end;
                     if k==floor(j/tm.n);
                        k = k+1;
                        l = 1;
                     else;
                        l=l+1;
                     end;
                  end;
                  if abs(rvec(i,1))==0;
                     thisrest = [thisrest ' = 0'];
                  else;
                     thisrest = [thisrest ' = ' num2str(rvec(i,1),'%1.2f')];
                  end;
                  myrest = strvcat(myrest,thisrest);
                  set(openalpharest.gmat,'String',myrest);
               end;
            else;
               txt = ['The file you selected implies that alpha has rank ' num2str(rank(checkalpha)) ', i.e. less than the number of cointegration vectors. Please select another file!'];
               about(txt,'warning',['Restrictions on Alpha - Information'],120,350);
               set(openalpharest.restfile,'String',tm.restfile);
            end;
         else;
            if rank(Rmat)>=1;
               txt = ['The ' num2str(gv1) ' restrictions you have selected for alpha are linearly dependent, i.e. the rank of the restrictions matrix is ' num2str(rank(Rmat)) '. Please select another file'];
            else;
               txt = ['The file you selected, ' getname(newrestfile) ', doesn''t contain any restrictions. Please select another file!'];
            end;
            about(txt,'warning',['Restrictions on Alpha - Information'],120,350);
            set(openalpharest.restfile,'String',tm.restfile);
         end;
      end;
      set(openalpharestdlg,'UserData',openalpharest);
   case 'use'
      tm.restfile = get(openalpharest.restfile,'String');
      if curr_ini.sillyq==0;
         txt = 'Are you sure you want to use these restrictions for alpha?';
         answer = query(txt,'question',120,'Use Restrictions on Alpha...',350);
      else;
         answer = 'Yes';
      end;
      if strcmp(answer,'Yes')==1;
         gmat = loaddata(tm.restfile);
         newrestfile = strcat(tm.modelsdir,'G-',num2str(tm.n),'x',num2str(tm.r),'-',tm.modelfile,'.rest');
         myprintstr = '%2.4f';
         for j=2:size(gmat,2);
            myprintstr = [myprintstr ' %2.4f'];
         end;
         myprintstr = [myprintstr '\n'];
         fid = fopen(newrestfile,'wt');
         fprintf(fid,myprintstr,gmat');
         fclose(fid);
         set(openalpharest.use,'Enable','off');
         setlogtext(strvcat(' ',['You decided to use "' getfilename(tm.restfile) '"'],['   for restricting alpha...']));
      end;
      set(openalpharestdlg,'UserData',openalpharest);
   case 'done'
      set(openalpharest.done,'UserData','done');
   case 'exit'
      set(openalpharest.done,'UserData','done');
%      if strcmp(get(openalpharest.gmat,'UserData'),'done')==1;
%         delete(openalpharestdlg);
%      end;
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(openalpharestdlg,'Name') ' ' fix_filepath([pwd '\icons\var_restfile.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(openalpharest.icon,'UserData',pid);
      end;
   end;
   set(openalpharestdlg,'Visible','on');
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(openalpharestdlg,'Name') ' 1'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(openalpharest.done);
   end;
end;

if nargout==1;
   h = openalpharestdlg;
end;

if strcmp(selector,'exit')==0;
   curr_ini.models = tm;
   set(openalpharest.restfile,'UserData',curr_ini);
end;

if thisexit==0;
   waitfor(openalpharest.done,'UserData','done');
end;

%
% end of openalpharestgui.m
%
