%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for displaying graphs of            %
%          parameter distributions                               %
%                                                                %
%          Function: param_graphdlg                              %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       c_m: structure with model info           %
%                       beta_param: string matrix with names     %
%                          for the parameters                    %
%                       beta_sorted: matrix with sorted values   %
%                          for the parameters                    %
%                       param_str: string vector with info about %
%                          the parameters                        %
%                       graph_title: string vector with base     %
%                          title                                 %
%                       fig_title: string vector with base name  %
%                          for figure                            %
%                       graph_type: string vector being function %
%                          or histogram depending on the type    %
%                          of graph that should be plotted       %
%                       add_height: No of pixels to add to the   %
%                          height of the text control            %
%                                                                %
%          Output:                                               %
%          	            h: handle                                %
%                                                                %
%          This version:        May 3, 2006                      %
%          Written by:          Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = param_graphdlg(selector,c_m,beta_param,beta_sorted,name,param_str,graph_title,fig_title,graph_type,add_height)

if strcmp(selector,'init')==1;
   thisexit = 0;
   curr_ini = find_inisettings;
   if isnumeric(curr_ini.external)==0;
      curr_ini.external = 0;
   end;
   c_m.ini = curr_ini;
   c_m.beta_sorted = beta_sorted;
   c_m.realscrsz = get(0,'ScreenSize');
   c_m.graph_title = graph_title;
   c_m.fig_title = fig_title;
   c_m.graph_type = graph_type;
else
   thisexit = 1;
   param_graphgui = findobj('Type','figure','Tag','ParamGraphDlg');
   param_graph = get(param_graphgui,'UserData');
end;

switch selector;
   case 'init';
      param_graphgui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','param_graphdlg.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(c_m.realscrsz(3)-341)/2 (c_m.realscrsz(4)-140)/2 341 140], ...
         'Tag','ParamGraphDlg', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name',name, ...
         'NumberTitle','off', ...
         'CloseRequestFcn','param_graphdlg done', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(param_graphgui,'DockControl','off');
      end;

      %
      % Outer axis
      %

      axesbox([2 2 339 130],'Graphics',45,[0.5 1]);

      imageaxes = axes('Units','pixels', ...
         'Box','on', ...
         'TickLength',[0 0], ...
         'CameraUpVector',[0 1 0], ...
         'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 80 39 39], ...
         'XTickLabelMode','manual', ...
         'YTickLabelMode','manual', ...
         'Tag','AxisLogo', ...
         'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

      mycons = getstoredimages;
      if curr_ini.use_toolbar_bgcolor==1;
         bgcolor = (1/255)*(round(255*get(0,'defaultuicontrolbackgroundcolor'))-[8 4 8]);
         bgcolor(1) = max(0,bgcolor(1));
         bgcolor(2) = max(0,bgcolor(2));
         bgcolor(3) = max(0,bgcolor(3));
      else;
         bgcolor = get(0,'defaultuicontrolbackgroundcolor');
      end;
      %
      image('CData',mirrorimage(maketrans(mycons.betamatlab_image,[160 160 164],bgcolor)),'Clipping','off','Parent',imageaxes);

      param_graph.icon = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 50 200 20+add_height], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String',param_str, ...
         'HorizontalAlignment','left', ...
         'Tag','SampleText');

      if strcmp(c_m.freq,'q')==1;
         set(param_graph.icon,'String',strrep(get(param_graph.icon,'String'),'period','quarter'));
      elseif strcmp(c_m.freq,'m')==1;
         set(param_graph.icon,'String',strrep(get(param_graph.icon,'String'),'period','month'));
      end;

      %
      % Select variable
      %

      param_graph.variables = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 16 80 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'UserData',c_m, ...
         'String','Parameter:', ...
         'HorizontalAlignment','left', ...
         'Tag','VariableText');


      param_graph.popup = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[105 20 100 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'String',beta_param, ...
         'HorizontalAlignment','center', ...
         'Tag','GraphPopup',...
         'Value',1);

      %
      % Create graph button
      %

      param_graph.show = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[236 55 90 20], ...
         'String','Display', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','param_graphdlg showgraph', ...
         'Enable','on', ...
         'UserData','working', ...
         'Tag','Done');

      %
      %  Done button
      %

      param_graph.done = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[236 20 90 20], ...
         'String','Done', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','param_graphdlg done', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','Done');

      set(param_graphgui,'UserData',param_graph,...
         'HandleVisibility','callback');
   case 'showgraph'
      c_m = get(param_graph.variables,'UserData');
      curr_ini = c_m.ini;
      curr_val = get(param_graph.popup,'Value');
      if curr_val==size(c_m.beta_sorted,2);
         new_val = 1;
      else;
         new_val = curr_val+1;
      end;
      curr_param = get(param_graph.popup,'String');
      curr_param = strtrim(curr_param(curr_val,:));
      set(param_graph.popup,'Value',new_val);
      i1 = findstr(curr_param,'(');
      if isempty(i1)==0;
         tag_name = curr_param(1,1:i1-1);
         i2 = findstr(curr_param,')');
         index_str = curr_param(1,i1+1:i2-1);
         index_str = strrep(index_str,',','-');
         v_istr = vecstr(strrep(index_str,'-',' '));
      else;
         tag_name = curr_param;
         v_istr = '';
      end;
      tex_param = ['\' tag_name];
      if isempty(v_istr)==0;
         tex_param = [tex_param  '_{' strtrim(v_istr(1,:)) strtrim(v_istr(2,:)) '}'];
         tag_name = [tag_name '-' index_str '-plot-'];
      else;
         tag_name = [tag_name '-plot-'];
      end;
      lag_param = '';
      if size(v_istr,1)>2;
         lag_str = [' for lag ' strtrim(v_istr(3,:))];
      end;
      %
      % prepare for the graph
      %
      beta_sorted = c_m.beta_sorted(:,curr_val);
      if curr_ini.colors==1;
         col.vec_1 = [0 0 1];
         col.vec_2 = [1 0 0];
         col.vec_3 = [0 0.75 0];
         col.vec_4 = [1 0.5 0];
         col.vec_5 = [0 0.75 0.75];
         col.vec_6 = [0 0 0];
         col.vec_7 = (1/255)*[255 28 28];
         col.vec_8 = [0 1 0];
         col.vec_9 = (1/255)*[255 255 177];
      else;
         col.vec_1 = [0 0 0];
         col.vec_2 = [0.7 0.7 0.7];
         col.vec_3 = [0.6 0.6 0.6];
         col.vec_4 = [0.5 0.5 0.5];
         col.vec_5 = [0.4 0.4 0.4];
         col.vec_6 = [0.3 0.3 0.3];
         col.vec_7 = [0.8 0.8 0.8];
         col.vec_8 = [0.2 0.2 0.2];
         col.vec_9 = col.vec_3;
      end;
      pos = [(c_m.realscrsz(3)-600)/2 (c_m.realscrsz(4)-400)/2];
      if strcmp(c_m.graph_type,'histogram')==0;
         t_str = [' with ' num2str(c_m.cbs,'%0.0f') '% confidence bands'];
      else;
         t_str = '';
      end;
      %
      [pos,bplot] = bayes_parm_dist(pos,tag_name,[c_m.fig_title ' - ' curr_param],[c_m.graph_title ' ' tex_param lag_str ' based on ' num2str(c_m.dist_draws,'%0.0f') ' draws' t_str],c_m,curr_ini,beta_sorted,curr_param,col);
      if curr_ini.external==0;
         set(bplot,'Visible','on');
      else;
         file = [c_m.outputdir c_m.modelfile '-' tag_name c_m.graph_type];
         set(0,'CurrentFigure',bplot);
         stat = autosavefigure(bplot,file);
         if isempty(stat)==0;
            if stat==0;
               autoshowfigure(file);
            end;
         end;
      end;
   case 'done'
      set(param_graph.done,'UserData','done');
      set(param_graphgui,'UserData',param_graph);
end;

if thisexit==0;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(param_graphgui,'Name') ' ' fix_filepath([pwd '\icons\matfile.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(param_graph.icon,'UserData',pid);
      end;
   end;
   %
   set(param_graphgui,'Visible','on');
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(param_graphgui,'Name') ' 1'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(param_graph.done);
   end;
   waitfor(param_graph.done,'UserData','done');
end;

if nargout==1;
   h = param_graphgui;
end;

%
% end of param_graphdlg.m
%
