function dist = ploberger(x,k,trunc)

%
% computes the probability that x0 is less than or equal
% to x for a truncation value (trunc) and for dimension
% k using equation (10) in Ploberger W, Krmer, W and Kontrus, K
% (1989), "A New Test for Structural Stability in the
% Linear Regression Model", Journal of Econometrics, 40,
% p. 307-318. The truncation value is due to an infinite
% sum being approximated. The larger, the better the approximation.
%

if nargin<3;
   trunc = 5000;
   if nargin<2;
      k = 1;
   end;
end;

if size(x,2)>size(x,1);
   x = x';
end;

n = size(x,1);

dist = zeros(n,1);

for j=1:n;
   if x(j,1)>0;
      distj = 0;
      for i=1:trunc;
         if isodd(i)==1;
            distj = distj-2*exp(-2*i*i*x(j,1)*x(j,1));
         else;
            distj = distj+2*exp(-2*i*i*x(j,1)*x(j,1));
         end;
      end;
      distj = (1+distj)^k;
      if distj<0;
         distj = 0;
      end;
   else;
      distj = 0;
   end;
   dist(j,1) = distj;
end;

%
% end of ploberger.m
%
