function dist = ploberger_cdf(x,k,trunc)

%
% computes the probability that x0 is less than or equal
% to x for a truncation value (trunc) and for dimension
% k using equation (10) in Ploberger W, Krmer, W and Kontrus, K
% (1989), "A New Test for Structural Stability in the
% Linear Regression Model", Journal of Econometrics, 40,
% p. 307-318. The truncation value is due to an infinite
% sum being approximated. The larger, the better the approximation.
%

if nargin<3;
   trunc = [];
   if nargin<2;
      k = 1;
   end;
end;

if size(x,2)>size(x,1);
   x = x';
end;
x = x(:,1);

n = size(x,1);

dist = ones(n,1);
if ispc==1;
   file = [pwd '\mat\ploberger.mat'];
else;
   file = [pwd '/mat/ploberger.mat'];
end;
my_dist = load(file);
my_table = my_dist.quantiles(:,k);
quantiles = quantiles_fcn;

for i=1:n;
   for j=1:221;
      if my_table(221-j+1,1)<=x(i,1);
         pos = 221-j+1;
         break;
      end;
      if j==221;
         pos = 1;
      end;
   end;
   if (pos>1)&(pos<221);
      x1 = my_table(pos-1,1);
      x2 = my_table(pos,1);
      beta = (x(i,1)-x1)/(x2-x1);
      z1 = quantiles(pos-1,1);
      z2 = quantiles(pos,1);
      dist(i,1) = ((1-beta)*z1)+(beta*z2);
   elseif pos==1;
      dist(i,1) = 0.0000;
   end;
end;

%
% end of ploberger_cdf.m
%
