function print_stationarity(tm,curr_ini,showwait)

if nargin==2;
   showwait = 1;
end;
%
% compute the tests
%
if (tm.deterselect(1,1)==1)|(tm.deterselect(1,3)==1);
   [tests,deg_free,pvals] = coint_stationarity(tm.Z0,tm.Z1,tm.Z2,tm.epsilon,tm.r,tm.q1,tm.dcoint,tm.df,curr_ini.sscorrect);
else;
   [tests,deg_free,pvals] = coint_stationarity_dcoint(tm.Z0,tm.Z1,tm.Z2,tm.myvars,tm.epsilon,tm.beta(:,1:tm.r),tm.r,tm.q1,tm.dcoint,tm.df,curr_ini.sscorrect,curr_ini.convcrit,curr_ini.betagrad,curr_ini.maxit,showwait);
end;
%
add_str = '';
if (tm.deterselect(1,3)==1)|(tm.deterselect(1,4)==1);
   add_str = ' trend';
end;
%
fout = fopen(tm.outputfile,'at');
%
% check the output format
%
if curr_ini.texoutputformat>=2;
   fprintf(fout,['\\subsection*{Stationarity Restrictions}\n\n\\header{For $r$=' num2str(tm.r) '}\n\n']);
   fprintf(fout,'\\header{LR-type test statistic}\n');
   fprintf(fout,'\\begin{tabular}{ll}\n');
   fprintf(fout,'$H_0$: & variable $k$ is%s stationary \\\\\n',add_str);
   fprintf(fout,'$H_A$: & variable $k$ is not%s stationary \\\\[2mm]\n',add_str);
   fprintf(fout,'\\end{tabular}\n\n\\begin{tabular}{rrrr}\n');
   if curr_ini.sscorrect==0;
      fprintf(fout,'$k$ & $LR$ & df & $p$-value \\\\\n');
      for i=1:size(tests,1);
         fprintf(fout,['%s & %0.' num2str(curr_ini.decimals,'%0.0f') 'f & %0.0f & %0.' num2str(curr_ini.decimals,'%0.0f') 'f \\\\\n'],txt2ltxmath(strtrim(tm.myvars(i,:))),tests(i,1),deg_free(i,1),pvals(i,1));
      end;
   else;
      fprintf(fout,'$k$ & $F$ & df & $p$-value \\\\\n');
      for i=1:size(tests,1);
         fprintf(fout,['%s & %0.' num2str(curr_ini.decimals,'%0.0f') 'f & (%0.0f,%0.0f) & %0.' num2str(curr_ini.decimals,'%0.0f') 'f \\\\\n'],txt2ltxmath(strtrim(tm.myvars(i,:))),tests(i,1),deg_free(i,1),deg_free(i,2),pvals(i,1));
      end;
   end;
   fprintf(fout,'\\end{tabular}\n\n\\ruler\n\n%%==============================================================================\n\n');
else;
   fprintf(fout,['STATIONARITY RESTRICTIONS (for rank=' num2str(tm.r,'%0.0f') ') \n\n']);
   fprintf(fout,'  LR-type test statistic\n  ~~~~~~~~~~~~~~~~~~~~~~\n\n');
   fprintf(fout,'Null Hypothesis:        variable k is%s stationary\n',add_str);
   fprintf(fout,'Alternative Hypothesis: variable k is not%s stationary\n\n',add_str);
   if curr_ini.sscorrect==0;
      fprintf(fout,' k         LR       df      p-value\n');
      prt_str = ['%s      %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f    %2.0f       %0.' num2str(curr_ini.decimals,'%0.0f') 'f \n'];
      for i=1:size(tests,1);
         fprintf(fout,prt_str,tm.myvars(i,:),tests(i,1),deg_free(i,1),pvals(i,1));
      end;
   else;
      fprintf(fout,' k         F         df         p-value\n');
      prt_str = ['%s      %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f    (%0.0f,%0.0f)       %0.' num2str(curr_ini.decimals,'%0.0f') 'f \n'];
      for i=1:size(tests,1);
         fprintf(fout,prt_str,tm.myvars(i,:),tests(i,1),deg_free(i,1),deg_free(i,2),pvals(i,1));
      end;
   end;
   fprintf(fout,'\n===============================================================================\n\n');
end;

fclose(fout);


%
% end of print_stationarity.m
%
