function cdf = beta_cdf(x, a, b)
% PURPOSE: cdf of the beta distribution
%--------------------------------------------------------------
% USAGE: cdf = beta_cdf(x,a,b)
% where:   x = prob[beta(a,b) <= x], x = vector
%          a = beta distribution parameter, a = scalar 
%          b = beta distribution parameter  b = scalar 
% NOTE: mean [beta(a,b)], variance = ab/((a+b)*(a+b)*(a+b+1))
%--------------------------------------------------------------
% RETURNS: cdf at each element of x of the beta distribution
%--------------------------------------------------------------
% SEE ALSO: beta_d, beta_pdf, beta_inv, beta_rnd
%--------------------------------------------------------------
%
% changes made by Anders Warne to make sure probabilities
% are bounded by 0 and 1.
%

if any(any((a<=0)|(b<=0)));
   error('Parameter a or b is nonpositive');
end;

%
% initialize cdf to 0
%
cdf = zeros(size(x));

f1 = find(a<=0 | b<=0);
if any(f1);
   hlp = NaN;
   cdf(f1) = hlp(ones(size(f1))); 
end;

%
% when x>=1 then cdf of x=1.
%
f2 = find(x >= 1);
if any(f2);
   cdf(f2) = ones(size(f2));
end;

f = find(x > 0 & x < 1 & a > 0 & b > 0);
if any(f);
   cdf(f) = betainc(x(f),a(f),b(f));
end;

%
% set upper bound for cdf to 1
%

f = find(cdf > 1);
cdf(f) = ones(size(f));

