%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for selecting signs of shocks       %
%          on variables for initial effects                      %
%                                                                %
%          Function: signdlg                                     %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       tm: structure with model info            %
%                       B_random: random B matrix satisfying     %
%                           the identifying assumptions          %
%                                                                %
%          Output:                                               %
%                       h = handle                               %
%                                                                %
%          This version:        May 17, 2006                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = signdlg(selector,tm,B_random)

if strcmp(selector,'init')==1;
   thisexit = 0;
   tm.signshock = sign_shock_fcn(tm,B_random);
   tm.B_random = B_random;
   tm.vars = '';
   tm.signs = '';
   for i=1:tm.n;
      tm.vars = strvcat(tm.vars,tm.myvars(tm.signshock(i,1),:));
      if tm.signshock(i,2)==1;
         tm.signs = strvcat(tm.signs,'positive');
      elseif tm.signshock(i,2)==-1;
         tm.signs = strvcat(tm.signs,'negative');
      else;
         tm.signs = strvcat(tm.signs,'postive');
      end;
   end;
   %
   % button icons
   %
   mycons = getstoredimages;
   cu_ini = find_inisettings;
   if cu_ini.use_toolbar_bgcolor==1;
      bgcolor = (1/255)*(round(255*get(0,'defaultuicontrolbackgroundcolor'))-[8 4 8]);
      bgcolor(1) = max(0,bgcolor(1));
      bgcolor(2) = max(0,bgcolor(2));
      bgcolor(3) = max(0,bgcolor(3));
   else;
      bgcolor = get(0,'defaultuicontrolbackgroundcolor');
   end;
   myup = maketrans(mycons.up_image,[160 160 164],bgcolor);
   mydown = maketrans(mycons.down_image,[160 160 164],bgcolor);
   %
   % Set screen size directly instead of using
   % get(0,'ScreenSize')!
   %
   if size(tm.myvars,1)>3;
      height = size(tm.myvars,1)*18+94+20;
   else;
      height = (size(tm.myvars,1)+2)*18+94+20;
   end;
   realscrsz = get(0,'ScreenSize');
   if height>realscrsz(4)-100;
      height = realscrsz(4)-100;
   elseif height<134;
      height = 152;
   end;
else;
   thisexit = 1;
   signgui = findobj('Type','figure','Tag','SignDialog');
   my_sign = get(signgui,'UserData');
   tm = get(my_sign.shocks,'UserData');
end;

switch selector;
   case 'init';
      signgui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','signdlg.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(realscrsz(3)-512)/2 (realscrsz(4)-height)/2 512 height], ...
         'Tag','SignDialog', ...
         'Resize','off', ...
         'Name','Signs of Structural Shocks', ...
         'NumberTitle','off', ...
         'Visible','off', ...
         'WindowStyle','modal', ...
         'CloseRequestFcn','signdlg exit', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(signgui,'DockControl','off');
      end;

      %
      % Outer axis
      %

      axesbox([2 2 510 height-10],'Sign Selection',70,[0.5 1]);

      %
      % Displaying the model files
      %

      my_sign.icon = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[20 height-44 100 15], ...
         'FontSize',cu_ini.gui_fontsize, ...
         'FontName',cu_ini.gui_fontname, ...
         'FontWeight',cu_ini.gui_fontweight, ...
         'FontAngle',cu_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','center', ...
         'String','Shocks', ...
         'Tag','SignText');

      my_sign.shocks = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[20 50 120 height-94], ...
         'FontSize',cu_ini.gui_fontsize+3, ...
         'FontName',cu_ini.gui_fontname, ...
         'FontWeight',cu_ini.gui_fontweight, ...
         'FontAngle',cu_ini.gui_fontangle, ...
         'Style','listbox', ...
         'Enable','inactive', ...
         'Max',2, ...
         'Value',[], ...
         'HorizontalAlignment','center', ...
         'String',tm.myshocks, ...
         'Tag','ShockList');

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[160 height-44 100 15], ...
         'FontSize',cu_ini.gui_fontsize, ...
         'FontName',cu_ini.gui_fontname, ...
         'FontWeight',cu_ini.gui_fontweight, ...
         'FontAngle',cu_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','center', ...
         'String','Variables', ...
         'Tag','VarText');

      my_sign.variables = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[160 50 120 height-94], ...
         'FontSize',cu_ini.gui_fontsize+3, ...
         'FontName',cu_ini.gui_fontname, ...
         'FontWeight',cu_ini.gui_fontweight, ...
         'FontAngle',cu_ini.gui_fontangle, ...
         'Style','listbox', ...
         'Enable','on', ...
         'Max',1, ...
         'Value',1, ...
         'HorizontalAlignment','center', ...
         'String',tm.vars, ...
         'Tag','VarList');

      %
      % Move models up and down
      %

      checkh = (realscrsz(4)-100)/2;

      my_sign.up = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[290 min(size(tm.myvars,1)*9+70,checkh+3) 50 22], ...
         'TooltipString','Move up', ...
         'CData',myup, ...
         'CallBack','signdlg up', ...
         'Enable','on', ...
         'Tag','UpButton');


      my_sign.down = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[290 min(size(tm.myvars,1)*9+44,checkh-23) 50 22], ...
         'TooltipString','Move down', ...
         'CData',mydown, ...
         'CallBack','signdlg down', ...
         'Enable','on', ...
         'Tag','DownButton');

      %
      % Selected signs
      %

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[350 height-44 122 15], ...
         'FontSize',cu_ini.gui_fontsize, ...
         'FontName',cu_ini.gui_fontname, ...
         'FontWeight',cu_ini.gui_fontweight, ...
         'FontAngle',cu_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','center', ...
         'String','Signs', ...
         'Tag','VarText');

      my_sign.signs = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[350 50 142 height-94], ...
         'FontSize',cu_ini.gui_fontsize+3, ...
         'FontName',cu_ini.gui_fontname, ...
         'FontWeight',cu_ini.gui_fontweight, ...
         'FontAngle',cu_ini.gui_fontangle, ...
         'Style','listbox', ...
         'Enable','on', ...
         'Max',1, ...
         'Min',0, ...
         'Callback','signdlg change_sign', ...
         'Value',1, ...
         'HorizontalAlignment','center', ...
         'String',tm.signs, ...
         'Tag','VarList');

      %
      % OK, Cancel and Apply buttons
      %

      my_sign.done = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[111 14 90 20], ...
         'String','OK', ...
         'FontSize',cu_ini.gui_fontsize, ...
         'FontName',cu_ini.gui_fontname, ...
         'FontWeight',cu_ini.gui_fontweight, ...
         'FontAngle',cu_ini.gui_fontangle, ...
         'CallBack','signdlg done', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','DoneButton');

      my_sign.cancel = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[211 14 90 20], ...
         'String','Cancel', ...
         'FontSize',cu_ini.gui_fontsize, ...
         'FontName',cu_ini.gui_fontname, ...
         'FontWeight',cu_ini.gui_fontweight, ...
         'FontAngle',cu_ini.gui_fontangle, ...
         'CallBack','signdlg cancel', ...
         'Enable','on', ...
         'UserData',[], ...
         'Tag','CancelButton');

      my_sign.apply = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[311 14 90 20], ...
         'String','Apply', ...
         'FontSize',cu_ini.gui_fontsize, ...
         'FontName',cu_ini.gui_fontname, ...
         'FontWeight',cu_ini.gui_fontweight, ...
         'FontAngle',cu_ini.gui_fontangle, ...
         'CallBack','signdlg apply', ...
         'Enable','off', ...
         'UserData','waiting', ...
         'Tag','ApplyButton');

      set(signgui,'UserData',my_sign,...
         'HandleVisibility','callback');

   case 'up';
      currval = get(my_sign.variables,'Value');
      var_str = get(my_sign.variables,'String');
      if currval>1;
         set(my_sign.apply,'Enable','on');
         if currval==2;
            if size(var_str,1)>2;
               var_str = strvcat(var_str(2,:),var_str(1,:),var_str(3:size(var_str,1),:));
            else;
               var_str = strvcat(var_str(2,:),var_str(1,:));
            end;
         elseif currval==size(var_str,1);
            var_str = strvcat(var_str(1:currval-2,:),var_str(currval,:),var_str(currval-1,:));
         else;
            var_str = strvcat(var_str(1:currval-2,:),var_str(currval,:),var_str(currval-1,:),var_str(currval+1:size(var_str,1),:));
         end;
         set(my_sign.variables,'String',var_str);
         set(my_sign.variables,'Value',currval-1);
      end;
   case 'down';
      currval = get(my_sign.variables,'Value');
      var_str = get(my_sign.variables,'String');
      if currval<size(var_str,1);
         set(my_sign.apply,'Enable','on');
         if currval==1;
            if size(var_str,1)>2;
               var_str = strvcat(var_str(2,:),var_str(1,:),var_str(3:size(var_str,1),:));
            else;
               var_str = strvcat(var_str(2,:),var_str(1,:));
            end;
         elseif currval==size(var_str,1)-1;
            var_str = strvcat(var_str(1:currval-1,:),var_str(currval+1,:),var_str(currval,:));
         else;
            var_str = strvcat(var_str(1:currval-1,:),var_str(currval+1,:),var_str(currval,:),var_str(currval+2:size(var_str,1),:));
         end;
         set(my_sign.variables,'String',var_str);
         set(my_sign.variables,'Value',currval+1);
      end;
   case 'change_sign'
      %
      % check if it was a double click
      %
      if strcmp(get(signgui,'SelectionType'),'open')==1;
         val = get(my_sign.signs,'Value');
         my_str = get(my_sign.signs,'String');
         hit_str = my_str(val,:);
         if strcmp(hit_str,'positive')==1;
            new_str = 'negative';
         elseif strcmp(hit_str,'negative')==1;
%            new_str = 'any';
%         else;
            new_str = 'positive';
         end;
         add_str = '';
         for i=1:tm.n;
            if i==val;
               add_str = strvcat(add_str,new_str);
            else;
               add_str = strvcat(add_str,strtrim(my_str(i,:)));
            end;
         end;
         set(my_sign.signs,'String',add_str);
         set(my_sign.apply,'Enable','on');
      end;
   case 'cancel';
      set(my_sign.variables,'String',tm.vars);
      set(my_sign.signs,'String',tm.signs);
      signdlg('apply');
   case 'apply';
      sign_str = get(my_sign.signs,'String');
      var_str = get(my_sign.variables,'String');
%      signmat = zeros(tm.n,2);
      signmat = [zeros(tm.n,1) ones(tm.n,1)];
      for i=1:tm.n;
         if strcmp(strtrim(sign_str(i,:)),'positive')==1;
            signmat(i,2) = 1;
         elseif strcmp(strtrim(sign_str(i,:)),'negative')==1;
            signmat(i,2) = -1;
         end;
         curr_var = strtrim(var_str(i,:));
         for j=1:tm.n;
            if strcmp(strtrim(tm.myvars(j,:)),curr_var)==1;
                  signmat(i,1) = j;
               break;
            end;
         end;
      end;
      %
      % need to check the validity before saving to file
      %
      status = test_sign(signmat,tm.B_random);
      if status==0;
         file = strcat(tm.modelsdir,'signs-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
         fout = fopen(file,'wt');
         fprintf(fout,'%3.0f %2.0f\n',signmat');
         fclose(fout);
      else;
         txt = 'The chosen identifying restrictions and the current sign selection scheme are incompatible. The identifying assumptions imply that at least one of the shocks has a zero contemporaneous effect on one of the variables in the dialog. Please select another ordering of the variables.';
         about(txt,'warning','Bad Selection...',160,400);
         set(my_sign.variables,'String',tm.vars);
      end;
      set(my_sign.apply,'Enable','off');
   case 'done';
      set(my_sign.done,'UserData','done');
   case 'exit';
      set(my_sign.done,'UserData','done');
%      if strcmp(get(my_sign.apply,'UserData'),'done')==1;
%         delete(signgui);
%      end;
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(cu_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(signgui,'Name') ' ' fix_filepath([pwd '\icons\sign.ico'])];
      dos(prog);
      if (strcmp(cu_ini.pstoolsdir,'')==0)&(appexist([cu_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(my_sign.icon,'UserData',pid);
      end;
   end;
   %
   set(signgui,'Visible','on');
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(signgui,'Name') ' 3'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(my_sign.done);
   end;
end;

if nargout==1;
   h = signgui;
end;

if strcmp(selector,'exit')==0;
   set(my_sign.shocks,'UserData',tm);
end;

if thisexit==0;
   waitfor(my_sign.done,'UserData','done');
end;

%
% end of signdlg.m
%
