%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for simulating the asymptotic       %
%          distribution of the trace test under various          %
%          scenarios about deterministics and exogenous I(1)     %
%          variables                                             %
%                                                                %
%          Function: trace_dist                                  %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       cm: structure with model info            %
%                                                                %
%          Output:                                               %
%                                                                %
%          This version:        June 22, 2006                    %
%          Written by:          Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function trace_dist(selector,cm)

%
% GUI for simulating the LR Trace test distributions
%

if (nargin==0)|(strcmp(selector,'init')==1);
   tm = cm;
   %
   % toolbar images
   %
   button_images = read_images;
   %
   % more initialization
   %
   selector = 'init';
   my_exit = 1;
   tm.const_model = [0 0 0 0 0];
   if tm.deterselect(1)==1;
      tm.const_model(3) = 1;
   elseif tm.deterselect(2)==1
      tm.const_model(2) = 1;
   elseif tm.deterselect(3)==1;
      tm.const_model(5) = 1;
   else;
      tm.const_model(4) = 1;
   end;
   if tm.q1>0;
      tm.const_model = [0 0 0 1 0];
      con_enable = 'off';
   else;
      con_enable = 'on';
   end;
   selector = 'init';
   %
   % Set screen size directly instead of using
   % get(0,'ScreenSize')!
   %
   tm.realscrsz = get(0,'ScreenSize');
   tm.trace_run = 0;
   %
   % read var.in
   %
   curr_ini = find_inisettings;
   my_T = curr_ini.nDraw;
   rep = curr_ini.nRep;
   repvalues = [100 1000 2000 3000 4000 5000 10000 20000 30000 40000 50000 100000 200000 300000 400000 500000 1000000];
   nRep_value = 1;
   for i=1:size(repvalues,2);
      if curr_ini.nRep==repvalues(1,i)-1;
         nRep_value = i;
         break;
      end;
   end;
   if direxist(curr_ini.simulatedir)==0;
      mystatus = makedirs(curr_ini.simulatedir);
   else;
      mystatus = 2;
   end;
   if mystatus==0;
      curr_ini.simulatedir = pwd;
      if ispc==1;
         curr_ini.simulatedir = [curr_ini.simulatedir '\'];
      end;
   end;
   if isnumeric(curr_ini.external)==0;
      curr_ini.external = 0;
   end;
   full_mat = '';
   if tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir 'trace-asymp-full-' num2str(tm.n) '.' num2str(tm.q1) '-' num2str(my_T) '.' num2str(rep+1) '-resconst.mat'];
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir 'trace-asymp-full-' num2str(tm.n) '.' num2str(tm.q1) '-' num2str(my_T) '.' num2str(rep+1) '-const.mat'];
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir 'trace-asymp-full-' num2str(tm.n) '.' num2str(tm.q1) '-' num2str(my_T) '.' num2str(rep+1) '-restrend.mat'];
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir 'trace-asymp-full-' num2str(tm.n) '.' num2str(tm.q1) '-' num2str(my_T) '.' num2str(rep+1) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
      view_enable = 'on';
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      trace_mat = load(full_mat);
      trace_data = trace_mat.LRtrace;
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
   else;
      view_enable = 'off';
      trace_data = [];
      full_mat = '';
      full_enable = 'off';
   end;
   summary_txt = '';
   if tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir 'trace-asymp-summary-' num2str(tm.n) '.' num2str(tm.q1) '-' num2str(my_T) '.' num2str(rep+1) '-resconst.txt'];
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir 'trace-asymp-summary-' num2str(tm.n) '.' num2str(tm.q1) '-' num2str(my_T) '.' num2str(rep+1) '-const.txt'];
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir 'trace-asymp-summary-' num2str(tm.n) '.' num2str(tm.q1) '-' num2str(my_T) '.' num2str(rep+1) '-restrend.txt'];
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir 'trace-asymp-summary-' num2str(tm.n) '.' num2str(tm.q1) '-' num2str(my_T) '.' num2str(rep+1) '-trend.txt'];
   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
   end;
   tm.interpolate = curr_ini.interpolate;
   if strcmp(tm.interpolate,'nearest')==1;
      tm.interpolate_value = 1;
   elseif strcmp(tm.interpolate,'linear')==1;
      tm.interpolate_value = 2;
   elseif strcmp(tm.interpolate,'spline')==1;
      tm.interpolate_value = 3;
   elseif strcmp(tm.interpolate,'cubic')==1;
      tm.interpolate_value = 4;
   elseif strcmp(tm.interpolate,'knorm')==1;
      tm.interpolate_value = 5;
   elseif strcmp(tm.interpolate,'kepan')==1;
      tm.interpolate_value = 6;
   elseif strcmp(tm.interpolate,'krect')==1;
      tm.interpolate_value = 7;
   elseif strcmp(tm.interpolate,'ktria')==1;
      tm.interpolate_value = 8;
   elseif strcmp(tm.interpolate,'kbiwe')==1;
      tm.interpolate_value = 9;
   elseif strcmp(tm.interpolate,'ktriw')==1;
      tm.interpolate_value = 10;
   elseif strcmp(tm.interpolate,'klapl')==1;
      tm.interpolate_value = 11;
   elseif strcmp(tm.interpolate,'klogi')==1;
      tm.interpolate_value = 12;
   end;
else;
   my_exit = 0;
   trace_gui = findobj('Type','figure','Tag','TraceDist')';
   my_trace = get(trace_gui,'UserData');
   curr_ini = get(my_trace.mfilebutton,'UserData');
   tm = curr_ini.models;
   button_images = curr_ini.images;
end;

switch selector
case 'init'
   trace_gui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','trace_dist.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(tm.realscrsz(3)-560)/2 (tm.realscrsz(4)-320)/2 560 320], ...
         'Tag','TraceDist', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name','Simulate Distributions for Trace Tests', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','trace_dist done', ...
         'ToolBar','none');

   if matlabnumber>=7.0;
      set(trace_gui,'DockControl','off');
   end;

   %
   % File menu
   %

   filemenu = uimenu('Parent',trace_gui, ...
      'Label','&File', ...
      'Tag','FileMenu');

   my_trace.simulatemenu = uimenu('Parent',filemenu, ...
         'Label','&Run Simulation', ...
         'Callback','trace_dist simulate', ...
         'Enable','on', ...
         'Accelerator','R', ...
         'Tag','SimulateMenu');

   my_trace.mfilemenu = uimenu('Parent',filemenu, ...
         'Label','Save to &m-file', ...
         'Separator','on', ...
         'Accelerator','M', ...
         'Callback','trace_dist mfile', ...
         'Enable',full_enable, ...
         'Tag','MFileMenu');

   my_trace.matfilemenu = uimenu('Parent',filemenu, ...
         'Label','Save to m&at-file', ...
         'Accelerator','A', ...
         'Enable',full_enable, ...
         'Callback','trace_dist matfile', ...
         'Tag','MatFileMenu');

   my_trace.summarymenu = uimenu('Parent',filemenu, ...
         'Label','&Simulation Summary', ...
         'Separator','on', ...
         'Callback','trace_dist summary', ...
         'UserData',summary_txt, ...
         'Accelerator','S', ...
         'Enable',summary_enable, ...
         'Tag','SummaryMenu');

   my_trace.fullmenu = uimenu('Parent',filemenu, ...
         'Label','&Full Simulation', ...
         'Callback','trace_dist full', ...
         'Accelerator','F', ...
         'UserData',full_mat, ...
         'Enable',full_enable, ...
         'Tag','FullMenu');


   if curr_ini.noprint==0;
      my_trace.output = uimenu('Parent',filemenu, ...
            'Label','Append to &Output', ...
            'Separator','on', ...
            'Callback','trace_dist output', ...
            'Accelerator','O', ...
            'Enable',summary_enable, ...
            'Tag','AppendMenu');
   end;

   uimenu('Parent',filemenu, ...
         'Label','Center &Window', ...
         'Separator','on', ...
         'Accelerator','W', ...
         'Enable','on', ...
         'Callback','center_figure_fcn', ...
         'Tag','CenterMenu');

   my_trace.returnmenu = uimenu('Parent',filemenu, ...
         'Label','R&eturn', ...
         'Separator','on', ...
         'Callback','trace_dist done', ...
         'Enable','on', ...
         'Tag','MenuFileReturn');

   my_trace.filemenu = filemenu;

   %
   % Graph Menu
   %

   graphmenu = uimenu('Parent',trace_gui, ...
      'Label','&Graphics', ...
      'Tag','GraphMenu');

   my_trace.displaymenu = uimenu('Parent',graphmenu, ...
         'Label','&Graph Distribution', ...
         'Callback','trace_dist display', ...
         'Accelerator','G', ...
         'UserData',tm.const_model, ...
         'Enable',view_enable, ...
         'Tag','DisplayMenu');

   my_trace.histogrammenu = uimenu('Parent',graphmenu, ...
         'Label','&Histogram of Distribution', ...
         'Callback','trace_dist display', ...
         'Accelerator','D', ...
         'Enable',view_enable, ...
         'Tag','HistogramMenu');

   my_trace.toolbar = uitoolbar('Parent',trace_gui, ...
                     'HandleVisibility','off', ...
                     'Interruptible','on', ...
                     'Clipping','on');

   xline([1 319 560],[0.5 1]);

   my_trace.simulate = uipushtool('Parent',my_trace.toolbar, ...
                      'TooltipString','Run Simulation', ...
                      'CData',button_images.simulate, ...
                      'ClickedCallback','trace_dist simulate', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable','on', ...
                      'UserData',0, ...
                      'Tag','Simulate');

   my_trace.mfilebutton = uipushtool('Parent',my_trace.toolbar, ...
                      'TooltipString','Save to m-file', ...
                      'CData',button_images.mfile, ...
                      'ClickedCallback','trace_dist mfile', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','MFileButton');

   my_trace.matfilebutton = uipushtool('Parent',my_trace.toolbar, ...
                      'TooltipString','Save to mat-file', ...
                      'CData',button_images.matfile, ...
                      'ClickedCallback','trace_dist matfile', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','MatFileButton');

   my_trace.summary = uipushtool('Parent',my_trace.toolbar, ...
                      'TooltipString','View Simulation Summary', ...
                      'CData',button_images.sim_summary, ...
                      'ClickedCallback','trace_dist summary', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',summary_enable, ...
                      'Tag','SummaryButton');

   my_trace.full = uipushtool('Parent',my_trace.toolbar, ...
                      'TooltipString','View Full Simulation', ...
                      'CData',button_images.sim_full, ...
                      'ClickedCallback','trace_dist full', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','FullButton');

   my_trace.display = uipushtool('Parent',my_trace.toolbar, ...
                      'TooltipString','Graph Distribution', ...
                      'CData',button_images.viewdist, ...
                      'ClickedCallback','trace_dist display', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',trace_data, ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','ViewDistButton');

   my_trace.histogram = uipushtool('Parent',my_trace.toolbar, ...
                      'TooltipString','Histogram of Distribution', ...
                      'CData',button_images.bars, ...
                      'ClickedCallback','trace_dist display', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','HistogramButton');

   my_trace.done = uipushtool('Parent',my_trace.toolbar, ...
                      'TooltipString','Return', ...
                      'CData',button_images.continue, ...
                      'ClickedCallback','trace_dist done', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'UserData','waiting', ...
                      'Enable','on', ...
                      'Tag','Done');

   axesbox([2 2 558 305],'Trace Tests',60,[0.5 1]);

   %
   % a program logo
   %

   imageaxes = axes('Units','pixels', ...
      'Box','on', ...
      'TickLength',[0 0], ...
      'CameraUpVector',[0 1 0], ...
      'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[430 16 39 39], ...
      'XTickLabelMode','manual', ...
      'YTickLabelMode','manual', ...
      'Tag','AxisLogo', ...
      'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

   image('CData',button_images.borg2,'Clipping','off','Parent',imageaxes);

   imageaxes2 = axes('Units','pixels', ...
      'Box','on', ...
      'TickLength',[0 0], ...
      'CameraUpVector',[0 1 0], ...
      'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[470 16 39 39], ...
      'XTickLabelMode','manual', ...
      'YTickLabelMode','manual', ...
      'Tag','AxisLogo', ...
      'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

   image('CData',button_images.borg,'Clipping','off','Parent',imageaxes2);

   imageaxes1 = axes('Units','pixels', ...
      'Box','on', ...
      'TickLength',[0 0], ...
      'CameraUpVector',[0 1 0], ...
      'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[390 16 39 39], ...
      'XTickLabelMode','manual', ...
      'YTickLabelMode','manual', ...
      'Tag','AxisLogo', ...
      'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

   image('CData',button_images.borg3,'Clipping','off','Parent',imageaxes1);

   imageaxes3 = axes('Units','pixels', ...
      'Box','on', ...
      'TickLength',[0 0], ...
      'CameraUpVector',[0 1 0], ...
      'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[510 16 39 39], ...
      'XTickLabelMode','manual', ...
      'YTickLabelMode','manual', ...
      'Tag','AxisLogo', ...
      'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

   image('CData',button_images.borg1,'Clipping','off','Parent',imageaxes3);

   axesbox([185 161 361 130],'Parameters',55,[0.5 1]);

   %
   % number of observations per replication
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 250 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of draws per replication:', ...
      'Tag','ObsText');

   my_trace.obs = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 255 168 20], ...
      'Value',floor(my_T/100), ...
      'String','100|200|300|400|500|600|700|800|900|1000|1100|1200|1300|1400|1500|1600|1700|1800|1900|2000|2500|3000|4000|5000|6000|7000|8000|9000|10000', ...
      'Style','popupmenu', ...
      'UserData',my_T, ...
      'Callback','trace_dist check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ObsPopup');

   %
   % number of replications
   %


   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 225 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of replications:', ...
      'Tag','SimulText');

   my_trace.rep = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 230 168 20], ...
      'Value',nRep_value, ...
      'String','100|1,000|2,000|3,000|4,000|5,000|10,000|20,000|30,000|40,000|50,000|100,000|200,000|300,000|400,000|500,000|1,000,000', ...
      'Style','popupmenu', ...
      'Callback','trace_dist check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'UserData',rep,...
      'Enable','on', ...
      'Tag','SimulPopup');

   %
   % number of variables
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 200 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of endogenous variables:', ...
      'Tag','EndoVarText');

   my_trace.my_n = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 205 168 20], ...
      'Value',tm.n, ...
      'String','1|2|3|4|5|6|7|8|9|10|11|12|13|14|15|16|17|18|19|20', ...
      'Style','popupmenu', ...
      'UserData',tm.n, ...
      'Callback','trace_dist check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','EndoVarPopup');

   %
   % number of exogenous I(1) variables
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 175 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of exogenous I(1) var''s:', ...
      'Tag','CointText');

   if tm.q1==0;
      this_q1 = 1;
   else;
      this_q1 = tm.q1+1;
   end;

   my_trace.my_q1 = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 180 168 20], ...
      'Value',this_q1, ...
      'String','0|1|2|3|4|5|6|7|8|9|10|11|12|13|14|15|16|17|18|19', ...
      'Style','popupmenu', ...
      'UserData',tm.q1, ...
      'Callback','trace_dist check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','CointPopup');

   %
   % Select interpolation function
   %

   axesbox([16 67 530 80],'Graphics',45,[0.5 1]);

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 105 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Interpolation function:', ...
      'Tag','InterpolateText');

   my_trace.interpolate = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 110 168 20], ...
      'Value',tm.interpolate_value, ...
      'String','Nearest neighborhood|Linear|Cubic spline|Cubic|Kernel density normal|Kernel density Epanechnikov|Kernel density rectangular|Kernel density triangular|Kernel density biweight|Kernel density triweight|Kernel density Laplace|Kernel density logistic', ...
      'Callback','trace_dist interpolate', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','InterpolatePopup');

   %
   % Number of cells for graphing density functions
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 80 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of cells for histograms:', ...
      'Tag','CellText');

   my_trace.cells = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 85 168 20], ...
      'Value',1, ...
      'String','20|25|30|35|40|45|50|55|60|65|70|75|80|85|90|95|100', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','CellPopup');

   my_trace.cdf = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 108 140 20], ...
      'Value',0, ...
      'String','Cumulative distribution', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','cdfCheckbox');

   my_trace.adaptive = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 83 140 20], ...
      'Value',0, ...
      'String','Adaptive KDE method', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','adaptiveCheckbox');

   if tm.interpolate_value>=5;
      set(my_trace.adaptive,'Enable','on');
   end;

   %
   % Display clock
   %

   my_trace.clock = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 36 160 20], ...
      'Value',1, ...
      'String','Show elapsed time', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','TimeCheck');

   my_trace.save = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 36 160 20], ...
      'Value',0, ...
      'String','Save full simulation', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','SaveCheck');

   my_trace.progress = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 16 160 20], ...
      'Value',1, ...
      'String','Show progress dialogue', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ProgressCheck');

   my_trace.mfile = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 16 160 20], ...
      'Value',0, ...
      'String','Quantiles to m-file', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','MfileCheck');

   %
   % model type
   %

   axesbox([16 161 155 130],'Model',30,[0.5 1]);

   my_trace.radio1 = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[30 278 115 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','radiobutton', ...
         'Value',tm.const_model(1), ...
         'Enable','on', ...
         'Max',1, ...
         'Visible','off', ...
         'UserData',1, ...
         'HorizontalAlignment','left', ...
      	 'String','No constant', ...
      	 'Tag','ModelRadio1');

   my_trace.radio2 = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[30 253 115 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','radiobutton', ...
         'Value',tm.const_model(2), ...
         'Enable','on', ...
         'Max',1, ...
         'UserData',2, ...
         'HorizontalAlignment','left', ...
         'Callback','trace_dist selectmodel', ...
      	 'String','Restricted constant', ...
      	 'Tag','ModelRadio2');

   my_trace.radio3 = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[30 228 125 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','radiobutton', ...
         'Value',tm.const_model(3), ...
         'Enable',con_enable, ...
         'Max',1, ...
         'UserData',3, ...
         'HorizontalAlignment','left', ...
         'Callback','trace_dist selectmodel', ...
      	 'String','Constant', ...
      	 'Tag','ModelRadio3');

   my_trace.radio4 = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[30 203 125 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','radiobutton', ...
         'Value',tm.const_model(4), ...
         'Enable','on', ...
         'Max',1, ...
         'UserData',4, ...
         'HorizontalAlignment','left', ...
         'Callback','trace_dist selectmodel', ...
      	 'String','Restricted linear trend', ...
      	 'Tag','ModelRadio4');

   my_trace.radio5 = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[30 178 125 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','radiobutton', ...
         'Value',tm.const_model(5), ...
         'Enable',con_enable, ...
         'Max',1, ...
         'UserData',5, ...
         'HorizontalAlignment','left', ...
         'Callback','trace_dist selectmodel', ...
      	 'String','Linear trend', ...
      	 'Tag','ModelRadio5');

   set(trace_gui,'UserData',my_trace,...
         'HandleVisibility','callback');

case 'output'
   txt_str = readtext(lower(get(my_trace.summarymenu,'UserData')));
   fout = fopen(tm.outputfile,'at');
   fprintf(fout,'                      Simulation of Trace Tests\n                      -------------------------\n');
   for i=5:size(txt_str,2)-4;
      fprintf(fout,'%s\n',txt_str{i});
   end;
   fprintf(fout,'\n===============================================================================\n\n');
   fclose(fout);
case 'interpolate'
   tm.interpolate_value = get(my_trace.interpolate,'Value');
   interpol_vec = strvcat('nearest','linear','spline','cubic','knorm','kepan','krect','ktria','kbiwe','ktriw','klapl','klogi');
   tm.interpolate = strtrim(interpol_vec(tm.interpolate_value,:));
   if tm.interpolate_value>=5;
      set(my_trace.adaptive,'Enable','on');
   else;
      set(my_trace.adaptive,'Enable','off','Value',0);
   end;
case 'mfile'
   LRtrace = get(my_trace.display,'UserData');
   rep = get(my_trace.rep,'UserData');
   my_n = get(my_trace.my_n,'UserData');
   my_q1 = get(my_trace.my_q1,'UserData');
   my_T = get(my_trace.obs,'UserData');
   my_const_model = get(my_trace.displaymenu,'UserData');
   %
   new_quantiles = ceil(rep*quantiles_fcn);
   quantiles = [];
   for i=50:99;
      quantiles = [quantiles;ceil((i/100)*rep)];
   end;
   cv_mean = zeros(221,my_n);
   quant_mean = zeros(50,my_n);
   for i=1:my_n;
      cv_mean(:,i) = LRtrace(new_quantiles,i);
      quant_mean(:,i) = LRtrace(quantiles,i);
   end;
   %
   if my_const_model(2)==1;
      file_mean = [curr_ini.simulatedir 'trace_asymp_' num2str(my_n) '_' num2str(my_q1) '_resconst.m'];
      file_qmean = [curr_ini.simulatedir 'trace_quantile_asymp_' num2str(my_n) '_' num2str(my_q1) '_resconst.m'];
   elseif my_const_model(3)==1;
      file_mean = [curr_ini.simulatedir 'trace_asymp_' num2str(my_n) '_' num2str(my_q1) '_const.m'];
      file_qmean = [curr_ini.simulatedir 'trace_quantile_asymp_' num2str(my_n) '_' num2str(my_q1) '_const.m'];
   elseif my_const_model(4)==1;
      file_mean = [curr_ini.simulatedir 'trace_asymp_' num2str(my_n) '_' num2str(my_q1) '_restrend.m'];
      file_qmean = [curr_ini.simulatedir 'trace_quantile_asymp_' num2str(my_n) '_' num2str(my_q1) '_restrend.m'];
   elseif my_const_model(5)==1;
      file_mean = [curr_ini.simulatedir 'trace_asymp_' num2str(my_n) '_' num2str(my_q1) '_trend.m'];
      file_qmean = [curr_ini.simulatedir 'trace_quantile_asymp_' num2str(my_n) '_' num2str(my_q1) '_trend.m'];
   end;
   if fileexist(file_mean)==1;
      my_text = ['The file "' getfilename(file_mean) '" already exists. Are you sure you want to overwrite it?'];
      answer = query(my_text,'question',120,'Save to m-file',500,'no');
   else;
      answer = 'Yes';
   end;
   if strcmp(answer,'Yes')==1;
      setlogtext('Saving results to m-files...');
      fid_mean = fopen(file_mean,'wt');
      fprintf(fid_mean,['function out = ' getname(file_mean) '\n\n%%\n%% Number of replications: ' num2str(rep) '\n%% Number of draws: ' num2str(my_T) '\n%%\n\n']);
      print_str = '%1.12f';
      for i=2:my_n;
         print_str = [print_str '          %1.12f'];
      end;
      for j=1:size(cv_mean,1);
         if j==1;
            fprintf(fid_mean,['out = [ ' print_str ';\n'],cv_mean(1,:)');
         elseif j==size(cv_mean,1);
            fprintf(fid_mean,['        ' print_str '];\n\n'],cv_mean(j,:)');
         else;
            fprintf(fid_mean,['        ' print_str ';\n'],cv_mean(j,:)');
         end;
      end;
      mean_text = ['%%\n%% end of ' getfilename(file_mean) '\n%%\n'];
      fprintf(fid_mean,mean_text);
      fclose(fid_mean);
      fid_qmean = fopen(file_qmean,'wt');
      fprintf(fid_qmean,['function out = ' getname(file_qmean) '\n\n%%\n%% Number of replications: ' num2str(rep) '\n%% Number of draws: ' num2str(my_T) '\n%%\n\n']);
      for j=1:size(quant_mean,1);
         if j==1;
            fprintf(fid_qmean,['out = [ ' print_str ';\n'],quant_mean(1,:)');
         elseif j==size(quant_mean,1);
            fprintf(fid_qmean,['        ' print_str '];\n\n'],quant_mean(j,:)');
         else;
            fprintf(fid_qmean,['        ' print_str ';\n'],quant_mean(j,:)');
         end;
      end;
      mean_text = ['%%\n%% end of ' getfilename(file_qmean) '\n%%\n'];
      fprintf(fid_qmean,mean_text);
      fclose(fid_qmean);
   end;
case 'matfile'
   LRtrace = get(my_trace.display,'UserData');
   rep = get(my_trace.rep,'UserData');
   my_n = get(my_trace.my_n,'UserData');
   my_q1 = get(my_trace.my_q1,'UserData');
   my_T = get(my_trace.obs,'UserData');
   my_const_model = get(my_trace.displaymenu,'UserData');
   if my_const_model(2)==1;
      full_mat = [curr_ini.simulatedir 'trace-asymp-full-' num2str(my_n) '.' num2str(my_q1) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif my_const_model(3)==1;
      full_mat = [curr_ini.simulatedir 'trace-asymp-full-' num2str(my_n) '.' num2str(my_q1) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif my_const_model(4)==1;
      full_mat = [curr_ini.simulatedir 'trace-asymp-full-' num2str(my_n) '.' num2str(my_q1) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif my_const_model(5)==1;
      full_mat = [curr_ini.simulatedir 'trace-asymp-full-' num2str(my_n) '.' num2str(my_q1) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      my_text = ['The file "' getfilename(full_mat) '" already exists. Are you sure you want to overwrite it?'];
      answer = query(my_text,'question',120,'Save to mat-file',500,'no');
   else;
      answer = 'Yes';
   end;
   if strcmp(answer,'Yes')==1;
      setlogtext('Savings results to mat-files...');
      Number = (1:1:rep)';
      save(full_mat,'Number','LRtrace');
      if fileexist(full_mat)==1;
         set(my_trace.full,'Enable','on');
         set(my_trace.fullmenu,'Enable','on','UserData',full_mat);
      end;
   end;
case 'check'
   T_str = get(my_trace.obs,'String');
   my_T = mystr2num(strtrim(T_str(get(my_trace.obs,'Value'),:)));
   repvalues = [100 1000 2000 3000 4000 5000 10000 20000 30000 40000 50000 100000 200000 300000 400000 500000 1000000];
   rep_val = get(my_trace.rep,'Value');
   rep = repvalues(rep_val);
   set(my_trace.rep,'UserData',rep);
   my_n = get(my_trace.my_n,'Value');
   my_q1 = get(my_trace.my_q1,'Value')-1;
   if my_q1>0;
      if get(my_trace.radio3,'Value')==1;
         set(my_trace.radio3,'Value',0);
         set(my_trace.radio4,'Value',1);
      elseif get(my_trace.radio5,'Value')==1;
         set(my_trace.radio5,'Value',0);
         set(my_trace.radio4,'Value',1);
      end;
      set(my_trace.radio3,'Enable','off');
      set(my_trace.radio5,'Enable','off');
      tm.const_model = [0 get(my_trace.radio2,'Value') 0 get(my_trace.radio4,'Value') 0];
   else;
      set(my_trace.radio3,'Enable','on');
      set(my_trace.radio5,'Enable','on');
   end;
   set(my_trace.obs,'UserData',my_T);
   set(my_trace.my_n,'UserData',my_n);
   set(my_trace.my_q1,'UserData',my_q1);
   %
   % adjusting the view text buttons
   %
   full_mat = '';
   if tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir 'trace-asymp-full-' num2str(my_n) '.' num2str(my_q1) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir 'trace-asymp-full-' num2str(my_n) '.' num2str(my_q1) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir 'trace-asymp-full-' num2str(my_n) '.' num2str(my_q1) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir 'trace-asymp-full-' num2str(my_n) '.' num2str(my_q1) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      trace_mat = load(full_mat);
      trace_data = trace_mat.LRtrace;
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
      %
      % adjusting the Graph Distrbution button
      %
      set(my_trace.display,'Enable','on','UserData',trace_data);
      set(my_trace.displaymenu,'Enable','on','UserData',tm.const_model);
      set(my_trace.histogram,'Enable','on');
      set(my_trace.histogrammenu,'Enable','on');
      set(my_trace.mfilebutton,'Enable','on');
      set(my_trace.mfilemenu,'Enable','on');
      set(my_trace.matfilebutton,'Enable','on');
      set(my_trace.matfilemenu,'Enable','on');
   else;
      full_mat = '';
      full_enable = 'off';
      set(my_trace.display,'Enable','off','UserData',[]);
      set(my_trace.displaymenu,'Enable','off','UserData',tm.const_model);
      set(my_trace.histogram,'Enable','off');
      set(my_trace.histogrammenu,'Enable','off');
      set(my_trace.mfilebutton,'Enable','off');
      set(my_trace.mfilemenu,'Enable','off');
      set(my_trace.matfilebutton,'Enable','off');
      set(my_trace.matfilemenu,'Enable','off');
   end;
   set(my_trace.fullmenu,'Enable',full_enable,'UserData',full_mat);
   set(my_trace.full,'Enable',full_enable);
   summary_txt = '';
   if tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir 'trace-asymp-summary-' num2str(my_n) '.' num2str(my_q1) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir 'trace-asymp-summary-' num2str(my_n) '.' num2str(my_q1) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir 'trace-asymp-summary-' num2str(my_n) '.' num2str(my_q1) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir 'trace-asymp-summary-' num2str(my_n) '.' num2str(my_q1) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
%      sim_summary = button_images.sim_summarydisable;
   end;
   if curr_ini.noprint==0;
      set(my_trace.output,'Enable',summary_enable);
   end;
   set(my_trace.summarymenu,'Enable',summary_enable,'UserData',summary_txt);
   set(my_trace.summary,'Enable',summary_enable);
   set(trace_gui,'UserData',my_trace);
case 'summary'
   set(trace_gui,'Visible','off');
   drawnow;
   file = lower(get(my_trace.summarymenu,'UserData'));
   prtgui = printgui('init',file,'Structural VAR - Trace Test Simulation Summary',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   myprint = get(prtgui,'UserData');
   set(myprint.print,'UserData','done');
   killguipid(prtgui);
   set(trace_gui,'Visible','on');
   drawnow;
   set(trace_gui,'UserData',my_trace);
case 'full'
   set(trace_gui,'Visible','off');
   drawnow;
   rep = get(my_trace.rep,'UserData');
   my_n = get(my_trace.my_n,'UserData');
   full_mat = lower(get(my_trace.fullmenu,'UserData'));
   sp_str = spacestr(curr_ini.decimals-2);
   prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
   head_txt = ' Number';
   prt_str = '%7.0f';
   for i=1:my_n;
      head_txt = [head_txt sprintf([sp_str ' LR trace(n-r=%2.0f)'],i)];
      prt_str = [prt_str '         ' prt_val];
   end;
   my_text = strvcat(' ',head_txt);
   abort = '';
   if rep>=5000;
      input_var.title = ['Progress for ' int2str(rep) ' replications'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.label = 'Replication number:';
      input_var.stop = 0;
      input_var.clock = 1;
      input_var.name = ['Data in ' getname(full_mat)];
      mywait = progressdlg(0,input_var);
%      set(mywait,'Name',['Data in ' getname(full_mat)]);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
      drawnow;
   end;
   trace_mat = load(full_mat);
   my_data = [trace_mat.Number trace_mat.LRtrace];
   for i=1:size(my_data,1);
      if rep>=5000;
         abort = get(mywait,'UserData');
         if strcmp(abort,'cancel')==1;
            break;
         else;
            progressdlg([(i/rep) i]);
         end;
      end;
      my_text = strvcat(my_text,sprintf(prt_str,my_data(i,:)'));
   end;
   my_text = strvcat(my_text,' ');
   if rep>=5000;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   end;
   if strcmp(abort,'cancel')==0;
      textgui(my_text,'Structural VAR - Trace Test Simulation',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   end;
   set(trace_gui,'Visible','on');
   drawnow;
   set(trace_gui,'UserData',my_trace);
case 'selectmodel'
   tm.const_model = [0 0 0 0 0];
   ch_val = get(gcbo,'UserData');
   tm.const_model(ch_val) = 1;
   set(my_trace.radio1,'Value',tm.const_model(1));
   set(my_trace.radio2,'Value',tm.const_model(2));
   set(my_trace.radio3,'Value',tm.const_model(3));
   set(my_trace.radio4,'Value',tm.const_model(4));
   set(my_trace.radio5,'Value',tm.const_model(5));
   curr_ini.models = tm;
   set(my_trace.mfilebutton,'UserData',curr_ini);
   set(trace_gui,'UserData',my_trace);
   trace_dist('check');
   curr_ini = get(my_trace.mfilebutton,'UserData');
   tm = curr_ini.models;
case 'display'
   LRtrace = get(my_trace.display,'UserData');
   rep = get(my_trace.rep,'UserData');
   my_n = get(my_trace.my_n,'UserData');
   my_q1 = get(my_trace.my_q1,'UserData');
   my_T = get(my_trace.obs,'UserData');
   my_const_model = get(my_trace.displaymenu,'UserData');
   if my_const_model(1)==1;
      this_mod = '(no constant)';
   elseif my_const_model(2)==1;
      this_mod = '(restricted constant)';
   elseif my_const_model(3)==1;
      this_mod = '(constant)';
   elseif my_const_model(4)==1;
      this_mod = '(restricted trend)';
   elseif my_const_model(5)==1;
      this_mod = '(trend)';
   end;
   cell_value = get(my_trace.cells,'Value');
   cell_vec = [20 25 30 35 40 45 50 55 60 65 70 75 80 85 90 95 100];
   numcells = cell_vec(cell_value);
   my_50 = floor(0.5*rep);
   my_80 = floor(0.8*rep);
   my_90 = floor(0.9*rep);
   my_95 = floor(0.95*rep);
   my_975 = floor(0.98*rep);
   my_99 = floor(0.99*rep);
   trace_plot = [];
   pos = [(tm.realscrsz(3)-600)/2 (tm.realscrsz(4)-400)/2];
   %
   for i=1:my_n;
      %
      % The Trace test
      %
      thisplot = figure('Units','pixels', ...
         'Position',[pos 600 400], ...
         'Menubar','none', ...
         'Toolbar','none', ...
         'NumberTitle','off', ...
         'Tag',['density-trace-' num2str(i,'%0.0f') '-' num2str(my_q1,'%0.0f') '-' num2str(my_T,'%0.0f') '-' num2str(rep,'%0.0f')], ...
         'Visible','off', ...
         'Name',['Density for LR Trace Test (n-r=' num2str(i) ')']);
      %
      if my_q1>0;
         set(thisplot,'Name',['Density for LR Trace Test (n-r=' num2str(i) ',q=' num2str(my_q1) ')']);
      end;
      %
      trace_plot = [trace_plot thisplot];
      %
      % obey centering and filling defaults
      %
      setfigureproperties(thisplot);
      %
      % reset position
      %
      pos = [pos(1)+22 pos(2)-22];
      if pos(1,1)>(tm.realscrsz(3)-600);
         pos = [0 tm.realscrsz(4)-470];
      end;
      if pos(1,2)>(tm.realscrsz(4)-470);
         pos = [0 tm.realscrsz(4)-470];
      elseif pos(1,2)<32;
         pos = [0 tm.realscrsz(4)-470];
      end;
      %
      [n1,n2] = hist(LRtrace(:,i),numcells);
      n1 = n1/rep;
      ylabelstr = 'Frequency';
      leg_pos = 1;
      cdf_value = get(my_trace.cdf,'Value');
      if (gcbo==my_trace.histogram)|(gcbo==my_trace.histogrammenu);
         set(thisplot,'Tag',[strrep(get(thisplot,'Tag'),'trace-','trace-hist-')]);
         if cdf_value==1;
            n1 = cumsum(n1);
            set(thisplot,'Name',[strrep(get(thisplot,'Name'),'Density','Distribution')]);
            set(thisplot,'Tag',[strrep(get(thisplot,'Tag'),'density-','distribution-')]);
         end;
         %
         n3 = bar(n2,n1,0.75);
         if curr_ini.colors==1;
            set(n3,'FaceColor',[0 0 0.8],'EdgeColor','k','LineWidth',1,'Tag','autopatch');
         else;
            set(n3,'FaceColor',[0.5 0.5 0.5],'EdgeColor','k','LineWidth',1,'Tag','autopatch');
         end;
         myleg = [];
         if cdf_value==1;
            set(gca,'YLim',[0 1.1],'XLim',[0 max(n2)+n2(1,2)-n2(1,1)]);
         end;
      else;
         ylabelstr = 'Density';
         if curr_ini.colors==1;
            c_vec_1 = [0 0 1];
            c_vec_2 = [1 0 0];
            c_vec_3 = [0 0.75 0];
            c_vec_4 = [1 0.5 0];
            c_vec_5 = [0 0.75 0.75];
            c_vec_6 = [0 0 0];
            c_vec_7 = [0 1 0];
         else;
            c_vec_1 = [0 0 0];
            c_vec_2 = [0.7 0.7 0.7];
            c_vec_3 = [0.6 0.6 0.6];
            c_vec_4 = [0.5 0.5 0.5];
            c_vec_5 = [0.4 0.4 0.4];
            c_vec_6 = [0.3 0.3 0.3];
            c_vec_7 = [0.2 0.2 0.2];
         end;
         %
         if (strcmp(tm.interpolate,'nearest')==1)|(strcmp(tm.interpolate,'linear')==1)|(strcmp(tm.interpolate,'spline')==1)|(strcmp(tm.interpolate,'cubic')==1);
            x_v = [];
            xsep = (n2(2)-n2(1))/100;
            for i=1:size(n2,2);
               x_v = [x_v n2(i)];
               if i<size(n2,2);
                  for j=1:99;
                     x_v = [x_v (n2(i)+(j*xsep))];
                  end;
               end;
            end;
            x_v = sort(x_v);
            n3 = interp1(n2,n1,x_v,tm.interpolate);
            cdf_n3 = cdf(x_v,n3);
            n3 = (1/max(cdf_n3))*n3;
         else;
            xmin = min(LRtrace(:,i));
            xmax = max(LRtrace(:,i));
            xrange = xmax-xmin;
            ax = xmin-xrange/4;
            bx = xmax+xrange/4;
            if strcmp(tm.interpolate,'knorm')==1;
               h = 0;
            else;
               h = hns(LRtrace(:,i),tm.interpolate);
            end;
            if get(my_trace.adaptive,'Value')==1;
               [x_v,xa,n3,h,hl] = kdadapt(LRtrace(:,i),tm.interpolate,512,h);
            else;
               [x_v,n3] = kdfft1(LRtrace(:,i),tm.interpolate,512,h,0,[ax,bx]);
            end;
         end;
         if cdf_value==1;
            ylabelstr = 'Frequency';
            leg_pos = 4;
            n3 = cdf(x_v,n3);
            set(thisplot,'Name',[strrep(get(thisplot,'Name'),'Density','Distribution')]);
            set(thisplot,'Tag',[strrep(get(thisplot,'Tag'),'density-','distribution-')]);
         end;
         %
         hl = plot(x_v,n3,'LineWidth',1,'Color',c_vec_1,'Tag',['trace-dist-' num2str(i,'%0.0f')]);
         if my_q1>0;
            set(hl,'Tag',['trace-dist-' num2str(i,'%0.0f') '-' num2str(my_q1)]);
         end;
         y_lim = [0 max(n3)+(0.1*max(n3))];
         set(gca,'YLim',y_lim);
         set(gca,'XLim',[0 max(x_v)]);
         hold('on');
         plot(LRtrace(my_50,i)*ones(1,2),y_lim,'Color',c_vec_7,'LineStyle','-','LineWidth',1);
         hold('on');
         plot(LRtrace(my_80,i)*ones(1,2),y_lim,'Color',c_vec_2,'LineStyle',':','LineWidth',1);
         hold('on');
         plot(LRtrace(my_90,i)*ones(1,2),y_lim,'Color',c_vec_3,'LineStyle','-.','LineWidth',1);
         hold('on');
         plot(LRtrace(my_95,i)*ones(1,2),y_lim,'Color',c_vec_4,'LineStyle','-','LineWidth',1);
         hold('on');
         plot(LRtrace(my_975,i)*ones(1,2),y_lim,'Color',c_vec_5,'LineStyle','-.','LineWidth',1);
         hold('on');
         plot(LRtrace(my_99,i)*ones(1,2),y_lim,'Color',c_vec_6,'LineStyle',':','LineWidth',1);
         hold('off');
         myleg = legend_fcn(ylabelstr,'50%','80%','90%','95%','98%','99%',leg_pos);
      end;
      if my_q1>0;
         setaxesfonts('Title',['LR trace test ' this_mod ' with ' num2str(i,'%0.0f') ' common trends and ' num2str(my_q1) ' exogenous I(1) variables'],'XLabel','Value','YLabel',ylabelstr);
      else;
         setaxesfonts('Title',['LR trace test ' this_mod ' with ' num2str(i,'%0.0f') ' common trends'],'XLabel','Value','YLabel',ylabelstr);
      end;
      if isempty(myleg)==0;
         setaxesfonts(myleg);
         myleg = update_legend(myleg);
      end;
      set(gca,'UserData',myleg);
      toolbar_fcn(gca);
      hold('off');
   end;
   %
   if curr_ini.external==0;
      set(trace_plot,'Visible','on');
   else;
      this_mod = strrep(this_mod,'(','');
      this_mod = strrep(this_mod,')','');
      this_mod = strtrim(this_mod);
      this_mod = strrep(this_mod,' ','.');
      file_names = '';
      stats = [];
      for i=1:my_n;
         set(0,'CurrentFigure',trace_plot(1,i));
         file = [curr_ini.simulatedir get(trace_plot(1,i),'Tag') '-' this_mod];
         stats = [stats autosavefigure(trace_plot(1,i),file)];
         file_names = strvcat(file_names,file);
      end;
      if isempty(stats)==0;
         for i=1:size(stats,2);
            if stats(i)==0;
               autoshowfigure(strtrim(file_names(i,:)));
            end;
         end;
      end;
   end;
   set(trace_gui,'UserData',my_trace);
   %
   % case simulate
   %
case 'simulate'
   tm.trace_run = 1;
   set(trace_gui,'Visible','off');
   drawnow;
   %
   % collect values
   %
   my_T = 100*get(my_trace.obs,'Value');
   repvalues = [100 1000 2000 3000 4000 5000 10000 20000 30000 40000 50000 100000 200000 300000 400000 500000 1000000];
   rep_val = get(my_trace.rep,'Value');
   rep = repvalues(rep_val);
   set(my_trace.simulate,'UserData',rep);
   my_n = get(my_trace.my_n,'UserData');
   my_q1 = get(my_trace.my_q1,'UserData');
   %
   % initialize and compute original statistics
   %
   same_deter = 0;
   if ((tm.deterselect(1,1)==1)&(tm.const_model(3)==1))|((tm.deterselect(1,2)==1)&(tm.const_model(2)==1))|((tm.deterselect(1,3)==1)&(tm.const_model(5)==1))|((tm.deterselect(1,4)==1)&(tm.const_model(4)==1));
      same_deter = 1;
   end;
   %
   abort = '';
   draw = 1;
   showprog = get(my_trace.progress,'Value');
   if showprog==1;
      input_var.title = ['Progress for ' int2str(rep) ' replications'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.clock = get(my_trace.clock,'Value');
      input_var.label = 'Replication number:';
      input_var.stop = 0;
      mywait = progressdlg(0,input_var);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
   else;
      this_text = strvcat('Resistence is futile. You will be assimulated...',' ',['Time: ' datestr(now,14)],' ','Please hold!');
      mywait = waitdlg(this_text,'borg','Trace Test Simulation');
      waitf = get(mywait,'UserData');
      tic;
   end;
   LRtrace = zeros(rep,my_n);
   if tm.const_model(2)==1;
      setlogtext(strvcat(' ','Simulating distribution for Trace test...',['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted constant',['       ' num2str(my_n) ' endogenous variables'],['       ' num2str(my_q1) ' exogenous I(1) variables'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Restricted constant model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      while (draw<=rep);
         if showprog==1;
            abort = get(mywait,'UserData');
            if strcmp(abort,'cancel')==1;
               break;
            else;
               progressdlg([(draw/rep) draw]);
            end;
         end;
         %
         % reset the random number generator
         %
         if curr_ini.random_state==2;
            randn('state',draw);
         elseif curr_ini.random_state==3;
            randn('state',sum(100*clock));
         elseif curr_ini.random_state==4;
            randn('state',sum(100*clock)+draw);
         end;
         Epr = randn(my_n+my_q1,my_T+50);
         Epr = Epr(:,51:my_T+50);
         %
         % make sure draws in Epr have identity covariance matrix
         %
         Sig = (1/my_T)*Epr*Epr';
         P_sig = chol(Sig)';
         Epr = P_sig\Epr;
         for i=1:my_n;
            %
            % i is the number of common trends from endogenous accumulated ignorance
            %
            E_T = Epr(1:i,:);
            S_T1 = [zeros(i+my_q1,1) Epr(1:i+my_q1,1:my_T-1)];
            S_T = [cumsum(S_T1,2);ones(1,my_T)];
            inv_ST = (S_T*S_T')\eye(i+1+my_q1);
            Q = E_T*S_T'*inv_ST*S_T*E_T';
            LRtrace(draw,i) = sum(diag(Q));
         end;
         draw = draw+1;
      end;
   elseif tm.const_model(3)==1;
      setlogtext(strvcat(' ','Simulating distribution for Trace test...',['Simulation started at: ' datestr(now,14) '...'],'Model:','       Unrestricted constant',['       ' num2str(my_n) ' endogenous variables'],['       ' num2str(my_q1) ' exogenous I(1) variables'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Constant model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      my_trend = (1:1:my_T);
      while (draw<=rep);
         if showprog==1;
            abort = get(mywait,'UserData');
            if strcmp(abort,'cancel')==1;
               break;
            else;
               progressdlg([(draw/rep) draw]);
            end;
         end;
         %
         % reset the random number generator
         %
         if curr_ini.random_state==2;
            randn('state',draw);
         elseif curr_ini.random_state==3;
            randn('state',sum(100*clock));
         elseif curr_ini.random_state==4;
            randn('state',sum(100*clock)+draw);
         end;
         Epr = randn(my_n,my_T+50);
         Epr = Epr(:,51:my_T+50);
         %
         % make sure draws in Epr have identity covariance matrix
         %
         Sig = (1/my_T)*Epr*Epr';
         P_sig = chol(Sig)';
         Epr = P_sig\Epr;
         for i=1:my_n;
            %
            % i is the number of common trends from endogenous accumulated ignorance
            %
            E_T = Epr(1:i,:);
            if i==1;
               S_T = [];
            else;
               S_T1 = [zeros(i-1,1) Epr(1:i-1,1:my_T-1)];
               S_T = cumsum(S_T1,2);
            end;
            S_T = [S_T;my_trend];
            S_T = S_T-((1/my_T)*sum(S_T,2)*ones(1,my_T));
            inv_ST = (S_T*S_T')\eye(i);
            Q = E_T*S_T'*inv_ST*S_T*E_T';
            LRtrace(draw,i) = sum(diag(Q));
         end;
         draw = draw+1;
      end;
   elseif tm.const_model(4)==1;
      setlogtext(strvcat(' ','Simulating distribution for Trace test...',['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted linear trend',['       ' num2str(my_n) ' endogenous variables'],['       ' num2str(my_q1) ' exogenous I(1) variables'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Restricted trend model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      my_trend = (1:1:my_T);
      while (draw<=rep);
         if showprog==1;
            abort = get(mywait,'UserData');
            if strcmp(abort,'cancel')==1;
               break;
            else;
               progressdlg([(draw/rep) draw]);
            end;
         end;
         %
         % reset the random number generator
         %
         if curr_ini.random_state==2;
            randn('state',draw);
         elseif curr_ini.random_state==3;
            randn('state',sum(100*clock));
         elseif curr_ini.random_state==4;
            randn('state',sum(100*clock)+draw);
         end;
         Epr = randn(my_n+my_q1,my_T+50);
         Epr = Epr(:,51:my_T+50);
         %
         % make sure draws in Epr have identity covariance matrix
         %
         Sig = (1/my_T)*Epr*Epr';
         P_sig = chol(Sig)';
         Epr = P_sig\Epr;
         for i=1:my_n;
            %
            % i is the number of common trends from endogenous accumulated ignorance
            %
            E_T = Epr(1:i,:);
            S_T1 = [zeros(i+my_q1,1) Epr(1:i+my_q1,1:my_T-1)];
            S_T = [cumsum(S_T1,2);my_trend];
            S_T = S_T-((1/my_T)*sum(S_T,2)*ones(1,my_T));
            inv_ST = (S_T*S_T')\eye(i+1+my_q1);
            Q = E_T*S_T'*inv_ST*S_T*E_T';
            LRtrace(draw,i) = sum(diag(Q));
         end;
         draw = draw+1;
      end;
   elseif tm.const_model(5)==1;
      setlogtext(strvcat(' ','Simulating distribution for Trace test...',['Simulation started at: ' datestr(now,14) '...'],'Model:','       Linear trend',['       ' num2str(my_n) ' endogenous variables'],['       ' num2str(my_q1) ' exogenous I(1) variables'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Linear trend model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      my_t = (1:1:my_T);
      my_t2 = my_t.*my_t;
      x_mat = [ones(1,my_T);my_t];
      x_mat2 = x_mat*x_mat';
      inv_xmat2 = x_mat2\eye(2);
      while (draw<=rep);
         if showprog==1;
            abort = get(mywait,'UserData');
            if strcmp(abort,'cancel')==1;
               break;
            else;
               progressdlg([(draw/rep) draw]);
            end;
         end;
         %
         % reset the random number generator
         %
         if curr_ini.random_state==2;
            randn('state',draw);
         elseif curr_ini.random_state==3;
            randn('state',sum(100*clock));
         elseif curr_ini.random_state==4;
            randn('state',sum(100*clock)+draw);
         end;
         Epr = randn(my_n,my_T+50);
         Epr = Epr(:,51:my_T+50);
         %
         % make sure draws in Epr have identity covariance matrix
         %
         Sig = (1/my_T)*Epr*Epr';
         P_sig = chol(Sig)';
         Epr = P_sig\Epr;
         for i=1:my_n;
            %
            % i is the number of common trends from endogenous accumulated ignorance
            %
            E_T = Epr(1:i,:);
            if i==1;
               S_T = [];
            else;
               S_T1 = [zeros(i-1,1) Epr(1:i-1,1:my_T-1)];
               S_T = cumsum(S_T1,2);
            end;
            S_T = [S_T;my_t2];
            S_T = S_T-(  S_T*x_mat'*inv_xmat2*x_mat  );
            inv_ST = (S_T*S_T')\eye(i);
            Q = E_T*S_T'*inv_ST*S_T*E_T';
            LRtrace(draw,i) = sum(diag(Q));
         end;
         draw = draw+1;
      end;
   end;
   if showprog==1;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   else;
      set(waitf.text,'UserData','done');
      delete(mywait);
      drawnow;
      new_time = toc;
      my_hrs = '00';
      my_min = '00';
      my_sec = num2str(new_time,'%0.2f');
      if new_time>=60;
         ch_min = floor(new_time/60);
         my_sec = num2str(new_time-(ch_min*60),'%0.2f');
         my_min = num2str(ch_min,'%0.0f');
         if ch_min>=60;
            ch_hrs = floor(ch_min/60);
            my_min = num2str(ch_min-(ch_hrs*60),'%0.0f');
            my_hrs = num2str(ch_hrs,'%0.0f');
         end;
      end;
      if size(my_sec,2)==4;
         my_sec = ['0' my_sec];
      end;
      if size(my_min,2)==1;
         my_min = ['0' my_min];
      end;
      if size(my_hrs,2)==1;
         my_hrs = ['0' my_hrs];
      end;
      clock_str = [my_hrs ':' my_min ':' my_sec];
      this_text = strvcat('The assimulation process took:',' ',['    ' clock_str ' (hrs:min:sec)']);
      about(this_text,'borg','Simulation Time',120,350);
   end;
   %
   % if we don't cancel
   %
   if (strcmp(abort,'cancel')==0)&(isempty(LRtrace)==0);
      setlogtext(['Simulation completed at: ' datestr(now,14) '!']);
      new_quantiles = ceil(rep*quantiles_fcn);
      quantiles = [];
      for i=50:99;
         quantiles = [quantiles;ceil((i/100)*rep)];
      end;
      cv_mean = zeros(221,my_n);
      quant_mean = zeros(50,my_n);
      for i=1:my_n
         LRtrace(:,i) = sort(LRtrace(:,i));
         cv_mean(:,i) = LRtrace(new_quantiles,i);
         quant_mean(:,i) = LRtrace(quantiles,i);
      end;
      %
      % Computing p-values
      %
      boot_pval = [];
      if (my_n==tm.n)&(same_deter==1)&(my_q1==tm.q1)&(tm.q0==0);
         setlogtext('Determining the asymptotic p-value of the Trace tests...');
         for i=1:my_n;
            for j=1:rep;
               if tm.trace(my_n+1-i,1)>=LRtrace(rep+1-j,i);
                  break;
               end;
            end;
            boot_pval = [j/rep;boot_pval];
         end;
      end;
      %
      set(my_trace.rep,'UserData',rep);
      set(my_trace.obs,'UserData',my_T);
      set(my_trace.my_n,'UserData',my_n);
      set(my_trace.my_q1,'UserData',my_q1);
      set(my_trace.displaymenu,'Enable','on','UserData',tm.const_model);
      if tm.const_model(2)==1;
         file_mean = [curr_ini.simulatedir 'trace_asymp_' num2str(my_n) '_' num2str(my_q1) '_resconst.m'];
         file_qmean = [curr_ini.simulatedir 'trace_quantile_asymp_' num2str(my_n) '_' num2str(my_q1) '_resconst.m'];
         my_mod = 'Restricted constant';
      elseif tm.const_model(3)==1;
         file_mean = [curr_ini.simulatedir 'trace_asymp_' num2str(my_n) '_' num2str(my_q1) '_const.m'];
         file_qmean = [curr_ini.simulatedir 'trace_quantile_asymp_' num2str(my_n) '_' num2str(my_q1) '_const.m'];
         my_mod = 'Constant';
      elseif tm.const_model(4)==1;
         file_mean = [curr_ini.simulatedir 'trace_asymp_' num2str(my_n) '_' num2str(my_q1) '_restrend.m'];
         file_qmean = [curr_ini.simulatedir 'trace_quantile_asymp_' num2str(my_n) '_' num2str(my_q1) '_restrend.m'];
         my_mod = 'Restricted linear trend';
      elseif tm.const_model(5)==1;
         file_mean = [curr_ini.simulatedir 'trace_asymp_' num2str(my_n) '_' num2str(my_q1) '_trend.m'];
         file_qmean = [curr_ini.simulatedir 'trace_quantile_asymp_' num2str(my_n) '_' num2str(my_q1) '_trend.m'];
         my_mod = 'Linear trend';
      end;
      if get(my_trace.mfile,'Value')==1;
         setlogtext('Saving results to m-files...');
         fid_mean = fopen(file_mean,'wt');
         fprintf(fid_mean,['function out = ' getname(file_mean) '\n\n%%\n%% Number of replications: ' num2str(rep) '\n%% Number of draws: ' num2str(my_T) '\n%%\n\n']);
         print_str = '%1.12f';
         for i=2:my_n;
            print_str = [print_str '          %1.12f'];
         end;
         for j=1:size(cv_mean,1);
            if j==1;
               fprintf(fid_mean,['out = [ ' print_str ';\n'],cv_mean(1,:)');
            elseif j==size(cv_mean,1);
               fprintf(fid_mean,['        ' print_str '];\n\n'],cv_mean(j,:)');
            else;
               fprintf(fid_mean,['        ' print_str ';\n'],cv_mean(j,:)');
            end;
         end;
         mean_text = ['%%\n%% end of ' getfilename(file_mean) '\n%%\n'];
         fprintf(fid_mean,mean_text);
         fclose(fid_mean);
         fid_qmean = fopen(file_qmean,'wt');
         fprintf(fid_qmean,['function out = ' getname(file_qmean) '\n\n%%\n%% Number of replications: ' num2str(rep) '\n%% Number of draws: ' num2str(my_T) '\n%%\n\n']);
         for j=1:size(quant_mean,1);
            if j==1;
               fprintf(fid_qmean,['out = [ ' print_str ';\n'],quant_mean(1,:)');
            elseif j==size(quant_mean,1);
               fprintf(fid_qmean,['        ' print_str '];\n\n'],quant_mean(j,:)');
            else;
               fprintf(fid_qmean,['        ' print_str ';\n'],quant_mean(j,:)');
            end;
         end;
         mean_text = ['%%\n%% end of ' getfilename(file_qmean) '\n%%\n'];
         fprintf(fid_qmean,mean_text);
         fclose(fid_qmean);
      end;
      %
      % save full simulations
      %
      if get(my_trace.save,'Value')==1;
         setlogtext('Saving results to mat-files...');
         if tm.const_model(2)==1;
            full_mat = [curr_ini.simulatedir 'trace-asymp-full-' num2str(my_n) '.' num2str(my_q1) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
         elseif tm.const_model(3)==1;
            full_mat = [curr_ini.simulatedir 'trace-asymp-full-' num2str(my_n) '.' num2str(my_q1) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
         elseif tm.const_model(4)==1;
            full_mat = [curr_ini.simulatedir 'trace-asymp-full-' num2str(my_n) '.' num2str(my_q1) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
         elseif tm.const_model(5)==1;
            full_mat = [curr_ini.simulatedir 'trace-asymp-full-' num2str(my_n) '.' num2str(my_q1) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
         end;
         Number = (1:1:rep)';
         save(full_mat,'Number','LRtrace');
         set(my_trace.fullmenu,'Enable','on','UserData',full_mat);
         set(my_trace.full,'Enable','on');
      end;
      setlogtext('Saving simulation summary to text file...');
      %
      % write summary to file
      %
      sp_str = spacestr(curr_ini.decimals-2);
      prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
      my_50 = floor(0.5*rep);
      my_80 = floor(0.8*rep);
      my_90 = floor(0.9*rep);
      my_95 = floor(0.95*rep);
      my_975 = floor(0.98*rep);
      my_99 = floor(0.99*rep);
      res_str = strvcat(' ','**************************************************************','*                          Results                           *');
      res_str = strvcat(res_str,'**************************************************************',' ',['  Model:                    ' my_mod],['  Endogenous variables:     ' num2str(my_n,'%0.0f')],['  Exogenous I(1) variables: ' num2str(my_q1,'%0.0f')],['  Replications:             ' num2str(rep,'%0.0f')],['  Draws per replication:    ' num2str(my_T,'%0.0f')],' ');
      res_str = strvcat(res_str,'                           Trace test','                           ----------',' ',['n-r       50%   ' sp_str '     80%    ' sp_str '    90%   ' sp_str '     95%    ' sp_str '    98%    ' sp_str '    99%    ' sp_str '    Mean  ' sp_str '  Std. Dev.']);
      add_str = '';
      if my_n>10;
         add_str = ' ';
      end;
      for i=1:my_n;
         trace_std = sqrt( (1/rep)*sum( ( LRtrace(:,i) - ( (1/rep)*sum(LRtrace(:,i)) ) ).*( LRtrace(:,i) - ( (1/rep)*sum(LRtrace(:,i)) ) ) ) );
         res_str = strvcat(res_str,sprintf(['%3.0f   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],i,LRtrace(my_50,i),LRtrace(my_80,i),LRtrace(my_90,i),LRtrace(my_95,i),LRtrace(my_975,i),LRtrace(my_99,i),(1/rep)*sum(LRtrace(:,i)),trace_std));
      end;
      res_str = strvcat(res_str,' ');
      if (my_n==tm.n)&(same_deter==1)&(my_q1==tm.q1)&(tm.q0==0);
         res_str = strvcat(res_str,'                      Asymptotic p-values','                      -------------------',' ');
         for i=1:my_n;
            res_str = strvcat(res_str,sprintf(['    LR(r<=%2.0f|%2.0f) = ' prt_val ',  p-value = %0.' num2str(curr_ini.decimals,'%0.0f') 'f'],i-1,my_n,tm.trace(i,1),boot_pval(i,1)));
         end;
         res_str = strvcat(res_str,' ');
      end;
      res_str = strvcat(res_str,'**************************************************************',' ');
      %
      if tm.const_model(2)==1;
         file_txt = [curr_ini.simulatedir 'trace-asymp-summary-' num2str(my_n) '.' num2str(my_q1) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
      elseif tm.const_model(3)==1;
         file_txt = [curr_ini.simulatedir 'trace-asymp-summary-' num2str(my_n) '.' num2str(my_q1) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
      elseif tm.const_model(4)==1;
         file_txt = [curr_ini.simulatedir 'trace-asymp-summary-' num2str(my_n) '.' num2str(my_q1) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
      elseif tm.const_model(5)==1;
         file_txt = [curr_ini.simulatedir 'trace-asymp-summary-' num2str(my_n) '.' num2str(my_q1) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
      end;
      fid_txt = fopen(file_txt,'wt');
      for i=1:size(res_str,1);
         fprintf(fid_txt,[strrep(res_str(i,:),'%','%%') '\n']);
      end;
      fprintf(fid_txt,['Output created on: ' datestr(now,0) '\n']);
      fclose(fid_txt);
      if curr_ini.noprint==0;
         set(my_trace.output,'Enable','on');
      end;
      set(my_trace.summarymenu,'Enable','on','UserData',file_txt);
      set(my_trace.summary,'Enable','on');
      set(my_trace.display,'Enable','on','UserData',LRtrace);
      set(my_trace.histogram,'Enable','on');
      set(my_trace.histogrammenu,'Enable','on');
      set(my_trace.mfilebutton,'Enable','on');
      set(my_trace.mfilemenu,'Enable','on');
      set(my_trace.matfilebutton,'Enable','on');
      set(my_trace.matfilemenu,'Enable','on');
   else;
      setlogtext('Cancelled...');
   end;
   tm.trace_run = 0;
   set(trace_gui,'Visible','on');
case 'done'
   if tm.trace_run==0;
      set(my_trace.done,'UserData','done');
      pid = get(my_trace.filemenu,'UserData');
      if isempty(pid)==1;
         delete(trace_gui);
      else;
         close(trace_gui);
      end;
   end;
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(trace_gui,'Name') ' ' fix_filepath([pwd '\icons\simulate.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(my_trace.filemenu,'UserData',pid);
         set(trace_gui,'CloseRequestFcn','killwinpid');
      end;
   end;
   set(trace_gui,'Visible','on');
end;

if strcmp(selector,'done')==0;
   curr_ini.models = tm;
   curr_ini.images = button_images;
   set(my_trace.mfilebutton,'UserData',curr_ini);
end;

if my_exit==1;
   waitfor(my_trace.done,'UserData','done');
end;

%
% end of trace_dist.m
%
