%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI for analysing Bayesian VAR model           %
%                                                                %
%          Function: bayesgui                                    %
%                                                                %
%          Input:                                                %
%                    selector: case switch function              %
%                    curr_model: structure with model info       %
%                                                                %
%          Output:                                               %
%                    h: handle                                   %
%                                                                %
%          This version:        July 10, 2006                    %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = bayesgui(selector,curr_model)

if strcmp(selector,'init')==1;
   cm = curr_model;
   curr_ini = find_inisettings;
   %
   if cm.deterselect(1,1)==1
      cm.determodel = '1.0.0.0-';
   elseif cm.deterselect(1,2)==1;
      cm.determodel = '0.1.0.0-';
   elseif cm.deterselect(1,3)==1;
      cm.determodel = '0.0.1.0-';
   elseif cm.deterselect(1,4)==1;
      cm.determodel = '0.0.0.1-';
   end;
   if cm.seasonal(1,1)==1;
      cm.determodel = [cm.determodel '1-'];
   else;
      cm.determodel = [cm.determodel '0-'];
   end;
   cm.lag_model = [num2str(cm.p,'%0.0f') '.' num2str(cm.pe,'%0.0f') '-' num2str(cm.T,'%0.0f') '-'];
   %
   % information for using seasonals in prior
   %
   if strcmp(cm.freq,'q')==1;
      cm.s = 4;
   elseif strcmp(cm.freq,'m')==1;
      cm.s = 12;
   else;
      cm.s = 1;
   end;
   cm.prior_draws = 1000;
   %
   % graphics options values
   %
   cm.cumdist = 0;
   cm.adaptivekde = 0;
   cm.numcells = 20;
   cm.numcells_control = 1;
   cm.interpolate = curr_ini.interpolate;
   if strcmp(cm.interpolate,'nearest')==1;
      cm.interpolate_value = 1;
   elseif strcmp(cm.interpolate,'linear')==1;
      cm.interpolate_value = 2;
   elseif strcmp(cm.interpolate,'spline')==1;
      cm.interpolate_value = 3;
   elseif strcmp(cm.interpolate,'cubic')==1;
      cm.interpolate_value = 4;
   elseif strcmp(cm.interpolate,'knorm')==1;
      cm.interpolate_value = 5;
   elseif strcmp(cm.interpolate,'kepan')==1;
      cm.interpolate_value = 6;
   elseif strcmp(cm.interpolate,'krect')==1;
      cm.interpolate_value = 7;
   elseif strcmp(cm.interpolate,'ktria')==1;
      cm.interpolate_value = 8;
   elseif strcmp(cm.interpolate,'kbiwe')==1;
      cm.interpolate_value = 9;
   elseif strcmp(cm.interpolate,'ktriw')==1;
      cm.interpolate_value = 10;
   elseif strcmp(cm.interpolate,'klapl')==1;
      cm.interpolate_value = 11;
   elseif strcmp(cm.interpolate,'klogi')==1;
      cm.interpolate_value = 12;
   end;
   %
   % MCMC values
   %
   cm.burn_in = curr_ini.burn_in;
   cm.save_draws = curr_ini.save_draws;
   cm.save_freq = curr_ini.save_freq;
   cm.discard_explosive = curr_ini.discard_explosive;
   cm.bad_draws = curr_ini.bad_draws;
   %
   cm.r = cm.n;
   dfc = round(((cm.n+cm.q1+cm.dcoint-cm.r)*cm.r)/cm.n);
   cm.df = cm.n*(cm.p-1)+cm.r+cm.q1*cm.pe+cm.q0*(cm.pe+1)+cm.d+dfc;
   cm.cbs = cm.c;
   %
   % Models structure
   %
   cm.bmodel = [];
   %
   % set default rank prior probabilities
   %
   cm.rankpriors = (1/(cm.n+1))*ones(cm.n+1,1);
   cm.r_values = 2*ones(1,cm.n+1);
   %
   % set default short-run dynamics prior hyperparameters
   %
   cm.lambda_b = curr_ini.lambda_b;
   cm.lambda_l = curr_ini.lambda_l;
   cm.lambda_theta = curr_ini.lambda_theta;
   cm.lambda_e = curr_ini.lambda_e;
   cm.lambda_alpha = curr_ini.lambda_alpha;
   cm.prior_inf_shortrun = curr_ini.prior_inf_shortrun;
   cm.prior_inf_deter = curr_ini.prior_inf_deter;
   cm.prior_inf_alpha = curr_ini.prior_inf_alpha;
   cm.prior_inf_omega = curr_ini.prior_inf_omega;
   cm.amat_type = curr_ini.amat_type;
   cm.lambda_a = curr_ini.lambda_a;
   cm.q_df = curr_ini.q_df;
   cm.amat_lag = curr_ini.amat_lag;
   if cm.q_df==1;
      cm.q_parm = cm.n+2;
   else;
      q_new = round(((cm.q_df-1)/10)*cm.T);
      cm.q_parm = max(cm.n+2,q_new);
   end;
   %
   % set default deterministic prior hyperparameters
   %
   cm.lambda_d = curr_ini.lambda_d;
   %
   % set default alpha prior hyperparameter
   %
   cm.lambda_alpha = curr_ini.lambda_alpha;
   %
   % setup certain strings matrices
   %
   prependstr = '     ';
   rank_str = ' ';
   ml_str = 'NA';
   for i=1:cm.n;
      prependstr = [prependstr;'     '];
      rank_str = [rank_str;' '];
      ml_str = [ml_str;'NA'];
   end;
   %
   % check if old output exists
   %
   res_file = '';
   if cm.cointvalue==1;
      marg_like = zeros(cm.n+1,1);
      for i=0:cm.n;
         file = [curr_ini.simulatedir cm.modelfile '-rank-' num2str(i) '-' num2str(cm.scale_endo,'%0.4f') '-gibbs-' cm.determodel cm.lag_model num2str(cm.burn_in,'%0.0f') '.' num2str(cm.save_draws,'%0.0f') '.' num2str(cm.save_freq,'%0.0f') '.' num2str(cm.discard_explosive,'%0.0f') '-' num2str(cm.prior_inf_shortrun,'%0.0f') '.' num2str(cm.prior_inf_deter,'%0.0f') '-' num2str(cm.lambda_alpha,'%0.3f')];
         if cm.amat_type==1;
            file = [file '-1'];
         else;
            file = [file '-0.' num2str(cm.lambda_a,'%0.2f') '.' num2str(cm.q_parm,'%0.0f')];
         end;
         if cm.prior_inf_shortrun==1;
            file = [file '.' num2str(cm.lambda_b,'%0.3f') '.' num2str(cm.lambda_theta,'%0.3f') '.' num2str(cm.lambda_l,'%0.3f') '.' num2str(cm.lambda_e,'%0.3f')];
         end;
         if cm.prior_inf_deter==1;
            file = [file '.' num2str(cm.lambda_d,'%0.3f')];
         end;
         file = [file '.mat'];
         if fileexist(file)==1;
            f = load(file);
            marg_like(i+1,1) = f.results.posterior_mode.log_marglike;
            clear('f');
         else;
            marg_like = [];
            break;
         end;
      end;
      if isempty(marg_like)==0;
         cm.log_marglike = marg_like;
         marg_like = fix_exp(marg_like-mean(marg_like));
         cm.rankprob_ml = (1/(cm.rankpriors'*marg_like))*(marg_like .* cm.rankpriors);
         ml_str = num2str(cm.rankprob_ml,'%12.4f');
         %
         % enable sertain controls
         %
      end;
      %
      % Setup the name of the results file
      %
      res_file = [curr_ini.simulatedir cm.modelfile '-rank-gibbs-' num2str(cm.scale_endo,'%0.4f') '-' cm.determodel cm.lag_model num2str(cm.burn_in,'%0.0f') '.' num2str(cm.save_draws,'%0.0f') '.' num2str(cm.save_freq,'%0.0f') '.' num2str(cm.discard_explosive,'%0.0f') '-' num2str(cm.prior_inf_shortrun,'%0.0f') '.' num2str(cm.prior_inf_deter,'%0.0f') '-' num2str(cm.lambda_alpha,'%0.3f')];
      if cm.amat_type==1;
         res_file = [res_file '-1'];
      else;
         res_file = [res_file '-0.' num2str(cm.lambda_a,'%0.2f') '.' num2str(cm.q_parm,'%0.0f')];
      end;
      if cm.prior_inf_shortrun==1;
         res_file = [res_file '.' num2str(cm.lambda_b,'%0.3f') '.' num2str(cm.lambda_theta,'%0.3f') '.' num2str(cm.lambda_l,'%0.3f') '.' num2str(cm.lambda_e,'%0.3f')];
      end;
      if cm.prior_inf_deter==1;
         res_file = [res_file '.' num2str(cm.lambda_d,'%0.3f')];
      end;
      res_file = [res_file '.txt'];
   else;
      %
      % check if results already exist for no cointegration sampling
      %
   end;
   %
   % posterior rank probabilities based on FML
   %
   my_ranks = (0:1:cm.n);
   cm.my_ranks = my_ranks';
   cm.rankprob_str = [rank_str num2str(my_ranks','%2.0f') prependstr num2str(cm.rankprob,'%12.4f') prependstr ml_str];
   cm.rankprob_str = strvcat(' ',cm.rankprob_str,' ');
   cm.prependstr = prependstr;
   cm.rank_str = rank_str;
   cm.ml_str = ml_str;
   %
   thisexit = 0;
   ranks = '0';
   i = 1;
   while i<=cm.n;
      ranks = [ranks '|' num2str(i)];
      i = i+1;
   end;
   textvars = ['Endogenous variables:        ' cm.evars];
   %
   % trim text if necessary
   %
   if strcmp(cm.restvec,'')==1;
      if size(cm.deter,2)>=60;
         thisdeter = cm.deter(1,1:60);
         for i=0:58;
            if strcmp(thisdeter(1,60-i),' ')==1;
               thisdeter = thisdeter(1,1:(59-i));
               break;
            end;
         end;
         thisdeter = [thisdeter '...'];
      else;
         thisdeter = cm.deter;
      end;
      textvars = strvcat(textvars,['Deterministic variables:     ' thisdeter]);
   else;
      thisdeter = strtrim([strtrim(cm.deter) ' ' cm.restvec]);
      if size(thisdeter,2)>=60;
         thisdeter = thisdeter(1,1:60);
         for i=0:58;
            if strcmp(thisdeter(1,60-i),' ')==1;
               thisdeter = thisdeter(1,1:(59-i));
               break;
            end;
         end;
         thisdeter = [thisdeter '...'];
      end;
      textvars = strvcat(textvars,['Deterministic variables:     ' thisdeter]);
   end;
   if cm.q1>0;
      thisxvars1 = cm.xvars1;
      if size(thisxvars1,2)>=60;
         thisxvars1 = thisxvars1(1,1:60);
         for i=0:58;
            if strcmp(thisxvars1(1,60-i),' ')==1;
               thisxvars1 = thisxvars1(1,1:(59-i));
               break;
            end;
         end;
         thisxvars1 = [thisxvars1 '...'];
      end;
      textvars = strvcat(textvars,['Exogenous I(1) variables:    ' thisxvars1]);
   else;
      textvars = strvcat(textvars,'Exogenous I(1) variables:    None');
   end;
   if cm.q0>0;
      thisxvars0 = cm.xvars0;
      if size(thisxvars0,2)>=60;
         thisxvars0 = thisxvars0(1,1:60);
         for i=0:58;
            if strcmp(thisxvars0(1,60-i),' ')==1;
               thisxvars0 = thisxvars0(1,1:(59-i));
               break;
            end;
         end;
         thisxvars0 = [thisxvars0 '...'];
      end;
      textvars = strvcat(textvars,['Exogenous I(0) variables:    ' thisxvars0]);
   else;
      textvars = strvcat(textvars,'Exogenous I(0) variables:    None');
   end;
   add_lag = '';
   if (cm.q0+cm.q1>0)&(cm.p~=cm.pe);
      add_lag = [' for endogenous and ' num2str(cm.pe) ' for exogenous variables'];
   end;
   textvars = strvcat(textvars,['Number of lags:              ' num2str(cm.p) add_lag]);
   textvars = strvcat(textvars,['Number of observations:      ' num2str(cm.T)]);
   cm.textvars = textvars;
   %
   % import images
   %
   button_images = read_images;
   %
   cm.running = 0;
   %
   showpdfdoc = [];
   if (strcmp(curr_ini.pdfviewer,'')==0)|(strcmp(curr_ini.epsviewer,'')==0)|(strcmp(curr_ini.psviewer,'')==0);
      pdf_file = [pwd '\doc\generalized-impulse-response.pdf'];
      if isunix==1;
         pdf_file = strrep(pdf_file,'\','/');
      end;
      if fileexist(pdf_file)==1;
         showpdfdoc.gir = pdf_file;
      else;
         showpdfdoc.gir = '';
      end;
      pdf_file = [pwd '\doc\common-cycles.pdf'];
      if isunix==1;
         pdf_file = strrep(pdf_file,'\','/');
      end;
      if fileexist(pdf_file)==1;
         showpdfdoc.cc = pdf_file;
      else;
         showpdfdoc.cc = '';
      end;
   end;
else;
   thisexit = 1;
   bayesdlg = findobj('Type','figure','Tag','BayesGUI')';
   controls = get(bayesdlg,'UserData');
   curr_ini = get(controls.viewdata,'UserData');
   button_images = curr_ini.images;
   cm = curr_ini.model;
end;

%
% Set screen size directly instead of using
% get(0,'ScreenSize')!
%

scrsz = [1 1 1024 768];
realscrsz = get(0,'ScreenSize');

switch selector;
   case 'init';
      bayesdlg = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','bayesgui.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(realscrsz(3)-650)/2 (realscrsz(4)-400)/2 650 400], ...
         'Tag','BayesGUI', ...
         'Resize','off', ...
         'Name','Structural VAR - Bayesian Analysis', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','bayesgui quit', ...
         'DoubleBuffer','on', ...
         'Visible','off', ...
         'WindowStyle','normal', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(bayesdlg,'DockControl','off');
      end;

      %
      % File menu
      %

      filemenu = uimenu('Parent',bayesdlg, ...
         'Label','&File', ...
         'Tag','FileMenu');

      %
      % Objects on File menu
      %

      controls.mcmc_menu = uimenu('Parent',filemenu, ...
         'Label','&MCMC Sampling', ...
         'Tag','MCMCMenu');

      controls.beta_estimate_menu = uimenu('Parent',controls.mcmc_menu, ...
         'Label','&Beta...', ...
         'Callback','bayesgui beta_estimate', ...
         'Enable','off', ...
         'Accelerator','B', ...
         'Tag','BetaEstimateMenu');

      controls.mcmc_unrest_menu = uimenu('Parent',controls.mcmc_menu, ...
         'Label','&Cointegration Rank...', ...
         'Callback','bayesgui mcmc_unrest', ...
         'Enable','on', ...
         'Accelerator','R', ...
         'Tag','MCMCUnrestMenu');

      controls.restrict_menu = uimenu('Parent',filemenu, ...
         'Label','&Restrictions', ...
         'Tag','RestrictionsMenu');

      controls.restrict_beta_menu = uimenu('Parent',controls.restrict_menu, ...
         'Label','&Beta...', ...
         'Callback','bayesgui restrict_beta', ...
         'Enable','off', ...
         'Tag','BetaRestrictMenu');

      controls.open_beta_restrict_menu = uimenu('Parent',controls.restrict_menu, ...
         'Label','Open B&eta Restrictions...', ...
         'Callback','bayesgui open_beta_restrict', ...
         'Enable','off', ...
         'Tag','OpenBetaRestrictMenu');

      controls.save_beta_restrict_menu = uimenu('Parent',controls.restrict_menu, ...
         'Label','Save Be&ta Restrictions...', ...
         'Callback','bayesgui save_beta_rest', ...
         'Enable','off', ...
         'Tag','SaveBetaRestrictMenu');

      controls.beta_rank_restrictions = uimenu('Parent',controls.restrict_menu, ...
         'Label','Beta &Rank Restrictions...', ...
         'Callback','bayesgui beta_rank_restrictions', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','SaveBetaRestrictMenu');
      if cm.n==1;
         set(controls.beta_rank_restrictions,'Enable','off');
      end;

      controls.viewdata = uimenu('Parent',filemenu, ...
         'Label','&View Data...', ...
         'Callback','bayesgui viewdata', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','ViewData');

      uimenu('Parent',filemenu, ...
         'Label','Center &Window', ...
         'Separator','on', ...
         'Accelerator','W', ...
         'Enable','on', ...
         'Callback','center_figure_fcn', ...
         'Tag','CenterMenu');

      controls.quitmenu = uimenu('Parent',filemenu, ...
         'Label','&Quit', ...
         'Callback','bayesgui quit', ...
         'Separator','on', ...
         'Accelerator','Q', ...
         'Enable','on', ...
         'Tag','QuitMenu');

      %
      % Tools menu
      %

      toolsmenu = uimenu('Parent',bayesdlg, ...
         'Label','&Tools', ...
         'Tag','ToolsMenu');

      controls.priors = uimenu('Parent',toolsmenu, ...
         'Label','&Prior Distributions', ...
         'Enable','on', ...
         'Tag','PriorsMenu');

      controls.priors_type = uimenu('Parent',controls.priors, ...
         'Label','&Type', ...
         'Enable','on', ...
         'Tag','PriorsTypeMenu');

      controls.type_alpha = uimenu('Parent',controls.priors_type, ...
         'Label','Informative &Alpha Prior', ...
         'Enable','off', ...
         'Check','off', ...
         'Callback','bayesgui prior_inf_alpha', ...
         'Tag','PriorInfAlphaCheck');

      controls.type_deter = uimenu('Parent',controls.priors_type, ...
         'Label','Informative &Deterministics Prior', ...
         'Enable','off', ...
         'Check','off', ...
         'Callback','bayesgui prior_inf_deter', ...
         'Tag','PriorInfDeterCheck');

      controls.type_omega = uimenu('Parent',controls.priors_type, ...
         'Label','Informative &Omega Prior', ...
         'Enable','off', ...
         'Check','off', ...
         'Callback','bayesgui prior_inf_omega', ...
         'Tag','PriorInfOmegaCheck');

      controls.type_shortrun = uimenu('Parent',controls.priors_type, ...
         'Label','Informative &Short-run Prior', ...
         'Enable','off', ...
         'Check','off', ...
         'Callback','bayesgui prior_inf_shortrun', ...
         'Tag','PriorInfShortrunCheck');

      controls.alphapriors = uimenu('Parent',controls.priors, ...
         'Label','&Alpha Prior', ...
         'Separator','on', ...
         'Enable','off', ...
         'Callback','bayesgui alpha_priors', ...
         'Tag','AlphaPriorsMenu');

      controls.deterpriors = uimenu('Parent',controls.priors, ...
         'Label','&Deterministics Prior', ...
         'Enable','on', ...
         'Callback','bayesgui deter_priors', ...
         'Tag','DeterministicsPriorsMenu');
      
      controls.omegapriors = uimenu('Parent',controls.priors, ...
         'Label','&Omega Prior', ...
         'Enable','on', ...
         'Callback','bayesgui omega_priors', ...
         'Tag','OmegaPriorsMenu');

      controls.rankpriors = uimenu('Parent',controls.priors, ...
         'Label','&Rank Prior', ...
         'Enable','off', ...
         'Callback','bayesgui rank_priors', ...
         'Tag','RankPriorsMenu');

      if cm.cointvalue==1;
         set(controls.rankpriors,'Enable','on');
         set(controls.alphapriors,'Enable','on');
         if cm.prior_inf_alpha==1;
            set(controls.type_alpha,'Check','on','Enable','on');
         else;
            set(controls.type_alpha,'Enable','on');
         end;
      end;

      controls.shortrunpriors = uimenu('Parent',controls.priors, ...
         'Label','&Short-run Prior', ...
         'Enable','on', ...
         'Callback','bayesgui shortrun_priors', ...
         'Tag','ShortrunPriorsMenu');

      if cm.prior_inf_deter==1;
         set(controls.type_deter,'Check','on','Enable','on');
      else;
         set(controls.type_deter,'Enable','on');
         set(controls.deterpriors,'Enable','off');
      end;
      if cm.prior_inf_shortrun==1;
         set(controls.type_shortrun,'Check','on','Enable','on');
      else;
         set(controls.type_shortrun,'Enable','on');
         set(controls.shortrunpriors,'Enable','off');
      end;

      if cm.prior_inf_alpha==2;
         set(controls.alphapriors,'Enable','off');
      end;
      if cm.prior_inf_omega==1;
         set(controls.type_omega,'Check','on','Enable','on');
         set(controls.omegapriors,'Enable','on');
      else;
         set(controls.type_omega,'Enable','on');
         set(controls.omegapriors,'Enable','off');
      end;

      controls.lagorder = uimenu('Parent',toolsmenu, ...
         'Label','&Lag Order...', ...
         'Callback','bayesgui lagorder', ...
         'Separator','on', ...
         'Enable','off', ...
         'Tag','LagOrderMenu');
      
      if cm.p>1;
         controls.change_lagorder = uimenu('Parent',toolsmenu, ...
            'Label','&Change Lag Order', ...
            'Enable','on', ...
            'Tag','ChangeLagOrderMenu');
         for i=1:cm.p;
            controls.lag_order(i).menuitem = uimenu('Parent',controls.change_lagorder, ...
               'Label',num2str(i,'%0.0f'), ...
               'Callback','bayesgui change_lagorder', ...
               'UserData',i, ...
               'Enable','on', ...
               'Checked','off', ...
               'Tag',['LagOrderMenu_' num2str(i,'%0.0f')]);
            %
            if i<10;
               set(controls.lag_order(i).menuitem,'Label',['&' num2str(i,'%0.0f')]);
            elseif i==10;
               set(controls.lag_order(i).menuitem,'Label','1&0');
            end;
            %
            if i==cm.p;
               set(controls.lag_order(i).menuitem,'Checked','on');
            end;
         end;
      end;


      if (cm.prior_inf_alpha==1)&(cm.prior_inf_omega==1)&(cm.prior_inf_shortrun==1);
         set(controls.lagorder,'Enable','on');
      end;

      controls.varforecast = uimenu('Parent',toolsmenu, ...
         'Label','Forecast &Variable Transformations...', ...
         'Callback','bayesgui varforecast', ...
         'Separator','on', ...
         'Enable','off', ...
         'Tag','VARForecastMenu');

      controls.bad_draws = uimenu('Parent',toolsmenu, ...
         'Label','&Skip Bad Draws', ...
         'Enable','on', ...
         'Separator','on', ...
         'Check','off', ...
         'Callback','bayesgui bad_draws', ...
         'Tag','BadDrawsMenu');

      if cm.bad_draws==1;
         set(controls.bad_draws,'Check','on');
      end;

      %
      % View menu
      %

      viewmenu = uimenu('Parent',bayesdlg, ...
         'Label','&View', ...
         'Tag','ViewMenu');

      controls.modelinfo = uimenu('Parent',viewmenu, ...
         'Label','&Model Information...', ...
         'Callback','bayesgui modelinfo', ...
         'Enable','on', ...
         'Tag','ModelInfoMenu');

      controls.results = uimenu('Parent',viewmenu, ...
         'Label','&Results', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','ResultsMenu');

      controls.results_beta = uimenu('Parent',controls.results, ...
         'Label','&Beta...', ...
         'Callback','bayesgui beta_results', ...
         'Enable','off', ...
         'UserData','', ...
         'Tag','BetaResultsMenu');

      controls.results_rank = uimenu('Parent',controls.results, ...
         'Label','&Cointegration Rank...', ...
         'Callback','bayesgui rank_results', ...
         'UserData','', ...
         'Enable','off', ...
         'Tag','RankResultsMenu');

      if (cm.cointvalue==1)&(fileexist(res_file)==1);
         if cm.q1+cm.q0==0;
            set(controls.varforecast,'Enable','on');
         end;
         set(controls.results_rank,'Enable','on','UserData',res_file);
      end;

      %
      % Graphics menu
      %

      graphmenu = uimenu('Parent',bayesdlg, ...
         'Label','&Graphics', ...
         'Tag','GraphicsMenu');

      controls.post_graph = uimenu('Parent',graphmenu, ...
         'Label','&Posterior', ...
         'Tag','PosteriorGraphicsMenu');
         
      controls.joint_postgraph = uimenu('Parent',controls.post_graph, ...
         'Label','&Joint', ...
         'Tag','JointPosteriorGraphicsMenu');

      controls.full_postgraph = uimenu('Parent',controls.joint_postgraph, ...
         'Label','&Distribution', ...
         'Tag','FullPosteriorGraphicsMenu');

      controls.full_alphagraph = uimenu('Parent',controls.full_postgraph, ...
         'Label','&Alpha...', ...
         'Callback','bayesgui full_alphagraph', ...
         'Enable','off', ...
         'Tag','FullPosteriorAlphaGraphMenu');

      controls.full_betagraph = uimenu('Parent',controls.full_postgraph, ...
         'Label','&Beta...', ...
         'Callback','bayesgui full_betagraph', ...
         'Enable','off', ...
         'Tag','FullPosteriorBetaGraphMenu');

      controls.full_eigengraph = uimenu('Parent',controls.full_postgraph, ...
         'Label','&Maximum Non-Unit Eigenvalue...', ...
         'Callback','bayesgui full_eigengraph', ...
         'Enable','off', ...
         'Tag','FullPosteriorEigenGraphMenu');

      controls.full_histogram = uimenu('Parent',controls.joint_postgraph, ...
         'Label','&Histogram', ...
         'Tag','FullPosteriorHistogramMenu');

      controls.full_hist_alphagraph = uimenu('Parent',controls.full_histogram, ...
         'Label','&Alpha...', ...
         'Callback','bayesgui full_alphagraph', ...
         'Enable','off', ...
         'Tag','FullPosteriorAlphaHistogramMenu');

      controls.full_hist_betagraph = uimenu('Parent',controls.full_histogram, ...
         'Label','&Beta...', ...
         'Callback','bayesgui full_betagraph', ...
         'Enable','off', ...
         'Tag','FullPosteriorBetaHistogramMenu');

      controls.full_hist_eigengraph = uimenu('Parent',controls.full_histogram, ...
         'Label','&Maximum Non-Unit Eigenvalue...', ...
         'Callback','bayesgui full_eigengraph', ...
         'Enable','off', ...
         'Tag','FullPosteriorEigenHistogramMenu');

      controls.part_postgraph = uimenu('Parent',controls.post_graph, ...
         'Label','&Partial', ...
         'Tag','PartialPosteriorGraphicsMenu');

      controls.part_postdistgraph = uimenu('Parent',controls.part_postgraph, ...
         'Label','&Distribution', ...
         'Tag','PartialPosteriorDistributionGraphicsMenu');

      controls.part_alphagraph = uimenu('Parent',controls.part_postdistgraph, ...
         'Label','&Alpha...', ...
         'Callback','bayesgui part_alphagraph', ...
         'Enable','off', ...
         'Tag','PartialPosteriorAlphaGraphMenu');

      controls.part_betagraph = uimenu('Parent',controls.part_postdistgraph, ...
         'Label','&Beta...', ...
         'Callback','bayesgui part_betagraph', ...
         'Enable','off', ...
         'Tag','PartialPosteriorBetaGraphMenu');

      controls.part_histogram = uimenu('Parent',controls.part_postgraph, ...
         'Label','&Histogram', ...
         'Tag','PartialPosteriorHistogramMenu');

      controls.part_hist_alphagraph = uimenu('Parent',controls.part_histogram, ...
         'Label','&Alpha...', ...
         'Callback','bayesgui part_alphagraph', ...
         'Enable','off', ...
         'Tag','PartialPosteriorAlphaHistogramMenu');

      controls.part_hist_betagraph = uimenu('Parent',controls.part_histogram, ...
         'Label','&Beta...', ...
         'Callback','bayesgui part_betagraph', ...
         'Enable','off', ...
         'Tag','PartialPosteriorBetaHistogramMenu');

      %
      % marginal distributions
      %

      controls.marg_postgraph = uimenu('Parent',controls.post_graph, ...
         'Label','&Marginal', ...
         'Tag','MarginalPosteriorGraphicsMenu');

      controls.marg_postdistgraph = uimenu('Parent',controls.marg_postgraph, ...
         'Label','&Distribution', ...
         'Tag','MarginalPosteriorDistributionGraphicsMenu');

      controls.marg_alphagraph = uimenu('Parent',controls.marg_postdistgraph, ...
         'Label','&Alpha...', ...
         'Callback','bayesgui marg_alphagraph', ...
         'Enable','off', ...
         'Tag','MarginalPosteriorAlphaGraphMenu');

      controls.marg_betagraph = uimenu('Parent',controls.marg_postdistgraph, ...
         'Label','&Beta...', ...
         'Callback','bayesgui marg_betagraph', ...
         'Enable','off', ...
         'Tag','MarginalPosteriorBetaGraphMenu');



      controls.marg_histogram = uimenu('Parent',controls.marg_postgraph, ...
         'Label','&Histogram', ...
         'Tag','MarginalPosteriorHistogramMenu');

      controls.marg_hist_alphagraph = uimenu('Parent',controls.marg_histogram, ...
         'Label','&Alpha...', ...
         'Callback','bayesgui marg_alphagraph', ...
         'Enable','off', ...
         'Tag','MarginalPosteriorAlphaHistogramMenu');

      controls.marg_hist_betagraph = uimenu('Parent',controls.marg_histogram, ...
         'Label','&Beta...', ...
         'Callback','bayesgui marg_betagraph', ...
         'Enable','off', ...
         'Tag','MarginalPosteriorBetaHistogramMenu');


      %
      % prior distributions
      %

      controls.prior_graph = uimenu('Parent',graphmenu, ...
         'Label','P&rior', ...
         'Tag','PriorGraphicsMenu');

      controls.prior_draws = uimenu('Parent',controls.prior_graph, ...
         'Label','&Number of Draws', ...
         'Tag','PriorDrawsMenu');

      controls.prior_draws_1 = uimenu('Parent',controls.prior_draws, ...
         'Label','100', ...
         'UserData',100, ...
         'Accelerator','1', ...
         'Callback','bayesgui prior_draws', ...
         'Tag','OneHundredDraws');

      controls.prior_draws_2 = uimenu('Parent',controls.prior_draws, ...
         'Label','500', ...
         'UserData',500, ...
         'Accelerator','2', ...
         'Callback','bayesgui prior_draws', ...
         'Tag','FiveHundredDraws');

      controls.prior_draws_3 = uimenu('Parent',controls.prior_draws, ...
         'Label','1,000', ...
         'UserData',1000, ...
         'Accelerator','3', ...
         'Callback','bayesgui prior_draws', ...
         'Tag','OneThousandDraws');

      controls.prior_draws_4 = uimenu('Parent',controls.prior_draws, ...
         'Label','5,000', ...
         'UserData',5000, ...
         'Accelerator','4', ...
         'Callback','bayesgui prior_draws', ...
         'Tag','FiveThousandDraws');

      controls.prior_draws_5 = uimenu('Parent',controls.prior_draws, ...
         'Label','10,000', ...
         'UserData',10000, ...
         'Accelerator','5', ...
         'Callback','bayesgui prior_draws', ...
         'Tag','TenThousandDraws');

      controls.prior_draws_6 = uimenu('Parent',controls.prior_draws, ...
         'Label','50,000', ...
         'UserData',50000, ...
         'Accelerator','6', ...
         'Callback','bayesgui prior_draws', ...
         'Tag','FiftyThousandDraws');

      controls.prior_draws_7 = uimenu('Parent',controls.prior_draws, ...
         'Label','100,000', ...
         'UserData',100000, ...
         'Accelerator','7', ...
         'Callback','bayesgui prior_draws', ...
         'Tag','OneHundredThousandDraws');

      if cm.prior_draws==100;
         pd_val = 1;
      elseif cm.prior_draws==500;
         pd_val = 2;
      elseif cm.prior_draws==1000;
         pd_val = 3;
      elseif cm.prior_draws==5000;
         pd_val = 4;
      elseif cm.prior_draws==10000;
         pd_val = 5;
      elseif cm.prior_draws==50000;
         pd_val = 6;
      else;
         pd_val = 7;
      end;
      set(getfield(controls,['prior_draws_' num2str(pd_val,'%0.0f')]),'Check','on');

      controls.prior_distgraph = uimenu('Parent',controls.prior_graph, ...
         'Label','&Distribution', ...
         'Separator','on', ...
         'Tag','PriorDistributionMenu');

      controls.prior_alphagraph = uimenu('Parent',controls.prior_distgraph, ...
         'Label','&Alpha...', ...
         'Callback','bayesgui prior_alphagraph', ...
         'Enable','off', ...
         'Tag','PriorAlphaGraphMenu');

      controls.prior_betagraph = uimenu('Parent',controls.prior_distgraph, ...
         'Label','&Beta...', ...
         'Callback','bayesgui prior_betagraph', ...
         'Enable','off', ...
         'Tag','PriorBetaGraphMenu');

      controls.prior_eigengraph = uimenu('Parent',controls.prior_distgraph, ...
         'Label','&Maximum Non-Unit Eigenvalue...', ...
         'Callback','bayesgui prior_eigengraph', ...
         'Enable','on', ...
         'Tag','PriorEigenGraphMenu');

      controls.prior_histogram = uimenu('Parent',controls.prior_graph, ...
         'Label','&Histogram', ...
         'Tag','PriorHistogramMenu');

      controls.prior_hist_alphagraph = uimenu('Parent',controls.prior_histogram, ...
         'Label','&Alpha...', ...
         'Callback','bayesgui prior_alphagraph', ...
         'Enable','off', ...
         'Tag','PriorHistAlphaGraphMenu');

      controls.prior_hist_betagraph = uimenu('Parent',controls.prior_histogram, ...
         'Label','&Beta...', ...
         'Callback','bayesgui prior_betagraph', ...
         'Enable','off', ...
         'Tag','PriorHistBetaGraphMenu');

      controls.prior_hist_eigengraph = uimenu('Parent',controls.prior_histogram, ...
         'Label','&Maximum Non-Unit Eigenvalue...', ...
         'Callback','bayesgui prior_eigengraph', ...
         'Enable','on', ...
         'Tag','PriorHistEigenGraphMenu');


      if cm.cointvalue==0;
         if (cm.prior_inf_shortrun==1)&(cm.prior_inf_omega==1);
            set(controls.prior_eigengraph,'Enable','on');
            set(controls.prior_hist_eigengraph,'Enable','on');
         else;
            set(controls.prior_eigengraph,'Enable','off');
            set(controls.prior_hist_eigengraph,'Enable','off');
         end;
      end;

      controls.coint_relations = uimenu('Parent',graphmenu, ...
         'Label','&Cointegration Relations', ...
         'Separator','on', ...
         'Tag','CointRelationsMenu');

      controls.cointgraphmenu = uimenu('Parent',controls.coint_relations, ...
         'Label','&Joint Distribution...', ...
         'Callback','bayesgui coint_graph', ...
         'Enable','off', ...
         'Tag','CointGraphMenu');

      controls.cointpartgraphmenu = uimenu('Parent',controls.coint_relations, ...
         'Label','&Partial Distribution...', ...
         'Callback','bayesgui coint_graph_partinal', ...
         'Enable','off', ...
         'Tag','CointMargGraphMenu');

      controls.convergence = uimenu('Parent',graphmenu, ...
         'Label','&MCMC Convergence', ...
         'Separator','on', ...
         'Tag','ConvergenceMenu');

      controls.joint_c = uimenu('Parent',controls.convergence, ...
         'Label','&Joint Distribution', ...
         'Tag','JointConvergenceMenu');

      controls.full_c_alpha = uimenu('Parent',controls.joint_c, ...
         'Label','&Alpha...', ...
         'Callback','bayesgui param_convergence', ...
         'Enable','off', ...
         'Tag','JointAlphaConvergenceMenu');

      controls.full_c_psi = uimenu('Parent',controls.joint_c, ...
         'Label','&Beta...', ...
         'Callback','bayesgui param_convergence', ...
         'Enable','off', ...
         'Tag','JointBetaConvergenceMenu');

      controls.full_c_delta = uimenu('Parent',controls.joint_c, ...
         'Label','&Delta...', ...
         'Callback','bayesgui param_convergence', ...
         'Enable','off', ...
         'Tag','JointdeltaConvergenceMenu');

      controls.full_c_gamma = uimenu('Parent',controls.joint_c, ...
         'Label','&Gamma...', ...
         'Callback','bayesgui param_convergence', ...
         'Enable','off', ...
         'Tag','JointGammaConvergenceMenu');

      controls.full_c_phi = uimenu('Parent',controls.joint_c, ...
         'Label','&Phi...', ...
         'Callback','bayesgui param_convergence', ...
         'Enable','off', ...
         'Tag','JointPhiConvergenceMenu');

      controls.full_c_omega = uimenu('Parent',controls.joint_c, ...
         'Label','&Omega...', ...
         'Callback','bayesgui param_convergence', ...
         'Enable','off', ...
         'Tag','JointOmegaConvergenceMenu');


      controls.part_c = uimenu('Parent',controls.convergence, ...
         'Label','&Partial Distribution', ...
         'Tag','PartialConvergenceMenu');

      controls.part_c_alpha = uimenu('Parent',controls.part_c, ...
         'Label','&Alpha...', ...
         'Callback','bayesgui param_convergence', ...
         'Enable','off', ...
         'Tag','PartialAlphaConvergenceMenu');

      controls.part_c_psi = uimenu('Parent',controls.part_c, ...
         'Label','&Beta...', ...
         'Callback','bayesgui param_convergence', ...
         'Enable','off', ...
         'Tag','PartialBetaConvergenceMenu');

      controls.part_c_omega = uimenu('Parent',controls.part_c, ...
         'Label','&Omega...', ...
         'Callback','bayesgui param_convergence', ...
         'Enable','off', ...
         'Tag','PartialOmegaConvergenceMenu');

      controls.marg_like_rank = uimenu('Parent',controls.convergence, ...
         'Label','&Marginal Likelihood - Rank', ...
         'Enable','off', ...
         'Separator','on', ...
         'Callback','bayesgui marg_like_rank', ...
         'Tag','MargLikeRankMenu');


      if (strcmp(get(controls.results_rank,'Enable'),'on')==1)&(cm.save_draws>=200);
         set(controls.marg_like_rank,'Enable','on');
      end;



      controls.options = uimenu('Parent',graphmenu, ...
         'Label','&Options...', ...
         'Callback','bayesgui graph_options', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','GraphOptionsMenu');

      if (cm.cointvalue==1)&(fileexist(res_file)==1);
         set(controls.full_eigengraph,'Enable','on');
         set(controls.full_hist_eigengraph,'Enable','on');
      end;
      if fileexist(res_file)==1;
         set(controls.full_c_omega,'Enable','on');
         if cm.d>0;
            set(controls.full_c_delta,'Enable','on');
         end;
         if cm.p>1;
            set(controls.full_c_gamma,'Enable','on');
         end;
         if cm.q0>0;
            set(controls.full_c_phi,'Enable','on');
         end;
      end;

      %
      % Help menu
      %

      helpmenu = uimenu('Parent',bayesdlg, ...
         'Label','&Help', ...
         'Tag','HelpMenu');

      controls.bayesdlg_help = uimenu('Parent',helpmenu, ...
            'Label','&Bayesian Analysis', ...
            'Callback','help_fcn(''BayesianAnalysisDialog'');', ...
            'Accelerator','H', ...
            'Separator','off', ...
            'Enable','on', ...
            'Tag','MenuBayesHelp');


         controls.priorhelp = uimenu('Parent',helpmenu, ...
            'Label','&Prior Distributions', ...
            'Callback','help_fcn(''PriorDistributions'');', ...
            'Separator','off', ...
            'Enable','on', ...
            'Tag','MenuPriorHelp');

%      if strcmp(showpdfdoc.cc,'')==0;
%         controls.pdf_cc = uimenu('Parent',helpmenu, ...
%            'Label','&Common Cycles - PDF file', ...
%            'Callback','show_pdf', ...
%            'Separator','off', ...
%            'UserData',showpdfdoc.cc, ...
%            'Enable','on', ...
%            'Tag','MenuDocCCEstimate');
%      end;
      %
%      if strcmp(showpdfdoc.gir,'')==0;
%         controls.pdf_gir = uimenu('Parent',helpmenu, ...
%            'Label','&Generalized Impulse Responses - PDF file', ...
%            'Callback','show_pdf', ...
%            'Separator','off', ...
%            'UserData',showpdfdoc.gir, ...
%            'Enable','on', ...
%            'Tag','MenuDocGIREstimate');
%      end;
      %

      xline([1 399 650],[0.5 1]);

      %
      % Outer axis
      %

      axesbox([2 2 648 385],'Bayesian Selections',95,[0.5 1]);

      %
      % Outer axis for cointegration rank controls
      %

      axesbox([254 291 380 67],'Cointegration Rank Selection',140,[0.5 1]);

      %
      % Outer axis for companion matrix eigenvalue control
      %

      axesbox([254 183 380 92],'Hyperparameters for Prior Distributions',180,[0.5 1]);

      %
      % Frame for model restrictions controls
      %

      axesbox([14 14 300 155],'Restrictions',55,[0.5 1]);
      
      %
      % Frame for MCMC Sampler controls
      %
      
      axesbox([328 14 306 155],'MCMC Sampler',75,[0.5 1]);
      
      %
      % Display hyperparameters
      %

      controls.hyperparametersaxes = axes('Units','pixels', ...
         'Tag','BGAxes', ...
         'Position',[264 193 360 72], ...
         'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Box','on', ...
         'XLim',[0 1], ...
         'ZLim',[0 1], ...
         'TickLength',[0 0], ...
         'XTickLabel',[], ...
         'YTickLabel',[], ...
         'Visible','on');

      set(controls.hyperparametersaxes,'Units','normalized');
      if cm.prior_inf_shortrun==1;
         hyp_txt = ['\lambda_{b}=' num2str(curr_ini.lambda_b,'%0.2f') ', \lambda_{\rho}=' num2str(curr_ini.lambda_theta,'%0.3f') ', \lambda_{l}=' num2str(curr_ini.lambda_l,'%0.1f')];
         if cm.q0+cm.q1>0;
            hyp_txt = [hyp_txt ', \lambda_{e}=' num2str(curr_ini.lambda_e,'%0.3f')];
         end;
      else;
         hyp_txt = 'P(\Gamma | \Omega)_{ } = ';
         if cm.q1>0;
            hyp_txt = [hyp_txt 'P(\Psi | \Omega) = '];
         end;
         if cm.q0>0;
            hyp_txt = [hyp_txt 'P(\Phi | \Omega) = '];
         end;
         hyp_txt = [hyp_txt '1'];
      end;
      if cm.prior_inf_deter==1;
         n_hyp_txt = ['\lambda_{d}=' num2str(curr_ini.lambda_d,'%0.2f')];
      else;
         n_hyp_txt = 'P(\delta | \Omega)_{ } = 1';
      end;
      if cm.cointvalue==1;
         n_hyp_txt = [n_hyp_txt  ', \lambda_{\alpha}=' num2str(curr_ini.lambda_alpha,'%0.2f')];
         r_hyp_txt = ['P(Rank=r)=' num2str(1/(cm.n+1),'%0.3f') ' \forall r \in {0,...,' num2str(cm.n,'%0.0f') '}'];
      else;
         r_hyp_txt = '';
      end;
      if (cm.prior_inf_omega==1)&(cm.amat_type==0);
         n_hyp_txt = [n_hyp_txt ', \lambda_{A}=' num2str(cm.lambda_a,'%0.2f') ', q=' num2str(cm.q_parm,'%0.0f')];
      end;
      hyp_txt = strvcat(hyp_txt,n_hyp_txt,r_hyp_txt);
      
      controls.hyptext = text('Parent',controls.hyperparametersaxes,'Position',[0.025 0.5],'String',hyp_txt,'FontSize',curr_ini.gui_fontsize+1,'FontName',curr_ini.gui_fontname,'HorizontalAlignment','left','Color',curr_ini.gui_foreground_color,'Clipping','on');

      controls.default_prior = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[520 240 100 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Callback','bayesgui default_prior', ...
         'String','Default Prior', ...
         'Enable','off', ...
         'Tag','DefaultPriorButton');

      %
      % Text control with header for results
      %

      controls.tracetext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[12 360 230 15], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','left', ...
         'String','   Rank      P(r|Data;FML)       P(r|Data;ML)', ...
         'Tag','Text2');

      %
      % Listbox control with results
      %

      controls.traceresults = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[14 183 228 175], ...
         'FontSize',10, ...
         'FontName','FixedWidth', ...
         'Style','listbox', ...
         'Enable','inactive', ...
         'Max',2, ...
         'HorizontalAlignment','center', ...
         'String',cm.rankprob_str, ...
         'Tag','Text1',...
         'Value',[]);

      %
      % Cointegration rank order control
      %

      controls.cointranktext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[268 310 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Enable','off', ...
         'Style','text', ...
         'HorizontalAlignment','left', ...
         'String','Number of Cointegration Relations:', ...
         'Tag','ListBoxRankText');

      controls.cointrank = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[522 315 90 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Value',cm.r+1, ...
         'Callback','bayesgui setrank', ...
         'Enable','off', ...
         'UserData',thisexit, ...
         'String',ranks, ...
         'Tag','ListBoxRank');

      if cm.cointvalue==1;
         set(controls.cointrank,'Enable','on');
         set(controls.cointranktext,'Enable','on');
      end;

      %
      % Parameter restrictions controls
      %

      controls.betarest = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 130 250 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',0, ...
         'Enable','off', ...
         'Callback','bayesgui check_model', ...
         'HorizontalAlignment','left', ...
         'String','Apply restrictions on beta', ...
         'Tag','CheckBetaRest');

      controls.alpharest = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 110 250 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',0, ...
         'Enable','off', ...
         'Callback','bayesgui check_model', ...
         'HorizontalAlignment','left', ...
         'String','Apply restrictions on alpha', ...
         'Tag','CheckAlphaRest');

      controls.shortrunrest = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 90 250 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',0, ...
         'Enable','off', ...
         'Callback','bayesgui check_model', ...
         'HorizontalAlignment','left', ...
         'String','Apply restrictions on short-run dynamics', ...
         'Tag','CheckShortRunRest');

      controls.svarrest = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 70 250 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',0, ...
         'Enable','off', ...
         'Callback','bayesgui check_model', ...
         'HorizontalAlignment','left', ...
         'String','Apply Structural VAR identification to:', ...
         'Tag','CheckIdentificationRest');

      controls.simultaneous = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[70 50 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','radio', ...
         'Value',1, ...
         'Enable','off', ...
         'Callback','bayesgui check_model', ...
         'HorizontalAlignment','left', ...
         'String','Simultaneous restrictions', ...
         'Tag','RadioSimultaneousRest');

      controls.contemporaneous = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[70 30 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','radio', ...
         'Value',0, ...
         'Enable','off', ...
         'Callback','bayesgui check_model', ...
         'HorizontalAlignment','left', ...
         'String','Contemporaneous restrictions', ...
         'Tag','RadioContemporaneousRest');

      %
      % MCMC Sampler controls
      %

      controls.burn_intext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[342 127 180 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','left', ...
         'String','Number of burn-in draws:', ...
         'Tag','BurnInDrawsText');

      controls.burn_in = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[510 132 110 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Value',1, ...
         'Callback','bayesgui burn_in', ...
         'String','0|100|200|300|400|500|600|700|800|900|1,000|1,500|2,000|2,500|3,000|3,500|4,000|4,500|5,000|6,000|7,000|8,000|9,000|10,000|15,000|20,000|25,000|30,000|35,000|40,000|45,000|50,000', ...
         'Tag','BurnInDrawsPopup');

      b_str = get(controls.burn_in,'String');
      for i=1:size(b_str,1);
         bs_val = mystr2num(strtrim(strrep(b_str(i,:),',','')));
         if bs_val==curr_ini.burn_in;
            b_val = i;
            break;
         end;
      end;
      set(controls.burn_in,'Value',b_val);

      controls.save_drawstext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[342 95 180 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','left', ...
         'String','Number of draws to save:', ...
         'Tag','SaveDrawsText');

      controls.save_draws = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[510 100 110 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Value',1, ...
         'Callback','bayesgui save_draws', ...
         'String','100|200|300|400|500|600|700|800|900|1,000|1,500|2,000|2,500|3,000|3,500|4,000|4,500|5,000|6,000|7,000|8,000|9,000|10,000|15,000|20,000|25,000|30,000|35,000|40,000|45,000|50,000|60,000|70,000|80,000|90,000|100,000|200,000|300,000|400,000|500,000', ...
         'Tag','SaveDrawsPopup');

      s_str = get(controls.save_draws,'String');
      for i=1:size(s_str,1);
         ss_val = mystr2num(strtrim(strrep(s_str(i,:),',','')));
         if ss_val==curr_ini.save_draws;
            s_val = i;
            break;
         end;
      end;
      set(controls.save_draws,'Value',s_val);


      controls.save_freqtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[342 63 180 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','left', ...
         'String','Draw saving frequency:', ...
         'Tag','SaveFreqText');

      controls.save_freq = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[510 68 110 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Value',curr_ini.save_freq, ...
         'Callback','bayesgui save_freq', ...
         'String','1 in 1 (100%)|1 in 2 (50%)|1 in 3 (33%)|1 in 4 (25%)|1 in 5 (20%)|1 in 6 (16.7%)|1 in 7 (14.3%)|1 in 8 (12.5%)|1 in 9 (11.1%)|1 in 10 (10%))|1 in 11 (9.1%)|1 in 12 (8.3%)|1 in 13 (7.7%)|1 in 14 (7.1%)|1 in 15 (6.7%)|1 in 16 (6.2%)|1 in 17 (5.9%)|1 in 18 (5.6%)|1 in 19 (5.3%)|1 in 20 (5%)', ...
         'Tag','SaveFreqPopup');

      controls.discard_explosive = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[342 30 158 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',cm.discard_explosive, ...
         'Callback','bayesgui discard_explosive', ...
         'HorizontalAlignment','left', ...
         'String','Discard explosive processes', ...
         'Tag','DiscardExplosiveCheck');

      controls.default_mcmc = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[510 30 110 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Callback','bayesgui default_mcmc', ...
         'String','MCMC Defaults', ...
         'Enable','off', ...
         'Tag','MCMCDefaultButton');


      %
      % The toolbar
      %

      controls.toolbar = uitoolbar('Parent',bayesdlg, ...
                        'HandleVisibility','off', ...
                        'Interruptible','on', ...
                        'Clipping','on');

      controls.mcmc_unrest = uipushtool('Parent',controls.toolbar, ...
                      'TooltipString','Run MCMC for all cointegration ranks', ...
                      'CData',button_images.rankest, ...
                      'ClickedCallback','bayesgui mcmc_unrest', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable','on', ...
                      'Tag','MCMCUnrestButton');

      if cm.cointvalue==0;
         set(controls.mcmc_unrest,'TooltipString','Run MCMC for reduced form model','CData',button_images.simulate);
         set(controls.mcmc_unrest_menu,'Label','&Reduced form model...');
      end;

      %
      % specific beta estimation for a given rank r
      %

      controls.restrict_beta = uipushtool('Parent',controls.toolbar, ...
                         'TooltipString','Restrict Beta', ...
                         'CData',button_images.betarest, ...
                         'ClickedCallback','bayesgui restrict_beta', ...
                         'Separator','on', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','off', ...
                         'Tag','RestrictBetaButton');

      controls.beta_estimate = uipushtool('Parent',controls.toolbar, ...
                         'TooltipString','Run MCMC for Beta Restrictions', ...
                         'CData',button_images.betaest, ...
                         'ClickedCallback','bayesgui beta_estimate', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','off', ...
                         'Tag','BetaEstimateButton');

      controls.open_beta_restrict = uipushtool('Parent',controls.toolbar, ...
                         'TooltipString','Open Beta Restrictions', ...
                         'CData',button_images.openbetarest, ...
                         'ClickedCallback','bayesgui open_beta_restrict', ...
                         'Separator','on', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','off', ...
                         'Tag','OpenBetaRestrictButton');


      controls.save_beta_restrict = uipushtool('Parent',controls.toolbar, ...
                         'TooltipString','Save Beta Restrictions', ...
                         'CData',button_images.savebeta, ...
                         'ClickedCallback','bayesgui save_beta_rest', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','off', ...
                         'Tag','SaveBetaRestrictButton');


      %
      % Quit button
      %

      controls.quit = uipushtool('Parent',controls.toolbar, ...
                         'TooltipString','Quit', ...
                         'CData',button_images.close, ...
                         'ClickedCallback','bayesgui quit', ...
                         'Separator','on', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'UserData','working', ...
                         'Enable','on', ...
                         'Tag','Return');

      set(bayesdlg,'UserData',controls,...
         'HandleVisibility','callback');

   case 'open_beta_restrict'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         thisopenrest = openrestgui('init',cm);
         openrest = get(thisopenrest,'UserData');
         set(openrest.hmat,'UserData','done');
         killguipid(thisopenrest);
         %
         % Test if H_i-modelfile.rest files exist in modelsdir
         %
         beta_enable = 'off';
         i = 1;
         while i<=cm.r;
            file = strcat(cm.modelsdir,'H_',num2str(i),'-',num2str(cm.n),'x',num2str(cm.r),'x',num2str(cm.dcoint+cm.q1),'-',cm.modelfile,'.rest');
            if fileexist(file)==1;
               i = i+1;
            else;
               break;
            end;
         end;
         %
         % if necessary test if normalize-modelfile.norm exists in modelsdir
         % and if so set cointbeta.estimate control to
         % being enabled
         %
         if i==cm.r+1;
            file = strcat(cm.modelsdir,'normalize-',num2str(cm.n),'x',num2str(cm.r),'x',num2str(cm.dcoint+cm.q1),'-',cm.modelfile,'.norm');
            if fileexist(file)==1;
               file = strcat(cm.modelsdir,'H_1-',num2str(cm.n),'x',num2str(cm.r),'x',num2str(cm.dcoint+cm.q1),'-',cm.modelfile,'.rest');
               checkH_1 = loaddata(file);
               if size(checkH_1,1)==size(cm.beta,1);
                  beta_enable = 'on';
               end;
            end;
         end;
         set(controls.beta_estimate,'Enable',beta_enable);
         set(controls.beta_estimate_menu,'Enable',beta_enable);
         %
         set(bayesdlg,'Visible','on');
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'save_beta_rest'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         thissaverest = saverestgui('init',cm);
         saverest = get(thissaverest,'UserData');
         set(saverest.hmat,'UserData','done');
         killguipid(thissaverest);
         %
         set(bayesdlg,'Visible','on');
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'restrict_beta'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         cm.index = 1;
         normalize = ones(cm.r,1);
         file = strcat(cm.modelsdir,'normalize-',num2str(cm.n),'x',num2str(cm.r),'x',num2str(cm.dcoint+cm.q1),'-',cm.modelfile,'.norm');
         if fileexist(file)==1;
            normalize = loaddata(file);
         end;
         if size(normalize,2)>size(normalize,1);
            normalize = normalize';
         end;
         while cm.index<=cm.r;
            cm.Hmat = zeros(cm.n+cm.q1+cm.dcoint-cm.r+1,cm.n+cm.q1+cm.dcoint);
            file = strcat(cm.modelsdir,'H_',int2str(cm.index),'-',num2str(cm.n),'x',num2str(cm.r),'x',num2str(cm.dcoint+cm.q1),'-',cm.modelfile,'.rest');
            if fileexist(file)==1;
              cm.Hmat = loaddata(file);
              cm.Hmat = cm.Hmat';
            end;
            cm.normvar = normalize(cm.index,1);
            rd = 'redraw';
            while strcmp(rd,'redraw')==1;
               thishmatfig = hmatgui('init',cm);
               hmats = get(thishmatfig,'UserData');
               cm.Hmat = get(hmats.text,'UserData');
               rd = get(hmats.rest,'UserData');
               newindex = get(hmats.cv,'Value');
               cancel = get(hmats.cancel,'UserData');
               cm.normvar = get(hmats.popup,'Value');
               set(hmats.popup,'UserData','done');
               killrestpid(thishmatfig);
               drawnow;
            end;
            if cancel<=1;
               normalize(cm.index,1) = cm.normvar;
               if newindex==cm.index;
                  cm.index = cm.index+1;
               else;
                  cm.index = newindex;
               end;
            elseif cancel==2;
               cm.index = cm.r+1;
            end;
         end;
         if size(normalize,1)==cm.r;
            savefile = strcat(cm.modelsdir,'normalize-',num2str(cm.n),'x',num2str(cm.r),'x',num2str(cm.dcoint+cm.q1),'-',cm.modelfile,'.norm');
            fid = fopen(savefile,'wt');
            fprintf(fid,'%1.0f\n',normalize);
            fclose(fid);
         end;
         %
         % Check if all the necessary files exist to estimate
         % beta under restrictions
         %
         i = 1;
         beta_enable = 'off';
         while i<=cm.r;
            file = strcat(cm.modelsdir,'H_',num2str(i),'-',num2str(cm.n),'x',num2str(cm.r),'x',num2str(cm.dcoint+cm.q1),'-',cm.modelfile,'.rest');
            if fileexist(file)==1;
               i = i+1;
            else;
               break;
            end;
         end;
         if i==cm.r+1;
            file = strcat(cm.modelsdir,'normalize-',num2str(cm.n),'x',num2str(cm.r),'x',num2str(cm.dcoint+cm.q1),'-',cm.modelfile,'.norm');
            if fileexist(file)==1;
               checkH_1 = loaddata(file);
               if size(checkH_1,1)==size(cm.rank(cm.r+1).beta,2);
                  beta_enable = 'on';
               end;
            end;
         end;
         set(controls.beta_estimate,'Enable',beta_enable);
         set(controls.beta_estimate_menu,'Enable',beta_enable);
         %
         % Fix beta results control
         %
         dfbeta = dfbeta_fcn(cm);
         res_file = [curr_ini.simulatedir cm.modelfile '-beta-gibbs-' num2str(cm.scale_endo,'%0.4f') '-' num2str(cm.r,'%0.0f') '.' num2str(dfbeta,'%0.0f') '-' cm.determodel cm.lag_model num2str(cm.burn_in,'%0.0f') '.' num2str(cm.save_draws,'%0.0f') '.' num2str(cm.save_freq,'%0.0f') '.' num2str(cm.discard_explosive,'%0.0f') '-' num2str(cm.prior_inf_shortrun,'%0.0f') '.' num2str(cm.prior_inf_deter,'%0.0f') '-' num2str(cm.prior_inf_alpha,'%0.0f') '-' num2str(cm.prior_inf_omega,'%0.0f')];
         if cm.prior_inf_omega==1;
            if cm.amat_type==1;
               res_file = [res_file '-1'];
            else;
               res_file = [res_file '-0.' num2str(cm.lambda_a,'%0.2f') '.' num2str(cm.q_parm,'%0.0f')];
            end;
         end;
         if cm.prior_inf_alpha==1;
            res_file = [res_file '.' num2str(cm.lambda_alpha,'%0.3f')];
         end;
         if cm.prior_inf_shortrun==1;
            res_file = [res_file '.' num2str(cm.lambda_b,'%0.3f') '.' num2str(cm.lambda_theta,'%0.3f') '.' num2str(cm.lambda_l,'%0.3f') '.' num2str(cm.lambda_e,'%0.3f')];
         end;
         if cm.prior_inf_deter==1;
            res_file = [res_file '.' num2str(cm.lambda_d,'%0.3f')];
         end;
         res_file = [res_file '.txt'];
         if fileexist(res_file)==1;
            set(controls.results_beta,'Enable','on','UserData',res_file);
         else;
            set(controls.results_beta,'Enable','off','UserData','');
         end;
         file = strrep(res_file,'.txt','.mat');
         if fileexist(file)==1;
            set(controls.betarest,'Enable','on');
         else;
            set(controls.betarest,'Enable','off','Value',0);
         end;
         %
         set(bayesdlg,'Visible','on');
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'beta_estimate'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         status = testident(cm.modelsdir,cm.modelfile,cm.r,cm.n,cm.dcoint,cm.q1);
         if sum(status)==cm.r;
            %
            % The restrictions passed the generic identification test
            %
            % First compute the ML estimates under the restrictions. This is used as
            % initial values by the Gibbs sampler
            %
            [cm.beta_rest.beta,newlambda,cm.beta_rest.dfbeta,stdbeta,outputtxt,abort,infomat,conv_txt] = betarestrict(cm.S_00,cm.S_11,cm.S_01,cm.S_10,cm.beta(:,1:cm.r),cm.T,cm.modelsdir,cm.modelfile,0,cm.dcoint);
            %
            % compute the remaining parameter estimates; all ML estimates are kept in the structure
            % cm.beta_rest
            %
            cm.beta_rest.alpha = (cm.S_01*cm.beta_rest.beta)*inverse(cm.beta_rest.beta'*cm.S_11*cm.beta_rest.beta);
            if isempty(cm.Z2)==0;
               cm.beta_rest.Psi = (cm.M_02/cm.M_22)-(cm.beta_rest.alpha*cm.beta_rest.beta'*(cm.M_12/cm.M_22));
               cm.beta_rest.epsilon = cm.Z0-(cm.beta_rest.alpha*cm.beta_rest.beta'*cm.Z1)-(cm.beta_rest.Psi*cm.Z2);
            else;
               cm.beta_rest.Psi = [];
               cm.beta_rest.epsilon = cm.Z0-(cm.beta_rest.alpha*cm.beta_rest.beta'*cm.Z1);
            end;
            cm.beta_rest.Omega = (1/cm.T)*cm.beta_rest.epsilon*cm.beta_rest.epsilon';
            %
            % Transform the restrictions matrices into h and H, where vec(beta) = h + H*psi
            %
            [cm.beta_rest.h_vec,cm.beta_rest.H_mat,cm.beta_rest.tot_free] = beta_restrictions(cm.beta_rest.beta,cm.n,cm.r,cm.dcoint,cm.q1,cm.modelsdir,cm.modelfile);
            %
            % Compute Draper's measure of the marginal likelihood for the ML estimator and if dfbeta>0 the LR test and its as. p-value
            %
            df_rest = cm.beta_rest.tot_free+(cm.n*(size(cm.Z2,1)+cm.r))+((cm.n*(cm.n+1))/2);
            df_unrest = df_rest+cm.beta_rest.dfbeta;
            marg_drap_rest = draper_fcn(cm.beta_rest.epsilon,df_rest);
            marg_drap_unrest = draper_fcn(cm.rank(cm.r+1).epsilon,df_unrest);
            if cm.beta_rest.dfbeta>0;
               LR = 2*(loglike(cm.rank(cm.r+1).epsilon)-loglike(cm.beta_rest.epsilon));
               pval = 1-chis_cdf(LR,cm.beta_rest.dfbeta);
               %
               % Determine model probabilities based on the Draper Marginal Likelihoods
               %
               marg_lnvec = [marg_drap_unrest;marg_drap_rest];
               marg_vec = fix_exp(marg_lnvec-mean(marg_lnvec));
               marg_prob = (1/sum(marg_vec))*marg_vec;
            else;
               marg_prob = [];
               LR = [];
               pval = [];
            end;
            %
            % Compute prior means and covariances for all parameters
            % that have proper unconditional priors
            %
            if isempty(cm.Z2)==0;
               [cm.prior.deter.mu,cm.prior.deter.sigma,cm.prior.shortrun.mu,cm.prior.shortrun.sigma] = prior_short_coint(cm);
            else;
               cm.prior.deter.mu = [];
               cm.prior.deter.sigma = [];
               cm.prior.shortrun.sigma = [];
               cm.prior.shortrun.mu = [];
            end;
            %
            % Ready to start up the Gibbs sampler
            %
            %
            if (cm.deterselect(1,1)==1)|(cm.deterselect(1,3)==1);
               %
               % compute Omega for lag order sm.amat_lag-1 if necessary
               %
               if (cm.amat_type==1)&(cm.amat_lag>1);
                  [cm.amat_val,cm.use_lag] = ml_omega(cm);
               end;
               [out,betafilename,warns,abort] = gibbs_beta(cm,curr_ini);
            else;
               set(bayesdlg,'Visible','on');
               drawnow;
               %
               cm.running = 0;
               curr_ini.model = cm;
               set(controls.viewdata,'UserData',curr_ini);
               return;
            end;
            if max(warns)>0;
               %
               % trouble with some covariance matrix. locate it through warns
               % and display appropriate text
               %
               % first get the row, r, where the maximum is located
               % then the column, c
               %
               [m_warns,c] = max(warns);
               if c==1;
                  par = 'Omega';
               elseif c==2;
                  par = 'delta';
               elseif c==3;
                  par = 'Gamma';
               elseif c==4;
                  par = 'alpha';
               elseif c==5;
                  par = 'beta';
               end;
               txt = ['The Gibbs sampler for beta restrictions was aborted. The reason was a badly determined covariance matrix for ' par '. This may be due to your choice of prior. If the problem persists, please consider selecting another prior.'];
               about(txt,'error','Gibbs Sampler Error',120,500);
               abort = 'cancel';
               setlogtext(strvcat(' ','Gibbs sampler error...',' '));
            end;
            if strcmp(abort,'cancel')==0;
               %
               % marginalize the posterior via the Gibbs sampler and apply the posterior mode for the parameters
               %
               if (cm.prior_inf_alpha==1)&(cm.prior_inf_omega==1);
                  cm.betafilename = betafilename;
                  warn = 0;
                  [out,stat_marglike] = margin_beta(cm,out);
                  %
                  cm = rmfield(cm,'betafilename');
                  if strcmp(abort,'cancel')==1;
                     setlogtext(strvcat(' ','Gibbs sampling cancelled...',' '));
                     %
                     if fileexist(betafilename)==1;
                        delete_file_fcn(betafilename);
                     end;
                     %
                     set(bayesdlg,'Visible','on');
                     drawnow;
                     %
                     cm.running = 0;
                     curr_ini.model = cm;
                     set(controls.viewdata,'UserData',curr_ini);
                     return;
                  end;
                  if warn==0;
                     %
                     % Compute the marginal likelihood
                     %
                     %marg_like = out.posterior_mode.log_posterior-out.posterior_mode.log_post;
                     marg_like = out.posterior_mode.log_post;
                     out.posterior_mode.log_post = out.posterior_mode.log_like+out.posterior_mode.log_prior-marg_like;
                  else;
                     setlogtext(strvcat(' ','Gibbs sampler error...'));
                  end;
               else;
                  marg_like = [];
                  warn = 0;
                  stat_marglike = 0;
               end;
               %
               % Write output to file
               %
               if warn==0;
                  if curr_ini.noprint==0;
                     %
                     % Send to print function
                     %
                     print_bayes_beta(cm,curr_ini,out,LR,pval,marg_like,marg_prob,marg_drap_unrest,marg_drap_rest,stat_marglike);
                  end;
                  %
                  % Create the results string
                  %
                  results_str = strvcat(' ','   Analyses of Identified Cointegration Vectors','   ============================================',' ');
                  results_str = strvcat(results_str,'Summary statistics from the Gibbs sampler','~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~');
                  results_str = strvcat(results_str,['    Total draws:               ' num2str(out.gibbs.draws,'%8.0f')],['    Burn-in draws:             ' num2str(cm.burn_in,'%8.0f')],['    Considered draws:          ' num2str(out.gibbs.real_draws,'%8.0f')]);
                  results_str = strvcat(results_str,['    Total discarded draws:     ' num2str(out.gibbs.discard_draws,'%8.0f')],['    Discarded explosive draws: ' num2str(out.gibbs.discard_explosive_draws,'%8.0f')],['    Draw saving frequency:     ' num2str(100/cm.save_freq,'%5.1f') '% '],['    Saved draws:               ' num2str(cm.save_draws,'%8.0f')],' ');
                  %
                  if cm.beta_rest.dfbeta>0;
                     results_str = strvcat(results_str,'Testing the restrictions using a classical LR test','~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                     results_str = strvcat(results_str,['LR(' num2str(cm.beta_rest.dfbeta,'%0.0f') ')  = ' num2str(LR,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])]);
                     results_str = strvcat(results_str,['p-value = ' num2str(pval,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ');
                     results_str = strvcat(results_str,'Approximation of the Marginal Likelihood','~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                     results_str = strvcat(results_str,['Exact Identification: log P(Data|beta model) = ' num2str(marg_drap_unrest,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ' --> P(beta model|Data) = ' num2str(marg_prob(1,1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])]);
                     results_str = strvcat(results_str,['Over-Identification:  log P(Data|beta model) = ' num2str(marg_drap_rest,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ' --> P(beta model|Data) = ' num2str(marg_prob(2,1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ');
                     results_str = strvcat(results_str,'where the two beta models have been given the same prior probability','P(beta model) = 1/2',' ');
                     results_str = strvcat(results_str,'NOTE: The marginal likelihoods are here approximated using equation (11) in:','      Draper, D. (1995), "Assessment and Propagation of Model Uncertainty",','      Journal of the Royal Statistical Society B, pp. 45-97.',' ');
                     if (cm.prior_inf_alpha==1)&(cm.prior_inf_omega==1);
                        results_str = strvcat(results_str,'Computed Marginal Likelihood','~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                        if stat_marglike==0;
                           results_str = strvcat(results_str,['log P(Data|beta model) = ' num2str(marg_like,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ');
                        else;
                           results_str = strvcat(results_str,'log P(Data|beta model) = Unable to compute',' ');
                        end;
                     end;
                     results_str = strvcat(results_str,'Posterior Mode Properties','~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                     results_str = strvcat(results_str,sprintf(['Max absolute eigenvalue of companion matrix: %' num2str(7+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'],out.posterior_mode.max_evalue));
                     results_str = strvcat(results_str,sprintf(['Value of log prior density:                  %' num2str(7+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'],out.posterior_mode.log_prior));
                     results_str = strvcat(results_str,sprintf(['Value of log data density:                   %' num2str(7+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'],out.posterior_mode.log_like));
                     if (cm.prior_inf_alpha==1)&(cm.prior_inf_omega==1);
                        if stat_marglike==0;
                           results_str = strvcat(results_str,sprintf(['Value of log posterior density:              %' num2str(7+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'],out.posterior_mode.log_post),' ');
                        else;
                           results_str = strvcat(results_str,'Value of log posterior density:              Unable to compute',' ');
                        end;
                     else;
                        results_str = strvcat(results_str,' ');
                     end;
                     results_str = strvcat(results_str,'Full Posterior Mode Estimates of beta','~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                     prt_str = '%2.0f';
                     for j=1:size(out.posterior_mode.beta,1);
                        prt_str = [prt_str ' %' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
                     end;
                     for j=1:cm.r;
                        res_str = sprintf(prt_str,j,out.posterior_mode.beta(:,j)');
                        results_str = strvcat(results_str,res_str);
                     end;
                     %
                     results_str = strvcat(results_str,' ','Full Posterior Median Estimates of beta','~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                     for j=1:cm.r;
                        res_str = sprintf(prt_str,j,out.posterior_median.beta(:,j)');
                        results_str = strvcat(results_str,res_str);
                     end;
                     %
                     results_str = strvcat(results_str,' ','Full Posterior Mean Estimates of beta','~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                     for j=1:cm.r;
                        res_str = sprintf(prt_str,j,out.posterior_mean.beta(:,j)');
                        results_str = strvcat(results_str,res_str);
                     end;
                     results_str = strvcat(results_str,' ',[num2str(cm.cbs,'%0.0f') '%  Confidence Bands for beta'],'~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ','Lower Bound:');
                     for j=1:cm.r;
                        res_str = sprintf(prt_str,j,out.confidence_bands.beta_lower(:,j)');
                        results_str = strvcat(results_str,res_str);
                     end;
                     results_str = strvcat(results_str,' ','Upper Bound:');
                     for j=1:cm.r;
                        res_str = sprintf(prt_str,j,out.confidence_bands.beta_upper(:,j)');
                        results_str = strvcat(results_str,res_str);
                     end;
                     results_str = strvcat(results_str,' ');
                     %
                     % add results from "marginal" Gibbs sampler for (alpha, beta, Omega)
                     %
                     if isfield(out.posterior_median,'beta_n')==1;
                        results_str = strvcat(results_str,'Partial Posterior Mode Estimates of beta','~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                        for j=1:cm.r;
                           res_str = sprintf(prt_str,j,out.posterior_mode.beta(:,j)');
                           results_str = strvcat(results_str,res_str);
                        end;
                        %
                        results_str = strvcat(results_str,' ','Partial Posterior Median Estimates of beta','~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                        for j=1:cm.r;
                           res_str = sprintf(prt_str,j,out.posterior_median.beta_n(:,j)');
                           results_str = strvcat(results_str,res_str);
                        end;
                        %
                        results_str = strvcat(results_str,' ','Partial Posterior Mean Estimates of beta','~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                        for j=1:cm.r;
                           res_str = sprintf(prt_str,j,out.posterior_mean.beta_n(:,j)');
                           results_str = strvcat(results_str,res_str);
                        end;
                        %
                        results_str = strvcat(results_str,' ',[num2str(cm.cbs,'%0.0f') '%  Confidence Bands for beta'],'~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ','Lower Bound:');
                        for j=1:cm.r;
                           res_str = sprintf(prt_str,j,out.confidence_bands.beta_n_lower(:,j)');
                           results_str = strvcat(results_str,res_str);
                        end;
                        results_str = strvcat(results_str,' ','Upper Bound:');
                        for j=1:cm.r;
                           res_str = sprintf(prt_str,j,out.confidence_bands.beta_n_upper(:,j)');
                           results_str = strvcat(results_str,res_str);
                        end;
                        results_str = strvcat(results_str,' ');
                     end;
                  else;
                     results_str = strvcat(results_str,'Approximation of the Marginal Likelihood','~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                     results_str = strvcat(results_str,['Exact Identification: log P(Data|beta model) = ' num2str(marg_drap_unrest,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ');
                     results_str = strvcat(results_str,'NOTE: The marginal likelihood is here approximated using equation (11) in:','      Draper, D. (1995), "Assessment and Propagation of Model Uncertainty",','      Journal of the Royal Statistical Society B, pp. 45-97.',' ');
                     if (cm.prior_inf_alpha==1)&(cm.prior_inf_omega==1);
                        results_str = strvcat(results_str,'Computed Marginal Likelihood','~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                        results_str = strvcat(results_str,['log P(Data|beta model) = ' num2str(marg_like,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ');
                     end;
                     results_str = strvcat(results_str,'Posterior Mode Properties','~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                     results_str = strvcat(results_str,sprintf(['Max absolute eigenvalue of companion matrix: %' num2str(7+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'],out.posterior_mode.max_evalue));
                     results_str = strvcat(results_str,sprintf(['Value of log prior density:                  %' num2str(7+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'],out.posterior_mode.log_prior));
                     results_str = strvcat(results_str,sprintf(['Value of log data density:                   %' num2str(7+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'],out.posterior_mode.log_like));
                     if (cm.prior_inf_alpha==1)&(cm.prior_inf_omega==1);
                        results_str = strvcat(results_str,sprintf(['Value of log posterior density:              %' num2str(7+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'],out.posterior_mode.log_post),' ');
                     else;
                        results_str = strvcat(results_str,' ');
                     end;
                     results_str = strvcat(results_str,'Full Posterior Mode Estimates of beta','~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                     prt_str = '%2.0f';
                     for j=1:size(out.posterior_mode.beta,1);
                        prt_str = [prt_str ' %' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
                     end;
                     for j=1:cm.r;
                        res_str = sprintf(prt_str,j,out.posterior_mode.beta(:,j)');
                        results_str = strvcat(results_str,res_str);
                     end;
                     %
                     results_str = strvcat(results_str,' ','Full Posterior Median Estimates of beta','~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                     for j=1:cm.r;
                        res_str = sprintf(prt_str,j,out.posterior_median.beta(:,j)');
                        results_str = strvcat(results_str,res_str);
                     end;
                     %
                     results_str = strvcat(results_str,' ','Posterior Mean Cointegration Space Estimator','~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                     for j=1:cm.r;
                        res_str = sprintf(prt_str,j,out.pmcs.beta(:,j)');
                        results_str = strvcat(results_str,res_str);
                     end;
                     results_str = strvcat(results_str,' ',['with projective Frobenius span variation: ' num2str(sqrt(out.pmcs.variation),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ','Normalized based on the Identifying Restrictions:',' ');
                     beta = fix_norm_beta(out.pmcs.beta,cm);
                     for j=1:cm.r;
                        res_str = sprintf(prt_str,j,beta(:,j)');
                        results_str = strvcat(results_str,res_str);
                     end;
                     results_str = strvcat(results_str,' ',[num2str(cm.cbs,'%0.0f') '%  Confidence Bands for beta'],'~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ','Lower Bound:');
                     for j=1:cm.r;
                        res_str = sprintf(prt_str,j,out.confidence_bands.beta_lower(:,j)');
                        results_str = strvcat(results_str,res_str);
                     end;
                     results_str = strvcat(results_str,' ','Upper Bound:');
                     for j=1:cm.r;
                        res_str = sprintf(prt_str,j,out.confidence_bands.beta_upper(:,j)');
                        results_str = strvcat(results_str,res_str);
                     end;
                     results_str = strvcat(results_str,' ');
                     %
                     % add results from "marginal" Gibbs sampler for (alpha, beta, Omega)
                     %
                     if isfield(out.posterior_median,'beta_n')==1;
                        results_str = strvcat(results_str,'Partial Posterior Mode Estimates of beta','~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                        for j=1:cm.r;
                           res_str = sprintf(prt_str,j,out.posterior_mode.beta(:,j)');
                           results_str = strvcat(results_str,res_str);
                        end;
                        %
                        results_str = strvcat(results_str,' ','Partial Posterior Mean Cointegration Space Estimator','~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                        for j=1:cm.r;
                           res_str = sprintf(prt_str,j,out.pmcs.beta_n(:,j)');
                           results_str = strvcat(results_str,res_str);
                        end;
                        results_str = strvcat(results_str,' ',['with projective Frobenius span variation: ' num2str(sqrt(out.pmcs.variation_n),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ','Normalized based on the Identifying Restrictions:',' ');
                        beta = fix_norm_beta(out.pmcs.beta_n,cm);
                        for j=1:cm.r;
                           res_str = sprintf(prt_str,j,beta(:,j)');
                           results_str = strvcat(results_str,res_str);
                        end;
                        %
                        results_str = strvcat(results_str,' ',[num2str(cm.cbs,'%0.0f') '%  Confidence Bands for beta'],'~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ','Lower Bound:');
                        for j=1:cm.r;
                           res_str = sprintf(prt_str,j,out.confidence_bands.beta_n_lower(:,j)');
                           results_str = strvcat(results_str,res_str);
                        end;
                        results_str = strvcat(results_str,' ','Upper Bound:');
                        for j=1:cm.r;
                           res_str = sprintf(prt_str,j,out.confidence_bands.beta_n_upper(:,j)');
                           results_str = strvcat(results_str,res_str);
                        end;
                        results_str = strvcat(results_str,' ');
                     end;
                  end;
                  %
                  %
                  % save all the results to file
                  %   1. results string
                  %
                  txt = strvcat(' ','Saving output to disk. Using the directory:',' ',curr_ini.simulatedir);
                  setlogtext(strvcat('Saving output to disk...',' '));
                  mywait = waitdlg(txt,'information');
                  waitf = get(mywait,'UserData');
                  %
                  res_file = [curr_ini.simulatedir cm.modelfile '-beta-gibbs-' num2str(cm.scale_endo,'%0.4f') '-' num2str(cm.r,'%0.0f') '.' num2str(cm.beta_rest.dfbeta,'%0.0f') '-' cm.determodel cm.lag_model num2str(cm.burn_in,'%0.0f') '.' num2str(cm.save_draws,'%0.0f') '.' num2str(cm.save_freq,'%0.0f') '.' num2str(cm.discard_explosive,'%0.0f') '-' num2str(cm.prior_inf_shortrun,'%0.0f') '.' num2str(cm.prior_inf_deter,'%0.0f') '-' num2str(cm.prior_inf_alpha,'%0.0f') '-' num2str(cm.prior_inf_omega,'%0.0f')];
                  if cm.prior_inf_omega==1;
                     if cm.amat_type==1;
                        res_file = [res_file '-1'];
                     else;
                        res_file = [res_file '-0.' num2str(cm.lambda_a,'%0.2f') '.' num2str(cm.q_parm,'%0.0f')];
                     end;
                  end;
                  if cm.prior_inf_alpha==1;
                     res_file = [res_file '.' num2str(cm.lambda_alpha,'%0.3f')];
                  end;
                  if cm.prior_inf_shortrun==1;
                     res_file = [res_file '.' num2str(cm.lambda_b,'%0.3f') '.' num2str(cm.lambda_theta,'%0.3f') '.' num2str(cm.lambda_l,'%0.3f') '.' num2str(cm.lambda_e,'%0.3f')];
                  end;
                  if cm.prior_inf_deter==1;
                     res_file = [res_file '.' num2str(cm.lambda_d,'%0.3f')];
                  end;
                  res_file = [res_file '.txt'];
                  f_id = fopen(res_file,'wt');
                  for i=1:size(results_str,1);
                     fprintf(f_id,'%s \n',results_str(i,:));
                  end;
                  fprintf(f_id,'*******************************************************************************\n\n');
                  fprintf(f_id,['Output created on: ' datestr(now,0) '\n']);
                  fclose(f_id);
                  %
                  %   2. results for the individual cointegration ranks
                  %
                  file = strrep(res_file,'.txt','.mat');
                  results = out;
                  save(file,'results','betafilename','marg_like');
                  %
                  % close down the wait dialog
                  %
                  set(waitf.text,'UserData','done');
                  delete(mywait);
                  drawnow;
                  %
                  % Enable controls
                  %
                  set(controls.betarest,'Enable','on');
                  set(controls.results_beta,'Enable','on','UserData',res_file);
                  if cm.q1+cm.q0==0;
                     set(controls.varforecast,'Enable','on');
                  end;
                  set(controls.full_c_omega,'Enable','on');
                  set(controls.full_alphagraph,'Enable','on');
                  set(controls.full_betagraph,'Enable','on');
                  set(controls.full_eigengraph,'Enable','on');
                  set(controls.full_hist_alphagraph,'Enable','on');
                  set(controls.full_hist_betagraph,'Enable','on');
                  set(controls.full_hist_eigengraph,'Enable','on');
                  set(controls.cointgraphmenu,'Enable','on');
                  set(controls.cointpartgraphmenu,'Enable','on');
                  set(controls.part_alphagraph,'Enable','on');
                  set(controls.part_hist_alphagraph,'Enable','on');
                  set(controls.part_betagraph,'Enable','on');
                  set(controls.part_hist_betagraph,'Enable','on');
                  set(controls.marg_betagraph,'Enable','on');
                  set(controls.marg_hist_betagraph,'Enable','on');
                  set(controls.marg_alphagraph,'Enable','on');
                  set(controls.marg_hist_alphagraph,'Enable','on');
                  set(controls.part_c_psi,'Enable','on');
                  set(controls.full_c_psi,'Enable','on');
                  set(controls.part_c_alpha,'Enable','on');
                  set(controls.full_c_alpha,'Enable','on');
                  set(controls.part_c_omega,'Enable','on');
                  if cm.d>0;
                     set(controls.full_c_delta,'Enable','on');
                  end;
                  if cm.p>1;
                     set(controls.full_c_gamma,'Enable','on');
                  end;
                  if cm.q0>0;
                     set(controls.full_c_phi,'Enable','on');
                  end;
                  %
                  % Prepare a display of the results
                  %
                  textgui(res_file,'Bayesian Cointegration Analysis - Beta',[(realscrsz(3)-770)/2 (realscrsz(4)-500)/2 770 500],'Results',38);
               end;
            end;
         else;
            unident = '';
            for i=1:cm.r;
               if status(i,1)==0;
                  if strcmp(unident,'')==1;
                     unident = ['beta(' num2str(i) ')'];
                     thisres = 'restriction';
                     thisfail = 'fails';
                  else;
                     unident = [unident ', beta(' num2str(i) ')'];
                     thisres = 'restrictions';
                     thisfail = 'fail';
                  end;
               end;
            end;
            setlogtext(strvcat(' ','ERROR: The restrictions are not identifying...'));
            txt = ['The restrictions you have selected for beta are not identifying. In particular, the ' thisres ' on ' unident ' ' thisfail ' the identification test.'];
            about(txt,'warning','Identification Test Failure',120,350,'identification');
         end;
         %
         set(bayesdlg,'Visible','on');
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'mcmc_unrest'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         if cm.cointvalue==1;
            %
            % First we need to set up the prior mean and covariances for all parameters and all ranks
            %
            %    Step 1: Find an "appropriate" normalization for all beta's where normalizations are
            %            only based on the largest absolute determinant of all submatrices of beta
            %            r columns and r rows corresponding to endogenous variables
            %
            cm = get_cmatrices(cm);
            %
            % Step 2: Compute prior means and covariances for all parameters
            %         that have proper unconditional priors
            %
            if isempty(cm.Z2)==0;
               [cm.prior.deter.mu,cm.prior.deter.sigma,cm.prior.shortrun.mu,cm.prior.shortrun.sigma] = prior_short_coint(cm);
            else;
               cm.prior.deter.mu = [];
               cm.prior.deter.sigma = [];
               cm.prior.shortrun.sigma = [];
               cm.prior.shortrun.mu = [];
            end;
            %
            % we are now ready to startup the Gibbs sampler
            %
            if (cm.deterselect(1,1)==1)|(cm.deterselect(1,3)==1);
               if (cm.amat_type==1)&(cm.amat_lag>1);
                  [cm.amat_val,cm.use_lag] = ml_omega(cm);
               end;
               [out,rankfilenames,warns,abort] = gibbs_rank(cm,curr_ini);
            else;
               set(bayesdlg,'Visible','on');
               drawnow;
               %
               cm.running = 0;
               curr_ini.model = cm;
               set(controls.viewdata,'UserData',curr_ini);
               return;
            end;
            if max(max(warns))>0;
               %
               % trouble with some covariance matrix. locate it through warns
               % and display appropriate text
               %
               % first get the row, r, where the maximum is located
               % then the column, c
               %
               [m_warns,ind] = max(warns);
               r = max(ind);
               [m_warns,c] = max(m_warns);
               if c==1;
                  par = 'Omega';
               elseif c==2;
                  par = 'delta';
               elseif c==3;
                  par = 'Gamma';
               elseif c==4;
                  par = 'alpha';
               elseif c==5;
                  par = 'beta';
               end;
               txt = ['The Gibbs sampler was aborted for the cointegration rank ' num2str(r-1) '. The reason was a badly determined covariance matrix for ' par '. This may be due to your choice of prior. If the problem persists, please consider selecting another prior.'];
               about(txt,'error','Gibbs Sampler Error',120,500);
               abort = 'cancel';
               setlogtext(strvcat(' ','Gibbs sampler error...',' '));
               if strcmp(rankfilenames,'')==0;
                  %
                  % need to clean up a bit
                  %
                  for i=1:size(rankfilenames,1);
                     file = strtrim(rankfilenames(i,:));
                     if fileexist(file)==1;
                        delete_file_fcn(file);
                     end;
                  end;
               end;
            end;
            if strcmp(abort,'cancel')==0;
               %
               % marginalize the posterior via the Gibbs sampler and apply the posterior mode for the parameters
               %
               cm.rankfilenames = rankfilenames;
               warn = 0;
               out = margin_rank(cm,out);
               cm = rmfield(cm,'rankfilenames');
               if strcmp(abort,'cancel')==1;
                  setlogtext(strvcat(' ','Gibbs sampling cancelled...',' '));
                  if strcmp(rankfilenames,'')==0;
                     %
                     % need to clean up a bit
                     %
                     for i=1:size(rankfilenames,1);
                        file = strtrim(rankfilenames(i,:));
                        if fileexist(file)==1;
                           delete_file_fcn(file);
                        end;
                     end;
                  end;
                  %
                  set(bayesdlg,'Visible','on');
                  drawnow;
                  %
                  cm.running = 0;
                  curr_ini.model = cm;
                  set(controls.viewdata,'UserData',curr_ini);
                  return;
               end;
               if warn==0;
                  %
                  % calculate rank probabilities based on the marginal likelihood
                  %
                  rankprob_ml = zeros(cm.n+1,1);
                  marg_like = zeros(cm.n+1,1);
                  for i=0:cm.n;
                     marg_like(i+1,1) = out.rank(i+1).posterior_mode.log_marglike;
                  end;
                  cm.log_marglike = marg_like;
                  %
                  % need to make sure that ranks which have zero prior probability
                  % do not results in all posterior probabilities being 0
                  %
                  if min(cm.rankpriors)==0;
                     for i=1:cm.n+1;
                        if cm.rankpriors(i,1)==0;
                           marg_like(i,1) = min(marg_like);
                        end;
                     end;
                  end;
                  %
                  cm.marg_like = fix_exp(marg_like-mean(marg_like));
                  cm.rankprob_ml = (1/(cm.rankpriors'*cm.marg_like))*(cm.marg_like .* cm.rankpriors);
                  %
                  % Update the display with the new probabilities
                  %
                  my_ranks = (0:1:cm.n);
                  cm.rankprob_str = [cm.rank_str num2str(my_ranks','%2.0f') cm.prependstr num2str(cm.rankprob,'%12.4f') cm.prependstr num2str(cm.rankprob_ml,'%12.4f')];
                  cm.rankprob_str = strvcat(' ',cm.rankprob_str,' ');
                  set(controls.traceresults,'String',cm.rankprob_str);
                  %
                  % we can now begin writing results to the output file
                  %
                  if curr_ini.noprint==0;
                     print_bayes_rank(cm,curr_ini,out);
                  end;
                  %
                  % create a string matrix with the output results
                  %
                  sp_str = spacestr(curr_ini.decimals-2);
                  results_str = strvcat(' ','Posterior Cointegration Rank Probabilities','==========================================',' ',['Rank    P(Rank|Data)' sp_str ' log[P(Data|Rank)] ' sp_str '  P(Rank)' sp_str sp_str ' st.err. log[P(Data|Rank)]']);
                  for i=0:cm.n;
                     if (i>0)&(i<cm.n);
                        res_str = sprintf(['  %2.0f        %0.' num2str(curr_ini.decimals,'%0.0f') 'f        %' num2str(8+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f        %0.' num2str(curr_ini.decimals,'%0.0f') 'f            %' num2str(2+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f '],i,cm.rankprob_ml(i+1,1),cm.log_marglike(i+1,1),cm.rankpriors(i+1,1),out.rank(i+1).posterior_mode.nse_marglike);
                     else;
                        res_str = sprintf(['  %2.0f        %0.' num2str(curr_ini.decimals,'%0.0f') 'f        %' num2str(8+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f        %0.' num2str(curr_ini.decimals,'%0.0f') 'f            None '],i,cm.rankprob_ml(i+1,1),cm.log_marglike(i+1,1),cm.rankpriors(i+1,1));
                     end;
                     results_str = strvcat(results_str,res_str);
                  end;
                  results_str = strvcat(results_str,' ','NOTE: The calculations are based on the Marginal Likelihood (ML), given by','      P(Data|Rank). It has been computed from the basic marginal likelihood','      identity with all parameters evaluated at the posterior mode.',' ');
                  results_str = strvcat(results_str,'      Numerical standard errors of the log marginal likelihood are based on the','      Newey-West correction, taking potential autocorrelation of the beta draws','      into account. Requires that the partial Gibbs sampler has converged.',' ');
                  %
                  % and the individual results
                  %
                  for i=0:cm.n;
                     results_str = strvcat(results_str,'-------------------------------------------------------------------------------',' ');
                     results_str = strvcat(results_str,['    Cointegration rank ' num2str(i,'%0.0f')],'    ====================',' ');
                     results_str = strvcat(results_str,'Summary statistics from the Gibbs sampler','~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',['    Total draws:               ' num2str(out.rank(i+1).gibbs.draws,'%8.0f')],['    Burn-in draws:             ' num2str(cm.burn_in,'%8.0f')],['    Considered draws:          ' num2str(out.rank(i+1).gibbs.real_draws,'%8.0f')],['    Total discarded draws:     ' num2str(out.rank(i+1).gibbs.discard_draws,'%8.0f')],['    Discarded explosive draws: ' num2str(out.rank(i+1).gibbs.discard_explosive_draws,'%8.0f')],['    Draw saving frequency:     ' num2str(100/cm.save_freq,'%5.1f') '%'],['    Saved draws:               ' num2str(cm.save_draws,'%8.0f')],' ');
                     if (i>0)&(i<cm.n);
                        results_str = strvcat(results_str,'Posterior Mean Cointegration Space Estimator','~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                        prt_str = '%2.0f';
                        for j=1:size(out.rank(i+1).pmcs.beta,1);
                           prt_str = [prt_str ' %' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
                        end;
                        for j=1:i;
                           res_str = sprintf(prt_str,j,out.rank(i+1).pmcs.beta(:,j)');
                           results_str = strvcat(results_str,res_str);
                        end;
                        results_str = strvcat(results_str,' ',['with projective Frobenius span variation: ' num2str(sqrt(out.rank(i+1).pmcs.variation),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ');
                        c_bar = cm.rank(i+1).c_mat*inverse(cm.rank(i+1).c_mat'*cm.rank(i+1).c_mat);
                        beta = out.rank(i+1).pmcs.beta*inverse(c_bar'*out.rank(i+1).pmcs.beta);
                        results_str = strvcat(results_str,'Normalized beta based on the Identifying Restrictions:',' ');
                        for j=1:i;
                           res_str = sprintf(prt_str,j,beta(:,j)');
                           results_str = strvcat(results_str,res_str);
                        end;
                        results_str = strvcat(results_str,' ');
                        if isfield(out.rank(i+1).pmcs,'beta_n')==1;
                           results_str = strvcat(results_str,'Partial Posterior Mean Cointegration Space Estimator','~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                           for j=1:i;
                              res_str = sprintf(prt_str,j,out.rank(i+1).pmcs.beta_n(:,j)');
                              results_str = strvcat(results_str,res_str);
                           end;
                           results_str = strvcat(results_str,' ',['with projective Frobenius span variation: ' num2str(sqrt(out.rank(i+1).pmcs.variation_n),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ');
                           c_bar = cm.rank(i+1).c_mat*inverse(cm.rank(i+1).c_mat'*cm.rank(i+1).c_mat);
                           beta = out.rank(i+1).pmcs.beta_n*inverse(c_bar'*out.rank(i+1).pmcs.beta_n);
                           results_str = strvcat(results_str,'Normalized beta based on the Identifying Restrictions:',' ');
                           for j=1:i;
                              res_str = sprintf(prt_str,j,beta(:,j)');
                              results_str = strvcat(results_str,res_str);
                           end;
                           results_str = strvcat(results_str,' ');
                        end;
                        results_str = strvcat(results_str,'Posterior Mode Cointegration Space Estimator','~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                        for j=1:i;
                           res_str = sprintf(prt_str,j,out.rank(i+1).posterior_mode.beta_cs(:,j)');
                           results_str = strvcat(results_str,res_str);
                        end;
                        results_str = strvcat(results_str,' ','Normalized beta based on the Identifying Restrictions:',' ');
                        for j=1:i;
                           res_str = sprintf(prt_str,j,out.rank(i+1).posterior_mode.beta(:,j)');
                           results_str = strvcat(results_str,res_str);
                        end;
                        results_str = strvcat(results_str,' ');
                     end;
                     results_str = strvcat(results_str,'Posterior Mode Properties','~~~~~~~~~~~~~~~~~~~~~~~~~',' ');
                     results_str = strvcat(results_str,['Max absolute eigenvalue of companion matrix: ' num2str(out.rank(i+1).posterior_mode.max_evalue,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])]);
                     results_str = strvcat(results_str,['Value of log prior density:                  ' num2str(out.rank(i+1).posterior_mode.log_prior,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])]);
                     results_str = strvcat(results_str,['Value of log data density:                   ' num2str(out.rank(i+1).posterior_mode.log_like,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])]);
                     results_str = strvcat(results_str,['Value of log posterior density:              ' num2str(out.rank(i+1).posterior_mode.log_post,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ');
                  end;
                  %
                  % save all the results to file
                  %   1. results string
                  %
                  txt = strvcat(' ','Saving output to disk. Using the directory:',' ',curr_ini.simulatedir);
                  setlogtext(strvcat('Saving output to disk...',' '));
                  mywait = waitdlg(txt,'information');
                  waitf = get(mywait,'UserData');
                  %
                  res_file = [curr_ini.simulatedir cm.modelfile '-rank-gibbs-' num2str(cm.scale_endo,'%0.4f') '-' cm.determodel cm.lag_model num2str(cm.burn_in,'%0.0f') '.' num2str(cm.save_draws,'%0.0f') '.' num2str(cm.save_freq,'%0.0f') '.' num2str(cm.discard_explosive,'%0.0f') '-' num2str(cm.prior_inf_shortrun,'%0.0f') '.' num2str(cm.prior_inf_deter,'%0.0f') '-' num2str(cm.lambda_alpha,'%0.3f')];
                  if cm.amat_type==1;
                     res_file = [res_file '-1'];
                  else;
                     res_file = [res_file '-0.' num2str(cm.lambda_a,'%0.2f') '.' num2str(cm.q_parm,'%0.0f')];
                  end;
                  if cm.prior_inf_shortrun==1;
                     res_file = [res_file '.' num2str(cm.lambda_b,'%0.3f') '.' num2str(cm.lambda_theta,'%0.3f') '.' num2str(cm.lambda_l,'%0.3f') '.' num2str(cm.lambda_e,'%0.3f')];
                  end;
                  if cm.prior_inf_deter==1;
                     res_file = [res_file '.' num2str(cm.lambda_d,'%0.3f')];
                  end;
                  res_file = [res_file '.txt'];
                  f_id = fopen(res_file,'wt');
                  for i=1:size(results_str,1);
                     fprintf(f_id,'%s \n',results_str(i,:));
                  end;
                  fprintf(f_id,'*******************************************************************************\n\n');
                  fprintf(f_id,['Output created on: ' datestr(now,0) '\n']);
                  fclose(f_id);
                  %
                  %   2. results for the individual cointegration ranks
                  %
                  for i=0:cm.n;
                     file = [curr_ini.simulatedir cm.modelfile '-rank-' num2str(i) '-' num2str(cm.scale_endo,'%0.4f') '-gibbs-' cm.determodel cm.lag_model num2str(cm.burn_in,'%0.0f') '.' num2str(cm.save_draws,'%0.0f') '.' num2str(cm.save_freq,'%0.0f') '.' num2str(cm.discard_explosive,'%0.0f') '-' num2str(cm.prior_inf_shortrun,'%0.0f') '.' num2str(cm.prior_inf_deter,'%0.0f') '-' num2str(cm.lambda_alpha,'%0.3f')];
                     if cm.amat_type==1;
                        file = [file '-1'];
                     else;
                        file = [file '-0.' num2str(cm.lambda_a,'%0.2f') '.' num2str(cm.q_parm,'%0.0f')];
                     end;
                     if cm.prior_inf_shortrun==1;
                        file = [file '.' num2str(cm.lambda_b,'%0.3f') '.' num2str(cm.lambda_theta,'%0.3f') '.' num2str(cm.lambda_l,'%0.3f') '.' num2str(cm.lambda_e,'%0.3f')];
                     end;
                     if cm.prior_inf_deter==1;
                        file = [file '.' num2str(cm.lambda_d,'%0.3f')];
                     end;
                     file = [file '.mat'];
                     results = out.rank(i+1);
                     save(file,'results','rankfilenames');
                  end;
                  %
                  % close down the wait dialog
                  %
                  set(waitf.text,'UserData','done');
                  delete(mywait);
                  drawnow;
                  %
                  % Enable controls that depend on the existence of gibbs output
                  %
                  set(controls.results_rank,'Enable','on','UserData',res_file);
                  if cm.save_draws>=200;
                     set(controls.marg_like_rank,'Enable','on');
                  end;
                  if cm.q1+cm.q0==0;
                     set(controls.varforecast,'Enable','on');
                  end;
                  set(controls.full_c_omega,'Enable','on');
                  set(controls.full_eigengraph,'Enable','on');
                  set(controls.full_hist_eigengraph,'Enable','on');
                  if cm.d>0;
                     set(controls.full_c_delta,'Enable','on');
                  end;
                  if cm.p>1;
                     set(controls.full_c_gamma,'Enable','on');
                  end;
                  if cm.q0>0;
                     set(controls.full_c_phi,'Enable','on');
                  end;
                  if (cm.r>0)&(cm.r<cm.n+cm.q1+cm.dcoint);
                     set(controls.full_alphagraph,'Enable','on');
                     set(controls.full_betagraph,'Enable','on');
                     set(controls.full_hist_alphagraph,'Enable','on');
                     set(controls.full_hist_betagraph,'Enable','on');
                     set(controls.cointgraphmenu,'Enable','on');
                     set(controls.cointpartgraphmenu,'Enable','on');
                     set(controls.part_alphagraph,'Enable','on');
                     set(controls.part_hist_alphagraph,'Enable','on');
                     set(controls.part_betagraph,'Enable','on');
                     set(controls.part_hist_betagraph,'Enable','on');
                     set(controls.marg_betagraph,'Enable','on');
                     set(controls.marg_hist_betagraph,'Enable','on');
                     set(controls.marg_alphagraph,'Enable','on');
                     set(controls.marg_hist_alphagraph,'Enable','on');
                     set(controls.part_c_psi,'Enable','on');
                     set(controls.full_c_psi,'Enable','on');
                     set(controls.part_c_alpha,'Enable','on');
                     set(controls.full_c_alpha,'Enable','on');
                     set(controls.part_c_omega,'Enable','on');
                  end;
                  %
                  % Display the results
                  %
                  textgui(res_file,'Bayesian Cointegration Analysis - Rank',[(realscrsz(3)-770)/2 (realscrsz(4)-500)/2 770 500],'Results',38);
               else;
                  setlogtext(strvcat(' ','Gibbs sampler error...',' '));
               end;
            end;




         else;
            %
            % dealing with the prior when there is no cointegration estimation
            %
            [cm.prior.deter.mu,cm.prior.deter.sigma,cm.prior.shortrun.mu,cm.prior.shortrun.sigma] = prior_minnesota(cm);
            %
            % we are now ready to starup the Gibbs sampler
            %







         end;
         %
         % Done with drawing from the posterior distribution.
         %



         %
         set(bayesdlg,'Visible','on');
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'change_lagorder'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         cm.p = get(gcbo,'UserData');
         cm.orig_p = size(controls.lag_order,2);
         for i=1:size(controls.lag_order,2);
            if i~=cm.p;
               set(controls.lag_order(i).menuitem,'Checked','off');
            else;
               set(controls.lag_order(i).menuitem,'Checked','on');
            end;
         end;
         %
         % fix the data matrices
         %
         sb = 1+(cm.orig_p-cm.p);
         se = size(cm.x0,1);
         if isempty(cm.x2)==1;
            [cm.Z0,cm.Z1,cm.Z2,cm.Z1t]=vecmdata(cm.x0(sb:se,:),cm.p,cm.x1(sb:se,:));
            if isempty(cm.x1_r)==0;
               [cm.X0,cm.X1] = vardata(cm.x0(sb:se,:),cm.p,[cm.x1(sb:se,:) cm.x1_r(sb:se,:)]);
            else;
               [cm.X0,cm.X1] = vardata(cm.x0(sb:se,:),cm.p,cm.x1(sb:se,:));
            end;
         else;
            [cm.Z0,cm.Z1,cm.Z2,cm.Z1t]=vecmdata(cm.x0(sb:se,:),cm.p,cm.x1(sb:se,:),cm.x2(sb:se,:),cm.q1,cm.pe);
            if isempty(cm.x1_r)==0;
               [cm.X0,cm.X1] = vardata(cm.x0(sb:se,:),cm.p,[cm.x1(sb:se,:) cm.x1_r(sb:se,:)],cm.x2(sb:se,:),cm.q1,cm.pe);
            else;
               [cm.X0,cm.X1] = vardata(cm.x0(sb:se,:),cm.p,cm.x1(sb:se,:),cm.x2(sb:se,:),cm.q1,cm.pe);
            end;
         end;
         %
         % fix related issues
         %
         if cm.p>cm.pe;
            if strcmp(cm.freq,'m')==1;
               samplebeg = cm.oldsamplebeg+((cm.orig_p-cm.p)/12);
            elseif strcmp(cm.freq,'q')==1;
               samplebeg = cm.oldsamplebeg+((cm.orig_p-cm.p)/4);
            else;
               samplebeg = cm.oldsamplebeg+(cm.orig_p-cm.p);
            end;
         else;
            samplebeg = cm.oldsamplebeg;
         end;
         [initfirst,initlast,samplefirst,samplelast] = sampledates(samplebeg,cm.sampleend,max(cm.p,cm.pe),cm.freq);
         lag_str = 'lags';
         if cm.p==1;
            lag_str = 'lag';
         end;
         if cm.q1+cm.q0>0;
            add_lag_str = ['Using ' num2str(cm.pe) ' lag'];
            if cm.pe~=1;
               add_lag_str = [add_lag_str 's'];
            end;
            add_lag_str = [add_lag_str ' for exogenous variables...'];
         else;
            add_lag_str = '';
         end;
         setlogtext(strvcat(' ','*********************************************************',' ','Changed lag order for the model...',' ',['Estimation sample: ' samplefirst ' - ' samplelast '...'],['Initial sample:    ' initfirst ' - ' initlast '...'],['Using ' num2str(cm.p,'%0.0f') ' ' lag_str ' for endogenous variables...'],add_lag_str));
         if cm.cointvalue==1;
            setlogtext('Computing fractional marginal likelihoods...');
         end;
         [cm.S_00,cm.S_01,cm.S_10,cm.S_11,cm.M_02,cm.M_22,cm.M_12,cm.beta,cm.lambda,cm.trace] = mlcointbasic(cm.Z0,cm.Z1,cm.Z2,cm.n);
         %
         % compute the fractional marginal likelihoods as discussed by Corrander and Villani (2004)
         %
         for i=0:cm.n;
            if i>0;
               cm.rank(i+1).beta = cm.beta(:,1:i);
               cm.rank(i+1).alpha = (cm.S_01*cm.rank(i+1).beta)/(cm.rank(i+1).beta'*cm.S_11*cm.rank(i+1).beta);
               if isempty(cm.Z2)==0;
                  cm.rank(i+1).Psi = (cm.M_02/cm.M_22)-(cm.rank(i+1).alpha*cm.rank(i+1).beta'*(cm.M_12/cm.M_22));
                  cm.rank(i+1).epsilon = cm.Z0-(cm.rank(i+1).alpha*cm.rank(i+1).beta'*cm.Z1)-(cm.rank(i+1).Psi*cm.Z2);
               else;
                  cm.rank(i+1).Psi = [];
                  cm.rank(i+1).epsilon = cm.Z0-(cm.rank(i+1).alpha*cm.rank(i+1).beta'*cm.Z1);
               end;
               c_r = size(cm.Z2,1)+i+round((size(cm.Z1,1)-i)*(i/cm.n));
            else;
               cm.rank(1).beta = [];
               cm.rank(1).alpha = [];
               if isempty(cm.Z2)==0;
                  cm.rank(1).Psi = cm.M_02/cm.M_22;
                  cm.rank(1).epsilon = cm.Z0-(cm.rank(i+1).Psi*cm.Z2);
               else;
                  cm.rank(1).Psi = [];
                  cm.rank(1).epsilon = cm.Z0;
               end;
               c_r = size(cm.Z2,1);
            end;
            m = cm.n+size(cm.Z1,1)+size(cm.Z2,1);
            cm.rank(i+1).Omega = (1/cm.T)*cm.rank(i+1).epsilon*cm.rank(i+1).epsilon';
            cm.rank(i+1).part_canon_corr = det(cm.rank(i+1).Omega)/det(cm.S_00);
            %
            % compute the product of the gamma function ratios in logs
            %
            cm.rank(i+1).log_gamma = gamma_product(cm.n,cm.T-c_r,m-c_r);
            cm.rank(i+1).log_fraction_marglike = -((cm.T-m)/2)*log(cm.rank(i+1).part_canon_corr)+cm.rank(i+1).log_gamma;
            cm.log_fracs(i+1,1) = cm.rank(i+1).log_fraction_marglike;
         end;
         %
         % we shall now normalize the log fractional marginal likelihoods by subtracting a common constant.
         % This constant is given by the lowest log fractional marginal likelihood. This constant is used to
         % handle units for the exponential function
         %
         sum_fml = 0;
         frac_marg_like = zeros(cm.n+1,1);
         for i=0:cm.n;
            frac_marg_like(i+1,1) = cm.rank(i+1).log_fraction_marglike;
            cm.rank(i+1).norm_fraction_marglike = fix_exp(cm.rank(i+1).log_fraction_marglike - mean(cm.log_fracs));
            sum_fml = sum_fml + cm.rank(i+1).norm_fraction_marglike;
         end;
         cm.rankprob = zeros(cm.n+1,1);
         for i=0:cm.n;
            cm.rankprob(i+1,1) = cm.rank(i+1).norm_fraction_marglike/sum_fml;
         end;
         %
         % Prepare scaling factors for endogenous and exogenous I(1) and I(0) variables
         % The scaling factors are in terms of variances
         %
         cm.scale_n = diag(cm.rank(cm.n+1).Omega);
         cm.scale_q1 = [];
         cm.scale_q0 = [];
         if cm.q1+cm.q0>0;
            y = cm.x2(cm.p+1:size(cm.x2,1),:)';
            if isempty(cm.old_x1_r)==1;
               x = [cm.x1(cm.p+1:size(cm.x2,1),:)]';
            else;
               x = [cm.x1(cm.p+1:size(cm.x2,1),:) cm.old_x1_r(cm.p+1:size(cm.x2,1),:)]';
            end;
            for i=1:cm.p;
               x = [x;cm.x2(cm.p+1-i:size(cm.x2,1)-i,:)'];
            end;
            b = y*x'*inverse(x*x');
            res = y-(b*x);
            sigma = (1/size(y,2))*res*res';
            s_f = diag(sigma);
            if cm.q1>0;
               cm.scale_q1 = s_f(1:cm.q1,1);
            end;
            if cm.q0>0;
               cm.scale_q0 = s_f(1+cm.q1:cm.q0+cm.q1,1);
            end;
         end;
         %
         % Write stuff to the output file
         %
         if curr_ini.noprint==0;
            fout = fopen(cm.outputfile,'at');
            if curr_ini.texoutputformat>=2;
               fprintf(fout,'\\ruler\n\n%%******************************************************************************\n\n');
               fprintf(fout,'\\begin{tabular}{ll}\n');
               fprintf(fout,['Endogenous variables: & %s \\\\\n'],txt2ltxmath(strtrim(cm.evars)));
               fprintf(fout,['Estimation Sample: & ' samplefirst ' -- ' samplelast ' \\\\\n']);
               fprintf(fout,['Initial Sample: & ' initfirst ' -- ' initlast ' \\\\\n']);
               fprintf(fout,['Number of lags: & ' num2str(cm.p) ' for endogenous variables \\\\\n']);
               if cm.q1+cm.q0>0;
                  fprintf(fout,['                & ' num2str(cm.pe) ' for exogenous variables \\\\\n']);
               end;
               fprintf(fout,['Number of observations: & ' num2str(size(cm.x0,1)-max(cm.p,cm.pe)) ' \\\\\n']);
               if cm.cointvalue==1;
                  fprintf(fout,['Deterministic variables: & %s \\\\\n'],txt2ltxmath(strtrim(cm.deter)));
                  if strcmp(cm.restvec,'')==0;
                     fprintf(fout,[' & %s in cointegration space \\\\\n'],txt2ltxmath(strtrim(cm.restvec)));
                  end;
               else;
                  fprintf(fout,['Deterministic variables: & %s \\\\\n'],txt2ltxmath(strtrim([cm.deter ' ' cm.restvec])));
               end;
               if strcmp(cm.deterdel,'')==0;
                  fprintf(fout,'Deleted variables: & %s \\\\\n',txt2ltxmath(strtrim(cm.deterdel)));
               end;
               if cm.q0+cm.q1>0;
                  if cm.q1>0;
                     fprintf(fout,['Exogenous I(1) variables: & %s \\\\\n'],txt2ltxmath(strtrim(cm.xvars1)));
                  end;
                  if size(cm.x2,2)-cm.q1>0;
                     fprintf(fout,['Exogenous I(0) variables: & %s \\\\\n'],txt2ltxmath(strtrim(cm.xvars0)));
                  end;
               end;
               fprintf(fout,'\\end{tabular}\n\n\\ruler\n\n');
               fprintf(fout,'\\subsection*{Bayesian Analysis}\n\n');
            else;
               fprintf(fout,'*******************************************************************************\n\n');
               fprintf(fout,['Endogenous variables:     ' cm.evars '\n']);
               fprintf(fout,['Estimation Sample:        ' samplefirst ' - ' samplelast '\n']);
               fprintf(fout,['Initial Sample:           ' initfirst ' - ' initlast '\n']);
               fprintf(fout,['Number of lags:           ' num2str(cm.p) ' for endogenous variables\n']);
               if cm.q1+cm.q0>0;
                  fprintf(fout,['                          ' num2str(cm.pe) ' for exogenous variables\n']);
               end;
               fprintf(fout,['Number of observations:   ' num2str(size(cm.x0,1)-max(cm.p,cm.pe)) '\n']);
               if cm.cointvalue==1;
                  fprintf(fout,['Deterministic variables:  ' cm.deter '\n']);
                  if strcmp(cm.restvec,'')==0;
                     fprintf(fout,['   ' cm.restvec ' in cointegration space\n']);
                  end;
               else;
                  fprintf(fout,['Deterministic variables:  ' strtrim([cm.deter ' ' cm.restvec]) '\n']);
               end;
               if strcmp(cm.deterdel,'')==0;
                  fprintf(fout,'Deleted variables:        %s\n',cm.deterdel);
               end;
               if cm.q0+cm.q1>0;
                  if cm.q1>0;
                     fprintf(fout,['Exogenous I(1) variables: ' cm.xvars1 '\n']);
                  end;
                  if size(cm.x2,2)-cm.q1>0;
                     fprintf(fout,['Exogenous I(0) variables: ' cm.xvars0 '\n']);
                  end;
               end;
               fprintf(fout,'\n*******************************************************************************\n\n');
               fprintf(fout,'BAYESIAN ANALYSIS\n=================\n\n');
            end;
            %
            % write rank probabilities output to file
            %
            if cm.cointvalue==1;
               if curr_ini.texoutputformat>=2;
                  prt_str = ['%2.0f & %0.' num2str(curr_ini.decimals,'%0.0f') 'f & %0.' num2str(curr_ini.decimals,'%0.0f') 'f & %0.' num2str(curr_ini.decimals,'%0.0f') 'f \\\\ \n'];
                  fprintf(fout,'\\header{Posterior Cointegration Rank Probabilities} \n\n');
                  fprintf(fout,'\\begin{tabular}{rrrr}\n');
      %            fprintf(fout,'\\multicolumn{4}{c}{Posterior Cointegration Rank Probabilities} \\\\\n');
                  fprintf(fout,'Rank & $P(\\mbox{\\rm Rank}|\\mbox{\\rm Data})$ & $\\log [P(\\mbox{\\rm Data}|\\mbox{\\rm Rank})]$ & $P(\\mbox{\\rm Rank})$ \\\\\n');
                  fprintf(fout,prt_str,[(0:1:cm.n)' cm.rankprob frac_marg_like (1/(cm.n+1))*ones(cm.n+1,1)]');
                  fprintf(fout,'\\end{tabular}\n\n');
                  fprintf(fout,['\\vspace*{2mm}\\noindent\n\\textbf{NOTE:} The calculations are based on the Fractional Marginal Likelihood (FML)\nfor a diffuse prior on the parameters conditional on the rank and equal\nprior probabilities for each rank. The fraction used is minimal, ' num2str(m/cm.T,'%0.2f') ',\nand is the relative part of the sample used to ``train'''' the improper\n(diffuse) prior into a proper distribution.\n\n']);
               else;
                  sp_str = spacestr(curr_ini.decimals-2);
                  prt_str = ['  %2.0f        %0.' num2str(curr_ini.decimals,'%0.0f') 'f        %' num2str(8+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f        %0.' num2str(curr_ini.decimals,'%0.0f') 'f \n'];
                  fprintf(fout,['Posterior Cointegration Rank Probabilities\n\n Rank    P(Rank|Data)' sp_str ' log[P(Data|Rank)] ' sp_str '  P(Rank) \n']);
                  fprintf(fout,prt_str,[(0:1:cm.n)' cm.rankprob frac_marg_like (1/(cm.n+1))*ones(cm.n+1,1)]');
                  fprintf(fout,['\nNOTE: The calculations are based on the Fractional Marginal Likelihood (FML)\n      for a diffuse prior on the parameters conditional on the rank and equal\n      prior probabilities for each rank. The fraction used is minimal, ' num2str(m/cm.T,'%0.2f') ',\n      and is the relative part of the sample used to "train" the improper\n      (diffuse) prior into a proper distribution.\n\n']);
               end;
            end;
            fclose(fout);
         end;
         %
         % fix controls
         %
         cm.lag_model = [num2str(cm.p,'%0.0f') '.' num2str(cm.pe,'%0.0f') '-' num2str(cm.T,'%0.0f') '-'];
         %
         % setup certain strings matrices
         %
         prependstr = '     ';
         rank_str = ' ';
         ml_str = 'NA';
         for i=1:cm.n;
            prependstr = [prependstr;'     '];
            rank_str = [rank_str;' '];
            ml_str = [ml_str;'NA'];
         end;
         %
         % check if old output exists
         %
         res_file = '';
         if cm.cointvalue==1;
            marg_like = zeros(cm.n+1,1);
            for i=0:cm.n;
               file = [curr_ini.simulatedir cm.modelfile '-rank-' num2str(i) '-' num2str(cm.scale_endo,'%0.4f') '-gibbs-' cm.determodel cm.lag_model num2str(cm.burn_in,'%0.0f') '.' num2str(cm.save_draws,'%0.0f') '.' num2str(cm.save_freq,'%0.0f') '.' num2str(cm.discard_explosive,'%0.0f') '-' num2str(cm.prior_inf_shortrun,'%0.0f') '.' num2str(cm.prior_inf_deter,'%0.0f') '-' num2str(cm.lambda_alpha,'%0.3f')];
               if cm.amat_type==1;
                  file = [file '-1'];
               else;
                  file = [file '-0.' num2str(cm.lambda_a,'%0.2f') '.' num2str(cm.q_parm,'%0.0f')];
               end;
               if cm.prior_inf_shortrun==1;
                  file = [file '.' num2str(cm.lambda_b,'%0.3f') '.' num2str(cm.lambda_theta,'%0.3f') '.' num2str(cm.lambda_l,'%0.3f') '.' num2str(cm.lambda_e,'%0.3f')];
               end;
               if cm.prior_inf_deter==1;
                  file = [file '.' num2str(cm.lambda_d,'%0.3f')];
               end;
               file = [file '.mat'];
               if fileexist(file)==1;
                  f = load(file);
                  marg_like(i+1,1) = f.results.posterior_mode.log_marglike;
                  clear('f');
               else;
                  marg_like = [];
                  break;
               end;
            end;
            if isempty(marg_like)==0;
               cm.log_marglike = marg_like;
               marg_like = fix_exp(marg_like-mean(marg_like));
               cm.rankprob_ml = (1/(cm.rankpriors'*marg_like))*(marg_like .* cm.rankpriors);
               ml_str = num2str(cm.rankprob_ml,'%12.4f');
               %
               % enable certain controls
               %
            end;
            %
            % Setup the name of the results file
            %
            res_file = [curr_ini.simulatedir cm.modelfile '-rank-gibbs-' num2str(cm.scale_endo,'%0.4f') '-' cm.determodel cm.lag_model num2str(cm.burn_in,'%0.0f') '.' num2str(cm.save_draws,'%0.0f') '.' num2str(cm.save_freq,'%0.0f') '.' num2str(cm.discard_explosive,'%0.0f') '-' num2str(cm.prior_inf_shortrun,'%0.0f') '.' num2str(cm.prior_inf_deter,'%0.0f') '-' num2str(cm.lambda_alpha,'%0.3f')];
            if cm.amat_type==1;
               res_file = [res_file '-1'];
            else;
               res_file = [res_file '-0.' num2str(cm.lambda_a,'%0.2f') '.' num2str(cm.q_parm,'%0.0f')];
            end;
            if cm.prior_inf_shortrun==1;
               res_file = [res_file '.' num2str(cm.lambda_b,'%0.3f') '.' num2str(cm.lambda_theta,'%0.3f') '.' num2str(cm.lambda_l,'%0.3f') '.' num2str(cm.lambda_e,'%0.3f')];
            end;
            if cm.prior_inf_deter==1;
               res_file = [res_file '.' num2str(cm.lambda_d,'%0.3f')];
            end;
            res_file = [res_file '.txt'];
         else;
            %
            % check if results already exist for no cointegration sampling
            %
         end;
         %
         % posterior rank probabilities based on FML
         %
         my_ranks = (0:1:cm.n);
         cm.my_ranks = my_ranks';
         cm.rankprob_str = [rank_str num2str(my_ranks','%2.0f') prependstr num2str(cm.rankprob,'%12.4f') prependstr ml_str];
         cm.rankprob_str = strvcat(' ',cm.rankprob_str,' ');
         cm.prependstr = prependstr;
         cm.rank_str = rank_str;
         cm.ml_str = ml_str;
         %
         ranks = '0';
         i = 1;
         while i<=cm.n;
            ranks = [ranks '|' num2str(i)];
            i = i+1;
         end;
         textvars = ['Endogenous variables:        ' cm.evars];
         %
         % trim text if necessary
         %
         if strcmp(cm.restvec,'')==1;
            if size(cm.deter,2)>=60;
               thisdeter = cm.deter(1,1:60);
               for i=0:58;
                  if strcmp(thisdeter(1,60-i),' ')==1;
                     thisdeter = thisdeter(1,1:(59-i));
                     break;
                  end;
               end;
               thisdeter = [thisdeter '...'];
            else;
               thisdeter = cm.deter;
            end;
            textvars = strvcat(textvars,['Deterministic variables:     ' thisdeter]);
         else;
            thisdeter = strtrim([strtrim(cm.deter) ' ' cm.restvec]);
            if size(thisdeter,2)>=60;
               thisdeter = thisdeter(1,1:60);
               for i=0:58;
                  if strcmp(thisdeter(1,60-i),' ')==1;
                     thisdeter = thisdeter(1,1:(59-i));
                     break;
                  end;
               end;
               thisdeter = [thisdeter '...'];
            end;
            textvars = strvcat(textvars,['Deterministic variables:     ' thisdeter]);
         end;
         if cm.q1>0;
            thisxvars1 = cm.xvars1;
            if size(thisxvars1,2)>=60;
               thisxvars1 = thisxvars1(1,1:60);
               for i=0:58;
                  if strcmp(thisxvars1(1,60-i),' ')==1;
                     thisxvars1 = thisxvars1(1,1:(59-i));
                     break;
                  end;
               end;
               thisxvars1 = [thisxvars1 '...'];
            end;
            textvars = strvcat(textvars,['Exogenous I(1) variables:    ' thisxvars1]);
         else;
            textvars = strvcat(textvars,'Exogenous I(1) variables:    None');
         end;
         if cm.q0>0;
            thisxvars0 = cm.xvars0;
            if size(thisxvars0,2)>=60;
               thisxvars0 = thisxvars0(1,1:60);
               for i=0:58;
                  if strcmp(thisxvars0(1,60-i),' ')==1;
                     thisxvars0 = thisxvars0(1,1:(59-i));
                     break;
                  end;
               end;
               thisxvars0 = [thisxvars0 '...'];
            end;
            textvars = strvcat(textvars,['Exogenous I(0) variables:    ' thisxvars0]);
         else;
            textvars = strvcat(textvars,'Exogenous I(0) variables:    None');
         end;
         add_lag = '';
         if (cm.q0+cm.q1>0)&(cm.p~=cm.pe);
            add_lag = [' for endogenous and ' num2str(cm.pe) ' for exogenous variables'];
         end;
         textvars = strvcat(textvars,['Number of lags:              ' num2str(cm.p) add_lag]);
         textvars = strvcat(textvars,['Number of observations:      ' num2str(cm.T)]);
         cm.textvars = textvars;
         %
         %
         %
         set(controls.traceresults,'String',cm.rankprob_str);
         if (cm.cointvalue==1)&(fileexist(res_file)==1);
            set(controls.results_rank,'Enable','on','UserData',res_file);
            if cm.save_draws>=200;
               set(controls.marg_like_rank,'Enable','on');
            else;
               set(controls.marg_like_rank,'Enable','off');
            end;
         else;
            set(controls.results_rank,'Enable','off','UserData','');
            set(controls.marg_like_rank,'Enable','off');
         end;
         if (cm.cointvalue==1)&(fileexist(res_file)==1);
            set(controls.full_eigengraph,'Enable','on');
            set(controls.full_hist_eigengraph,'Enable','on');
         else;
            set(controls.full_eigengraph,'Enable','off');
            set(controls.full_hist_eigengraph,'Enable','off');
         end;
         if fileexist(res_file)==1;
            set(controls.full_c_omega,'Enable','on');
            if cm.d>0;
               set(controls.full_c_delta,'Enable','on');
            end;
            if cm.p>1;
               set(controls.full_c_gamma,'Enable','on');
            else;
               set(controls.full_c_gamma,'Enable','off');
            end;
            if cm.q0>0;
               set(controls.full_c_phi,'Enable','on');
            end;
         else;
            set(controls.full_c_omega,'Enable','off');
            set(controls.full_c_delta,'Enable','off');
            set(controls.full_c_gamma,'Enable','off');
            set(controls.full_c_phi,'Enable','off');
         end;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         % Make sure all controls are set correctly
         %
         bayesgui('check_model');
      end;
   case 'lagorder'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         if cm.amat_lag>1;
            [cm.amat_val,cm.use_lag] = ml_omega(cm);
         end;
         %
         [ml_k,prob_k] = bayes_lagorder(cm,curr_ini);
         %
         sp_str = spacestr(curr_ini.decimals-2);
         lag_str = strvcat(' ','Posterior Lag Order Probabilities','=================================',' ',['  Lag    P(Lag|Data) ' sp_str '  log[P(Data|Lag)] ' sp_str '  P(Lag)']);
         for i=1:size(ml_k,1);
            l_str = sprintf(['  %2.0f        %0.' num2str(curr_ini.decimals,'%0.0f') 'f        %' num2str(8+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f        %0.' num2str(curr_ini.decimals,'%0.0f') 'f '],i,prob_k(i,1),ml_k(i,1),1/size(ml_k,1));
            lag_str = strvcat(lag_str,l_str);
         end;
         lag_str = strvcat(lag_str,' ',['NOTE: Computations are based on a cointegration rank of ' num2str(cm.n) '.'],' ');
         %
         textgui(lag_str,'Lag Order Determination',[(realscrsz(3)-680)/2 (realscrsz(4)-400)/2 680 400],'Results',38);
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','on');
         drawnow;
      end;
   case 'fix_hyptext'
      %
      % Only executed from other functions
      %
      if cm.prior_inf_shortrun==1;
         hyp_txt = ['\lambda_{b}=' num2str(curr_ini.lambda_b,'%0.2f') ', \lambda_{\rho}=' num2str(curr_ini.lambda_theta,'%0.3f') ', \lambda_{l}=' num2str(curr_ini.lambda_l,'%0.1f')];
         if cm.q0+cm.q1>0;
            hyp_txt = [hyp_txt ', \lambda_{e}=' num2str(curr_ini.lambda_e,'%0.3f')];
         end;
      else;
         hyp_txt = 'P(\Gamma | \Omega)_{ } = ';
         if cm.q1>0;
            hyp_txt = [hyp_txt 'P(\Psi | \Omega) = '];
         end;
         if cm.q0>0;
            hyp_txt = [hyp_txt 'P(\Phi | \Omega) = '];
         end;
         hyp_txt = [hyp_txt '1'];
      end;
      if cm.prior_inf_deter==1;
         n_hyp_txt = ['\lambda_{d}=' num2str(curr_ini.lambda_d,'%0.2f')];
      else;
         n_hyp_txt = 'P(\delta | \Omega)_{ } = 1';
      end;
      if cm.cointvalue==1;
         n_hyp_txt = [n_hyp_txt  ', \lambda_{\alpha}=' num2str(curr_ini.lambda_alpha,'%0.2f')];
         old_txt = get(controls.hyptext,'String');
         r_hyp_txt = old_txt(3,:);
      else;
         r_hyp_txt = '';
      end;
      if (cm.prior_inf_omega==1)&(cm.amat_type==0);
         n_hyp_txt = [n_hyp_txt ', \lambda_{A}=' num2str(cm.lambda_a,'%0.2f') ', q=' num2str(cm.q_parm,'%0.0f')];
      end;
      hyp_txt = strvcat(hyp_txt,n_hyp_txt,r_hyp_txt);
      set(controls.hyptext,'String',hyp_txt);
   case 'bad_draws'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         check_draws = get(controls.bad_draws,'Check');
         if strcmp(check_draws,'off')==1;
            cm.bad_draws = 1;
            set(controls.bad_draws,'Check','on');
         else;
            cm.bad_draws = 0;
            set(controls.bad_draws,'Check','off');
         end;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','on');
         drawnow;
      end;
   case 'prior_inf_deter'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         check_deter = get(controls.type_deter,'Check');
         if strcmp(check_deter,'off')==1;
            set(controls.type_deter,'Check','on');
            set(controls.deterpriors,'Enable','on');
            cm.prior_inf_deter = 1;
         else;
            set(controls.type_deter,'Check','off');
            set(controls.deterpriors,'Enable','off');
            cm.prior_inf_deter = 2;
         end;
         set(controls.default_prior,'Enable','on');
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         % Make sure all controls are set correctly
         %
         bayesgui('fix_hyptext');
         bayesgui('check_model');
         %
         set(bayesdlg,'Visible','on');
         drawnow;
      end;
   case 'prior_inf_omega'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         check_omega = get(controls.type_omega,'Check');
         if strcmp(check_omega,'off')==1;
            set(controls.type_omega,'Check','on');
            cm.prior_inf_omega = 1;
            set(controls.omegapriors,'Enable','on');
         else;
            set(controls.type_omega,'Check','off');
            cm.prior_inf_omega = 2;
            set(controls.omegapriors,'Enable','off');
         end;
         set(controls.default_prior,'Enable','on');
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         % Make sure all controls are set correctly
         %
         bayesgui('fix_hyptext');
         bayesgui('check_model');
         %
         set(bayesdlg,'Visible','on');
         drawnow;
      end;
   case 'prior_inf_shortrun'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         check_shortrun = get(controls.type_shortrun,'Check');
         if strcmp(check_shortrun,'off')==1;
            set(controls.type_shortrun,'Check','on');
            set(controls.shortrunpriors,'Enable','on');
            cm.prior_inf_shortrun = 1;
         else;
            set(controls.type_shortrun,'Check','off');
            set(controls.shortrunpriors,'Enable','off');
            cm.prior_inf_shortrun = 2;
         end;
         set(controls.default_prior,'Enable','on');
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         % Make sure all controls are set correctly
         %
         bayesgui('fix_hyptext');
         bayesgui('check_model');
         %
         set(bayesdlg,'Visible','on');
         drawnow;
      end;
   case 'prior_inf_alpha'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         check_alpha = get(controls.type_alpha,'Check');
         if strcmp(check_alpha,'off')==1;
            set(controls.type_alpha,'Check','on');
            set(controls.alphapriors,'Enable','on');
            cm.prior_inf_alpha = 1;
         else;
            set(controls.type_alpha,'Check','off');
            set(controls.alphapriors,'Enable','off');
            cm.prior_inf_alpha = 2;
         end;
         set(controls.default_prior,'Enable','on');
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         % Make sure all controls are set correctly
         %
         bayesgui('check_model');
         %
         set(bayesdlg,'Visible','on');
         drawnow;
      end;
   case 'alpha_priors'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         my_ini.loadguiicon = curr_ini.loadguiicon;
         my_ini.pstoolsdir = curr_ini.pstoolsdir;
         %
         my_ini.lambda_alpha = cm.lambda_alpha;
         my_ini.gui_fontsize = curr_ini.gui_fontsize;
         my_ini.gui_fontname = curr_ini.gui_fontname;
         my_ini.gui_fontweight = curr_ini.gui_fontweight;
         my_ini.gui_fontangle = curr_ini.gui_fontangle;
         %
         % show GUI
         %
         hyp_gui = alphaprior_dlg('init',my_ini);
         lambda_controls = get(hyp_gui,'UserData');
         tm = get(lambda_controls.apply,'UserData');
         new_my_ini = tm.ini;
         new_value = 0;
         if abs(new_my_ini.lambda_alpha-cm.lambda_alpha)>0;
            cm.lambda_alpha = new_my_ini.lambda_alpha;
            new_value = 1;
         end;
         killguipid(hyp_gui);
         %
         % fix hyperparameter text if changes have been recorded
         %
         if new_value==1;
            if cm.prior_inf_deter==1;
               n_hyp_txt = ['\lambda_{d}=' num2str(cm.lambda_d,'%0.2f') ', \lambda_{\alpha}=' num2str(cm.lambda_alpha,'%0.2f')];
            else;
               n_hyp_txt = ['P(\delta | \Omega)_{ } = 1, \lambda_{\alpha}=' num2str(cm.lambda_alpha,'%0.2f')];
            end;
            if (cm.prior_inf_omega==1)&(cm.amat_type==0);
               n_hyp_txt = [n_hyp_txt ', \lambda_{A}=' num2str(cm.lambda_a,'%0.2f') ', q=' num2str(cm.q_parm,'%0.0f')];
            end;
            old_txt = get(controls.hyptext,'String');
            hyp_txt = old_txt(1,:);
            r_hyp_txt = old_txt(3,:);
            hyp_txt = strvcat(hyp_txt,n_hyp_txt,r_hyp_txt);
            set(controls.hyptext,'String',hyp_txt);
            set(controls.default_prior,'Enable','on');
         end;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         % Make sure all controls are set correctly
         %
         bayesgui('check_model');
         %
         set(bayesdlg,'Visible','on');
         drawnow;
      end;
   case 'omega_priors'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         my_ini.loadguiicon = curr_ini.loadguiicon;
         my_ini.pstoolsdir = curr_ini.pstoolsdir;
         %
         my_ini.lambda_a = cm.lambda_a;
         my_ini.amat_type = cm.amat_type;
         my_ini.q_df = cm.q_df;
         my_ini.amat_lag = cm.amat_lag;
         my_ini.maxlag = curr_ini.maxlag;
         my_ini.gui_fontsize = curr_ini.gui_fontsize;
         my_ini.gui_fontname = curr_ini.gui_fontname;
         my_ini.gui_fontweight = curr_ini.gui_fontweight;
         my_ini.gui_fontangle = curr_ini.gui_fontangle;
         %
         % show GUI
         %
         hyp_gui = omegaprior_dlg('init',my_ini);
         lambda_controls = get(hyp_gui,'UserData');
         tm = get(lambda_controls.apply,'UserData');
         new_my_ini = tm.ini;
         new_value = 0;
         if abs(new_my_ini.amat_type-cm.amat_type)>0;
            cm.amat_type = new_my_ini.amat_type;
            new_value = 1;
         end;
         if cm.amat_type==0;
            if abs(new_my_ini.lambda_a-cm.lambda_a)>0;
               cm.lambda_a = new_my_ini.lambda_a;
               new_value = 1;
            end;
            if abs(new_my_ini.q_df-cm.q_df)>0;
               cm.q_df = new_my_ini.q_df;
               new_value = 1;
            end;
         end;
         if abs(new_my_ini.amat_lag-cm.amat_lag)>0;
            cm.amat_lag = new_my_ini.amat_lag;
            new_value = 1;
         end;
         killguipid(hyp_gui);
         if new_value==1;
            set(controls.default_prior,'Enable','on');
         end;
         if cm.q_df==1;
            cm.q_parm = cm.n+2;
         else;
            q_new = round(((cm.q_df-1)/10)*cm.T);
            cm.q_parm = max(cm.n+2,q_new);
         end;
         %
         % fix hyperparameter text if changes have been recorded
         %
         if new_value==1;
            if cm.prior_inf_deter==1;
               n_hyp_txt = ['\lambda_{d}=' num2str(cm.lambda_d,'%0.2f')];
            else;
               n_hyp_txt = 'P(\delta | \Omega)_{ } = 1';
            end;
            old_txt = get(controls.hyptext,'String');
            hyp_txt = old_txt(1,:);
            if cm.cointvalue==1;
               n_hyp_txt = [n_hyp_txt  ', \lambda_{\alpha}=' num2str(cm.lambda_alpha,'%0.2f')];
               r_hyp_txt = old_txt(3,:);
            else;
               r_hyp_txt = '';
            end;
            if (cm.prior_inf_omega==1)&(cm.amat_type==0);
               n_hyp_txt = [n_hyp_txt ', \lambda_{A}=' num2str(cm.lambda_a,'%0.2f') ', q=' num2str(cm.q_parm,'%0.0f')];
            end;
            hyp_txt = strvcat(hyp_txt,n_hyp_txt,r_hyp_txt);
            set(controls.hyptext,'String',hyp_txt);
            set(controls.default_prior,'Enable','on');
         end;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         % Make sure all controls are set correctly
         %
         bayesgui('check_model');
         %
         set(bayesdlg,'Visible','on');
         drawnow;
      end;
   case 'deter_priors'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         my_ini.loadguiicon = curr_ini.loadguiicon;
         my_ini.pstoolsdir = curr_ini.pstoolsdir;
         %
         my_ini.lambda_d = cm.lambda_d;
         my_ini.gui_fontsize = curr_ini.gui_fontsize;
         my_ini.gui_fontname = curr_ini.gui_fontname;
         my_ini.gui_fontweight = curr_ini.gui_fontweight;
         my_ini.gui_fontangle = curr_ini.gui_fontangle;
         %
         % show GUI
         %
         hyp_gui = deterprior_dlg('init',my_ini);
         lambda_controls = get(hyp_gui,'UserData');
         tm = get(lambda_controls.apply,'UserData');
         new_my_ini = tm.ini;
         new_value = 0;
         if abs(new_my_ini.lambda_d-cm.lambda_d)>0;
            cm.lambda_d = new_my_ini.lambda_d;
            new_value = 1;
         end;
         killguipid(hyp_gui);
         %
         % fix hyperparameter text if changes have been recorded
         %
         if new_value==1;
            n_hyp_txt = ['\lambda_{d}=' num2str(cm.lambda_d,'%0.2f')];
            old_txt = get(controls.hyptext,'String');
            hyp_txt = old_txt(1,:);
            if cm.cointvalue==1;
               n_hyp_txt = [n_hyp_txt  ', \lambda_{\alpha}=' num2str(cm.lambda_alpha,'%0.2f')];
               r_hyp_txt = old_txt(3,:);
            else;
               r_hyp_txt = '';
            end;
            if (cm.prior_inf_omega==1)&(cm.amat_type==0);
               n_hyp_txt = [n_hyp_txt ', \lambda_{A}=' num2str(cm.lambda_a,'%0.2f') ', q=' num2str(cm.q_parm,'%0.0f')];
            end;
            hyp_txt = strvcat(hyp_txt,n_hyp_txt,r_hyp_txt);
            set(controls.hyptext,'String',hyp_txt);
            set(controls.default_prior,'Enable','on');
         end;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         % Make sure all controls are set correctly
         %
         bayesgui('check_model');
         %
         set(bayesdlg,'Visible','on');
         drawnow;
      end;
   case 'shortrun_priors'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         my_ini.loadguiicon = curr_ini.loadguiicon;
         my_ini.pstoolsdir = curr_ini.pstoolsdir;
         %
         my_ini.lambda_b = cm.lambda_b;
         my_ini.lambda_l = cm.lambda_l;
         my_ini.lambda_theta = cm.lambda_theta;
         my_ini.lambda_e = cm.lambda_e;
         my_ini.gui_fontsize = curr_ini.gui_fontsize;
         my_ini.gui_fontname = curr_ini.gui_fontname;
         my_ini.gui_fontweight = curr_ini.gui_fontweight;
         my_ini.gui_fontangle = curr_ini.gui_fontangle;
         %
         % show GUI
         %
         hyp_gui = lambda_dlg('init',my_ini);
         lambda_controls = get(hyp_gui,'UserData');
         tm = get(lambda_controls.apply,'UserData');
         new_my_ini = tm.ini;
         new_value = 0;
         if abs(new_my_ini.lambda_b-cm.lambda_b)>0;
            cm.lambda_b = new_my_ini.lambda_b;
            new_value = 1;
         end;
         if abs(new_my_ini.lambda_l-cm.lambda_l)>0;
            cm.lambda_l = new_my_ini.lambda_l;
            new_value = 1;
         end;
         if abs(new_my_ini.lambda_theta-cm.lambda_theta)>0;
            cm.lambda_theta = new_my_ini.lambda_theta;
            new_value = 1;
         end;
         if abs(new_my_ini.lambda_e-cm.lambda_e)>0;
            cm.lambda_e = new_my_ini.lambda_e;
            new_value = 1;
         end;
         killguipid(hyp_gui);
         %
         % fix hyperparameter text if changes have been recorded
         %
         if new_value==1;
            hyp_txt = ['\lambda_{b}=' num2str(cm.lambda_b,'%0.2f') ', \lambda_{\rho}=' num2str(cm.lambda_theta,'%0.3f') ', \lambda_{l}=' num2str(cm.lambda_l,'%0.1f')];
            if cm.q0+cm.q1>0;
               hyp_txt = [hyp_txt ', \lambda_{e}=' num2str(cm.lambda_e,'%0.3f')];
            end;
            old_txt = get(controls.hyptext,'String');
            n_hyp_txt = old_txt(2,:);
            if cm.cointvalue==1;
               r_hyp_txt = old_txt(3,:);
            else;
               r_hyp_txt = '';
            end;
            hyp_txt = strvcat(hyp_txt,n_hyp_txt,r_hyp_txt);
            set(controls.hyptext,'String',hyp_txt);
            set(controls.default_prior,'Enable','on');
         end;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         % Make sure all controls are set correctly
         %
         bayesgui('check_model');
         %
         set(bayesdlg,'Visible','on');
         drawnow;
      end;
   case 'rank_priors'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         % open the prior rank probabilities dialog
         %
         rw_dlg = rank_weights('init',cm);
         rw = get(rw_dlg,'UserData');
         t_m = get(rw.variables,'UserData');
         action = t_m.action;
         r_weights = t_m.r_weights;
         r_values = [];
         for i=1:size(rw.controls,2);
            r_values = [r_values get(rw.controls(1,i),'Value')];
         end;
         killguipid(rw_dlg);
         if strcmp(action,'cancel')==0;
            %
            % check if values have been changed.
            %
            if isequal(max(r_values)*cm.r_values,max(cm.r_values)*r_values)==0;
               cm.rankpriors = r_weights';
               cm.r_values = r_values;
               %
               % Fix text about rank priors
               %
               prior_txt = get(controls.hyptext,'String');
               %
               % now check if all weights are equal
               %
               if (1/max(r_values))*r_values==ones(size(r_values));
                  r_hyp_txt = ['P(Rank=r)=' num2str(1/(cm.n+1),'%0.3f') ' \forall r \in {0,...,' num2str(cm.n,'%0.0f') '}'];
               else;
                  r_hyp_txt = 'P(Rank=i)=[';
                  for i=0:cm.n;
                     r_hyp_txt = [r_hyp_txt num2str(cm.rankpriors(i+1,1),'%0.3f') ' '];
                  end;
                  r_hyp_txt = [strtrim(r_hyp_txt) '] i=0,...,' num2str(cm.n,'%0.0f')];
               end;
               if (size(r_hyp_txt,2)>=64)&(size(r_hyp_txt,2)<72);
                  fntsize = 8;
               elseif size(r_hyp_txt,2)>=72;
                  fntsize = 7;
               else;
                  fntsize = 9;
               end;
               prior_txt = strvcat(prior_txt(1:2,:),r_hyp_txt);
               set(controls.hyptext,'String',prior_txt,'FontSize',fntsize);
               %
               % recompute posterior rank probabilities for FML
               %
               sum_fml = 0;
               for i=0:cm.n;
                  sum_fml = sum_fml + (cm.rank(i+1).norm_fraction_marglike*cm.rankpriors(i+1,1));
               end;
               cm.rankprob = zeros(cm.n+1,1);
               for i=0:cm.n;
                  cm.rankprob(i+1,1) = (cm.rank(i+1).norm_fraction_marglike*cm.rankpriors(i+1,1))/sum_fml;
               end;
               my_ranks = (0:1:cm.n);
               if isfield(cm,'rankprob_ml')==1;
                  %
                  % need to make sure that ranks which have zero prior probability
                  % do not results in all posterior probabilities being 0
                  %
                  marg_like = cm.log_marglike;
                  if min(cm.rankpriors)==0;
                     for i=1:cm.n+1;
                        if cm.rankpriors(i,1)==0;
                           marg_like(i,1) = min(marg_like);
                        end;
                     end;
                  end;
                  marg_like = fix_exp(marg_like-mean(marg_like));
                  cm.rankprob_ml = (1/(cm.rankpriors'*marg_like))*(marg_like .* cm.rankpriors);
                  ml_str = num2str(cm.rankprob_ml,'%12.4f');
               else;
                  ml_str = cm.ml_str;
               end;
               cm.rankprob_str = [cm.rank_str num2str(my_ranks','%2.0f') cm.prependstr num2str(cm.rankprob,'%12.4f') cm.prependstr ml_str];
               cm.rankprob_str = strvcat(' ',cm.rankprob_str,' ');
               set(controls.traceresults,'String',cm.rankprob_str);
               set(controls.default_prior,'Enable','on');
            end;
         end;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         % Make sure all controls are set correctly
         %
         bayesgui('check_model');
         %
         set(bayesdlg,'Visible','on');
         drawnow;
      end;
   case 'graph_options'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         my_ini.loadguiicon = curr_ini.loadguiicon;
         my_ini.pstoolsdir = curr_ini.pstoolsdir;
         %
         my_ini.interpolate = cm.interpolate;
         my_ini.interpolate_value = cm.interpolate_value;
         my_ini.cumdist = cm.cumdist;
         my_ini.adaptivekde = cm.adaptivekde;
         my_ini.numcells = cm.numcells;
         my_ini.numcells_control = cm.numcells_control;
         my_ini.gui_fontsize = curr_ini.gui_fontsize;
         my_ini.gui_fontname = curr_ini.gui_fontname;
         my_ini.gui_fontweight = curr_ini.gui_fontweight;
         my_ini.gui_fontangle = curr_ini.gui_fontangle;
         %
         % show GUI
         %
         hyp_gui = graphoptions_dlg('init',my_ini);
         lambda_controls = get(hyp_gui,'UserData');
         tm = get(lambda_controls.apply,'UserData');
         new_my_ini = tm.ini;
         if abs(new_my_ini.interpolate_value-cm.interpolate_value)>0;
            cm.interpolate_value = new_my_ini.interpolate_value;
            cm.interpolate = new_my_ini.interpolate;
         end;
         if abs(new_my_ini.cumdist-cm.cumdist)>0;
            cm.cumdist = new_my_ini.cumdist;
         end;
         if abs(new_my_ini.adaptivekde-cm.adaptivekde)>0;
            cm.adaptivekde = new_my_ini.adaptivekde;
         end;
         if abs(new_my_ini.numcells-cm.numcells)>0;
            cm.numcells = new_my_ini.numcells;
            cm.numcells_control = new_my_ini.numcells_control;
         end;
         killguipid(hyp_gui);
         %
         set(bayesdlg,'Visible','on');
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'coint_graph'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         % Load posterior draws
         %
         posterior_data = getposteriordata(controls,cm);
         if isempty(posterior_data)==0;
            thisgraph = bayes_cointgraphdlg('init',cm,posterior_data,1);
            graph = get(thisgraph,'UserData');
            set(graph.show,'UserData','done');
            killguipid(thisgraph);
         else;
            txt = 'There are not any posterior draws available for the selected model. Make sure that you have check marked the correct Restrictions selections.';
            about(txt,'information','Graph Cointegration Relations',120,500);
         end;
         %
         set(bayesdlg,'Visible','on');
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'marg_like_rank'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         if cm.cointvalue==1;
            cm = get_cmatrices(cm);
            if isempty(cm.Z2)==0;
               [cm.prior.deter.mu,cm.prior.deter.sigma,cm.prior.shortrun.mu,cm.prior.shortrun.sigma] = prior_short_coint(cm);
            else;
               cm.prior.deter.mu = [];
               cm.prior.deter.sigma = [];
               cm.prior.shortrun.sigma = [];
               cm.prior.shortrun.mu = [];
            end;
            %
            % we are now ready to startup the Gibbs sampler
            %
            if (cm.deterselect(1,1)==1)|(cm.deterselect(1,3)==1);
               if (cm.amat_type==1)&(cm.amat_lag>1);
                  [cm.amat_val,cm.use_lag] = ml_omega(cm);
               end;
            else;
               set(bayesdlg,'Visible','on');
               drawnow;
               %
               cm.running = 0;
               curr_ini.model = cm;
               set(controls.viewdata,'UserData',curr_ini);
               return;
            end;
            %
            % Compute marginal likelihood for the various cointegration ranks
            %
            file = get(controls.results_rank,'UserData');
            file = strrep(file,'.txt','.mat');
            rec_marg_like = marginal_likelihood_rank(cm,file);
            %
            % all data are now computed and stored in the structure rec_marg_like having cm.n+1 elements
            % with fields: log_marg_like and nse_marglike. The first stores the recursively estimated log marginal
            % likelihood values, while the second stores the recursively estimated numerical standard errors of
            % these log marginal likelihoods
            %
            % we can now display these
            %
            %
            set(bayesdlg,'Visible','on');
            drawnow;
            drawnow;
            %
            show_recursive_rank_marglike(rec_marg_like,cm,curr_ini)
         else;
            %
            % we're in the no cointegration estimation case
            %


            %
            set(bayesdlg,'Visible','on');
            drawnow;
            %

         end;
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'param_convergence'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         % Load gibbs draws data
         %
         gibbs_draws = getgibbsdraws(controls,cm);
         if isempty(gibbs_draws)==0;
            if (gcbo==controls.part_c_psi)|(gcbo==controls.full_c_psi);
               param_name = 'Beta';
               if isfield(gibbs_draws,'psi_n')==1;
                  if gcbo==controls.part_c_psi;
                     param_mat = gibbs_draws.psi_n;
                     dist_type = 'Partial';
                  else;
                     param_mat = gibbs_draws.psi;
                     dist_type = 'Joint';
                  end;
                  no_draws = 0;
                  %
                  % setup a param_str string matrix with parameter names
                  %
                  param_str = '';
                  psi_1 = param_mat(:,1);
                  psi_2 = param_mat(:,2);
                  if get(controls.betarest,'Value')==0;
                     cm = get_cmatrices(cm);
                     c_mat = cm.rank(cm.r+1).c_mat;
                     c_mat_orth = cm.rank(cm.r+1).c_mat_orth;
                     h_vec = vec(c_mat);
                     H_mat = kron(eye(cm.r),c_mat_orth);
                  else;
                     [h_vec,H_mat,tot_free] = beta_restrictions(cm.rank(cm.r).beta,cm.n,cm.r,cm.dcoint,cm.q1,cm.modelsdir,cm.modelfile);
                  end;
                  beta_1 = vecinv(h_vec+(H_mat*psi_1),cm.n+cm.q1+cm.dcoint);
                  beta_2 = vecinv(h_vec+(H_mat*psi_2),cm.n+cm.q1+cm.dcoint);
                  beta_mat = H_mat*param_mat;
                  %
                  row = cm.n+cm.q1+cm.dcoint;
                  col = cm.r;
                  param_mat = [];
                  num = 1;
                  for i=1:col;
                     for j=1:row;
                        if isalmostequal(beta_1(j,i),beta_2(j,i))==0;
                           param_str = strvcat(param_str,['beta(' num2str(i,'%0.0f') ',' num2str(j,'%0.0f') ')']);
                           param_mat = [param_mat;beta_mat(num,:)];
                        end;
                        num = num+1;
                     end;
                  end;
               else;
                  no_draws = 1;
               end;
            elseif (gcbo==controls.part_c_alpha)|(gcbo==controls.full_c_alpha);
               param_name = 'Alpha';
               if isfield(gibbs_draws,'alpha_n')==1;
                  if gcbo==controls.part_c_alpha;
                     param_mat = gibbs_draws.alpha_n;
                     dist_type = 'Partial';
                  else;
                     param_mat = gibbs_draws.alpha;
                     dist_type = 'Joint';
                  end;
                  no_draws = 0;
                  %
                  % setup a param_str string matrix with parameter names
                  %
                  param_str = '';
                  row = cm.n;
                  col = cm.r;
                  for i=1:col;
                     for j=1:row;
                        param_str = strvcat(param_str,['alpha(' num2str(j,'%0.0f') ',' num2str(i,'%0.0f') ')']);
                     end;
                  end;
               else;
                  no_draws = 1;
               end;
            elseif (gcbo==controls.part_c_omega)|(gcbo==controls.full_c_omega);
               param_name = 'Omega';
               if isfield(gibbs_draws,'Omega')==1;
                  if (gcbo==controls.part_c_omega)&(isfield(gibbs_draws,'Omega_n'));
                     param_mat = gibbs_draws.Omega_n;
                     dist_type = 'Partial';
                  else;
                     param_mat = gibbs_draws.Omega;
                     dist_type = 'Joint';
                  end;
                  no_draws = 0;
                  %
                  % setup a param_str string matrix with parameter names
                  %
                  param_str = '';
                  for i=1:cm.n;
                     for j=i:cm.n;
                        param_str = strvcat(param_str,['Omega(' num2str(j,'%0.0f') ',' num2str(i,'%0.0f') ')']);
                     end;
                  end;
               else;
                  no_draws = 1;
               end;
            elseif gcbo==controls.full_c_delta;
               param_name = 'delta';
               if isfield(gibbs_draws,'delta')==1;
                  param_mat = gibbs_draws.delta;
                  dist_type = 'Joint';
                  no_draws = 0;
                  %
                  % setup a param_str string matrix with parameter names
                  %
                  param_str = '';
                  for i=1:cm.d;
                     for j=1:cm.n;
                        param_str = strvcat(param_str,['delta(' num2str(j,'%0.0f') ',' num2str(i,'%0.0f') ')']);
                     end;
                  end;
               else;
                  no_draws = 1;
               end;
            elseif gcbo==controls.full_c_gamma;
               param_name = 'Gamma';
               if isfield(gibbs_draws,'Gamma')==1;
                  param_mat = gibbs_draws.Gamma(1:cm.n*cm.n*(cm.p-1),:);
                  dist_type = 'Joint';
                  no_draws = 0;
                  %
                  % setup a param_str string matrix with parameter names
                  %
                  param_str = '';
                  for i=1:cm.p-1;
                     for j=1:cm.n;
                        for k=1:cm.n;
                           param_str = strvcat(param_str,['Gamma(' num2str(k,'%0.0f') ',' num2str(j,'%0.0f') ',' num2str(i,'%0.0f') ')']);
                        end;
                     end;
                  end;
               else;
                  no_draws = 1;
               end;
            elseif gcbo==controls.full_c_phi;
               param_name = 'Phi';
               if isfield(gibbs_draws,'Gamma')==1;
                  param_mat = gibbs_draws.Gamma((cm.n*cm.n*(cm.p-1))+1:(cm.n*cm.n*(cm.p-1))+(cm.n*cm.q0*(cm.pe+1)),:);
                  dist_type = 'Joint';
                  no_draws = 0;
                  %
                  % setup a param_str string matrix with parameter names
                  %
                  param_str = '';
                  for i=0:cm.pe;
                     for j=1:cm.q0;
                        for k=1:cm.n;
                           param_str = strvcat(param_str,['Phi(' num2str(k,'%0.0f') ',' num2str(j,'%0.0f') ',' num2str(i,'%0.0f') ')']);
                        end;
                     end;
                  end;
               else;
                  no_draws = 1;
               end;
            else;




               no_draws = 1;
            end;
            if no_draws==0;
               %
               % we are now in a position to compute the median over all draws recursively
               %
               median_mat = zeros(size(param_mat));
               median_mat(:,1) = param_mat(:,1);
               %
               % setup a wait dialog
               %
               txt = strvcat(' ',['Computing the median recursively over all posterior draws of the ' lower(param_name) ' parameters.'],' ','Draw No: 1');
               mywait = waitdlg(txt,'information','Convergence Graphs',400,130,1);
               waitf = get(mywait,'UserData');
               abort = '';
               if size(param_mat,2)>=1000;
                  setlogtext(strvcat(' ',['Computations started at:   ' datestr(now,14)]));
               end;
               %
               for i=2:size(param_mat,2);
                  abort = get(waitf.cancel,'UserData');
                  if strcmp(abort,'cancel')==0;
                     txt = strvcat(' ',['Computing the median recursively over all posterior draws of the ' lower(param_name) ' parameters.'],' ',['Draw No: ' num2str(i,'%0.0f')]);
                     set(waitf.text,'String',txt);
                     drawnow;
                     drawnow;
                     median_mat(:,i) = median(param_mat(:,1:i),2);
                  else;
                     break;
                  end;
               end;
               %
               % Close the wait dialog
               %
               set(waitf.text,'UserData','done');
               delete(mywait);
               drawnow;
               if size(param_mat,2)>=1000;
                  setlogtext(['Computations completed at: ' datestr(now,14)]);
               end;
               %
               %
               if strcmp(abort,'cancel')==0;
                  %
                  % we are now ready to graphs the recursively determined medians
                  %
                  thisgraph = bayes_graph_median('init',cm,curr_ini,median_mat,param_str,param_name,dist_type);
                  graph = get(thisgraph,'UserData');
                  set(graph.show,'UserData','done');
                  killguipid(thisgraph);
               end;
            else;
               txt = ['There are no draws of ' lower(param_name) ' for the selected model. Make sure that you have check marked the correct Restrictions selections.'];
               about(txt,'information','Convergence Graphs',120,500);
            end;
         else;
            txt = 'There are not any posterior draws available for the selected model. Make sure that you have check marked the correct Restrictions selections.';
            about(txt,'information','Convergence Graphs',120,500);
         end;
         %
         set(bayesdlg,'Visible','on');
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'coint_graph_partinal'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         % Load posterior draws
         %
         posterior_data = getposteriordata(controls,cm);
         if isempty(posterior_data)==0;
            thisgraph = bayes_cointgraphdlg('init',cm,posterior_data,0);
            graph = get(thisgraph,'UserData');
            set(graph.show,'UserData','done');
            killguipid(thisgraph);
         else;
            txt = 'There are not any posterior draws available for the selected model. Make sure that you have check marked the correct Restrictions selections.';
            about(txt,'information','Graph Cointegration Relations',120,500);
         end;
         %
         set(bayesdlg,'Visible','on');
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'prior_betagraph'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         % Construct draws from prior
         %
         if get(controls.betarest,'Value')==0;
            cm = get_cmatrices(cm);
         else;
            [cm.beta_rest.h_vec,cm.beta_rest.H_mat,cm.beta_rest.tot_free] = beta_restrictions(cm.rank(cm.r).beta,cm.n,cm.r,cm.dcoint,cm.q1,cm.modelsdir,cm.modelfile);
            if cm.beta_rest.tot_free==0;
               %
               % There are no free beta parameters
               %
               txt = 'The are no free beta parameters for this model.';
               about(txt,'information','Graph Beta Parameters',120,350);
               %
               set(bayesdlg,'Visible','on');
               drawnow;
               drawnow;
               drawnow;
               %
               cm.running = 0;
               curr_ini.model = cm;
               set(controls.viewdata,'UserData',curr_ini);
               return;
            end;
         end;
         if isempty(cm.Z2)==0;
            [cm.prior.deter.mu,cm.prior.deter.sigma,cm.prior.shortrun.mu,cm.prior.shortrun.sigma] = prior_short_coint(cm);
         else;
            cm.prior.deter.mu = [];
            cm.prior.deter.sigma = [];
            cm.prior.shortrun.sigma = [];
            cm.prior.shortrun.mu = [];
         end;
         if (cm.amat_type==1)&(cm.amat_lag>1);
            [cm.amat_val,cm.use_lag] = ml_omega(cm);
         end;
         [prior_data,abort] = getpriordata(controls,cm,curr_ini,0,1,0,0,0);
         if strcmp(abort,'cancel')==0;
            %
            % determine names for parameters and collect the sorted data
            %
            row = cm.n;
            col = cm.r;
            beta_sorted = [];
            beta_param = '';
            for i=1:col;
               for j=1:row;
                  beta_ij = zeros(cm.prior_draws,1);
                  for k=1:cm.prior_draws;
                     beta_ij(k,1) = prior_data(k).beta(j,i);
                  end;
                  beta_ij = sort(beta_ij);
                  if isalmostequal(beta_ij(cm.prior_draws,1),beta_ij(1,1))==0;
                     beta_sorted = [beta_sorted beta_ij];
                     beta_param = strvcat(beta_param,['beta(' num2str(i,'%0.0f') ',' num2str(j,'%0.0f') ')']);
                  end;
               end;
            end;
            %
            % determine the type of graph
            %
            if gcbo==controls.prior_betagraph;
               graph_type = 'function';
               gr_str = 'Graphs of ';
            else;
               graph_type = 'histogram';
               gr_str = 'Histograms of ';
            end;
            cm.dist_draws = cm.prior_draws;
            thisgraph = param_graphdlg('init',cm,beta_param,beta_sorted,[gr_str 'Beta Parameters'],['Prior for beta with ' num2str(cm.prior_draws,'%0.0f') ' draws'],'Prior Density for','Prior Density',graph_type,0);
            param_graph = get(thisgraph,'UserData');
            set(param_graph.show,'UserData','done');
            killguipid(thisgraph);
         end;
         %
         set(bayesdlg,'Visible','on');
         drawnow;
         drawnow;
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'prior_alphagraph'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         % Construct draws from prior
         %
         if get(controls.betarest,'Value')==0;
            cm = get_cmatrices(cm);
         else;
            if cm.prior_inf_alpha==1;
               [cm.beta_rest.h_vec,cm.beta_rest.H_mat,cm.beta_rest.tot_free] = beta_restrictions(cm.rank(cm.r).beta,cm.n,cm.r,cm.dcoint,cm.q1,cm.modelsdir,cm.modelfile);
            else;
               %
               % There is a non-informative prior on alpha
               %
               txt = 'You have selected a non-informative prior on alpha. Unable to draw from this prior.';
               about(txt,'information','Graph Alpha Parameters',120,350);
               %
               set(bayesdlg,'Visible','on');
               drawnow;
               drawnow;
               drawnow;
               %
               cm.running = 0;
               curr_ini.model = cm;
               set(controls.viewdata,'UserData',curr_ini);
               return;
            end;
         end;
         if isempty(cm.Z2)==0;
            [cm.prior.deter.mu,cm.prior.deter.sigma,cm.prior.shortrun.mu,cm.prior.shortrun.sigma] = prior_short_coint(cm);
         else;
            cm.prior.deter.mu = [];
            cm.prior.deter.sigma = [];
            cm.prior.shortrun.sigma = [];
            cm.prior.shortrun.mu = [];
         end;
         %
         if (cm.amat_type==1)&(cm.amat_lag>1);
            [cm.amat_val,cm.use_lag] = ml_omega(cm);
         end;
         [prior_data,abort] = getpriordata(controls,cm,curr_ini,1,1,1,0,0);
         if strcmp(abort,'cancel')==0;
            %
            % determine names for parameters and collect the sorted data
            %
            alpha_sorted = [];
            alpha_param = '';
            for i=1:cm.r;
               for j=1:cm.n;
                  alpha_ij = zeros(cm.prior_draws,1);
                  for k=1:cm.prior_draws;
                     alpha_ij(k,1) = prior_data(k).alpha(j,i);
                  end;
                  alpha_ij = sort(alpha_ij);
                  if isalmostequal(alpha_ij(cm.prior_draws,1),alpha_ij(1,1))==0;
                     alpha_sorted = [alpha_sorted alpha_ij];
                     alpha_param = strvcat(alpha_param,['alpha(' num2str(j,'%0.0f') ',' num2str(i,'%0.0f') ')']);
                  end;
               end;
            end;
            %
            % open a graph data dialog
            %
            if isempty(alpha_param)==0;
               %
               % determine the type of graph
               %
               if gcbo==controls.prior_alphagraph;
                  graph_type = 'function';
                  gr_str = 'Graphs of ';
               else;
                  graph_type = 'histogram';
                  gr_str = 'Histograms of ';
               end;
               cm.dist_draws = cm.prior_draws;
               thisgraph = param_graphdlg('init',cm,alpha_param,alpha_sorted,[gr_str 'Alpha Parameters'],['Prior for alpha with ' num2str(cm.prior_draws,'%0.0f') ' draws'],'Prior Density for','Prior Density',graph_type,0);
               param_graph = get(thisgraph,'UserData');
               set(param_graph.show,'UserData','done');
               killguipid(thisgraph);
            else;
               %
               % There are no free alpha parameters
               %
               txt = 'The are no free alpha parameters for this model.';
               about(txt,'information','Graph Alpha Parameters',120,350);
            end;
         end;
         %
         set(bayesdlg,'Visible','on');
         drawnow;
         drawnow;
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'prior_eigengraph'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         % Construct draws from the prior
         %
         if get(controls.betarest,'Value')==0;
            %
            % We should not apply over-identifying restrictions on beta
            %
            if cm.cointvalue==1;
               cm = get_cmatrices(cm);
               if isempty(cm.Z2)==0;
                  [cm.prior.deter.mu,cm.prior.deter.sigma,cm.prior.shortrun.mu,cm.prior.shortrun.sigma] = prior_short_coint(cm);
               else;
                  cm.prior.deter.mu = [];
                  cm.prior.deter.sigma = [];
                  cm.prior.shortrun.sigma = [];
                  cm.prior.shortrun.mu = [];
               end;
               if (cm.amat_type==1)&(cm.amat_lag>1);
                  [cm.amat_val,cm.use_lag] = ml_omega(cm);
               end;
               [prior_data,abort] = getpriordata(controls,cm,curr_ini,1,1,1,0,1);
               if strcmp(abort,'cancel')==0;
                  %
                  % determine names for parameters and collect the sorted data
                  %
                  eigen_sorted = zeros(cm.prior_draws,1);
                  for k=1:cm.prior_draws;
                     eigen_sorted(k,1) = prior_data(k).max_evalue;
                  end;
                  eigen_sorted = sort(eigen_sorted);
                  eigen_param = 'lambda';
                  %
                  % determine the type of graph
                  %
                  if gcbo==controls.prior_eigengraph;
                     graph_type = 'function';
                     gr_str = 'Graph of ';
                  else;
                     graph_type = 'histogram';
                     gr_str = 'Histogram of ';
                  end;
                  cm.dist_draws = cm.prior_draws;
                  thisgraph = param_graphdlg('init',cm,eigen_param,eigen_sorted,[gr_str 'Maximum Eigenvalue'],['Prior for maximum non-unit eigenvalue with ' num2str(cm.prior_draws,'%0.0f') ' draws'],'Prior Density for','Prior Density',graph_type,10);
                  param_graph = get(thisgraph,'UserData');
                  set(param_graph.show,'UserData','done');
                  killguipid(thisgraph);
               end;
            else;
               %
               % No cointegration
               %


            end;
         else;
            %
            % Over-identifying restrictions on beta should be used
            %
            [cm.beta_rest.h_vec,cm.beta_rest.H_mat,cm.beta_rest.tot_free] = beta_restrictions(cm.rank(cm.r).beta,cm.n,cm.r,cm.dcoint,cm.q1,cm.modelsdir,cm.modelfile);
            if isempty(cm.Z2)==0;
               [cm.prior.deter.mu,cm.prior.deter.sigma,cm.prior.shortrun.mu,cm.prior.shortrun.sigma] = prior_short_coint(cm);
            else;
               cm.prior.deter.mu = [];
               cm.prior.deter.sigma = [];
               cm.prior.shortrun.sigma = [];
               cm.prior.shortrun.mu = [];
            end;
            if (cm.amat_type==1)&(cm.amat_lag>1);
               [cm.amat_val,cm.use_lag] = ml_omega(cm);
            end;
            [prior_data,abort] = getpriordata(controls,cm,curr_ini,1,1,1,0,1);
            if strcmp(abort,'cancel')==0;
               %
               % determine names for parameters and collect the sorted data
               %
               eigen_sorted = zeros(cm.prior_draws,1);
               for k=1:cm.prior_draws;
                  eigen_sorted(k,1) = prior_data(k).max_evalue;
               end;
               eigen_sorted = sort(eigen_sorted);
               eigen_param = 'lambda';
               %
               % determine the type of graph
               %
               if gcbo==controls.prior_eigengraph;
                  graph_type = 'function';
                  gr_str = 'Graph of ';
               else;
                  graph_type = 'histogram';
                  gr_str = 'Histogram of ';
               end;
               cm.dist_draws = cm.prior_draws;
               thisgraph = param_graphdlg('init',cm,eigen_param,eigen_sorted,[gr_str 'Maximum Eigenvalue'],['Prior for maximum non-unit eigenvalue with ' num2str(cm.prior_draws,'%0.0f') ' draws'],'Prior Density for','Prior Density',graph_type,10);
               param_graph = get(thisgraph,'UserData');
               set(param_graph.show,'UserData','done');
               killguipid(thisgraph);
            end;
         end;
         %
         set(bayesdlg,'Visible','on');
         drawnow;
         drawnow;
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'full_eigengraph'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         % Load posterior draws
         %
         posterior_data = getposteriordata(controls,cm);
         if isempty(posterior_data)==0;
            %
            % determine names for parameters and collect the sorted data
            %
            eigen_sorted = zeros(cm.save_draws,1);
            for k=1:cm.save_draws;
               eigen_sorted(k,1) = posterior_data(k).max_evalue;
            end;
            eigen_sorted = sort(eigen_sorted);
            eigen_param = 'lambda';
            %
            % determine the type of graph
            %
            if gcbo==controls.full_eigengraph;
               graph_type = 'function';
               gr_str = 'Graph of ';
            else;
               graph_type = 'histogram';
               gr_str = 'Histogram of ';
            end;
            cm.dist_draws = cm.save_draws;
            thisgraph = param_graphdlg('init',cm,eigen_param,eigen_sorted,[gr_str 'Maximum Eigenvalue'],['Posterior for maximum non-unit eigenvalue with ' num2str(cm.save_draws,'%0.0f') ' draws'],'Posterior Density for','Posterior Density',graph_type,10);
            param_graph = get(thisgraph,'UserData');
            set(param_graph.show,'UserData','done');
            killguipid(thisgraph);
         else;
            txt = 'There are not any posterior draws available for the selected model. Make sure that you have check marked the correct Restrictions selections.';
            about(txt,'information','Graph Maximum Non-Unit Eigenvalue',120,500);
         end;
         %
         set(bayesdlg,'Visible','on');
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'part_alphagraph'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         % Load posterior draws
         %
         posterior_data = getposteriordata(controls,cm);
         if isempty(posterior_data)==0;
            %
            % determine names for parameters and collect the sorted data
            %
            alpha_sorted = [];
            alpha_param = '';
            for i=1:cm.r;
               for j=1:cm.n;
                  alpha_ij = zeros(cm.save_draws,1);
                  for k=1:cm.save_draws;
                     alpha_ij(k,1) = posterior_data(k).alpha_n(j,i);
                  end;
                  alpha_ij = sort(alpha_ij);
                  if isalmostequal(alpha_ij(cm.save_draws,1),alpha_ij(1,1))==0;
                     alpha_sorted = [alpha_sorted alpha_ij];
                     alpha_param = strvcat(alpha_param,['alpha(' num2str(j,'%0.0f') ',' num2str(i,'%0.0f') ')']);
                  end;
               end;
            end;
            %
            % open a graph data dialog
            %
            if isempty(alpha_param)==0;
               %
               % determine the type of graph
               %
               if gcbo==controls.part_alphagraph;
                  graph_type = 'function';
                  gr_str = 'Graphs of ';
               else;
                  graph_type = 'histogram';
                  gr_str = 'Histograms of ';
               end;
               cm.dist_draws = cm.save_draws;
               thisgraph = param_graphdlg('init',cm,alpha_param,alpha_sorted,[gr_str 'Alpha Parameters'],['Posterior for alpha with ' num2str(cm.save_draws,'%0.0f') ' draws'],'Partial Posterior Density for','Posterior Density',graph_type,0);
               param_graph = get(thisgraph,'UserData');
               set(param_graph.show,'UserData','done');
               killguipid(thisgraph);
            else;
               %
               % There are no free alpha parameters
               %
               txt = 'The are no free alpha parameters for this model.';
               about(txt,'information','Graph Alpha Parameters',120,350);
            end;
         else;
            txt = 'There are not any posterior draws available for the selected model. Make sure that you have check marked the correct Restrictions selections.';
            about(txt,'information','Graph Alpha Parameters',120,500);
         end;
         %
         set(bayesdlg,'Visible','on');
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'full_alphagraph'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         % Load posterior draws
         %
         posterior_data = getposteriordata(controls,cm);
         if isempty(posterior_data)==0;
            %
            % determine names for parameters and collect the sorted data
            %
            alpha_sorted = [];
            alpha_param = '';
            for i=1:cm.r;
               for j=1:cm.n;
                  alpha_ij = zeros(cm.save_draws,1);
                  for k=1:cm.save_draws;
                     alpha_ij(k,1) = posterior_data(k).alpha(j,i);
                  end;
                  alpha_ij = sort(alpha_ij);
                  if isalmostequal(alpha_ij(cm.save_draws,1),alpha_ij(1,1))==0;
                     alpha_sorted = [alpha_sorted alpha_ij];
                     alpha_param = strvcat(alpha_param,['alpha(' num2str(j,'%0.0f') ',' num2str(i,'%0.0f') ')']);
                  end;
               end;
            end;
            %
            % open a graph data dialog
            %
            if isempty(alpha_param)==0;
               %
               % determine the type of graph
               %
               if gcbo==controls.full_alphagraph;
                  graph_type = 'function';
                  gr_str = 'Graphs of ';
               else;
                  graph_type = 'histogram';
                  gr_str = 'Histograms of ';
               end;
               cm.dist_draws = cm.save_draws;
               thisgraph = param_graphdlg('init',cm,alpha_param,alpha_sorted,[gr_str 'Alpha Parameters'],['Posterior for alpha with ' num2str(cm.save_draws,'%0.0f') ' draws'],'Joint Posterior Density for','Posterior Density',graph_type,0);
               param_graph = get(thisgraph,'UserData');
               set(param_graph.show,'UserData','done');
               killguipid(thisgraph);
            else;
               %
               % There are no free alpha parameters
               %
               txt = 'The are no free alpha parameters for this model.';
               about(txt,'information','Graph Alpha Parameters',120,350);
            end;
         else;
            txt = 'There are not any posterior draws available for the selected model. Make sure that you have check marked the correct Restrictions selections.';
            about(txt,'information','Graph Alpha Parameters',120,500);
         end;
         %
         set(bayesdlg,'Visible','on');
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'marg_alphagraph'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         % Load posterior draws
         %
         posterior_data = getposteriordata(controls,cm);
         if isempty(posterior_data)==0;
            %
            % determine names for parameters
            %
            alpha_param = '';
            for i=1:cm.r;
               for j=1:cm.n;
                  alpha_ij = zeros(cm.save_draws,1);
                  for k=1:cm.save_draws;
                     alpha_ij(k,1) = posterior_data(k).alpha(j,i);
                  end;
                  alpha_ij = sort(alpha_ij);
                  if isalmostequal(alpha_ij(cm.save_draws,1),alpha_ij(1,1))==0;
                     alpha_param = strvcat(alpha_param,['alpha(' num2str(j,'%0.0f') ',' num2str(i,'%0.0f') ')']);
                  end;
               end;
            end;
            %
            % open a graph data dialog
            %
            if isempty(alpha_param)==0;
               %
               % determine the type of graph
               %
               if gcbo==controls.marg_alphagraph;
                  graph_type = 'function';
                  gr_str = 'Graphs of ';
               else;
                  graph_type = 'histogram';
                  gr_str = 'Histograms of ';
               end;
               if get(controls.betarest,'Value')==0;
                  cm = get_cmatrices(cm);
                  c_mat = cm.rank(cm.r+1).c_mat;
                  c_mat_orth = cm.rank(cm.r+1).c_mat_orth;
                  h_vec = vec(c_mat);
                  H_mat = kron(eye(cm.r),c_mat_orth);
                  beta_rest = 0;
               else;
                  [h_vec,H_mat,tot_free] = beta_restrictions(cm.rank(cm.r).beta,cm.n,cm.r,cm.dcoint,cm.q1,cm.modelsdir,cm.modelfile);
                  beta_rest = 1;
               end;
               thisgraph = marginal_graphdlg('init',cm,'Alpha',alpha_param,posterior_data,graph_type,beta_rest,h_vec,H_mat);
               param_graph = get(thisgraph,'UserData');
               set(param_graph.show,'UserData','done');
               killguipid(thisgraph);
            else;
               %
               % There are no free alpha parameters
               %
               txt = 'The are no free alpha parameters for this model.';
               about(txt,'information','Graph Alpha Parameters',120,350);
            end;
         else;
            txt = 'There are not any posterior draws available for the selected model. Make sure that you have check marked the correct Restrictions selections.';
            about(txt,'information','Graph Alpha Parameters',120,500);
         end;
         %
         set(bayesdlg,'Visible','on');
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'marg_betagraph'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         % Load posterior draws
         %
         posterior_data = getposteriordata(controls,cm);
         if isempty(posterior_data)==0;
            %
            % determine names for parameters and collect the sorted data
            %
            if get(controls.betarest,'Value')==0;
               cm = get_cmatrices(cm);
               c_mat = cm.rank(cm.r+1).c_mat;
               c_mat_orth = cm.rank(cm.r+1).c_mat_orth;
               h_vec = vec(c_mat);
               H_mat = kron(eye(cm.r),c_mat_orth);
               beta_rest = 0;
            else;
               [h_vec,H_mat,tot_free] = beta_restrictions(cm.rank(cm.r).beta,cm.n,cm.r,cm.dcoint,cm.q1,cm.modelsdir,cm.modelfile);
               beta_rest = 1;
            end;
            if isempty(H_mat)==0;
               beta_1 = vecinv(h_vec+(H_mat*randn(size(H_mat,2),1)),size(posterior_data(1).beta_n,1));
               beta_2 = vecinv(h_vec+(H_mat*randn(size(H_mat,2),1)),size(posterior_data(1).beta_n,1));
               param_str = '';
               for i=1:cm.r;
                  for j=1:size(beta_1,1);
                     if isalmostequal(beta_1(j,i),beta_2(j,i))==0;
                        param_str = strvcat(param_str,['beta(' num2str(i,'%0.0f') ',' num2str(j,'%0.0f') ')']);
                     end;
                     num = num+1;
                  end;
               end;
               %
               % determine the type of graph
               %
               if gcbo==controls.marg_betagraph;
                  graph_type = 'function';
               else;
                  graph_type = 'histogram';
               end;
               thisgraph = marginal_graphdlg('init',cm,'Beta',param_str,posterior_data,graph_type,beta_rest,h_vec,H_mat);
               param_graph = get(thisgraph,'UserData');
               set(param_graph.show,'UserData','done');
               killguipid(thisgraph);
            else;
               %
               % There are no free beta parameters
               %
               txt = 'The are no free beta parameters for this model.';
               about(txt,'information','Graph Beta Parameters',120,350);
            end;
         else;
            txt = 'There are not any posterior draws available for the selected model. Make sure that you have check marked the correct Restrictions selections.';
            about(txt,'information','Graph Beta Parameters',120,500);
         end;
         %
         set(bayesdlg,'Visible','on');
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'part_betagraph'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         % Load posterior draws
         %
         posterior_data = getposteriordata(controls,cm);
         if isempty(posterior_data)==0;
            %
            % determine names for parameters and collect the sorted data
            %
            row = size(posterior_data(1).beta_n,1);
            col = cm.r;
            beta_sorted = [];
            beta_param = '';
            for i=1:col;
               for j=1:row;
                  beta_ij = zeros(cm.save_draws,1);
                  for k=1:cm.save_draws;
                     beta_ij(k,1) = posterior_data(k).beta_n(j,i);
                  end;
                  beta_ij = sort(beta_ij);
                  if isalmostequal(beta_ij(cm.save_draws,1),beta_ij(1,1))==0;
                     beta_sorted = [beta_sorted beta_ij];
                     beta_param = strvcat(beta_param,['beta(' num2str(i,'%0.0f') ',' num2str(j,'%0.0f') ')']);
                  end;
               end;
            end;
            %
            % open a graph data dialog
            %
            if isempty(beta_param)==0;
               %
               % determine the type of graph
               %
               if gcbo==controls.part_betagraph;
                  graph_type = 'function';
                  gr_str = 'Graphs of ';
               else;
                  graph_type = 'histogram';
                  gr_str = 'Histograms of ';
               end;
               cm.dist_draws = cm.save_draws;
               thisgraph = param_graphdlg('init',cm,beta_param,beta_sorted,[gr_str 'Beta Parameters'],['Posterior for beta with ' num2str(cm.save_draws,'%0.0f') ' draws'],'Partial Posterior Density for','Posterior Density',graph_type,0);
               param_graph = get(thisgraph,'UserData');
               set(param_graph.show,'UserData','done');
               killguipid(thisgraph);
            else;
               %
               % There are no free beta parameters
               %
               txt = 'The are no free beta parameters for this model.';
               about(txt,'information','Graph Beta Parameters',120,350);
            end;
         else;
            txt = 'There are not any posterior draws available for the selected model. Make sure that you have check marked the correct Restrictions selections.';
            about(txt,'information','Graph Beta Parameters',120,500);
         end;
         %
         set(bayesdlg,'Visible','on');
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'full_betagraph'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         % Load posterior draws
         %
         posterior_data = getposteriordata(controls,cm);
         if isempty(posterior_data)==0;
            %
            % determine names for parameters and collect the sorted data
            %
            row = size(posterior_data(1).beta,1);
            col = cm.r;
            beta_sorted = [];
            beta_param = '';
            for i=1:col;
               for j=1:row;
                  beta_ij = zeros(cm.save_draws,1);
                  for k=1:cm.save_draws;
                     beta_ij(k,1) = posterior_data(k).beta(j,i);
                  end;
                  beta_ij = sort(beta_ij);
                  if isalmostequal(beta_ij(cm.save_draws,1),beta_ij(1,1))==0;
                     beta_sorted = [beta_sorted beta_ij];
                     beta_param = strvcat(beta_param,['beta(' num2str(i,'%0.0f') ',' num2str(j,'%0.0f') ')']);
                  end;
               end;
            end;
            %
            % open a graph data dialog
            %
            if isempty(beta_param)==0;
               %
               % determine the type of graph
               %
               if gcbo==controls.full_betagraph;
                  graph_type = 'function';
                  gr_str = 'Graphs of ';
               else;
                  graph_type = 'histogram';
                  gr_str = 'Histograms of ';
               end;
               cm.dist_draws = cm.save_draws;
               thisgraph = param_graphdlg('init',cm,beta_param,beta_sorted,[gr_str 'Beta Parameters'],['Posterior for beta with ' num2str(cm.save_draws,'%0.0f') ' draws'],'Joint Posterior Density for','Posterior Density',graph_type,0);
               param_graph = get(thisgraph,'UserData');
               set(param_graph.show,'UserData','done');
               killguipid(thisgraph);
            else;
               %
               % There are no free beta parameters
               %
               txt = 'The are no free beta parameters for this model.';
               about(txt,'information','Graph Beta Parameters',120,350);
            end;
         else;
            txt = 'There are not any posterior draws available for the selected model. Make sure that you have check marked the correct Restrictions selections.';
            about(txt,'information','Graph Beta Parameters',120,500);
         end;
         %
         set(bayesdlg,'Visible','on');
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'varforecast'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         % Load posterior draws
         %
         posterior_data = getposteriordata(controls,cm);
         if isempty(posterior_data)==0;
            thisgraph = bayes_var_forecastdlg('init',cm,posterior_data);
            f_cast = get(thisgraph,'UserData');
            set(f_cast.show,'UserData','done');
            killguipid(thisgraph);
         else;
            txt = 'There are not any posterior draws available for the selected model. Make sure that you have check marked the correct Restrictions selections.';
            about(txt,'information','Forecast Variable Transformation',120,500);
         end;
         %
         set(bayesdlg,'Visible','on');
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'discard_explosive'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         cm.discard_explosive = get(controls.discard_explosive,'Value');
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         % Make sure all controls are set correctly
         %
         bayesgui('check_model');
      end;
   case 'beta_rank_restrictions'
      %
      % requires that cm.n>1
      %
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         % check if there is a file with normalizing data
         %
         file = [cm.modelsdir cm.modelfile '-ranknorm-' num2str(cm.n,'%0.0f') '.norm'];
         if fileexist(file)==1;
            cm.rank_norm_data = loaddata(file);
         else;
            %
            % create default values
            %
            for i=1:cm.n-1;
               beta = cm.rank(i+1).beta;
               %
               % premultiply beta by scaling factors
               %
               scale_beta = sqrt(cm.scale_n);
               if size(beta,1)>cm.n;
                  scale_beta = [scale_beta;ones(size(beta,1)-cm.n,1)];
               end;
               scale_beta = diag(scale_beta);
               beta = scale_beta*beta;
               %
               % compare all cases
               %
               if ispc==1;
                  file = [pwd '\mat\states-' num2str(cm.n,'%0.0f') '.' num2str(i,'%0.0f') '.mat'];
               else;
                  file = [pwd '/mat/states-' num2str(cm.n,'%0.0f') '.' num2str(i,'%0.0f') '.mat'];
               end;
               %
               % we need to make sure that the file exists. otherwise we need to create it
               %
               if fileexist(file)==1;
                  states_data = load(file);
                  states = states_data.states;
                  clear('states_data');
               else;
                  %
                  % show a wait dialog
                  %
                  txt = strvcat(' ',['Determining the number of combinations of ' num2str(cm.n,'%0.0f') ' states to choose normalization of beta...'],'Please hold!');
                  mywait = waitdlg(txt,'information');
                  waitf = get(mywait,'UserData');
                  states = var_comb(cm.n);
                  txt = strvcat(' ','Saving data to file...','Please hold!');
                  set(waitf.text,'String',txt);
                  %
                  % save to disk
                  %
                  if ispc==1;
                     file = [pwd '\mat\states-' num2str(cm.n,'%0.0f') '.' num2str(cm.n,'%0.0f') '.mat'];
                  else;
                     file = [pwd '/mat/states-' num2str(cm.n,'%0.0f') '.' num2str(cm.n,'%0.0f') '.mat'];
                  end;
                  %
                  save(file,'states');
                  %
                  f_states = states;
                  clear('states');
                  %
                  if cm.n>1;
                     for j=1:cm.n-1;
                        if j<cm.n-1;
                           states = [];
                           for k=1:size(f_states,1);
                              stat_r = f_states(k,:);
                              stat_r = stat_r(stat_r~=0);
                              if size(stat_r,2)<=j;
                                 states = [states;f_states(k,:)];
                              end;
                           end;
                        else;
                           states = f_states(1:size(f_states,1)-1,:);
                        end;
                        if ispc==1;
                           file = [pwd '\mat\states-' num2str(cm.n,'%0.0f') '.' num2str(j,'%0.0f') '.mat'];
                        else;
                           file = [pwd '/mat/states-' num2str(cm.n,'%0.0f') '.' num2str(j,'%0.0f') '.mat'];
                        end;
                        save(file,'states');
                     end;
                     clear('states');
                  end;
                  clear('f_states');
                  %
                  % now load the correct file with states
                  %
                  if ispc==1;
                     file = [pwd '\mat\states-' num2str(cm.n,'%0.0f') '.' num2str(i,'%0.0f') '.mat'];
                  else;
                     file = [pwd '/mat/states-' num2str(cm.n,'%0.0f') '.' num2str(i,'%0.0f') '.mat'];
                  end;
                  states_data = load(file);
                  states = states_data.states;
                  clear('states_data');
                  %
                  % close wait dialog
                  %
                  set(waitf.text,'UserData','done');
                  delete(mywait);
               end;
               %
               max_beta_det = [];
               for j=1:size(states,1);
                  norm_beta = states(j,:);
                  norm_beta = norm_beta(norm_beta~=0);
                  if i==size(norm_beta,2);
                     beta_det = abs(det(beta(norm_beta,:)));
                     if isempty(max_beta_det)==0;
                        if beta_det>max_beta_det;
                           max_beta_det = beta_det;
                           cm.rank(i+1).norm_beta = norm_beta;
                        end;
                     else;
                        max_beta_det = beta_det;
                        cm.rank(i+1).norm_beta = norm_beta;
                     end;
                  end;
               end;
            end;
            cm.rank_norm_data = zeros(cm.n-1,cm.n);
            for i=1:cm.n-1;
               norm_beta = cm.rank(i+1).norm_beta;
               for j=1:i;
                  cm.rank_norm_data(i,norm_beta(1,j)) = 1;
               end;
            end;
         end;
         %
         % we are now ready to display the normalization selection dialog
         %
         norm_beta_gui = normalize_beta_dlg('init',cm,curr_ini);
         killguipid(norm_beta_gui);
         %
         % display the bayesian analysis dialog
         %
         set(bayesdlg,'Visible','on');
         drawnow;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'check_model'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         % fix the radio controls
         %
         if gcbo==controls.simultaneous;
            set(gcbo,'Value',1);
            set(controls.contemporaneous,'Value',0);
         elseif gcbo==controls.contemporaneous;
            set(gcbo,'Value',1);
            set(controls.simultaneous,'Value',0);
         end;
         if (cm.prior_inf_alpha==1)&(cm.prior_inf_omega==1)&(cm.prior_inf_shortrun==1);
            set(controls.lagorder,'Enable','on');
         else;
            set(controls.lagorder,'Enable','off');
         end;
         %
         % Check if results already exist
         %
         if cm.r>0;
            if cm.cointvalue==1;
               if ((cm.prior_inf_alpha==1)&(cm.prior_inf_omega==1))|(get(controls.betarest,'Value')==0);
                  set(controls.prior_eigengraph,'Enable','on');
                  set(controls.prior_hist_eigengraph,'Enable','on');
                  if cm.r<cm.n;
                     set(controls.prior_betagraph,'Enable','on');
                     set(controls.prior_hist_betagraph,'Enable','on');
                     set(controls.prior_alphagraph,'Enable','on');
                     set(controls.prior_hist_alphagraph,'Enable','on');
                  end;
               else;
                  set(controls.prior_eigengraph,'Enable','off');
                  set(controls.prior_hist_eigengraph,'Enable','off');
                  set(controls.prior_betagraph,'Enable','off');
                  set(controls.prior_hist_betagraph,'Enable','off');
                  set(controls.prior_alphagraph,'Enable','off');
                  set(controls.prior_hist_alphagraph,'Enable','off');
               end;
            else;
               if (cm.prior_inf_shortrun==1)&(cm.prior_inf_omega==1);
                  set(controls.prior_eigengraph,'Enable','on');
                  set(controls.prior_hist_eigengraph,'Enable','on');
               else;
                  set(controls.prior_eigengraph,'Enable','off');
                  set(controls.prior_hist_eigengraph,'Enable','off');
               end;
            end;
         else;
            if (cm.prior_inf_shortrun==1)&(cm.prior_inf_omega==1);
               set(controls.prior_eigengraph,'Enable','on');
               set(controls.prior_hist_eigengraph,'Enable','on');
            else;
               set(controls.prior_eigengraph,'Enable','off');
               set(controls.prior_hist_eigengraph,'Enable','off');
            end;
         end;





         res_file = '';
         if cm.cointvalue==1;
            marg_like = zeros(cm.n+1,1);
            for i=0:cm.n;
               file = [curr_ini.simulatedir cm.modelfile '-rank-' num2str(i) '-' num2str(cm.scale_endo,'%0.4f') '-gibbs-' cm.determodel cm.lag_model num2str(cm.burn_in,'%0.0f') '.' num2str(cm.save_draws,'%0.0f') '.' num2str(cm.save_freq,'%0.0f') '.' num2str(cm.discard_explosive,'%0.0f') '-' num2str(cm.prior_inf_shortrun,'%0.0f') '.' num2str(cm.prior_inf_deter,'%0.0f') '-' num2str(cm.lambda_alpha,'%0.3f')];
               if cm.amat_type==1;
                  file = [file '-1'];
               else;
                  file = [file '-0.' num2str(cm.lambda_a,'%0.2f') '.' num2str(cm.q_parm,'%0.0f')];
               end;
               if cm.prior_inf_shortrun==1;
                  file = [file '.' num2str(cm.lambda_b,'%0.3f') '.' num2str(cm.lambda_theta,'%0.3f') '.' num2str(cm.lambda_l,'%0.3f') '.' num2str(cm.lambda_e,'%0.3f')];
               end;
               if cm.prior_inf_deter==1;
                  file = [file '.' num2str(cm.lambda_d,'%0.3f')];
               end;
               file = [file '.mat'];
               if fileexist(file)==1;
                  f = load(file);
                  marg_like(i+1,1) = f.results.posterior_mode.log_marglike;
                  clear('f');
               else;
                  marg_like = [];
                  break;
               end;
            end;
            if isempty(marg_like)==0;
               cm.log_marglike = marg_like;
               marg_like = fix_exp(marg_like-mean(marg_like));
               cm.rankprob_ml = (1/(cm.rankpriors'*marg_like))*(marg_like .* cm.rankpriors);
               ml_str = num2str(cm.rankprob_ml,'%12.4f');
            else;
               if isfield(cm,'rankprob_ml')==1;
                  cm = rmfield(cm,'rankprob_ml');
               end;
               ml_str = 'NA';
               for i=1:cm.n;
                  ml_str = [ml_str;'NA'];
               end;
            end;
            cm.ml_str = ml_str;
            %
            % Setup the name of the results file
            %
            res_file = [curr_ini.simulatedir cm.modelfile '-rank-gibbs-' num2str(cm.scale_endo,'%0.4f') '-' cm.determodel cm.lag_model num2str(cm.burn_in,'%0.0f') '.' num2str(cm.save_draws,'%0.0f') '.' num2str(cm.save_freq,'%0.0f') '.' num2str(cm.discard_explosive,'%0.0f') '-' num2str(cm.prior_inf_shortrun,'%0.0f') '.' num2str(cm.prior_inf_deter,'%0.0f') '-' num2str(cm.lambda_alpha,'%0.3f')];
            if cm.amat_type==1;
               res_file = [res_file '-1'];
            else;
               res_file = [res_file '-0.' num2str(cm.lambda_a,'%0.2f') '.' num2str(cm.q_parm,'%0.0f')];
            end;
            if cm.prior_inf_shortrun==1;
               res_file = [res_file '.' num2str(cm.lambda_b,'%0.3f') '.' num2str(cm.lambda_theta,'%0.3f') '.' num2str(cm.lambda_l,'%0.3f') '.' num2str(cm.lambda_e,'%0.3f')];
            end;
            if cm.prior_inf_deter==1;
               res_file = [res_file '.' num2str(cm.lambda_d,'%0.3f')];
            end;
            res_file = [res_file '.txt'];
            my_ranks = (0:1:cm.n);
            cm.rankprob_str = [cm.rank_str num2str(my_ranks','%2.0f') cm.prependstr num2str(cm.rankprob,'%12.4f') cm.prependstr ml_str];
            cm.rankprob_str = strvcat(' ',cm.rankprob_str,' ');
            set(controls.traceresults,'String',cm.rankprob_str);
            %
            % adjust cointegration rank results control
            %
            if fileexist(res_file)==1;
               set(controls.results_rank,'Enable','on','UserData',res_file);
               if cm.save_draws>=200;
                  set(controls.marg_like_rank,'Enable','on');
               else;
                  set(controls.marg_like_rank,'Enable','off');
               end;
            else;
               set(controls.results_rank,'Enable','off','UserData','');
               set(controls.marg_like_rank,'Enable','off');
            end;
            %
            % Adjust beta results control
            %
            dfbeta = dfbeta_fcn(cm);
            res_file = [curr_ini.simulatedir cm.modelfile '-beta-gibbs-' num2str(cm.scale_endo,'%0.4f') '-' num2str(cm.r,'%0.0f') '.' num2str(dfbeta,'%0.0f') '-' cm.determodel cm.lag_model num2str(cm.burn_in,'%0.0f') '.' num2str(cm.save_draws,'%0.0f') '.' num2str(cm.save_freq,'%0.0f') '.' num2str(cm.discard_explosive,'%0.0f') '-' num2str(cm.prior_inf_shortrun,'%0.0f') '.' num2str(cm.prior_inf_deter,'%0.0f') '-' num2str(cm.prior_inf_alpha,'%0.0f') '-' num2str(cm.prior_inf_omega,'%0.0f')];
            if cm.prior_inf_omega==1;
               if cm.amat_type==1;
                  res_file = [res_file '-1'];
               else;
                  res_file = [res_file '-0.' num2str(cm.lambda_a,'%0.2f') '.' num2str(cm.q_parm,'%0.0f')];
               end;
            end;
            if cm.prior_inf_alpha==1;
               res_file = [res_file '.' num2str(cm.lambda_alpha,'%0.3f')];
            end;
            if cm.prior_inf_shortrun==1;
               res_file = [res_file '.' num2str(cm.lambda_b,'%0.3f') '.' num2str(cm.lambda_theta,'%0.3f') '.' num2str(cm.lambda_l,'%0.3f') '.' num2str(cm.lambda_e,'%0.3f')];
            end;
            if cm.prior_inf_deter==1;
               res_file = [res_file '.' num2str(cm.lambda_d,'%0.3f')];
            end;
            res_file = [res_file '.txt'];
            if fileexist(res_file)==1;
               set(controls.results_beta,'Enable','on','UserData',res_file);
            else;
               set(controls.results_beta,'Enable','off','UserData','');
            end;
            file = strrep(res_file,'.txt','.mat');
            if fileexist(file)==1;
               set(controls.betarest,'Enable','on');
            else;
               set(controls.betarest,'Enable','off','Value',0);
            end;


         else;
            %
            % check if results already exist for no cointegration sampling
            %
         end;




         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         bayesgui('setrank');
      end;
   case 'setrank';
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         cm.r = get(controls.cointrank,'Value')-1;
         %
         % Check if cointegration rank results exists. if so make graphics controls enabled
         %
         file = get(controls.results_rank,'UserData');
         enable_graphs = 'off';
         if strcmp(file,'')==0;
            file = strrep(file,'.txt','.mat');
            file = strrep(file,['rank-gibbs-' num2str(cm.scale_endo,'%0.4f')],['rank-' num2str(cm.r,'%0.0f') '-' num2str(cm.scale_endo,'%0.4f') '-gibbs']);
            if fileexist(file)==1;
               f = load(file);
               if isfield(f,'rankfilenames')==1;
                  file = strtrim(f.rankfilenames(cm.r+1,:));
                  if fileexist(file)==1;
                     enable_graphs = 'on';
                  end;
               end;
               clear('f');
            end;
         end;
         if cm.r>0;
            if cm.cointvalue==1;
               if ((cm.prior_inf_alpha==1)&(cm.prior_inf_omega==1))|(get(controls.betarest,'Value')==0);
                  set(controls.prior_eigengraph,'Enable','on');
                  set(controls.prior_hist_eigengraph,'Enable','on');
                  if cm.r<cm.n;
                     set(controls.prior_betagraph,'Enable','on');
                     set(controls.prior_hist_betagraph,'Enable','on');
                     set(controls.prior_alphagraph,'Enable','on');
                     set(controls.prior_hist_alphagraph,'Enable','on');
                  else;
                     set(controls.prior_betagraph,'Enable','off');
                     set(controls.prior_hist_betagraph,'Enable','off');
                     set(controls.prior_alphagraph,'Enable','off');
                     set(controls.prior_hist_alphagraph,'Enable','off');
                  end;
               else;
                  set(controls.prior_eigengraph,'Enable','off');
                  set(controls.prior_hist_eigengraph,'Enable','off');
               end;
            else;
               if (cm.prior_inf_shortrun==1)&(cm.prior_inf_omega==1);
                  set(controls.prior_eigengraph,'Enable','on');
                  set(controls.prior_hist_eigengraph,'Enable','on');
               else;
                  set(controls.prior_eigengraph,'Enable','off');
                  set(controls.prior_hist_eigengraph,'Enable','off');
               end;
            end;
         else;
            set(controls.prior_betagraph,'Enable','off');
            set(controls.prior_hist_betagraph,'Enable','off');
            set(controls.prior_alphagraph,'Enable','off');
            set(controls.prior_hist_alphagraph,'Enable','off');
            if (cm.prior_inf_shortrun==1)&(cm.prior_inf_omega==1);
               set(controls.prior_eigengraph,'Enable','on');
               set(controls.prior_hist_eigengraph,'Enable','on');
            else;
               set(controls.prior_eigengraph,'Enable','off');
               set(controls.prior_hist_eigengraph,'Enable','off');
            end;
         end;
         if (cm.r>0)&(cm.r<cm.n+cm.q1+cm.dcoint);
            set(controls.restrict_beta,'Enable','on');
            set(controls.restrict_beta_menu,'Enable','on');
            set(controls.open_beta_restrict,'Enable','on');
            set(controls.open_beta_restrict_menu,'Enable','on');
            set(controls.save_beta_restrict,'Enable','on');
            set(controls.save_beta_restrict_menu,'Enable','on');
            %
            % Test if H_i-modelfile.rest files exist in modelsdir
            %
            beta_enable = 'off';
            i = 1;
            while i<=cm.r;
               file = strcat(cm.modelsdir,'H_',num2str(i),'-',num2str(cm.n),'x',num2str(cm.r),'x',num2str(cm.dcoint+cm.q1),'-',cm.modelfile,'.rest');
               if fileexist(file)==1;
                  i = i+1;
               else;
                  break;
               end;
            end;
            %
            % if necessary test if normalize-modelfile.norm exists in modelsdir
            % and if so set cointbeta.estimate control to
            % being enabled
            %
            if i==cm.r+1;
               file = strcat(cm.modelsdir,'normalize-',num2str(cm.n),'x',num2str(cm.r),'x',num2str(cm.dcoint+cm.q1),'-',cm.modelfile,'.norm');
               if fileexist(file)==1;
                  file = strcat(cm.modelsdir,'H_1-',num2str(cm.n),'x',num2str(cm.r),'x',num2str(cm.dcoint+cm.q1),'-',cm.modelfile,'.rest');
                  checkH_1 = loaddata(file);
                  if size(checkH_1,1)==size(cm.rank(cm.r+1).beta,1);
                     beta_enable = 'on';
                  end;
               end;
            end;
            set(controls.beta_estimate,'Enable',beta_enable);
            set(controls.beta_estimate_menu,'Enable',beta_enable);
            %
            % Handle the betarest control if the model has already been estimated
            %
            dfbeta = dfbeta_fcn(cm);
            res_file = [curr_ini.simulatedir cm.modelfile '-beta-gibbs-' num2str(cm.scale_endo,'%0.4f') '-' num2str(cm.r,'%0.0f') '.' num2str(dfbeta,'%0.0f') '-' cm.determodel cm.lag_model num2str(cm.burn_in,'%0.0f') '.' num2str(cm.save_draws,'%0.0f') '.' num2str(cm.save_freq,'%0.0f') '.' num2str(cm.discard_explosive,'%0.0f') '-' num2str(cm.prior_inf_shortrun,'%0.0f') '.' num2str(cm.prior_inf_deter,'%0.0f') '-' num2str(cm.prior_inf_alpha,'%0.0f') '-' num2str(cm.prior_inf_omega,'%0.0f')];
            if cm.prior_inf_omega==1;
               if cm.amat_type==1;
                  res_file = [res_file '-1'];
               else;
                  res_file = [res_file '-0.' num2str(cm.lambda_a,'%0.2f') '.' num2str(cm.q_parm,'%0.0f')];
               end;
            end;
            if cm.prior_inf_alpha==1;
               res_file = [res_file '.' num2str(cm.lambda_alpha,'%0.3f')];
            end;
            if cm.prior_inf_shortrun==1;
               res_file = [res_file '.' num2str(cm.lambda_b,'%0.3f') '.' num2str(cm.lambda_theta,'%0.3f') '.' num2str(cm.lambda_l,'%0.3f') '.' num2str(cm.lambda_e,'%0.3f')];
            end;
            if cm.prior_inf_deter==1;
               res_file = [res_file '.' num2str(cm.lambda_d,'%0.3f')];
            end;
            res_file = [res_file '.txt'];
            if fileexist(res_file)==1;
               set(controls.results_beta,'Enable','on','UserData',res_file);
            else;
               set(controls.results_beta,'Enable','off','UserData','');
            end;
            file = strrep(res_file,'.txt','.mat');
            if fileexist(file)==1;
               set(controls.betarest,'Enable','on');
               set(controls.full_betagraph,'Enable','on');
               set(controls.full_hist_betagraph,'Enable','on');
               set(controls.full_alphagraph,'Enable','on');
               set(controls.full_hist_alphagraph,'Enable','on');
               set(controls.full_eigengraph,'Enable','on');
               set(controls.full_hist_eigengraph,'Enable','on');
               set(controls.cointgraphmenu,'Enable','on');
               set(controls.cointpartgraphmenu,'Enable','on');
               set(controls.part_alphagraph,'Enable','on');
               set(controls.part_hist_alphagraph,'Enable','on');
               set(controls.part_betagraph,'Enable','on');
               set(controls.part_hist_betagraph,'Enable','on');
               set(controls.marg_betagraph,'Enable','on');
               set(controls.marg_hist_betagraph,'Enable','on');
               set(controls.marg_alphagraph,'Enable','on');
               set(controls.marg_hist_alphagraph,'Enable','on');
               set(controls.part_c_psi,'Enable','on');
               set(controls.full_c_psi,'Enable','on');
               set(controls.part_c_alpha,'Enable','on');
               set(controls.full_c_alpha,'Enable','on');
               set(controls.part_c_omega,'Enable','on');
               if cm.q1+cm.q0==0;
                  set(controls.varforecast,'Enable','on');
               end;
               set(controls.full_c_omega,'Enable','on');
               if cm.d>0;
                  set(controls.full_c_delta,'Enable','on');
               end;
               if cm.p>1;
                  set(controls.full_c_gamma,'Enable','on');
               end;
               if cm.q0>0;
                  set(controls.full_c_phi,'Enable','on');
               end;
            else;
               set(controls.betarest,'Enable','off','Value',0);
               set(controls.full_betagraph,'Enable',enable_graphs);
               set(controls.full_hist_betagraph,'Enable',enable_graphs);
               set(controls.full_alphagraph,'Enable',enable_graphs);
               set(controls.full_hist_alphagraph,'Enable',enable_graphs);
               set(controls.full_eigengraph,'Enable',enable_graphs);
               set(controls.full_hist_eigengraph,'Enable',enable_graphs);
               set(controls.cointgraphmenu,'Enable',enable_graphs);
               set(controls.cointpartgraphmenu,'Enable',enable_graphs);
               set(controls.part_alphagraph,'Enable',enable_graphs);
               set(controls.part_hist_alphagraph,'Enable',enable_graphs);
               set(controls.part_betagraph,'Enable',enable_graphs);
               set(controls.part_hist_betagraph,'Enable',enable_graphs);
               set(controls.marg_betagraph,'Enable',enable_graphs);
               set(controls.marg_hist_betagraph,'Enable',enable_graphs);
               set(controls.marg_alphagraph,'Enable',enable_graphs);
               set(controls.marg_hist_alphagraph,'Enable',enable_graphs);
               set(controls.part_c_psi,'Enable',enable_graphs);
               set(controls.full_c_psi,'Enable',enable_graphs);
               set(controls.part_c_alpha,'Enable',enable_graphs);
               set(controls.full_c_alpha,'Enable',enable_graphs);
               set(controls.part_c_omega,'Enable',enable_graphs);
               if cm.q1+cm.q0==0;
                  set(controls.varforecast,'Enable',enable_graphs);
               else;
                  set(controls.varforecast,'Enable','off');
               end;
               set(controls.full_c_omega,'Enable',enable_graphs);
               if cm.d>0;
                  set(controls.full_c_delta,'Enable',enable_graphs);
               end;
               if cm.p>1;
                  set(controls.full_c_gamma,'Enable',enable_graphs);
               end;
               if cm.q0>0;
                  set(controls.full_c_phi,'Enable',enable_graphs);
               end;
            end;
         else;
            set(controls.restrict_beta,'Enable','off');
            set(controls.restrict_beta_menu,'Enable','off');
            set(controls.open_beta_restrict,'Enable','off');
            set(controls.open_beta_restrict_menu,'Enable','off');
            set(controls.save_beta_restrict,'Enable','off');
            set(controls.save_beta_restrict_menu,'Enable','off');
            set(controls.beta_estimate,'Enable','off');
            set(controls.beta_estimate_menu,'Enable','off');
            set(controls.betarest,'Enable','off','Value',0);
            set(controls.results_beta,'Enable','off');
            set(controls.full_betagraph,'Enable','off');
            set(controls.full_hist_betagraph,'Enable','off');
            set(controls.full_alphagraph,'Enable','off');
            set(controls.full_hist_alphagraph,'Enable','off');
            set(controls.full_eigengraph,'Enable',enable_graphs);
            set(controls.full_hist_eigengraph,'Enable',enable_graphs);
            set(controls.cointgraphmenu,'Enable','off');
            set(controls.cointpartgraphmenu,'Enable','off');
            set(controls.part_alphagraph,'Enable','off');
            set(controls.part_hist_alphagraph,'Enable','off');
            set(controls.part_betagraph,'Enable','off');
            set(controls.part_hist_betagraph,'Enable','off');
            set(controls.marg_betagraph,'Enable','off');
            set(controls.marg_hist_betagraph,'Enable','off');
            set(controls.marg_alphagraph,'Enable','off');
            set(controls.marg_hist_alphagraph,'Enable','off');
            set(controls.part_c_psi,'Enable','off');
            set(controls.full_c_psi,'Enable','off');
            set(controls.part_c_alpha,'Enable','off');
            set(controls.full_c_alpha,'Enable','off');
            set(controls.part_c_omega,'Enable','off');
            if cm.q1+cm.q0==0;
               set(controls.varforecast,'Enable',enable_graphs);
            else;
               set(controls.varforecast,'Enable','off');
            end;
            set(controls.full_c_omega,'Enable',enable_graphs);
            if cm.d>0;
               set(controls.full_c_delta,'Enable',enable_graphs);
            end;
            if cm.p>1;
               set(controls.full_c_gamma,'Enable',enable_graphs);
            end;
            if cm.q0>0;
               set(controls.full_c_phi,'Enable',enable_graphs);
            end;
         end;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'default_prior'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         % set default informative part of prior
         %
         cm.prior_inf_shortrun = curr_ini.prior_inf_shortrun;
         cm.prior_inf_deter = curr_ini.prior_inf_deter;
         cm.prior_inf_alpha = curr_ini.prior_inf_alpha;
         cm.prior_inf_omega = curr_ini.prior_inf_omega;
         %
         % fix the controls
         %
         if cm.cointvalue==1;
            set(controls.alphapriors,'Enable','on');
            if cm.prior_inf_alpha==1;
               set(controls.type_alpha,'Check','on','Enable','on');
            else;
               set(controls.type_alpha,'Enable','on');
            end;
         end;
         %
         if cm.prior_inf_deter==1;
            set(controls.type_deter,'Check','on','Enable','on');
            set(controls.deterpriors,'Enable','on');
         else;
            set(controls.type_deter,'Enable','on');
            set(controls.deterpriors,'Enable','off');
         end;
         if cm.prior_inf_shortrun==1;
            set(controls.type_shortrun,'Check','on','Enable','on');
            set(controls.shortrunpriors,'Enable','on');
         else;
            set(controls.type_shortrun,'Enable','on');
            set(controls.shortrunpriors,'Enable','off');
         end;
         %
         if cm.prior_inf_alpha==2;
            set(controls.alphapriors,'Enable','off');
         end;
         if cm.prior_inf_omega==1;
            set(controls.type_omega,'Check','on','Enable','on');
            set(controls.omegapriors,'Enable','on');
         else;
            set(controls.type_omega,'Enable','on');
            set(controls.omegapriors,'Enable','off');
         end;
         %
         % set default rank prior probabilities
         %
         cm.rankpriors = (1/(cm.n+1))*ones(cm.n+1,1);
         cm.r_values = 2*ones(1,cm.n+1);
         %
         % set default short-run dynamics prior hyperparameters
         %
         cm.lambda_b = curr_ini.lambda_b;
         cm.lambda_l = curr_ini.lambda_l;
         cm.lambda_theta = curr_ini.lambda_theta;
         cm.lambda_e = curr_ini.lambda_e;
         %
         % set default deterministic prior hyperparameters
         %
         cm.lambda_d = curr_ini.lambda_d;
         %
         % set default alpha prior hyperparameter
         %
         cm.lambda_alpha = curr_ini.lambda_alpha;
         %
         % set default Omega prior
         %
         cm.amat_type = curr_ini.amat_type;
         cm.lambda_a = curr_ini.lambda_a;
         cm.q_df = curr_ini.q_df;
         if cm.q_df==1;
            cm.q_parm = cm.n+2;
         else;
            q_new = round(((cm.q_df-1)/10)*cm.T);
            cm.q_parm = max(cm.n+2,q_new);
         end;
         cm.amat_lag = curr_ini.amat_lag;
         %
         % Fix prior text
         %
         if cm.prior_inf_shortrun==1;
            hyp_txt = ['\lambda_{b}=' num2str(curr_ini.lambda_b,'%0.2f') ', \lambda_{\rho}=' num2str(curr_ini.lambda_theta,'%0.3f') ', \lambda_{l}=' num2str(curr_ini.lambda_l,'%0.1f')];
            if cm.q0+cm.q1>0;
               hyp_txt = [hyp_txt ', \lambda_{e}=' num2str(curr_ini.lambda_e,'%0.3f')];
            end;
         else;
            hyp_txt = 'P(\Gamma | \Omega)_{ } = ';
            if cm.q1>0;
               hyp_txt = [hyp_txt 'P(\Psi | \Omega) = '];
            end;
            if cm.q0>0;
               hyp_txt = [hyp_txt 'P(\Phi | \Omega) = '];
            end;
            hyp_txt = [hyp_txt '1'];
         end;
         if cm.prior_inf_deter==1;
            n_hyp_txt = ['\lambda_{d}=' num2str(curr_ini.lambda_d,'%0.2f')];
         else;
            n_hyp_txt = 'P(\delta | \Omega)_{ } = 1';
         end;
         if cm.cointvalue==1;
            n_hyp_txt = [n_hyp_txt  ', \lambda_{\alpha}=' num2str(curr_ini.lambda_alpha,'%0.2f')];
            r_hyp_txt = ['P(Rank=r)=' num2str(1/(cm.n+1),'%0.3f') ' \forall r \in {0,...,' num2str(cm.n,'%0.0f') '}'];
         else;
            r_hyp_txt = '';
         end;
         if (cm.prior_inf_omega==1)&(cm.amat_type==0);
            n_hyp_txt = [n_hyp_txt ', \lambda_{A}=' num2str(cm.lambda_a,'%0.2f') ', q=' num2str(cm.q_parm,'%0.0f')];
         end;
         hyp_txt = strvcat(hyp_txt,n_hyp_txt,r_hyp_txt);
         set(controls.hyptext,'String',hyp_txt,'FontSize',9);
         %
         % recompute posterior rank probabilities for FML
         %
         sum_fml = 0;
         for i=0:cm.n;
            sum_fml = sum_fml + (cm.rank(i+1).norm_fraction_marglike*cm.rankpriors(i+1,1));
         end;
         cm.rankprob = zeros(cm.n+1,1);
         for i=0:cm.n;
            cm.rankprob(i+1,1) = (cm.rank(i+1).norm_fraction_marglike*cm.rankpriors(i+1,1))/sum_fml;
         end;
         my_ranks = (0:1:cm.n);
         if isfield(cm,'rankprob_ml')==1;
            %
            % need to make sure that ranks which have zero prior probability
            % do not results in all posterior probabilities being 0
            %
            marg_like = cm.log_marglike;
            if min(cm.rankpriors)==0;
               for i=1:cm.n+1;
                  if cm.rankpriors(i,1)==0;
                     marg_like(i,1) = min(marg_like);
                  end;
               end;
            end;
            marg_like = fix_exp(marg_like-mean(marg_like));
            cm.rankprob_ml = (1/(cm.rankpriors'*marg_like))*(marg_like .* cm.rankpriors);
            ml_str = num2str(cm.rankprob_ml,'%12.4f');
         else;
            ml_str = cm.ml_str;
         end;
         cm.rankprob_str = [cm.rank_str num2str(my_ranks','%2.0f') cm.prependstr num2str(cm.rankprob,'%12.4f') cm.prependstr ml_str];
         cm.rankprob_str = strvcat(' ',cm.rankprob_str,' ');
         set(controls.traceresults,'String',cm.rankprob_str);
         set(controls.default_prior,'Enable','off');
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         % Make sure all controls are set correctly
         %
         bayesgui('check_model');
      end;
   case 'default_mcmc'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         cm.burn_in = curr_ini.burn_in;
         cm.save_draws = curr_ini.save_draws;
         cm.save_freq = curr_ini.save_freq;
         %
         b_str = get(controls.burn_in,'String');
         for i=1:size(b_str,1);
            bs_val = mystr2num(strtrim(strrep(b_str(i,:),',','')));
            if bs_val==curr_ini.burn_in;
               b_val = i;
               break;
            end;
         end;
         set(controls.burn_in,'Value',b_val);
         %
         s_str = get(controls.save_draws,'String');
         for i=1:size(s_str,1);
            ss_val = mystr2num(strtrim(strrep(s_str(i,:),',','')));
            if ss_val==curr_ini.save_draws;
               s_val = i;
               break;
            end;
         end;
         set(controls.save_draws,'Value',s_val);
         %
         set(controls.save_freq,'Value',curr_ini.save_freq);
         %
         set(controls.default_mcmc,'Enable','off');
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         % Make sure all controls are set correctly
         %
         bayesgui('check_model');
      end;
   case 'save_freq'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         save_freq = get(controls.save_freq,'Value');
         if abs(save_freq-cm.save_freq)>0;
            cm.save_freq = save_freq;
            set(controls.default_mcmc,'Enable','on');
         end;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         % Make sure all controls are set correctly
         %
         bayesgui('check_model');
      end;
   case 'save_draws'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         save_draws_val = get(controls.save_draws,'Value');
         save_draws_str = get(controls.save_draws,'String');
         save_draws = mystr2num(strtrim(save_draws_str(save_draws_val,:)));
         if abs(save_draws-cm.save_draws)>0;
            cm.save_draws = save_draws;
            set(controls.default_mcmc,'Enable','on');
         end;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         % Make sure all controls are set correctly
         %
         bayesgui('check_model');
      end;
   case 'burn_in'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         burn_in_val = get(controls.burn_in,'Value');
         burn_in_str = get(controls.burn_in,'String');
         burn_in = mystr2num(strtrim(burn_in_str(burn_in_val,:)));
         if abs(burn_in-cm.burn_in)>0;
            cm.burn_in = burn_in;
            set(controls.default_mcmc,'Enable','on');
         end;
         %
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         %
         % Make sure all controls are set correctly
         %
         bayesgui('check_model');
      end;
   case 'prior_draws'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         cm.prior_draws = get(gcbo,'UserData');
         %
         if cm.prior_draws==100;
            pd_val = 1;
         elseif cm.prior_draws==500;
            pd_val = 2;
         elseif cm.prior_draws==1000;
            pd_val = 3;
         elseif cm.prior_draws==5000;
            pd_val = 4;
         elseif cm.prior_draws==10000;
            pd_val = 5;
         elseif cm.prior_draws==50000;
            pd_val = 6;
         else;
            pd_val = 7;
         end;
         for i=1:7;
            set(getfield(controls,['prior_draws_' num2str(i,'%0.0f')]),'Check','off');
         end;
         set(gcbo,'Check','on');
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'modelinfo'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         set(bayesdlg,'Visible','off');
         drawnow;
         if (cm.amat_type==1)&(cm.amat_lag>1);
            [cm.amat_val,cm.use_lag] = ml_omega(cm);
         end;
         %
         textvars = strvcat(cm.textvars,['Value of log-likelihood:     ' num2str(loglike(cm.rank(get(controls.cointrank,'Value')).epsilon),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])]);
         if cm.cointvalue==1;
            textvars = strvcat(textvars,['                             (for cointegration rank ' num2str(get(controls.cointrank,'Value')-1) ')']);
         end;
         textvars = strvcat(textvars,' ','HYPERPARAMETERS FOR PRIOR DISTRIBUTIONS','=======================================',' ');
         textvars = strvcat(textvars,['Baseline shrinkage:                      ' num2str(cm.lambda_b,'%0.4f')]);
         textvars = strvcat(textvars,['Lag length shrinkage:                    ' num2str(cm.lambda_l,'%0.4f')]);
         textvars = strvcat(textvars,['Off-diagonal/correlation shrinkage:      ' num2str(cm.lambda_theta,'%0.4f')]);
         if cm.q1+cm.q0>0;
            textvars = strvcat(textvars,['Exogeneity shrinkage:                    ' num2str(cm.lambda_e,'%0.4f')]);
         end;
         textvars = strvcat(textvars,['Deterministic shrinkage:                 ' num2str(cm.lambda_d,'%0.4f')]);
         if cm.cointvalue==1;
            textvars = strvcat(textvars,['Alpha shrinkage:                         ' num2str(cm.lambda_alpha,'%0.4f')]);
         end;
         if cm.amat_type==1;
            textvars = strvcat(textvars,'Omega prior type:                        ML estimate of Omega for full rank model');
            if (cm.amat_type==1)&(cm.amat_lag>1);
               textvars = strvcat(textvars,['                                         with ' num2str(cm.use_lag,'%0.0f') ' lags as A matrix']);
               Omega = cm.amat_val;
            else;
               textvars = strvcat(textvars,['                                         with ' num2str(cm.p,'%0.0f') ' lags as A matrix']);
               Omega = cm.rank(cm.n+1).Omega;
            end;
            textvars = strvcat(textvars,' ');
            textvars = strvcat(textvars,'A matrix:',' ');
            for i=1:cm.n;
               textvars = strvcat(textvars,[cm.myvars(i,:) '  ' num2str(Omega(i,:),'%12.6f')]);
            end;
            textvars = strvcat(textvars,' ');
            textvars = strvcat(textvars,['q parameter:                             ' num2str(cm.n+2,'%0.0f') ' degrees of freedom']);
         else;
            textvars = strvcat(textvars,'Omega prior type:                        A matrix shrinkage times identity');
            textvars = strvcat(textvars,['A matrix shrinkage:                      ' num2str(cm.lambda_a,'%0.4f')]);
            q_df = cm.n+2;
            if cm.q_df>=2;
               new_df = round(((cm.q_df-1)/10)*cm.T);
               q_df = max(q_df,new_df);
            end;
            textvars = strvcat(textvars,['q parameter:                             ' num2str(q_df,'%0.0f') ' degrees of freedom']);
         end;
         if cm.cointvalue==1;
            for i=0:cm.n;
               textvars = strvcat(textvars,['P(Rank=' num2str(i,'%0.0f') '):                               ' num2str(cm.rankpriors(i+1,1),'%0.4f')]);
            end;
         end;
         %
         textgui(strvcat(' ',textvars,' '),'Model Information',[(realscrsz(3)-720)/2 (realscrsz(4)-450)/2 720 450],'Results',38);
         drawnow;
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         set(bayesdlg,'Visible','on');
         drawnow;
      end;
   case 'quit'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         if curr_ini.sillyq==0;
            txt = ['Are you sure you want to quit the Bayesian analysis?'];
            answer = query(txt,'question',120,'Bayesian Analysis',350);
         else;
            answer = 'Yes';
         end;
         if strcmp(answer,'Yes');
            set(controls.quit,'UserData','done');
            set(bayesdlg,'UserData',controls);
         end;
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
   case 'rank_results'
      if cm.running==0;
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         res_file = get(controls.results_rank,'UserData');
         if fileexist(res_file)==1;
            textgui(res_file,'Bayesian Cointegration Analysis - Rank',[(realscrsz(3)-770)/2 (realscrsz(4)-500)/2 770 500],'Results',38);
         else;
            txt = 'Unable to locate the text file containing a summary of the results.';
            about(txt,'information','Lost File...',120,350);
            set(controls.results_rank,'Enable','off','UserData','');
            set(controls.marg_like_rank,'Enable','off');
         end;
         %
         set(bayesdlg,'Visible','on');
         drawnow;
      end;
   case 'beta_results'
      if cm.running==0;
         set(bayesdlg,'Visible','off');
         drawnow;
         %
         res_file = get(controls.results_beta,'UserData');
         if fileexist(res_file)==1;
            textgui(res_file,'Bayesian Cointegration Analysis - Beta',[(realscrsz(3)-770)/2 (realscrsz(4)-500)/2 770 500],'Results',38);
         else;
            txt = 'Unable to locate the text file containing a summary of the results.';
            about(txt,'information','Lost File...',120,350);
            set(controls.results_beta,'Enable','off','UserData','');
         end;
         %
         set(bayesdlg,'Visible','on');
         drawnow;
      end;
   case 'viewdata'
      if cm.running==0;
         cm.running = 1;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
         if matlabnumber>=6.0;
            myfile = {'*.txt;*.data;*.wk1;*.xls;*.mat;*.csv', 'Data Files (*.txt, *.data, *.wk1, *.xls, *.mat, *.csv)'; ...
                    '*.txt;*.data', 'Text Files (*.txt, *.data)'; ...
                    '*.mat', 'MatLab MAT Files (*.mat)'; ...
                    '*.wk1', 'Lotus 1-2-3 Spreadsheets (*.wk1)'; ...
                    '*.xls', 'Excel Spreadsheets (*.xls)'; ...
                    '*.csv', 'Comma Separated Value Files (*.csv)'; ...
                    '*.*', 'All Files (*.*)'};
         else;
            if (iscompiled==1)&(iswinnt==1)&(curr_ini.opendialog==1);
               fix_fig = findobj('Tag','StructuralVAR');
               model = get(fix_fig,'UserData');
               afile = get(model.endogenous,'String');
               basedir = getpath(strtrim(afile));
               file_fltr = 'Data Files (*.txt, *.data, *.wk1, *.mat, *.csv)|*.txt;*.data;*.wk1;*.mat;*.csv|Text Files (*.txt, *.data)|*.txt;*.data|MatLab MAT Files (*.mat)|*.mat|Lotus 1-2-3 Spreadsheets (*.wk1)|*.wk1|Comma Separated Value Files (*.csv)|*.csv|All Files (*.*)|*.*|';
               best_pos = 1;
               title_txt = 'Open';
            else;
               fix_fig = findobj('Tag','StructuralVAR');
               model = get(fix_fig,'UserData');
               afile = get(model.endogenous,'String');
               afile = strtrim(afile);
               if fileexist(afile)==1;
                  adir = getpath(afile);
                  if ispc==1;
                     if strcmp(adir(1,size(adir,2)),'\')==0;
                        adir = [adir '\'];
                     end;
                  else;
                     if strcmp(adir(1,size(adir,2)),'/')==0;
                        adir = [adir '/'];
                     end;
                  end;
               else;
                  adir = cm.outputdir;
               end;
               myfile = [adir '*.txt;*.data;*.wk1;*.mat;*.csv'];
            end;
         end;
         if (iscompiled==1)&(iswinnt==1)&(curr_ini.opendialog==1)&(matlabnumber<6.0);
            [openfile,openpath] = fileopen(basedir,file_fltr,best_pos,title_txt);
         else;
            if matlabnumber>=6;
               [openfile,openpath] = uigetfile(myfile,'Open',getpath(cm.endofile));
            else;
               [openfile,openpath] = uigetfile(myfile,'Open');
            end;
         end;
         drawnow;
         if isnumeric(openfile)==0;
            openfile = strcat(openpath,openfile);
            set(bayesdlg,'Visible','off');
            drawnow;
            textgui(openfile,['View Data - ' openfile],[(realscrsz(3)-(realscrsz(4)-80))/2 1 realscrsz(4)-80 realscrsz(4)-54],'Data',25);
            set(bayesdlg,'Visible','on');
            drawnow;
         end;
         cm.running = 0;
         curr_ini.model = cm;
         set(controls.viewdata,'UserData',curr_ini);
      end;
end;

if strcmp(selector,'init')==1;
   if strcmp(cm.deterdel,'')==0;
      deterdelinfo = ['Due to linear dependence, the following deterministic variables were deleted: ' cm.deterdel '.'];
      set(controls.traceresults,'TooltipString',deterdelinfo);
   end;
   set(bayesdlg,'Visible','on');
end;

if nargout==1;
   h = bayesdlg;
end;

curr_ini.images = button_images;
curr_ini.model = cm;
set(controls.viewdata,'UserData',curr_ini);

if thisexit==0;
   controls = get(bayesdlg,'UserData');
   waitfor(controls.quit,'UserData','done');
end;

%
% end of bayesgui.m
%
