%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for bootstrapping specification     %
%          tests, weak exogeneity and Granger causality tests    %
%                                                                %
%          Function: specification_bootstrap                     %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       cm: structure with model info            %
%                                                                %
%          Output:                                               %
%                                                                %
%          This version:        July 5, 2006                     %
%          Written by:          Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function specification_bootstrap(varargin)

%
% GUI for bootstrapping the test distributions
%

selector = varargin{1};
if (nargin==0)|(strcmp(selector,'init')==1);
   tm = varargin{2};
   %
   % toolbar images
   %
   button_images = read_images;
   %
   % more initialization
   %
   selector = 'init';
   my_exit = 1;
   tm.const_model = [0 0 0 0 0];
   if tm.deterselect(1)==1;
      tm.const_model(3) = 1;
   elseif tm.deterselect(2)==1
      tm.const_model(2) = 1;
   elseif tm.deterselect(3)==1;
      tm.const_model(5) = 1;
   else;
      tm.const_model(4) = 1;
   end;
   selector = 'init';
   if nargin>2;
      my_r_enable = 'off';
   else;
      my_r_enable = 'on';
   end;
   %
   % Set screen size directly instead of using
   % get(0,'ScreenSize')!
   %
   tm.realscrsz = get(0,'ScreenSize');
   tm.specification_run = 0;
   %
   % read var.in
   %
   curr_ini = find_inisettings;
   my_T = tm.T;
   rep = curr_ini.nRep;
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   nRep_value = 1;
   for i=1:size(repvalues,2);
      if curr_ini.nRep==repvalues(1,i);
         nRep_value = i;
         break;
      end;
   end;
   if direxist(curr_ini.simulatedir)==0;
      mystatus = makedirs(curr_ini.simulatedir);
   else;
      mystatus = 2;
   end;
   if mystatus==0;
      curr_ini.simulatedir = pwd;
      if ispc==1;
         curr_ini.simulatedir = [curr_ini.simulatedir '\'];
      end;
   end;
   if isnumeric(curr_ini.external)==0;
      curr_ini.external = 0;
   end;
   if isfield(tm,'restrict')==1;
      if tm.restrict(1,1)==1;
         tm.resalpha = 'alpha-';
      else;
         tm.resalpha = '';
      end;
      if tm.restrict(1,2)==1;
         tm.resbeta = 'beta-';
      else;
         tm.resbeta = '';
      end;
   else;
      tm.resalpha = '';
      tm.resbeta = '';
   end;
   %
   if curr_ini.sscorrect==1;
      tm.testtype = 'f-';
   else;
      tm.testtype = '';
   end;
   if curr_ini.parametric==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(curr_ini.blocksize) '-'];
   end;
   %
   full_mat = '';
   if tm.const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-specification-boot-full-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
   elseif tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-specification-boot-full-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-specification-boot-full-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-specification-boot-full-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-specification-boot-full-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
      view_enable = 'on';
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      specification_mat = load(full_mat);
      specification_results = specification_mat.specification_sorted;
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
   else;
      view_enable = 'off';
      specification_results = [];
      full_mat = '';
      full_enable = 'off';
   end;
   summary_txt = '';
   if tm.const_model(1)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-specification-boot-summary-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
      mod_type = 'noconst';
      model_type = 'No Constant';
   elseif tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-specification-boot-summary-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
      mod_type = 'resconst';
      model_type = 'Restricted Constant';
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-specification-boot-summary-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
      mod_type = 'const';
      model_type = 'Constant';
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-specification-boot-summary-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
      mod_type = 'restrend';
      model_type = 'Restricted Linear Trend';
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-specification-boot-summary-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
      mod_type = 'trend';
      model_type = 'Linear Trend';
   end;
%   if curr_ini.texoutputformat>=2;
%      summary_txt = strrep(summary_txt,'.txt','.ltx');
%   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
   end;
   %
   % check if file with bootstrapped residuals exists
   %
   epsfile = [curr_ini.simulatedir tm.modelfile '-' 'specification-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
   testfile = strrep(epsfile,'.mat',['-specification-data.mat']);
   if fileexist(epsfile)==1;
      boot_enable = 'on';;
   else;
      epsfile = '';
      testfile = '';
      boot_enable = 'off';
   end;
   %
   tm.interpolate = curr_ini.interpolate;
   if strcmp(tm.interpolate,'nearest')==1;
      tm.interpolate_value = 1;
   elseif strcmp(tm.interpolate,'linear')==1;
      tm.interpolate_value = 2;
   elseif strcmp(tm.interpolate,'spline')==1;
      tm.interpolate_value = 3;
   elseif strcmp(tm.interpolate,'cubic')==1;
      tm.interpolate_value = 4;
   elseif strcmp(tm.interpolate,'knorm')==1;
      tm.interpolate_value = 5;
   elseif strcmp(tm.interpolate,'kepan')==1;
      tm.interpolate_value = 6;
   elseif strcmp(tm.interpolate,'krect')==1;
      tm.interpolate_value = 7;
   elseif strcmp(tm.interpolate,'ktria')==1;
      tm.interpolate_value = 8;
   elseif strcmp(tm.interpolate,'kbiwe')==1;
      tm.interpolate_value = 9;
   elseif strcmp(tm.interpolate,'ktriw')==1;
      tm.interpolate_value = 10;
   elseif strcmp(tm.interpolate,'klapl')==1;
      tm.interpolate_value = 11;
   elseif strcmp(tm.interpolate,'klogi')==1;
      tm.interpolate_value = 12;
   end;
else;
   my_exit = 0;
   specification_boot_gui = findobj('Type','figure','Tag','SpecificationBoot')';
   boot_specification = get(specification_boot_gui,'UserData');
   curr_ini = get(boot_specification.matfilebutton,'UserData');
   tm = curr_ini.models;
   button_images = curr_ini.images;
end;

switch selector
case 'init'
   specification_boot_gui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','specification_bootstrap.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(tm.realscrsz(3)-729)/2 (tm.realscrsz(4)-405)/2 729 405], ...
         'Tag','SpecificationBoot', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name','Bootstrap Distributions for Specification Tests', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','specification_bootstrap done', ...
         'ToolBar','none');

   if matlabnumber>=7.0;
      set(specification_boot_gui,'DockControl','off');
   end;

   if strcmp(curr_ini.helpexe,'')==1;
      helpenable = 'off';
   else;
      helpenable = 'on';
   end;

   %
   % File menu
   %

   filemenu = uimenu('Parent',specification_boot_gui, ...
      'Label','&File', ...
      'Tag','FileMenu');

   boot_specification.simulatemenu = uimenu('Parent',filemenu, ...
         'Label','&Run Bootstrap', ...
         'Callback','specification_bootstrap simulate', ...
         'Enable','on', ...
         'Accelerator','R', ...
         'Tag','SimulateMenu');

   boot_specification.matfilemenu = uimenu('Parent',filemenu, ...
         'Label','Save to m&at-file', ...
         'Separator','on', ...
         'Accelerator','A', ...
         'Enable',full_enable, ...
         'Callback','specification_bootstrap matfile', ...
         'Tag','MatFileMenu');

   boot_specification.summarymenu = uimenu('Parent',filemenu, ...
         'Label','&Simulation Summary', ...
         'Separator','on', ...
         'Callback','specification_bootstrap summary', ...
         'UserData',summary_txt, ...
         'Accelerator','S', ...
         'Enable',summary_enable, ...
         'Tag','SummaryMenu');

   boot_specification.fullmenu = uimenu('Parent',filemenu, ...
         'Label','&Full Simulation', ...
         'Callback','specification_bootstrap full', ...
         'Accelerator','F', ...
         'UserData',full_mat, ...
         'Enable',full_enable, ...
         'Tag','FullMenu');

   if curr_ini.noprint==0;
      boot_specification.output = uimenu('Parent',filemenu, ...
            'Label','Append to &Output', ...
            'Separator','on', ...
            'Callback','specification_bootstrap output', ...
            'Accelerator','O', ...
            'Enable',summary_enable, ...
            'Tag','SummaryMenu');
   end;

   uimenu('Parent',filemenu, ...
         'Label','Center &Window', ...
         'Separator','on', ...
         'Accelerator','W', ...
         'Enable','on', ...
         'Callback','center_figure_fcn', ...
         'Tag','CenterMenu');

   boot_specification.returnmenu = uimenu('Parent',filemenu, ...
         'Label','R&eturn', ...
         'Separator','on', ...
         'Callback','specification_bootstrap done', ...
         'Enable','on', ...
         'Tag','MenuFileReturn');

   boot_specification.filemenu = filemenu;

   %
   % Graph Menu
   %

   graphmenu = uimenu('Parent',specification_boot_gui, ...
      'Label','&Graphics', ...
      'Tag','GraphMenu');

   boot_specification.bootstrapgraphmenu = uimenu('Parent',graphmenu, ...
         'Label','Graph &Bootstrap Sample', ...
         'Callback','specification_bootstrap display_bootstrap', ...
         'Accelerator','B', ...
         'UserData',testfile, ...
         'Enable',boot_enable, ...
         'Tag','BootstrapGraphMenu');

   boot_specification.displaymenu = uimenu('Parent',graphmenu, ...
         'Label','&Graph Distribution', ...
         'Callback','specification_bootstrap display', ...
         'Separator','on', ...
         'Accelerator','G', ...
         'UserData',tm.const_model, ...
         'Enable',view_enable, ...
         'Tag','DisplayMenu');

   boot_specification.histogrammenu = uimenu('Parent',graphmenu, ...
         'Label','&Histogram of Distribution', ...
         'Callback','specification_bootstrap display', ...
         'Accelerator','D', ...
         'Enable',view_enable, ...
         'Tag','HistogramMenu');

   %
   % Help Menu
   %

   helpmenu = uimenu('Parent',specification_boot_gui, ...
      'Label','&Help', ...
      'Tag','HelpMenu');

   boot_specification.helpmenu = uimenu('Parent',helpmenu, ...
         'Label','&Help Topics', ...
         'Callback','help_fcn(''bootstrapping'')', ...
         'Accelerator','H', ...
         'Enable',helpenable, ...
         'Tag','HelpMenu');

   %
   % The toolbar
   %

   boot_specification.toolbar = uitoolbar('Parent',specification_boot_gui, ...
                     'HandleVisibility','off', ...
                     'Interruptible','on', ...
                     'Clipping','on');

   if (iswinxp==0)|(matlabnumber<7);
      xline([1 404 729],[0.5 1]);
   end;

   boot_specification.simulate = uipushtool('Parent',boot_specification.toolbar, ...
                      'TooltipString','Run Bootstrap', ...
                      'CData',button_images.simulate, ...
                      'ClickedCallback','specification_bootstrap simulate', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable','on', ...
                      'UserData',0, ...
                      'Tag','Simulate');


   boot_specification.matfilebutton = uipushtool('Parent',boot_specification.toolbar, ...
                      'TooltipString','Save to mat-file', ...
                      'CData',button_images.matfile, ...
                      'ClickedCallback','specification_bootstrap matfile', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','MatFileButton');

   boot_specification.summary = uipushtool('Parent',boot_specification.toolbar, ...
                      'TooltipString','View Simulation Summary', ...
                      'CData',button_images.sim_summary, ...
                      'ClickedCallback','specification_bootstrap summary', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',summary_enable, ...
                      'Tag','SummaryButton');

   boot_specification.full = uipushtool('Parent',boot_specification.toolbar, ...
                      'TooltipString','View Full Simulation', ...
                      'CData',button_images.sim_full, ...
                      'ClickedCallback','specification_bootstrap full', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','FullButton');

   boot_specification.bootstrapgraph = uipushtool('Parent',boot_specification.toolbar, ...
                      'TooltipString','Graph Bootstrap Sample', ...
                      'CData',button_images.bootstrapsmall, ...
                      'ClickedCallback','specification_bootstrap display_bootstrap', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',epsfile, ...
                      'Clipping','on', ...
                      'Enable',boot_enable, ...
                      'Tag','ViewBootstrapButton');

   boot_specification.display = uipushtool('Parent',boot_specification.toolbar, ...
                      'TooltipString','Graph Distribution', ...
                      'CData',button_images.viewdist, ...
                      'ClickedCallback','specification_bootstrap display', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',specification_results, ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','ViewDistButton');

   boot_specification.histogram = uipushtool('Parent',boot_specification.toolbar, ...
                      'TooltipString','Histogram of Distribution', ...
                      'CData',button_images.bars, ...
                      'ClickedCallback','specification_bootstrap display', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','HistogramButton');

   boot_specification.help = uipushtool('Parent',boot_specification.toolbar, ...
                      'TooltipString','Help Topics', ...
                      'CData',button_images.help, ...
                      'ClickedCallback','help_fcn(''bootstrapping'')', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',helpenable, ...
                      'Tag','HelpButton');

   boot_specification.done = uipushtool('Parent',boot_specification.toolbar, ...
                      'TooltipString','Return', ...
                      'CData',button_images.continue, ...
                      'ClickedCallback','specification_bootstrap done', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'UserData','waiting', ...
                      'Enable','on', ...
                      'Tag','Done');

   axesbox([2 2 727 390],'Specification Tests',90,[0.5 1]);

   %
   % GUI Header
   %

   header_txt = ['Bootstrap Specification Tests (' model_type ')'];
   desc_txt = 'Select specification tests, the type of bootstrap you wish to perform, the number of observations and replications. Press the "Run Bootstrap" button when you''re satisfied with your choices and wait for the computations to finish.';
   dialog_header_fcn([16 306 699 70],button_images.bootstrap,header_txt,desc_txt);

   %
   % Options
   %

   axesbox([185 130 155 160],'Options',35,[0.5 1]);

   boot_specification.clock = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[201 255 130 20], ...
      'Value',1, ...
      'String','Show elapsed time', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','TimeCheck');

   boot_specification.progress = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[201 235 130 20], ...
      'Value',1, ...
      'String','Show progress dialog', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ProgressCheck');

   boot_specification.save = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[201 215 130 20], ...
      'Value',1, ...
      'String','Save full simulation', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','SaveCheck');

   boot_specification.parametric = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[201 195 130 20], ...
      'Value',curr_ini.parametric, ...
      'String','Parametric bootstrap', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'Callback','specification_bootstrap fixobscontrol', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ParametricCheck');


   boot_specification.blocktext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[216 165 100 20], ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Style','text', ...
      'HorizontalAlignment','left', ...
      'String','Block size:', ...
      'Enable','off', ...
      'Tag','BlockText');

   boot_specification.block = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[276 170 50 20], ...
      'Value',1, ...
      'String','1|2|3|4|5|6|7|8|9|10|11|12', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Value',curr_ini.blocksize, ...
      'Enable','off', ...
      'Callback','specification_bootstrap check', ...
      'Tag','BlockPopup');
   
   if curr_ini.parametric==0;
      set(boot_specification.blocktext,'Enable','on');
      set(boot_specification.block,'Enable','on');
   end;


   boot_specification.bootstrap = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[201 145 130 20], ...
      'Value',curr_ini.reuse_bootstrap, ...
      'String','Reuse/save residuals', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ReuseBootstrapCheck');

   %
   % selected tests
   %

   axesbox([16 16 155 274],'Tests',25,[0.5 1]);

   boot_specification.serial = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 254 130 20], ...
      'Value',tm.spectest(1,1), ...
      'String','Serial correlation', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'Callback','specification_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','SerialCorrelationCheck');

   boot_specification.portmanteau = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[50 226 100 20], ...
      'Value',min(curr_ini.portmanteau,tm.spectest(1,1)), ...
      'String','Ljung-Box', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'Callback','specification_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','LjungBoxCheck');

   boot_specification.arch = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 198 130 20], ...
      'Value',tm.spectest(1,2), ...
      'String','Univariate ARCH', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'Callback','specification_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ARCHCheck');

   boot_specification.march = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[50 170 120 20], ...
      'Value',tm.spectest(1,2), ...
      'String','Multivariate ARCH', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'Callback','specification_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','MARCHCheck');

   boot_specification.normality = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 142 130 20], ...
      'Value',tm.spectest(1,3), ...
      'String','Normality', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'Callback','specification_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','NormalityCheck');

   boot_specification.omnibus = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[50 114 100 20], ...
      'Value',min(curr_ini.omnibus,tm.spectest(1,3)), ...
      'String','Omnibus', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'Callback','specification_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','OmnibusCheck');

   boot_specification.lagorder = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 86 130 20], ...
      'Value',0, ...
      'String','Lag order', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'Callback','specification_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','LagOrderCheck');

   if curr_ini.lagtest==0;
      set(boot_specification.lagorder,'Enable','off');
   end;

   boot_specification.weakexo = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 58 130 20], ...
      'Value',0, ...
      'String','Weak exogeneity', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'Callback','specification_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','WeakExogeneityCheck');

   if (tm.r==tm.n)|(tm.r==0);
      set(boot_specification.weakexo,'Enable','off','Value',0);
   end;

   boot_specification.gctest = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 30 130 20], ...
      'Value',0, ...
      'String','Granger causality', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'Callback','specification_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','GrangerCausalityCheck');

   if tm.n==1;
      set(boot_specification.gctest,'Enable','off','Value',0);
   end;

   svarguidlg = findobj('Type','figure','Tag','SVARGUI')';
   if isempty(svarguidlg)==0;
      svar = get(svarguidlg,'UserData');
      if strcmp(get(svar.struc_undo,'Enable'),'on')==1;
         set(boot_specification.weakexo,'Enable','off');
         set(boot_specification.gctest,'Enable','off');
      end;
   end;

   if max(tm.spectest(1,1:3))==0;
      set(boot_specification.simulate,'Enable','off');
      set(boot_specification.simulatemenu,'Enable','off');
   end;

   axesbox([354 130 361 160],'Parameters',55,[0.5 1]);

   %
   % number of observations per replication
   %

   boot_specification.obstext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[368 249 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'HorizontalAlignment','left', ...
      'String','Number of observations:', ...
      'Tag','ObsText');

   boot_specification.obs = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[531 254 168 20], ...
      'Value',1, ...
      'String',[num2str(my_T) '|100|200|300|400|500|600|700|800|900|1000|1100|1200|1300|1400|1500|1600|1700|1800|1900|2000|2500|3000|4000|5000|6000|7000|8000|9000|10000'], ...
      'Style','popupmenu', ...
      'UserData',my_T, ...
      'Callback','specification_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','ObsPopup');

   if (tm.q1+tm.q0==0)&(isempty(tm.deterfile)==1);
      set(boot_specification.obstext,'Enable','on');
      set(boot_specification.obs,'Enable','on');
   end;

   %
   % number of replications
   %


   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[368 196.5 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of replications:', ...
      'Tag','SimulText');

   boot_specification.rep = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[531 201.5 168 20], ...
      'Value',nRep_value, ...
      'String','99|999|1,999|2,999|3,999|4,999|9,999|19,999|29,999|39,999|49,999|99,999|199,999|299,999|399,999|499,999|999,999', ...
      'Style','popupmenu', ...
      'Callback','specification_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'UserData',rep,...
      'Enable','on', ...
      'Tag','SimulPopup');

   %
   % number of cointegration relations
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[368 144 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable',my_r_enable, ...
      'HorizontalAlignment','left', ...
      'String','Number of cointegration relations:', ...
      'Tag','CointText');

   r_str = '0';
   for i=1:tm.n;
      r_str = [r_str '|' num2str(i)];
   end;

   boot_specification.my_r = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[531 149 168 20], ...
      'Value',tm.r+1, ...
      'String',r_str, ...
      'Style','popupmenu', ...
      'UserData',tm.r, ...
      'Callback','specification_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable',my_r_enable, ...
      'Tag','CointPopup');

   %
   % Select interpolation function
   %

   axesbox([185 16 530 100],'Graphics',45,[0.5 1]);

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[368 74 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Interpolation function:', ...
      'Tag','InterpolateText');

   boot_specification.interpolate = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[531 79 168 20], ...
      'Value',tm.interpolate_value, ...
      'String','Nearest neighborhood|Linear|Cubic spline|Cubic|Kernel density normal|Kernel density Epanechnikov|Kernel density rectangular|Kernel density triangular|Kernel density biweight|Kernel density triweight|Kernel density Laplace|Kernel density logistic', ...
      'Callback','specification_bootstrap interpolate', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','InterpolatePopup');

   %
   % Number of cells for graphing density functions
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[368 29 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of cells for histograms:', ...
      'Tag','CellText');

   boot_specification.cells = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[531 34 168 20], ...
      'Value',1, ...
      'String','20|25|30|35|40|45|50|55|60|65|70|75|80|85|90|95|100', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','CellPopup');

   boot_specification.cdf = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[201 85 140 20], ...
      'Value',0, ...
      'String','Cumulative distribution', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','cdfCheckbox');

   boot_specification.adaptive = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[201 65 140 20], ...
      'Value',0, ...
      'String','Adaptive KDE method', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','adaptiveCheckbox');

   boot_specification.bart = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[201 45 140 20], ...
      'Value',0, ...
      'String','Bartlett corr. bootstrap', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','BartlettCheckbox');

   boot_specification.pqplot = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[201 25 140 20], ...
      'Value',0, ...
      'String','P-value plots, etc.', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','PQPlotCheckbox');

   if tm.interpolate_value>=5;
      set(boot_specification.adaptive,'Enable','on');
   end;

   set(specification_boot_gui,'UserData',boot_specification,...
         'HandleVisibility','callback');

case 'output'
   if curr_ini.texoutputformat>=2;
      file = strrep(lower(get(boot_specification.summarymenu,'UserData')),'.txt','.ltx');
      txt_str = readtext(file);
      fout = fopen(tm.outputfile,'at');
      fprintf(fout,'\\subsection*{Bootstrap Simulation of Specification Tests} \n\n');
      for i=1:size(txt_str,2);
         fprintf(fout,'%s\n',txt_str{i});
      end;
      fclose(fout);
   else;
      txt_str = readtext(lower(get(boot_specification.summarymenu,'UserData')));
      fout = fopen(tm.outputfile,'at');
      fprintf(fout,'                      Bootstrap Simulation of Specification Tests\n                      -------------------------------------------\n');
      for i=5:size(txt_str,2)-4;
         fprintf(fout,'%s\n',txt_str{i});
      end;
      fprintf(fout,'\n===============================================================================\n\n');
      fclose(fout);
   end;
case 'display_bootstrap'
   epsfile = get(boot_specification.bootstrapgraph,'UserData');
   testfile = get(boot_specification.bootstrapgraphmenu,'UserData');
   my_r = get(boot_specification.my_r,'UserData');
   my_T = get(boot_specification.obs,'UserData');
   rep = get(boot_specification.rep,'UserData');
   if rep<4999;
      answer = 'Yes';
   else;
      check_txt = ['Your bootstrap setup includes ' num2str(rep) ' draws of the residuals. With ' num2str(tm.n) ' series and ' num2str(my_T) ' observations, this yields ' num2str(rep*tm.n*my_T) ' observations. Are you sure you want to load that much data into memory?'];
      answer = query(check_txt,'warning',120,'Exit',500,'no');
   end;
   if strcmp(answer,'Yes')==1;
      txt_str = '';
      %
      if strcmp(get(boot_specification.my_r,'Enable'),'on')==1;
         mybeta = tm.beta(:,1:my_r);
      else;
         mybeta = tm.beta;
      end;
      set(specification_boot_gui,'Visible','off');
      drawnow;
      thisgraph = bootgraphdlg('init',tm,epsfile,testfile,txt_str,mybeta,rep,my_T,my_r);
      bootgraph = get(thisgraph,'UserData');
      set(bootgraph.show,'UserData','done');
      killguipid(thisgraph);
      set(specification_boot_gui,'Visible','on');
      drawnow;
   end;
case 'fixobscontrol'
   if get(boot_specification.parametric,'Value')==0;
      T_str = get(boot_specification.obs,'String');
      my_T = mystr2num(strtrim(T_str(get(boot_specification.obs,'Value'),:)));
      set(boot_specification.obs,'Value',1,'UserData',my_T,'Enable','off');
      set(boot_specification.obstext,'Enable','off');
   elseif (tm.q1+tm.q0==0)&(isempty(tm.deterfile)==1);
      set(boot_specification.obs,'Enable','on');
      set(boot_specification.obstext,'Enable','on');
   end;
   specification_bootstrap('check');
case 'interpolate'
   tm.interpolate_value = get(boot_specification.interpolate,'Value');
   interpol_vec = strvcat('nearest','linear','spline','cubic','knorm','kepan','krect','ktria','kbiwe','ktriw','klapl','klogi');
   tm.interpolate = strtrim(interpol_vec(tm.interpolate_value,:));
   if tm.interpolate_value>=5;
      set(boot_specification.adaptive,'Enable','on');
   else;
      set(boot_specification.adaptive,'Enable','off','Value',0);
   end;
case 'matfile'
   specification_sorted = get(boot_specification.display,'UserData');
   rep = get(boot_specification.rep,'UserData');
   my_r = get(boot_specification.my_r,'UserData');
   my_T = get(boot_specification.obs,'UserData');
   my_const_model = get(boot_specification.displaymenu,'UserData');
   if get(boot_specification.parametric,'Value')==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(get(boot_specification.block,'Value')) '-'];
   end;
   if my_const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-specification-boot-full-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
   elseif my_const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-specification-boot-full-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif my_const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-specification-boot-full-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif my_const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-specification-boot-full-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif my_const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-specification-boot-full-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      my_text = ['The file "' getfilename(full_mat) '" already exists. Are you sure you want to overwrite it?'];
      answer = query(my_text,'question',120,'Save to mat-file',500,'no');
   else;
      answer = 'Yes';
   end;
   if strcmp(answer,'Yes')==1;
      setlogtext('Savings results to mat-files...');
      Number = (1:1:rep)';
      save(full_mat,'specification_sorted');
   end;
case 'check'
   T_str = get(boot_specification.obs,'String');
   my_T = mystr2num(strtrim(T_str(get(boot_specification.obs,'Value'),:)));
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   rep_val = get(boot_specification.rep,'Value');
   rep = repvalues(rep_val);
   set(boot_specification.rep,'UserData',rep);
   my_r = get(boot_specification.my_r,'Value')-1;
   set(boot_specification.obs,'UserData',my_T);
   set(boot_specification.my_r,'UserData',my_r);
   if strcmp(get(boot_specification.my_r,'Enable'),'on')==1;
      tm.alpha = tm.S_01*tm.beta(:,1:my_r)*inverse(tm.beta(:,1:my_r)'*tm.S_11*tm.beta(:,1:my_r));
      if isempty(tm.Z2)==0;
         tm.Psi = tm.M_02*inverse(tm.M_22)-(tm.alpha*tm.beta(:,1:my_r)'*tm.M_12*inverse(tm.M_22));
         tm.epsilon = tm.Z0-(tm.alpha*tm.beta(:,1:my_r)'*tm.Z1)-(tm.Psi*tm.Z2);
      else;
         tm.Psi = [];
         tm.epsilon = tm.Z0-(tm.alpha*tm.beta(:,1:my_r)'*tm.Z1);
      end;
      tm.Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
   end;
   %
   dis_weakexo = 0;
   svarguidlg = findobj('Type','figure','Tag','SVARGUI')';
   if isempty(svarguidlg)==0;
      svar = get(svarguidlg,'UserData');
      if strcmp(get(svar.struc_undo,'Enable'),'on')==1;
         dis_weakexo = 1;
      end;
   end;
   %
   if (my_r==tm.n)|(my_r==0);
      set(boot_specification.weakexo,'Enable','off','Value',0);
   else;
      if (gcbo~=boot_specification.weakexo)&(dis_weakexo==0);
         set(boot_specification.weakexo,'Enable','on');
      end;
   end;
   %
   % check if there are any tests to perform during bootstrap
   %
   check_test = get(boot_specification.serial,'Value')+get(boot_specification.portmanteau,'Value')+get(boot_specification.arch,'Value')+get(boot_specification.march,'Value')+get(boot_specification.normality,'Value')+get(boot_specification.omnibus,'Value')+get(boot_specification.lagorder,'Value')+get(boot_specification.weakexo,'Value')+get(boot_specification.gctest,'Value');
   if check_test>0;
      set(boot_specification.simulate,'Enable','on');
      set(boot_specification.simulatemenu,'Enable','on');
   else;
      set(boot_specification.simulate,'Enable','off');
      set(boot_specification.simulatemenu,'Enable','off');
   end;
   %
   if get(boot_specification.parametric,'Value')==1;
      bootstyle = '';
      set(boot_specification.blocktext,'Enable','off');
      set(boot_specification.block,'Enable','off','Value',1);
   else;
      if strcmp(get(boot_specification.block,'Enable'),'off')==1;
         set(boot_specification.blocktext,'Enable','on');
         set(boot_specification.block,'Enable','on','Value',curr_ini.blocksize);
      end;
      bootstyle = ['np' num2str(get(boot_specification.block,'Value')) '-'];
   end;
   %
   % adjusting the view text buttons
   %
   full_mat = '';
   if tm.const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-specification-boot-full-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
      mod_type = 'noconst';
   elseif tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-specification-boot-full-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
      mod_type = 'resconst';
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-specification-boot-full-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
      mod_type = 'const';
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-specification-boot-full-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
      mod_type = 'restrend';
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-specification-boot-full-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
      mod_type = 'trend';
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      specification_mat = load(full_mat);
      specification_results = specification_mat.specification_sorted;
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
      %
      % adjusting the Graph Distrbution button
      %
      set(boot_specification.display,'Enable','on','UserData',specification_results);
      set(boot_specification.displaymenu,'Enable','on','UserData',tm.const_model);
      set(boot_specification.histogram,'Enable','on');
      set(boot_specification.histogrammenu,'Enable','on');
      set(boot_specification.matfilebutton,'Enable','on');
      set(boot_specification.matfilemenu,'Enable','on');
   else;
      full_mat = '';
      full_enable = 'off';
      set(boot_specification.display,'Enable','off','UserData',[]);
      set(boot_specification.displaymenu,'Enable','off','UserData',tm.const_model);
      set(boot_specification.histogram,'Enable','off');
      set(boot_specification.histogrammenu,'Enable','off');
      set(boot_specification.matfilebutton,'Enable','off');
      set(boot_specification.matfilemenu,'Enable','off');
   end;
   %
   % Checking if residuals file exists
   %
   epsfile = [curr_ini.simulatedir tm.modelfile '-' 'specification-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
   testfile = strrep(epsfile,'.mat',['-specification-data.mat']);
   %
   if (fileexist(epsfile)==1)&(fileexist(testfile)==1);
      set(boot_specification.bootstrapgraph,'Enable','on','UserData',epsfile);
      set(boot_specification.bootstrapgraphmenu,'Enable','on','UserData',testfile);
   else;
      set(boot_specification.bootstrapgraph,'Enable','off','UserData',[]);
      set(boot_specification.bootstrapgraphmenu,'Enable','off','UserData','');
   end;
   %
   set(boot_specification.fullmenu,'Enable',full_enable,'UserData',full_mat);
   set(boot_specification.full,'Enable',full_enable);
   summary_txt = '';
   if tm.const_model(1)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-specification-boot-summary-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
   elseif tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-specification-boot-summary-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-specification-boot-summary-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-specification-boot-summary-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-specification-boot-summary-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
   end;
%   if curr_ini.texoutputformat>=2;
%      summary_txt = strrep(summary_txt,'.txt','.ltx');
%   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
   end;
   if curr_ini.noprint==0;
      set(boot_specification.output,'Enable',summary_enable);
   end;
   set(boot_specification.summarymenu,'Enable',summary_enable,'UserData',summary_txt);
   set(boot_specification.summary,'Enable',summary_enable);
   set(specification_boot_gui,'UserData',boot_specification);
case 'summary'
   set(specification_boot_gui,'Visible','off');
   drawnow;
   file = lower(get(boot_specification.summarymenu,'UserData'));
   prtgui = printgui('init',file,'Structural VAR - Specification Tests Simulation Summary',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   myprint = get(prtgui,'UserData');
   set(myprint.print,'UserData','done');
   killguipid(prtgui);
   set(specification_boot_gui,'Visible','on');
   drawnow;
   set(specification_boot_gui,'UserData',boot_specification);
case 'full'
   set(specification_boot_gui,'Visible','off');
   drawnow;
   rep = get(boot_specification.rep,'UserData');
   my_T = get(boot_specification.obs,'UserData');
   full_mat = lower(get(boot_specification.fullmenu,'UserData'));
   abort = '';
   if rep>=5000;
      input_var.title = ['Progress for ' int2str(rep) ' replications'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.label = 'Replication number:';
      input_var.stop = 0;
      input_var.clock = 1;
      input_var.name = ['Data in ' getname(full_mat)];
      mywait = progressdlg(0,input_var);
%      set(mywait,'Name',['Data in ' getname(full_mat)]);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
      drawnow;
   end;
   specification_mat = load(full_mat);
   specification_sorted = specification_mat.specification_sorted;
   test_data = [];
   sp_str = spacestr(curr_ini.decimals-2);
   if size(tm.myvars,2)<10;
      add_sp_str = spacestr(10-size(tm.myvars,2));
   else;
      add_sp_str = '';
   end;
   prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
   prt_str = '%7.0f';
   head_str = ' Number';
   %
   if isfield(specification_sorted,'serial')==1;
      test_data = [test_data specification_sorted.serial];
      prt_str = [prt_str '     ' prt_val];
      head_str = [head_str '        Lag 1' sp_str];
      if strcmp(tm.freq,'q')==1;
         prt_str = [prt_str '     ' prt_val];
         head_str = [head_str '        Lag 4' sp_str];
      elseif strcmp(tm.freq,'m')==1;
         prt_str = [prt_str '     ' prt_val];
         head_str = [head_str '       Lag 12' sp_str];
      end;
   end;
   %
   if isfield(specification_sorted,'portmanteau')==1;
      test_data = [test_data specification_sorted.portmanteau];
      prt_str = [prt_str '     ' prt_val];
      head_str = [head_str sprintf('     LB(%4.0f)',specification_sorted.portmanteau_df(1,1)) sp_str];
   end;
   %
   if isfield(specification_sorted,'arch')==1;
      test_data = [test_data specification_sorted.arch];
      for i=1:tm.n;
         if curr_ini.sscorrect==1;
            prt_str = [prt_str '               ' prt_val];
            head_str = [head_str sprintf('   %sF(%2.0f,%3.0f) %s',add_sp_str,specification_sorted.arch_df(1,1),specification_sorted.arch_df(1,2),tm.myvars(i,:)) sp_str];
         else;
            prt_str = [prt_str '               ' prt_val];
            head_str = [head_str sprintf('      %sLM(%2.0f) %s',add_sp_str,specification_sorted.arch_df(1,1),tm.myvars(i,:)) sp_str];
         end;
      end;
      if strcmp(tm.freq,'')==0;
         for i=1:tm.n;
            if curr_ini.sscorrect==1;
               prt_str = [prt_str '               ' prt_val];
               head_str = [head_str sprintf('   %sF(%2.0f,%3.0f) %s',add_sp_str,specification_sorted.arch_df(1,3),specification_sorted.arch_df(1,4),tm.myvars(i,:)) sp_str];
            else;
               prt_str = [prt_str '               ' prt_val];
               head_str = [head_str sprintf('      %sLM(%2.0f) %s',add_sp_str,specification_sorted.arch_df(1,2),tm.myvars(i,:)) sp_str];
            end;
         end;
      end;
   end;
   %
   if isfield(specification_sorted,'march')==1;
      test_data = [test_data specification_sorted.march];
      if curr_ini.sscorrect==1;
         prt_str = [prt_str '     ' prt_val];
         head_str = [head_str sprintf('  F(%4.0f,%3.0f)',specification_sorted.march_df(1,1),specification_sorted.march_df(1,2)) sp_str];
      else;
         prt_str = [prt_str '     ' prt_val];
         head_str = [head_str sprintf('     LM(%4.0f)',specification_sorted.march_df(1,1)) sp_str];
      end;
   end;
   %
   if isfield(specification_sorted,'normality')==1;
      test_data = [test_data specification_sorted.normality];
      for i=1:3;
         if curr_ini.sscorrect==1;
            prt_str = [prt_str '     ' prt_val];
            head_str = [head_str sprintf('    F(%2.0f,%3.0f)',specification_sorted.normality_df(i,1),specification_sorted.normality_df(i,2)) sp_str];
         else;
            prt_str = [prt_str '     ' prt_val];
            head_str = [head_str sprintf('        W(%2.0f)',specification_sorted.normality_df(i,1)) sp_str];
         end;
      end;
   end;
   %
   if isfield(specification_sorted,'omnibus')==1;
      test_data = [test_data specification_sorted.omnibus];
      if curr_ini.sscorrect==1;
         prt_str = [prt_str '     ' prt_val];
         head_str = [head_str sprintf('    F(%2.0f,%3.0f)',specification_sorted.omnibus_df(1,1),specification_sorted.omnibus_df(1,2)) sp_str];
      else;
         prt_str = [prt_str '     ' prt_val];
         head_str = [head_str sprintf('    E_%2.0f(%3.0f)',tm.n,specification_sorted.omnibus_df(1,1)) sp_str];
      end;
   end;
   %
   if isfield(specification_sorted,'lagorder')==1;
      test_data = [test_data specification_sorted.lagorder];
      lag_count = 0;
      for lag=1:curr_ini.lagtest;
         if ((my_T-tm.df)-lag*(tm.n+tm.q1+tm.q0))>0;
            lag_count = lag_count+1;
            if curr_ini.sscorrect==1;
               prt_str = [prt_str '               ' prt_val];
               head_str = [head_str sprintf('   F(%3.0f,%3.0f) %2.0f vs. %2.0f',specification_sorted.lagorder_df(lag_count).df(1,1),specification_sorted.lagorder_df(lag_count).df(1,2),tm.p,tm.p+lag) sp_str];
            else;
               prt_str = [prt_str '               ' prt_val];
               head_str = [head_str sprintf('      LM(%3.0f) %2.0f vs. %2.0f',specification_sorted.lagorder_df(lag_count).df(1,1),tm.p,tm.p+lag) sp_str];
            end;
         end;
         if (tm.p-lag)>=1;
            lag_count = lag_count+1;
            if curr_ini.sscorrect==1;
               prt_str = [prt_str '               ' prt_val];
               head_str = [head_str sprintf('   F(%3.0f,%3.0f) %2.0f vs. %2.0f',specification_sorted.lagorder_df(lag_count).df(1,1),specification_sorted.lagorder_df(lag_count).df(1,2),tm.p-lag,tm.p) sp_str];
            else;
               prt_str = [prt_str '               ' prt_val];
               head_str = [head_str sprintf('       W(%3.0f) %2.0f vs. %2.0f',specification_sorted.lagorder_df(lag_count).df(1,1),tm.p-lag,tm.p) sp_str];
            end;
         end;
      end;
   end;
   %
   if isfield(specification_sorted,'weakexo')==1;
      for i=1:tm.n;
         if specification_sorted.weakexo_df(i,1)>0;
            test_data = [test_data specification_sorted.weakexo(:,i)];
            if curr_ini.sscorrect==1;
               prt_str = [prt_str '               ' prt_val];
               head_str = [head_str sprintf('   %sF(%2.0f,%3.0f) %s',add_sp_str,specification_sorted.weakexo_df(i,1),specification_sorted.weakexo_df(i,2),tm.myvars(i,:)) sp_str];
            else;
               prt_str = [prt_str '               ' prt_val];
               head_str = [head_str sprintf('       %sW(%2.0f) %s',add_sp_str,specification_sorted.weakexo_df(i,1),tm.myvars(i,:)) sp_str];
            end;
         end;
      end;
   end;
   %
   if isfield(specification_sorted,'gctest')==1;
      gc_count = 0;
      for i=1:tm.n;
         for j=1:tm.n;
            if isequal(i,j)==0;
               gc_count = gc_count+1;
               if specification_sorted.gctest_df(gc_count,1)>0;
                  test_data = [test_data specification_sorted.gctest(:,gc_count)];
                  if curr_ini.sscorrect==1;
                     prt_str = [prt_str '                            ' prt_val];
                     head_str = [head_str sprintf('   %s%sF(%2.0f,%3.0f) %s=|>%s',add_sp_str,add_sp_str,specification_sorted.gctest_df(gc_count,1),specification_sorted.gctest_df(gc_count,2),tm.myvars(j,:),tm.myvars(i,:)) sp_str];
                  else;
                     prt_str = [prt_str '                            ' prt_val];
                     head_str = [head_str sprintf('       %s%sW(%2.0f) %s=|>%s',add_sp_str,add_sp_str,specification_sorted.gctest_df(gc_count,1),tm.myvars(j,:),tm.myvars(i,:)) sp_str];
                  end;
               end;
            end;
         end;
      end;
   end;
   %
   my_data = [specification_mat.Number test_data];
   my_text = strvcat(' ',head_str,' ');
   for i=1:size(my_data,1);
      if rep>=5000;
         abort = get(mywait,'UserData');
         if strcmp(abort,'cancel')==1;
            break;
         else;
            progressdlg([(i/rep) i]);
         end;
      end;
      my_text = strvcat(my_text,sprintf(prt_str,my_data(i,:)'));
   end;
   my_text = strvcat(my_text,' ');
   if rep>=5000;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   end;
   if strcmp(abort,'cancel')==0;
      textgui(my_text,'Structural VAR - Specification Tests Simulation',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   end;
   set(specification_boot_gui,'Visible','on');
   drawnow;
   set(specification_boot_gui,'UserData',boot_specification);
case 'display'
   specification_sorted = get(boot_specification.display,'UserData');
   %
   % need to fix the rest
   %
   rep = get(boot_specification.rep,'UserData');
   my_r = get(boot_specification.my_r,'UserData');
   my_T = get(boot_specification.obs,'UserData');
   my_const_model = get(boot_specification.displaymenu,'UserData');
   if my_const_model(1)==1;
      this_mod = '(no constant)';
   elseif my_const_model(2)==1;
      this_mod = '(restricted constant)';
   elseif my_const_model(3)==1;
      this_mod = '(constant)';
   elseif my_const_model(4)==1;
      this_mod = '(restricted trend)';
   elseif my_const_model(5)==1;
      this_mod = '(trend)';
   end;
   cell_value = get(boot_specification.cells,'Value');
   cell_vec = [20 25 30 35 40 45 50 55 60 65 70 75 80 85 90 95 100];
   numcells = cell_vec(cell_value);
   my_80 = floor(0.8*rep);
   my_90 = floor(0.9*rep);
   my_95 = floor(0.95*rep);
   my_975 = floor(0.98*rep);
   my_99 = floor(0.99*rep);
   spec_plot = [];
   pos = [(tm.realscrsz(3)-600)/2 (tm.realscrsz(4)-400)/2];
   %
   if curr_ini.colors==1;
      col.vec_1 = [0 0 1];
      col.vec_2 = [1 0 0];
      col.vec_3 = [0 0.75 0];
      col.vec_4 = [1 0.5 0];
      col.vec_5 = [0 0.75 0.75];
      col.vec_6 = [0 0 0];
      col.vec_7 = (1/255)*[255 28 28];
      col.vec_8 = [0 1 0];
   else;
      col.vec_1 = [0 0 0];
      col.vec_2 = [0.7 0.7 0.7];
      col.vec_3 = [0.6 0.6 0.6];
      col.vec_4 = [0.5 0.5 0.5];
      col.vec_5 = [0.4 0.4 0.4];
      col.vec_6 = [0.3 0.3 0.3];
      col.vec_7 = [0.8 0.8 0.8];
      col.vec_8 = [0.2 0.2 0.2];
   end;
   %
   % serial correlation tests
   %
   if isfield(specification_sorted,'serial')==1;
      serial_sorted = specification_sorted.serial(:,1);
      serial_series = [];
      if (gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu);
         [serial_series,serial_quant,serial_table] = asymp_series(specification_sorted.serial_df(1,:),curr_ini.sscorrect);
         if get(boot_specification.pqplot,'Value')==1;
            [p_series,pp_series,qq_series] = pq_plot_series(serial_sorted,serial_quant,serial_table,specification_sorted.serial_df(1,:),curr_ini.sscorrect);
         end;
      end;
      %
      % computations for p-value plots
      %
      %
      if curr_ini.sscorrect==1;
         add_name = ['F(' num2str(specification_sorted.serial_df(1,1),'%0.0f') ',' num2str(specification_sorted.serial_df(1,2),'%0.0f') ')'];
      else;
         add_name = ['LM(' num2str(specification_sorted.serial_df(1,1),'%0.0f') ')'];
      end;
      %
      %
      if ((gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu))&(get(boot_specification.pqplot,'Value')==1);
         %
         % plotting p-value plots etc.
         %
         [pos,spec_ploti] = pq_plot(pos,'serial-corr-1-pq-plot-',['Serial Correlation, Lag 1 - P-value and Quantile Plots for ' add_name ' Test'],['P-value plot of ' add_name],['P-value discrepancy plot of ' add_name],['PP plot of ' add_name],['QQ plot of ' add_name],tm,serial_quant,serial_table,p_series,pp_series,qq_series,col);
         spec_plot = [spec_plot spec_ploti];
      end;
      %
      % The actual serial correlation test
      %
      [pos,spec_ploti] = dist_plot(pos,'serial-corr-1-',['Serial Correlation, Lag 1 - Density for ' add_name ' Test'],[add_name ' lag 1 test ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(tm.r) ' cointegration vectors'],tm,curr_ini,boot_specification,serial_sorted,serial_series,1,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,specification_sorted.serial_df(1,:));
      spec_plot = [spec_plot spec_ploti];
      %
      if strcmp(tm.freq,'')==0;
         serial_sorted = specification_sorted.serial(:,2);
         if strcmp(tm.freq,'q')==1;
            lag_str = '4';
         else;
            lag_str = '12';
         end;
         %
         % computations for p-value plots
         %
         if (gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu);
            [serial_series,serial_quant,serial_table] = asymp_series(specification_sorted.serial_df(2,:),curr_ini.sscorrect);
            if get(boot_specification.pqplot,'Value')==1;
               [p_series,pp_series,qq_series] = pq_plot_series(serial_sorted,serial_quant,serial_table,specification_sorted.serial_df(2,:),curr_ini.sscorrect);
            end;
         end;
         %
         if curr_ini.sscorrect==1;
            add_name = ['F(' num2str(specification_sorted.serial_df(2,1),'%0.0f') ',' num2str(specification_sorted.serial_df(2,2),'%0.0f') ')'];
         else;
            add_name = ['LM(' num2str(specification_sorted.serial_df(2,1),'%0.0f') ')'];
         end;
         %
         %
         if ((gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu))&(get(boot_specification.pqplot,'Value')==1);
            %
            % plotting p-value plots etc.
            %
            [pos,spec_ploti] = pq_plot(pos,['serial-corr-' lag_str '-pq-plot-'],['Serial Correlation, Lag ' lag_str ' - P-value and Quantile Plots for ' add_name ' Test'],['P-value plot of ' add_name],['P-value discrepancy plot of ' add_name],['PP plot of ' add_name],['QQ plot of ' add_name],tm,serial_quant,serial_table,p_series,pp_series,qq_series,col);
            spec_plot = [spec_plot spec_ploti];
         end;
         %
         % The actual serial correlation test
         %
         [pos,spec_ploti] = dist_plot(pos,['serial-corr-' lag_str '-'],['Serial Correlation, Lag ' lag_str ' - Density for ' add_name ' Test'],[add_name ' lag ' lag_str ' test ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(tm.r) ' cointegration vectors'],tm,curr_ini,boot_specification,serial_sorted,serial_series,1,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,specification_sorted.serial_df(2,:));
         spec_plot = [spec_plot spec_ploti];
      end;
   end;
   %
   % portmanteau test
   %
   if isfield(specification_sorted,'portmanteau')==1;
      portmanteau_sorted = specification_sorted.portmanteau;
      portmanteau_series = [];
      %
      if (gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu);
         [portmanteau_series,portmanteau_quant,portmanteau_table] = asymp_series(specification_sorted.portmanteau_df,0);
         if get(boot_specification.pqplot,'Value')==1;
            [p_series,pp_series,qq_series] = pq_plot_series(portmanteau_sorted,portmanteau_quant,portmanteau_table,specification_sorted.portmanteau_df,0);
         end;
      end;
      %
      %
      add_name = ['LB(' num2str(specification_sorted.portmanteau_df(1,1),'%0.0f') ')'];
      %
      %
      if ((gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu))&(get(boot_specification.pqplot,'Value')==1);
         %
         % plotting p-value plots etc.
         %
         [pos,spec_ploti] = pq_plot(pos,'portmanteau-pq-plot-',['P-value and Quantile Plots for ' add_name ' Portmanteau Test'],['P-value plot of ' add_name],['P-value discrepancy plot of ' add_name],['PP plot of ' add_name],['QQ plot of ' add_name],tm,portmanteau_quant,portmanteau_table,p_series,pp_series,qq_series,col);
         spec_plot = [spec_plot spec_ploti];
      end;
      %
      % The actual portmanteau test
      %
      [pos,spec_ploti] = dist_plot(pos,'portmanteau-',['Density for ' add_name ' Portmanteau Test'],[add_name ' Portmanteau test ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(tm.r) ' cointegration vectors'],tm,curr_ini,boot_specification,portmanteau_sorted,portmanteau_series,1,0,1,col,my_80,my_90,my_95,my_975,my_99,numcells,specification_sorted.portmanteau_df);
      spec_plot = [spec_plot spec_ploti];
   end;
   %
   % ARCH tests
   %
   if isfield(specification_sorted,'arch')==1;
      arch_series = [];
      %
      if (gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu);
         [arch_series,arch_quant,arch_table] = asymp_series(specification_sorted.arch_df(1,:),curr_ini.sscorrect);
      end;
      %
      for i=1:tm.n;
         arch_sorted = specification_sorted.arch(:,i);
         if ((gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu))&(get(boot_specification.pqplot,'Value')==1);
            [p_series,pp_series,qq_series] = pq_plot_series(arch_sorted,arch_quant,arch_table,specification_sorted.arch_df(1,:),curr_ini.sscorrect);
         end;
         %
         if curr_ini.sscorrect==1;
            add_name = ['F(' num2str(specification_sorted.arch_df(1,1),'%0.0f') ',' num2str(specification_sorted.arch_df(1,2),'%0.0f') ')'];
         else;
            add_name = ['LM(' num2str(specification_sorted.arch_df(1,1),'%0.0f') ')'];
         end;
         %
         if ((gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu))&(get(boot_specification.pqplot,'Value')==1);
            %
            % plotting p-value plots etc.
            %
            [pos,spec_ploti] = pq_plot(pos,['arch-1-pq-plot-' strtrim(tm.myvars(i,:)) '-'],['P-value and Quantile Plots for ' add_name ' ARCH Test of Order 1 - ' strtrim(tm.myvars(i,:))],['P-value plot of ' add_name ' for ' strtrim(tm.myvars(i,:))],['P-value discrepancy plot of ' add_name ' for ' strtrim(tm.myvars(i,:))],['PP plot of ' add_name ' for ' strtrim(tm.myvars(i,:))],['QQ plot of ' add_name ' for ' strtrim(tm.myvars(i,:))],tm,arch_quant,arch_table,p_series,pp_series,qq_series,col);
            spec_plot = [spec_plot spec_ploti];
         end;
         %
         % plotting the distributions
         %
         [pos,spec_ploti] = dist_plot(pos,['arch-1-' strtrim(tm.myvars(i,:)) '-'],['Density for ' add_name ' ARCH Test of Order 1 - ' strtrim(tm.myvars(i,:))],[add_name ' ARCH test for ' strtrim(tm.myvars(i,:)) ' ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(tm.r) ' cointegration vectors'],tm,curr_ini,boot_specification,arch_sorted,arch_series,1,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,specification_sorted.arch_df(1,:));
         spec_plot = [spec_plot spec_ploti];
      end;
      %
      % lags 1 to frequency of data
      %
      if strcmp(tm.freq,'')==0;
         arch_series = [];
         if curr_ini.sscorrect==1;
            this_df = [specification_sorted.arch_df(1,3) specification_sorted.arch_df(1,4)];
         else;
            this_df = specification_sorted.arch_df(1,2);
         end;
         if (gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu);
            [arch_series,arch_quant,arch_table] = asymp_series(this_df,curr_ini.sscorrect);
         end;
         %
         if strcmp(tm.freq,'q')==1;
            lag_str = '4';
         else;
            lag_str = '12';
         end;
         %
         % looping over the variables
         %
         for i=1:tm.n;
            arch_sorted = specification_sorted.arch(:,i+tm.n);
            if ((gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu))&(get(boot_specification.pqplot,'Value')==1);
               [p_series,pp_series,qq_series] = pq_plot_series(arch_sorted,arch_quant,arch_table,this_df,curr_ini.sscorrect);
            end;
            %
            if curr_ini.sscorrect==1;
               add_name = ['F(' num2str(specification_sorted.arch_df(1,3),'%0.0f') ',' num2str(specification_sorted.arch_df(1,4),'%0.0f') ')'];
            else;
               add_name = ['LM(' num2str(specification_sorted.arch_df(1,2),'%0.0f') ')'];
            end;
            %
            if ((gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu))&(get(boot_specification.pqplot,'Value')==1);
               %
               % plotting p-value plots etc.
               %
               [pos,spec_ploti] = pq_plot(pos,['arch-' lag_str '-pq-plot-' strtrim(tm.myvars(i,:)) '-'],['P-value and Quantile Plots for ' add_name ' ARCH Test of Order 1 to ' lag_str ' - ' strtrim(tm.myvars(i,:))],['P-value plot of ' add_name ' for ' strtrim(tm.myvars(i,:))],['P-value discrepancy plot of ' add_name ' for ' strtrim(tm.myvars(i,:))],['PP plot of ' add_name ' for ' strtrim(tm.myvars(i,:))],['QQ plot of ' add_name ' for ' strtrim(tm.myvars(i,:))],tm,arch_quant,arch_table,p_series,pp_series,qq_series,col);
               spec_plot = [spec_plot spec_ploti];
            end;
            %
            % plotting the distributions
            %
            [pos,spec_ploti] = dist_plot(pos,['arch-' lag_str '-' strtrim(tm.myvars(i,:)) '-'],['Density for ' add_name ' ARCH Test of Order 1 to ' lag_str ' - ' strtrim(tm.myvars(i,:))],[add_name ' ARCH test for ' strtrim(tm.myvars(i,:)) ' ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(tm.r) ' cointegration vectors'],tm,curr_ini,boot_specification,arch_sorted,arch_series,1,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,this_df);
            spec_plot = [spec_plot spec_ploti];
         end;
      end;
   end;
   %
   % multivariate ARCH tests
   %
   if isfield(specification_sorted,'march')==1;
      march_series = [];
      %
      % constructing a series with specification tests which can be displayed
      % as the asymptotic distribution for the skewness and kurtosis statistic
      %
      if (gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu);
         [march_series,march_quant,march_table] = asymp_series(specification_sorted.march_df,curr_ini.sscorrect);
      end;
      %
      hyp_str = '';
      if curr_ini.rest_march==1;
         hyp_str = 'restricted';
      end;
      %
      % the sorted test statistic series
      %
      march_sorted = specification_sorted.march(:,1);
      if ((gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu))&(get(boot_specification.pqplot,'Value')==1);
         [p_series,pp_series,qq_series] = pq_plot_series(march_sorted,march_quant,march_table,specification_sorted.march_df,curr_ini.sscorrect);
      end;
      %
      if curr_ini.sscorrect==1;
         add_name = ['F(' num2str(specification_sorted.march_df(1,1),'%0.0f') ',' num2str(specification_sorted.march_df(1,2),'%0.0f') ')'];
      else;
         add_name = ['LM(' num2str(specification_sorted.march_df(1,1),'%0.0f') ')'];
      end;
      %
      if ((gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu))&(get(boot_specification.pqplot,'Value')==1);
         %
         % plotting p-value plots etc.
         %
         [pos,spec_ploti] = pq_plot(pos,['march-' hyp_str '-pq-plot-'],['P-value and Quantile Plots of multivariate ' hyp_str ' ARCH test ' add_name],['P-value plot of MARCH ' add_name ' test'],['P-value discrepancy plot of MARCH ' add_name ' test'],['PP plot of MARCH ' add_name ' test'],['QQ plot of MARCH ' add_name ' test'],tm,march_quant,march_table,p_series,pp_series,qq_series,col);
         spec_plot = [spec_plot spec_ploti];
      end;
      %
      % plotting the distributions
      %
      [pos,spec_ploti] = dist_plot(pos,['march-' hyp_str '-'],['Density of multivariate ARCH test ' add_name],['Multivariate ARCH ' add_name ' test ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(tm.r) ' cointegration vectors'],tm,curr_ini,boot_specification,march_sorted,march_series,1,1,0,col,my_80,my_90,my_95,my_975,my_99,numcells,specification_sorted.march_df);
      spec_plot = [spec_plot spec_ploti];
   end;
   %
   % normality tests
   %
   if isfield(specification_sorted,'normality')==1;
      normality_series = [];
      %
      % constructing a series with specification tests which can be displayed
      % as the asymptotic distribution for the skewness and kurtosis statistic
      %
      if (gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu);
         [normality_series,normality_quant,normality_table] = asymp_series(specification_sorted.normality_df(1,:),curr_ini.sscorrect);
      end;
      %
      for i=1:3;
         if i==1;
            hyp_str = 'skewness';
         elseif i==2;
            hyp_str = 'kurtosis';
         else;
            hyp_str = 'skewness-kurtosis';
            %
            % we now have to reconstruct the asymptotic distribution
            %
            if (gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu);
               [normality_series,normality_quant,normality_table] = asymp_series(specification_sorted.normality_df(3,:),curr_ini.sscorrect);
            end;
         end;
         %
         % the sorted test statistic series
         %
         normality_sorted = specification_sorted.normality(:,i);
         if ((gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu))&(get(boot_specification.pqplot,'Value')==1);
            [p_series,pp_series,qq_series] = pq_plot_series(normality_sorted,normality_quant,normality_table,specification_sorted.normality_df(i,:),curr_ini.sscorrect);
         end;
         %
         if curr_ini.sscorrect==1;
            add_name = ['F(' num2str(specification_sorted.normality_df(i,1),'%0.0f') ',' num2str(specification_sorted.normality_df(i,2),'%0.0f') ')'];
         else;
            add_name = ['W(' num2str(specification_sorted.normality_df(i,1),'%0.0f') ')'];
         end;
         %
         if ((gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu))&(get(boot_specification.pqplot,'Value')==1);
            %
            % plotting p-value plots etc.
            %
            [pos,spec_ploti] = pq_plot(pos,['normality-' hyp_str '-pq-plot-'],['P-value and Quantile Plots of ' add_name ' for ' hyp_str],['P-value plot of ' add_name ' for ' hyp_str],['P-value discrepancy plot of ' add_name ' for ' hyp_str],['PP plot of ' add_name ' for ' hyp_str],['QQ plot of ' add_name ' for ' hyp_str],tm,normality_quant,normality_table,p_series,pp_series,qq_series,col);
            spec_plot = [spec_plot spec_ploti];
         end;
         %
         % plotting the distributions
         %
         [pos,spec_ploti] = dist_plot(pos,['normality-' hyp_str '-'],['Density of ' add_name ' for ' hyp_str],[add_name ' test for ' hyp_str ' ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(tm.r) ' cointegration vectors'],tm,curr_ini,boot_specification,normality_sorted,normality_series,1,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,specification_sorted.normality_df(i,:));
         spec_plot = [spec_plot spec_ploti];
      end;
   end;
   %
   % Omnibus test
   %
   if isfield(specification_sorted,'omnibus')==1;
      omnibus_series = [];
      %
      % constructing a series with specification tests which can be displayed
      % as the asymptotic distribution for the skewness and kurtosis statistic
      %
      if (gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu);
         [omnibus_series,omnibus_quant,omnibus_table] = asymp_series(specification_sorted.omnibus_df,curr_ini.sscorrect);
      end;
      %
      hyp_str = 'skewness-kurtosis';
      %
      % the sorted test statistic series
      %
      omnibus_sorted = specification_sorted.omnibus(:,1);
      if ((gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu))&(get(boot_specification.pqplot,'Value')==1);
         [p_series,pp_series,qq_series] = pq_plot_series(omnibus_sorted,omnibus_quant,omnibus_table,specification_sorted.omnibus_df,curr_ini.sscorrect);
      end;
      %
      if curr_ini.sscorrect==1;
         add_name = ['F(' num2str(specification_sorted.omnibus_df(1,1),'%0.0f') ',' num2str(specification_sorted.omnibus_df(1,2),'%0.0f') ')'];
      else;
         add_name = ['E_' num2str(tm.n,'%0.0f') '(' num2str(specification_sorted.omnibus_df(1,1),'%0.0f') ')'];
      end;
      %
      if ((gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu))&(get(boot_specification.pqplot,'Value')==1);
         %
         % plotting p-value plots etc.
         %
         [pos,spec_ploti] = pq_plot(pos,['omnibus-' hyp_str '-pq-plot-'],['P-value and Quantile Plots of Omnibus test ' add_name ' for ' hyp_str],['P-value plot of ' add_name ' for ' hyp_str],['P-value discrepancy plot of ' add_name ' for ' hyp_str],['PP plot of ' add_name ' for ' hyp_str],['QQ plot of ' add_name ' for ' hyp_str],tm,omnibus_quant,omnibus_table,p_series,pp_series,qq_series,col);
         spec_plot = [spec_plot spec_ploti];
      end;
      %
      % plotting the distributions
      %
      [pos,spec_ploti] = dist_plot(pos,['omnibus-' hyp_str '-'],['Density of Omnibus test ' add_name ' for ' hyp_str],['Omnibus ' add_name ' test for ' hyp_str ' ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(tm.r) ' cointegration vectors'],tm,curr_ini,boot_specification,omnibus_sorted,omnibus_series,1,1,0,col,my_80,my_90,my_95,my_975,my_99,numcells,specification_sorted.omnibus_df);
      spec_plot = [spec_plot spec_ploti];
   end;
   %
   % lag order tests
   %
   if isfield(specification_sorted,'lagorder')==1;
      if curr_ini.bartserial==1;
         bc_str = 'Bartlett corrected ';
      else;
         bc_str = '';
      end;
      %
      lag_count = 0;
      for lag=1:curr_ini.lagtest;
         if ((my_T-tm.df)-lag*(tm.n+tm.q1+tm.q0))>0;
            lag_count = lag_count+1;
            %
            % LM tests of tm.p vs tmp+lag
            %
            lagorder_series = [];
            %
            if (gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu);
               [lagorder_series,lagorder_quant,lagorder_table] = asymp_series(specification_sorted.lagorder_df(lag_count).df,specification_sorted.lagorder_correct(1,lag_count));
            end;
            %
            % the sorted test statistic series
            %
            lagorder_sorted = specification_sorted.lagorder(:,lag_count);
            if ((gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu))&(get(boot_specification.pqplot,'Value')==1);
               [p_series,pp_series,qq_series] = pq_plot_series(lagorder_sorted,lagorder_quant,lagorder_table,specification_sorted.lagorder_df(lag_count).df,specification_sorted.lagorder_correct(1,lag_count));
            end;
            %
            if specification_sorted.lagorder_correct(1,lag_count)==1;
               add_name = ['F(' num2str(specification_sorted.lagorder_df(lag_count).df(1,1),'%0.0f') ',' num2str(specification_sorted.lagorder_df(lag_count).df(1,2),'%0.0f') ')'];
            else;
               add_name = ['LM(' num2str(specification_sorted.lagorder_df(lag_count).df(1,1),'%0.0f') ')'];
            end;
            %
            if ((gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu))&(get(boot_specification.pqplot,'Value')==1);
               %
               % plotting p-values plots etc.
               %
               [pos,spec_ploti] = pq_plot(pos,['lagorder-' num2str(tm.p,'%0.0f') '-' num2str(tm.p+lag,'%0.0f') '-pq-plot-'],['P-value and Quantile Plots of ' bc_str add_name ' for ' num2str(tm.p,'%0.0f') ' vs ' num2str(tm.p+lag,'%0.0f') ' lags'],['P-value plot of ' add_name ' lag order test'],['P-value discrepancy plot of ' add_name ' lag order test'],['PP plot of ' add_name ' lag order test'],['QQ plot of ' bc_str add_name ' lag order test'],tm,lagorder_quant,lagorder_table,p_series,pp_series,qq_series,col);
               spec_plot = [spec_plot spec_ploti];
            end;
            %
            % plotting the distributions
            %
            [pos,spec_ploti] = dist_plot(pos,['lagorder-' num2str(tm.p,'%0.0f') '-' num2str(tm.p+lag,'%0.0f') '-'],['Density of ' bc_str add_name ' test for ' num2str(tm.p,'%0.0f') ' vs ' num2str(tm.p+lag,'%0.0f') ' lags'],[bc_str add_name ' test for ' num2str(tm.p,'%0.0f') ' vs ' num2str(tm.p+lag,'%0.0f') ' lags ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(tm.r) ' cointegration vectors'],tm,curr_ini,boot_specification,lagorder_sorted,lagorder_series,0,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,specification_sorted.lagorder_df(lag_count).df);
            spec_plot = [spec_plot spec_ploti];
         end;
         if (tm.p-lag)>=1;
            lag_count = lag_count+1;
            %
            % Wald tests of: tm.p-lag vs tm.p
            %
            lagorder_series = [];
            %
            if (gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu);
               [lagorder_series,lagorder_quant,lagorder_table] = asymp_series(specification_sorted.lagorder_df(lag_count).df,specification_sorted.lagorder_correct(1,lag_count));
            end;
            %
            %
            % the sorted test statistic series
            %
            lagorder_sorted = specification_sorted.lagorder(:,lag_count);
            if ((gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu))&(get(boot_specification.pqplot,'Value')==1);
               [p_series,pp_series,qq_series] = pq_plot_series(lagorder_sorted,lagorder_quant,lagorder_table,specification_sorted.lagorder_df(lag_count).df,specification_sorted.lagorder_correct(1,lag_count));
            end;
            %
            if specification_sorted.lagorder_correct(1,lag_count)==1;
               add_name = ['F(' num2str(specification_sorted.lagorder_df(lag_count).df(1,1),'%0.0f') ',' num2str(specification_sorted.lagorder_df(lag_count).df(1,2),'%0.0f') ')'];
            else;
               add_name = ['W(' num2str(specification_sorted.lagorder_df(lag_count).df(1,1),'%0.0f') ')'];
            end;
            %
            if ((gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu))&(get(boot_specification.pqplot,'Value')==1);
               %
               % plotting p-value plots etc.
               %
               [pos,spec_ploti] = pq_plot(pos,['lagorder-' num2str(tm.p-lag,'%0.0f') '-' num2str(tm.p,'%0.0f') '-pq-plot-'],['P-value and Quantile Plots of ' bc_str add_name ' for ' num2str(tm.p-lag,'%0.0f') ' vs ' num2str(tm.p,'%0.0f') ' lags'],['P-value plot of ' add_name ' lag order test'],['P-value discrepancy plot of ' add_name ' lag order test'],['PP plot of ' add_name ' lag order test'],['QQ plot of ' bc_str add_name ' lag order test'],tm,lagorder_quant,lagorder_table,p_series,pp_series,qq_series,col);
               spec_plot = [spec_plot spec_ploti];
            end;
            %
            % plotting the distributions
            %
            [pos,spec_ploti] = dist_plot(pos,['lagorder-' num2str(tm.p-lag,'%0.0f') '-' num2str(tm.p,'%0.0f') '-'],['Density of ' bc_str add_name ' test for ' num2str(tm.p-lag,'%0.0f') ' vs ' num2str(tm.p,'%0.0f') ' lags'],[bc_str add_name ' test for ' num2str(tm.p-lag,'%0.0f') ' vs ' num2str(tm.p,'%0.0f') ' lags ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(tm.r) ' cointegration vectors'],tm,curr_ini,boot_specification,lagorder_sorted,lagorder_series,0,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,specification_sorted.lagorder_df(lag_count).df);
            spec_plot = [spec_plot spec_ploti];
         end;
      end;
   end;
   %
   % weak exogeneity tests
   %
   if isfield(specification_sorted,'weakexo')==1;
      for i=1:tm.n;
         if specification_sorted.weakexo_df(i,1)>0;
            weakexo_sorted = specification_sorted.weakexo(:,i);
            weakexo_series = [];
            %
            if (gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu);
               [weakexo_series,weakexo_quant,weakexo_table] = asymp_series(specification_sorted.weakexo_df(i,:),curr_ini.sscorrect);
               if get(boot_specification.pqplot,'Value')==1;
                  [p_series,pp_series,qq_series] = pq_plot_series(weakexo_sorted,weakexo_quant,weakexo_table,specification_sorted.weakexo_df(i,:),curr_ini.sscorrect);
               end;
            end;
            %
            if curr_ini.sscorrect==1;
               add_name = ['F(' num2str(specification_sorted.weakexo_df(i,1),'%0.0f') ',' num2str(specification_sorted.weakexo_df(i,2),'%0.0f') ')'];
            else;
               add_name = ['W(' num2str(specification_sorted.weakexo_df(i,1),'%0.0f') ')'];
            end;
            %
            if ((gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu))&(get(boot_specification.pqplot,'Value')==1);
               %
               % plotting p-value plots etc.
               %
               [pos,spec_ploti] = pq_plot(pos,['weakexo-' strtrim(tm.myvars(i,:)) '-pq-plot-'],['P-value and Quantile Plots of Weak Exogeneity test ' add_name ' for ' strtrim(tm.myvars(i,:))],['P-value plot of ' add_name ' for ' strtrim(tm.myvars(i,:))],['P-value discrepancy plot of ' add_name ' for ' strtrim(tm.myvars(i,:))],['PP plot of ' add_name ' for ' strtrim(tm.myvars(i,:))],['QQ plot of ' add_name ' for ' strtrim(tm.myvars(i,:))],tm,weakexo_quant,weakexo_table,p_series,pp_series,qq_series,col);
               spec_plot = [spec_plot spec_ploti];
            end;
            %
            % plotting the distributions
            %
            [pos,spec_ploti] = dist_plot(pos,['weakexo-' strtrim(tm.myvars(i,:)) '-'],['Density of Weak Exogeneity test ' add_name ' for ' strtrim(tm.myvars(i,:))],['Weak exogeneity test ' add_name ' for ' strtrim(tm.myvars(i,:)) ' ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(tm.r) ' cointegration vectors'],tm,curr_ini,boot_specification,weakexo_sorted,weakexo_series,1,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,specification_sorted.weakexo_df(i,:));
            spec_plot = [spec_plot spec_ploti];
         end;
      end;
   end;
   %
   % Granger causality tests
   %
   if isfield(specification_sorted,'gctest')==1;
      gc_count = 0;
      for j=1:tm.n;
         for i=1:tm.n;
            if isequal(i,j)==0;
               gc_count = gc_count+1;
               if specification_sorted.gctest_df(gc_count,1)>0;
                  gctest_sorted = specification_sorted.gctest(:,gc_count);
                  gctest_series = [];
                  %
                  if (gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu);
                     [gctest_series,gctest_quant,gctest_table] = asymp_series(specification_sorted.gctest_df(gc_count,:),curr_ini.sscorrect);
                     if get(boot_specification.pqplot,'Value')==1;
                        [p_series,pp_series,qq_series] = pq_plot_series(gctest_sorted,gctest_quant,gctest_table,specification_sorted.gctest_df(gc_count,:),curr_ini.sscorrect);
                     end;
                  end;
                  %
                  if curr_ini.sscorrect==1;
                     add_name = ['F(' num2str(specification_sorted.gctest_df(gc_count,1),'%0.0f') ',' num2str(specification_sorted.gctest_df(gc_count,2),'%0.0f') ')'];
                  else;
                     add_name = ['W(' num2str(specification_sorted.gctest_df(gc_count,1),'%0.0f') ')'];
                  end;
                  %
                  if ((gcbo==boot_specification.display)|(gcbo==boot_specification.displaymenu))&(get(boot_specification.pqplot,'Value')==1);
                     %
                     % plotting p-value plots etc.
                     %
                     [pos,spec_ploti] = pq_plot(pos,['gctest-' strtrim(tm.myvars(i,:)) '.' strtrim(tm.myvars(j,:)) '-pq-plot-'],['P-value and Quantile Plots of Granger Causality ' add_name ' test for ' strtrim(tm.myvars(i,:)) ' on ' strtrim(tm.myvars(j,:))],['P-value plot of ' add_name ' test for ' strtrim(tm.myvars(i,:)) '-|>' strtrim(tm.myvars(j,:))],['P-value discrepancy plot of ' add_name ' test for ' strtrim(tm.myvars(i,:)) '-|>' strtrim(tm.myvars(j,:))],['PP plot of ' add_name ' test for ' strtrim(tm.myvars(i,:)) '-|>' strtrim(tm.myvars(j,:))],['QQ plot of ' add_name ' test for ' strtrim(tm.myvars(i,:)) '-|>' strtrim(tm.myvars(j,:))],tm,gctest_quant,gctest_table,p_series,pp_series,qq_series,col);
                     spec_plot = [spec_plot spec_ploti];
                  end;
                  %
                  % plotting the distributions
                  %
                  [pos,spec_ploti] = dist_plot(pos,['gctest-' strtrim(tm.myvars(i,:)) '.' strtrim(tm.myvars(j,:)) '-'],['Density of Granger Causality ' add_name ' test for ' strtrim(tm.myvars(i,:)) ' on ' strtrim(tm.myvars(j,:))],['Granger causality test ' add_name ' for ' strtrim(tm.myvars(i,:)) '-|>' strtrim(tm.myvars(j,:)) ' ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(tm.r) ' cointegration vectors'],tm,curr_ini,boot_specification,gctest_sorted,gctest_series,1,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,specification_sorted.gctest_df(gc_count,:));
                  spec_plot = [spec_plot spec_ploti];
               end;
            end;
         end;
      end;
   end;
   %
   % show and/or save plots
   %
   if curr_ini.external==0;
      set(spec_plot,'Visible','on');
   else;
      stats = [];
      file_names = '';
      this_mod = strrep(this_mod,'(','');
      this_mod = strrep(this_mod,')','');
      this_mod = strtrim(this_mod);
      this_mod = strrep(this_mod,' ','.');
      stats = [];
      file_names = '';
      for i=1:size(spec_plot,2);
         if (gcbo==boot_specification.histogram)|(gcbo==boot_specification.histogrammenu);
            file = [curr_ini.simulatedir tm.modelfile '-specification-hist-boot-' get(spec_plot(1,i),'Tag') num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
         else;
            file = [curr_ini.simulatedir tm.modelfile '-specification-boot-' get(spec_plot(1,i),'Tag') num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
         end;
         set(0,'CurrentFigure',spec_plot(1,i));
         stats = [stats autosavefigure(spec_plot(1,i),file)];
         file_names = strvcat(file_names,file);
      end;
      if isempty(stats)==0;
         for i=1:size(stats,2);
            if stats(i)==0;
               autoshowfigure(strtrim(file_names(i,:)));
            end;
         end;
      end;
   end;
   set(specification_boot_gui,'UserData',boot_specification);
   %
   % case simulate
   %
case 'simulate'
   tm.specification_run = 1;
   set(specification_boot_gui,'Visible','off');
   drawnow;
   %
   % collect values
   %
   T_str = get(boot_specification.obs,'String');
   my_T = mystr2num(strtrim(T_str(get(boot_specification.obs,'Value'),:)));
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   rep_val = get(boot_specification.rep,'Value');
   rep = repvalues(rep_val);
   blocksize = get(boot_specification.block,'Value');
   block_txt = '';
   if blocksize>1;
      block_txt = ['Applying block bootstrap with block length ' num2str(blocksize,'%0.0f') '...'];
   end;
   block_txt = strvcat(block_txt,'Selected tests:');
   if get(boot_specification.serial,'Value')==1;
      block_txt = strvcat(block_txt,'   Serial correlation tests');
   end;
   if get(boot_specification.portmanteau,'Value')==1;
      block_txt = strvcat(block_txt,'   Ljung-Box portmanteau tests');
   end;
   if get(boot_specification.arch,'Value')==1;
      block_txt = strvcat(block_txt,'   Univariate ARCH tests');
   end;
   if get(boot_specification.march,'Value')==1;
      block_txt = strvcat(block_txt,'   Multivariate ARCH test');
   end;
   if get(boot_specification.normality,'Value')==1;
      block_txt = strvcat(block_txt,'   Normality tests');
   end;
   if get(boot_specification.omnibus,'Value')==1;
      block_txt = strvcat(block_txt,'   Shenton-Bowman/Doornik-Hansen omnibus test');
   end;
   if get(boot_specification.lagorder,'Value')==1;
      block_txt = strvcat(block_txt,'   Lag order tests');
   end;
   if get(boot_specification.weakexo,'Value')==1;
      block_txt = strvcat(block_txt,'   Weak exogeneity tests');
   end;
   if get(boot_specification.gctest,'Value')==1;
      block_txt = strvcat(block_txt,'   Granger causality tests');
   end;
   if get(boot_specification.parametric,'Value')==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(get(boot_specification.block,'Value')) '-'];
   end;
   %
   set(boot_specification.simulate,'UserData',rep);
   my_r = get(boot_specification.my_r,'Value')-1;
   if strcmp(get(boot_specification.my_r,'Enable'),'on')==1;
      mybeta = tm.beta(:,1:my_r);
   else;
      mybeta = tm.beta;
   end;
   specification_test = [];
   use_c_restrict = 0;
   if (tm.r==my_r)&(size(tm.restrict,2)==3)&(tm.restrict(1,3)==1);
      use_c_restrict = 1;
   end;
   %
   % initialize
   %
   if get(boot_specification.serial,'Value')==1;
      if strcmp(tm.freq,'')==0;
         specification_test.serial = zeros(rep,2);
      else;
         specification_test.serial = zeros(rep,1);
      end;
      %
      % compute tests
      %
      if my_T==tm.T;
%         [results,degfreedom] = autocorr(tm.epsilon,tm.freq,tm.T-tm.df);
         [results,degfreedom] = lmautocorr(tm.epsilon,tm.Z0,tm.Z1,tm.Z2,mybeta,tm.freq,tm.T-tm.df);
         if strcmp(tm.freq,'')==0;
            tm.serial = [results(1,1) results(1,3)];
         else;
            tm.serial = results(1,1);
         end;
      end;
   end;
   %
   if get(boot_specification.portmanteau,'Value')==1;
      specification_test.portmanteau = zeros(rep,1);
      if my_T==tm.T;
         [results,degfreedom] = portmanteau_fcn(tm.epsilon,tm.p,tm);
         tm.portmanteau = results(1,1);
      end;
   end;
   %
   if get(boot_specification.arch,'Value')==1;
      if strcmp(tm.freq,'')==0;
         specification_test.arch = zeros(rep,2*tm.n);
      else;
         specification_test.arch = zeros(rep,tm.n);
      end;
      %
      if my_T==tm.T;
         [results,dfmat] = arch(tm.epsilon,tm.freq,tm.T-tm.df);
         if strcmp(tm.freq,'')==0;
            tm.arch = [results(:,1)' results(:,2)'];
         else;
            tm.arch = results(:,1)';
         end;
      end;
   end;
   %
   if get(boot_specification.march,'Value')==1;
      specification_test.march = zeros(rep,1);
      %
      if my_T==tm.T;
         [m_res,m_df] = march(tm.epsilon,tm.T-tm.df,curr_ini.rest_march,curr_ini.sscorrect);
         tm.march = m_res(1,1);
      end;
   end;
   %
   if get(boot_specification.normality,'Value')==1;
      specification_test.normality = zeros(rep,3);
      if my_T==tm.T;
         [results,degfreedom] = normality(tm.epsilon,tm.T-tm.df);
         tm.normality = results([1 3 5]);
      end;
   end;
   %
   if get(boot_specification.omnibus,'Value')==1;
      specification_test.omnibus = zeros(rep,1);
      if my_T==tm.T;
         [results,degfreedom] = omnibus_fcn(tm.epsilon,tm.T-tm.df);
         tm.omnibus = results(1,1);
      end;
   end;
   %
   % check how many lag order tests
   %
   lag_count = 0;
   check_waldlag = 0;
   if get(boot_specification.lagorder,'Value')==1;
      for lag=1:curr_ini.lagtest;
         if ((my_T-tm.df)-lag*(tm.n+tm.q1+tm.q0))>0;
            lag_count = lag_count+1;
            check_waldlag = 1;
         end;
         if (tm.p-lag)>=1;
            lag_count = lag_count+1;
         end;
      end;
   end;
   %
   if lag_count>0;
      specification_test.lagorder = zeros(rep,lag_count);
      if curr_ini.sscorrect==1;
         specification_test.lagorder_correct = ones(1,lag_count);
      else;
         specification_test.lagorder_correct = zeros(1,lag_count);
      end;
      if tm.T==my_T;
         num_lgt = 1;
         tm.lagorder = zeros(1,lag_count);
         %
         % obtain a possible covariance matrix for estimated Psi and alpha parameters
         %
         my_Sigma_theta = [];
         ind = 0;
         sind = 0;
         if (isfield(tm,'restrict')==1)&(tm.restrict(1,1)==1);
            betaguidlg = findobj('Type','figure','Tag','BetaGUI')';
            if isempty(betaguidlg)==0;
               cointbeta = get(betaguidlg,'UserData');
               my_Sigma_theta = get(cointbeta.genalpha,'UserData');
               ind = 1;
            else;
               svarguidlg = findobj('Type','figure','Tag','SVARGUI')';
               if isempty(svarguidlg)==0;
                  my_Sigma_theta = tm.Sigma_theta;
                  ind = 1;
                  svar = get(svarguidlg,'UserData');
                  if strcmp(get(svar.struc_undo,'Enable'),'on')==1;
                     sind = 1;
                  end;
               end;
            end;
         elseif (isfield(tm,'restrict')==1)&(tm.restrict(1,1)==0);
            %
            % check if we are in the structural part
            %
            svarguidlg = findobj('Type','figure','Tag','SVARGUI')';
            if isempty(svarguidlg)==0;
               my_Sigma_theta = tm.Sigma_theta;
               ind = 0;
               svar = get(svarguidlg,'UserData');
               if strcmp(get(svar.struc_undo,'Enable'),'on')==1;
                  sind = 1;
               end;
            end;
         end;
         %
         for lag=1:curr_ini.lagtest;
            if lag==1;
               lag_status = zeros(1,curr_ini.lagtest);
            end;
            if ((tm.T-tm.df)-lag*(tm.n+tm.q1+tm.q0))>0;
               [results,degfree,mycorrect] = lmlagtest(tm.epsilon,tm.x0,tm.x1,tm.x1_r,tm.x2,tm.p,tm.pe,lag,tm.q1,tm.q0,mybeta,tm.T-tm.df,ind,tm.modelsdir,tm.modelfile,use_c_restrict,tm.Psi,tm.alpha,tm.Z1,tm.Z2,tm.d);
               tm.lagorder(1,num_lgt) = results(1,1);
               num_lgt = num_lgt+1;
            end;
            if ((tm.p-lag)>=1)&(sind==0);
               [results,degfree,lag_stat] = waldlagtest(tm.Psi,tm.alpha,mybeta,tm.p,tm.pe,lag,tm.epsilon,tm.Z1,tm.Z2,tm.q1,tm.q0,tm.d,tm.T-tm.df,my_Sigma_theta);
               lag_status(1,lag) = lag_stat;
               if lag_status(1,lag)==0;
                  tm.lagorder(1,num_lgt) = results(1,1);
                  num_lgt = num_lgt+1;
               end;
            else;
               lag_status(1,lag) = 1;
            end;
         end;
      end;
   end;
   %
   if get(boot_specification.weakexo,'Value')==1;
      specification_test.weakexo = zeros(rep,tm.n);
      if my_T==tm.T;
         %
         % obtain a possible covariance matrix for estimated Psi and alpha parameters
         %
         my_Sigma_theta = [];
         ind = 0;
         if (isfield(tm,'restrict')==1)&(tm.restrict(1,1)==1);
            betaguidlg = findobj('Type','figure','Tag','BetaGUI')';
            if isempty(betaguidlg)==0;
               cointbeta = get(betaguidlg,'UserData');
               my_Sigma_theta = get(cointbeta.genalpha,'UserData');
               ind = 1;
            else;
               %
               % check if we are in the structural part
               %
               svarguidlg = findobj('Type','figure','Tag','SVARGUI')';
               if isempty(svarguidlg)==0;
                  my_Sigma_theta = tm.Sigma_theta;
                  ind = 1;
               end;
            end;
         elseif (isfield(tm,'restrict')==1)&(tm.restrict(1,1)==0);
            %
            % check if we are in the structural part
            %
            svarguidlg = findobj('Type','figure','Tag','SVARGUI')';
            if isempty(svarguidlg)==0;
               my_Sigma_theta = tm.Sigma_theta;
            end;
         end;
         [results,degfree] = weakexotest(tm.alpha,mybeta,tm.epsilon,tm.Z1,tm.Z2,tm.T-tm.df,ind,tm.modelsdir,tm.modelfile,my_Sigma_theta,use_c_restrict,tm.Psi,tm.p,tm.pe,tm.d,tm.q1,tm.q0);
         tm.weakexo = results(:,1);
      end;
   end;
   %
   if get(boot_specification.gctest,'Value')==1;
      specification_test.gctest = zeros(rep,tm.n*(tm.n-1));
      if my_T==tm.T;
         %
         % obtain a possible covariance matrix for estimated Psi and alpha parameters
         %
         my_Sigma_theta = [];
         ind = 0;
         if (isfield(tm,'restrict')==1)&(tm.restrict(1,1)==1);
            betaguidlg = findobj('Type','figure','Tag','BetaGUI')';
            if isempty(betaguidlg)==0;
               cointbeta = get(betaguidlg,'UserData');
               my_Sigma_theta = get(cointbeta.genalpha,'UserData');
               ind = 1;
            else;
               %
               % check if we are in the structural part
               %
               svarguidlg = findobj('Type','figure','Tag','SVARGUI')';
               if isempty(svarguidlg)==0;
                  my_Sigma_theta = tm.Sigma_theta;
                  ind = 1;
               end;
            end;
         elseif (isfield(tm,'restrict')==1)&(tm.restrict(1,1)==0);
            %
            % check if we are in the structural part
            %
            svarguidlg = findobj('Type','figure','Tag','SVARGUI')';
            if isempty(svarguidlg)==0;
               my_Sigma_theta = tm.Sigma_theta;
            end;
         end;
         [results,dfmat] = waldgctest(tm.Psi,tm.alpha,mybeta,tm.p,tm.pe,tm.epsilon,tm.Z1,tm.Z2,tm.q1,tm.q0,tm.d,tm.T-tm.df,ind,tm.modelsdir,tm.modelfile,my_Sigma_theta);
         tm.gctest = results(:,1);
      end;
   end;
   %
   if curr_ini.symmetric==0;
      Omega_sig = chol(tm.Omega)';
   else;
      Omega_sig = symm(tm.Omega);
   end;
   abort = '';
   draw = 1;
   showprog = get(boot_specification.progress,'Value');
   if showprog==1;
      input_var.title = ['Progress for ' int2str(rep) ' replications'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.clock = get(boot_specification.clock,'Value');
      input_var.label = 'Replication number:';
      input_var.stop = 0;
      mywait = progressdlg(0,input_var);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
   else;
      this_text = strvcat('Bootstrapping. The art of pulling oneself up by the bootstraps. Attempt started at...',' ',['Time: ' datestr(now,14)],' ','Please hold!');
      mywait = waitdlg(this_text,'bootstrap','Specification Tests Bootstrap Simulation');
      waitf = get(mywait,'UserData');
      tic;
   end;
   if tm.const_model(2)==1;
      setlogtext(strvcat(' ','Bootstrapping distributions for specification tests...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted constant',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(my_r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Restricted constant model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'resconst';
   elseif tm.const_model(3)==1;
      setlogtext(strvcat(' ','Bootstrapping distribution for specification tests...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Unrestricted constant',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(my_r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Constant model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'const';
   elseif tm.const_model(4)==1;
      setlogtext(strvcat(' ','Bootstrapping distribution for specification tests...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted linear trend',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(my_r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Restricted trend model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'restrend';
   elseif tm.const_model(5)==1;
      setlogtext(strvcat(' ','Bootstrapping distribution for specification tests...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Linear trend',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(my_r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Linear trend model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'trend';
   end;
   if get(boot_specification.bootstrap,'Value')==1;
      %
      % epsilon-file
      %
      epsfile = [curr_ini.simulatedir tm.modelfile '-' 'specification-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
      if fileexist(epsfile)==1;
         load_eps = 1;
         %
         % load old epsilons
         %
         eps_data = load(epsfile);
      else;
         load_eps = 0;
      end;
   else;
      load_eps = 0;
   end;
   %
   % replicating
   %
   prev_sample_status = 0;
   while (draw<=rep);  % should be until rep
      if showprog==1;
         abort = get(mywait,'UserData');
         if strcmp(abort,'cancel')==1;
            break;
         else;
            progressdlg([(draw/rep) draw]);
         end;
      end;
      sample_status = 0;
      %
      % check for bootstrap style
      %
      if load_eps==0;
         if get(boot_specification.parametric,'Value')==1;
            %
            % reset the random number generator
            %
            if curr_ini.random_state==2;
               randn('state',draw);
            elseif curr_ini.random_state==3;
               randn('state',sum(100*clock));
            elseif curr_ini.random_state==4;
               randn('state',sum(100*clock)+draw);
            end;
            if prev_sample_status==1;
               randn('state',sum(100*clock));
            end;
            %
            Epr = randn(tm.n,my_T+50);
            Epr = Epr(:,51:my_T+50);
            %
            % make sure draws in Epr have identity covariance matrix
            %
            Sig = (1/my_T)*Epr*Epr';
            P_sig = chol(Sig)';
            Epr = P_sig\Epr;
            Epr = Omega_sig*Epr;
         else;
            %
            % reset the random number generator
            %
            if curr_ini.random_state==2;
               rand('state',draw);
            elseif curr_ini.random_state==3;
               rand('state',sum(100*clock));
            elseif curr_ini.random_state==4;
               rand('state',sum(100*clock)+draw);
            end;
            if prev_sample_status==1;
               rand('state',sum(100*clock));
            end;
            %
            % resample from estimated epsilons
            %
            uni_draws = rand([1 my_T+50]);
            uni_draws = uni_draws(1,51:my_T+50);
            Epr = boot_draw(uni_draws,tm.epsilon,blocksize);
         end;
         if get(boot_specification.bootstrap,'Value')==1;
            bootstrap(draw).epsilon = Epr;
         end;
      else;
         Epr = eps_data.bootstrap(draw).epsilon;
      end;
      %
      % create new sample
      %
      boot = bootstrap_sample(tm,mybeta,Epr);
      %
      if check_waldlag==1;
         boot.x0 = [tm.x0(1:tm.p,:);cumsum(boot.Z0')+ones(size(boot.Z0,2),1)*tm.x0(tm.p,:)];
         %
         if tm.const_model(3)==1;
            boot.x1 = ones(size(boot.x0,1),1);
            boot.x1_r = [];
         elseif tm.const_model(2)==1;
            boot.x1 = [];
            boot.x1_r = ones(size(boot.x0,1),1);
         elseif tm.const_model(5)==1;
            boot.x1 = [ones(size(boot.x0,1),1) (1:size(boot.x0,1))'-tm.p];
            boot.x1_r = [];
         elseif tm.const_model(4)==1;
            boot.x1 = ones(size(boot.x0,1),1);
            boot.x1_r = (1:size(boot.x0,1))'-tm.p;
         end;
         %
         if isempty(boot.x1_r)==0;
            boot.x1_r = boot.x1_r(tm.p+1:size(boot.x1_r,1),:);
         end;
         %
      end;
      %
      % Computing parameters
      %
      [S_00,S_01,S_10,S_11,M_02,M_22,M_12,beta,lambda,trace_test] = mlcointbasic(boot.Z0,boot.Z1,boot.Z2,tm.n);
      if my_r>0;
         beta = beta(:,1:my_r);
         %
         % to avoid scaling problems
         %
         beta_base = beta(1:my_r,:);
         beta = beta/beta_base;
      else;
         beta = [];
      end;
      %
      if my_r>0;
         if isfield(tm,'restrict')==1;
            if tm.restrict(1,2)==1;
               [beta,newlambda,newdfbeta,stdbeta,outputtxt,new_abort] = betarestrict(S_00,S_11,S_01,S_10,beta,my_T,tm.modelsdir,tm.modelfile,0,tm.dcoint);
               if (tm.restrict(1,1)==1)&(tm.r==my_r);
                  %
                  % need to cover the case when alpha is estimated under restrictions
                  %
                  alpha = S_01*beta*inverse(beta'*S_11*beta);
                  if isempty(boot.Z2)==0;
                     Psi = M_02*inverse(M_22)-(alpha*beta'*M_12*inverse(M_22));
                     Z3 = [boot.Z2;beta'*boot.Z1];
                  else;
                     Psi = [];
                     Z3 = beta'*boot.Z1;
                  end;
                  Theta = [Psi alpha];
                  file = strcat(tm.modelsdir,'G-',int2str(tm.n),'x',int2str(my_r),'-',tm.modelfile,'.rest');
                  G = loaddata(file);
                  [Rmat,rvec] = rmatrix(G,tm.n,my_r);
                  tm.dfalpha = size(G,1);
                  if isempty(boot.Z2)==0;
                     Rmat = [zeros(tm.dfalpha,size(boot.Z2,1)*tm.n) Rmat];
                  end;
                  if curr_ini.reestbeta==0;
                     [theta,Sigma_theta,infomat,abort] = linrest(boot.Z0,Z3,Theta,Rmat,rvec);
                  else;
                     [theta,Sigma_theta,beta,newstdbeta,Z3,infomat,abort] = alpha_beta_restrict(boot.Z0,boot.Z1,boot.Z2,Z3,beta,Theta,Rmat,rvec,tm.dcoint,tm.q1,tm.modelsdir,tm.modelfile);
                  end;
                  g2 = size(theta,2);
                  alpha = theta(:,g2-tm.r+1:g2);
                  if g2>tm.r;
                     Psi = theta(:,1:g2-tm.r);
                  else;
                     Psi = [];
                  end;
                  epsilon = boot.Z0-(theta*Z3);
                  aind = tm.restrict(1,1);
               else;
                  alpha = S_01*beta*inverse(beta'*S_11*beta);
                  if isempty(boot.Z2)==0;
                     Psi = M_02*inverse(M_22)-(alpha*beta'*M_12*inverse(M_22));
                     epsilon = boot.Z0-(alpha*beta'*boot.Z1)-(Psi*boot.Z2);
                  else;
                     Psi = [];
                     epsilon = boot.Z0-(alpha*beta'*boot.Z1);
                  end;
                  Omega = (1/my_T)*epsilon*epsilon';
                  Sigma_theta = [];
                  aind = 0;
               end;
            else;
               alpha = S_01*beta*inverse(beta'*S_11*beta);
               if isempty(boot.Z2)==0;
                  Psi = M_02*inverse(M_22)-(alpha*beta'*M_12*inverse(M_22));
                  epsilon = boot.Z0-(alpha*beta'*boot.Z1)-(Psi*boot.Z2);
               else;
                  Psi = [];
                  epsilon = boot.Z0-(alpha*beta'*boot.Z1);
               end;
               Omega = (1/my_T)*epsilon*epsilon';
               Sigma_theta = [];
               aind = 0;
            end;
         else;
            alpha = S_01*beta*inverse(beta'*S_11*beta);
            if isempty(boot.Z2)==0;
               Psi = M_02*inverse(M_22)-(alpha*beta'*M_12*inverse(M_22));
               epsilon = boot.Z0-(alpha*beta'*boot.Z1)-(Psi*boot.Z2);
            else;
               Psi = [];
               epsilon = boot.Z0-(alpha*beta'*boot.Z1);
            end;
            Omega = (1/my_T)*epsilon*epsilon';
            Sigma_theta = [];
            aind = 0;
         end;
      else;
         %
         % case no cointegration
         %
         alpha = [];
         if isempty(boot.Z2)==0;
            Psi = M_02*inverse(M_22);
            epsilon = boot.Z0-(Psi*boot.Z2);
         else;
            Psi = [];
            epsilon = boot.Z0;
         end;
         Omega = (1/my_T)*epsilon*epsilon';
         Sigma_theta = [];
         aind = 0;
      end;
      %
      % taken C restrictions into account
      %
      if (tm.r==my_r)&(size(tm.restrict,2)==3)&(tm.restrict(1,3)==1);
         if draw==1;
            file = strcat(tm.modelsdir,'C-',int2str(tm.n),'x',int2str(my_r),'-',tm.modelfile,'.rest');
            G = loaddata(file);
            [Rmat_C,rvec_C] = rmatrix(G,tm.n,tm.n);
         end;
         [theta,Sigma_theta,beta,stdbeta,C,Sigma_C,num_c_rest,num_a_rest,infomat,abort] = c_restrict(boot.Z0,boot.Z1,boot.Z2,tm.restrict,beta,[Psi alpha],Rmat_C,rvec_C,tm.p,tm.pe,tm.d,tm.dcoint,tm.q0,tm.q1,tm.modelsdir,tm.modelfile,0);
         alpha = [];
         Psi = [];
         if tm.r>0;
            Z3 = beta'*boot.Z1;
            alpha = theta(:,size(theta,2)-tm.r+1:size(theta,2));
         end;
         if isempty(boot.Z2)==0;
            Z3 = [boot.Z2;Z3];
            Psi = theta(:,1:size(theta,2)-tm.r);
         end;
         epsilon = boot.Z0-(theta*Z3);
         Omega = (1/my_T)*epsilon*epsilon';
      end;
      %
      % computing tests
      %
      if isfield(specification_test,'serial')==1;
%         [results,degfreedom] = autocorr(epsilon,tm.freq,my_T-tm.df);
         [results,degfreedom] = lmautocorr(epsilon,boot.Z0,boot.Z1,boot.Z2,beta,tm.freq,my_T-tm.df);
         if draw==1;
            degf = [];
            for i=1:size(degfreedom,1);
               degi = strrep(degfreedom(i,:),'(','');
               degi = strrep(degi,')','');
               degi = mystr2num(strtrim(strrep(degi,',',' ')));
               degf = [degf;degi];
            end;
            specification_test.serial_df = degf;
         end;
         if strcmp(tm.freq,'')==0;
            specification_test.serial(draw,:) = [results(1,1) results(1,3)];
         else;
            specification_test.serial(draw,1) = results(1,1);
         end;
      end;
      %
      if isfield(specification_test,'portmanteau')==1;
         [results,degfreedom] = portmanteau_fcn(epsilon,tm.p,tm);
         if draw==1;
            degf = [];
            for i=1:size(degfreedom,1);
               degf = [degf;mystr2num(strtrim(degfreedom(i,:)))];
            end;
            specification_test.portmanteau_df = degf;
         end;
         specification_test.portmanteau(draw,1) = results(1,1);
      end;
      %
      if isfield(specification_test,'arch')==1;
         [results,dfmat] = arch(epsilon,tm.freq,my_T-tm.df);
         if draw==1;
            specification_test.arch_df = dfmat;
         end;
         if strcmp(tm.freq,'')==0;
            specification_test.arch(draw,:) = [results(:,1)' results(:,2)'];
         else;
            specification_test.arch(draw,:) = results(:,1)';
         end;
      end;
      %
      if isfield(specification_test,'march')==1;
         if draw==1;
            if curr_ini.rest_march==1;
               %
               % set up restrictions for dialgonal lag matrix
               % in multivariate ARCH model
               %
               m = (tm.n*(tm.n+1))/2;
               R_march_orth = zeros(m,m*m);
               my_eye = eye(m);
               for i=1:m;
                  e_i = my_eye(i,:);
                  R_march_orth(i,:) = kron(e_i,e_i);
               end;
               R_march = null(R_march_orth)';
               R_march = [zeros(size(R_march,1),m) R_march];
               r_arch = zeros(m*(m-1),1);
            else;
               R_march = [];
               r_arch = [];
            end;
         end;
         %
         % compute the test
         %
         [m_res,m_df] = march(epsilon,my_T-tm.df,curr_ini.rest_march,curr_ini.sscorrect,R_march,r_arch);
         specification_test.march(draw,1) = m_res(1,1);
         if draw==1;
            specification_test.march_df = m_df;
         end;
      end;
      %
      if isfield(specification_test,'normality')==1;
         [results,degfreedom] = normality(epsilon,my_T-tm.df);
         if draw==1;
            degf = [];
            for i=1:size(degfreedom,1);
               degi = strrep(degfreedom(i,:),'(','');
               degi = strrep(degi,')','');
               degi = mystr2num(strtrim(strrep(degi,',',' ')));
               degf = [degf;degi];
            end;
            specification_test.normality_df = degf;
         end;
         specification_test.normality(draw,:) = results([1 3 5]);
      end;
      %
      if isfield(specification_test,'omnibus')==1;
         [results,degfreedom] = omnibus_fcn(epsilon,my_T-tm.df);
         if draw==1;
            degi = strrep(degfreedom,'(','');
            degi = strrep(degi,')','');
            degi = mystr2num(strtrim(strrep(degi,',',' ')));
            specification_test.omnibus_df = degi;
         end;
         specification_test.omnibus(draw,1) = results(1,1);
      end;
      %
      if isfield(specification_test,'lagorder')==1;
         lag_count = 0;
         for lag=1:curr_ini.lagtest;
            if ((my_T-tm.df)-lag*(tm.n+tm.q1+tm.q0))>0;
               lag_count = lag_count+1;
               [results,degfree,mycorrect] = lmlagtest(epsilon,boot.x0,boot.x1,boot.x1_r,tm.x2,tm.p,tm.pe,lag,tm.q1,tm.q0,beta,my_T-tm.df,1,tm.modelsdir,tm.modelfile,use_c_restrict,Psi,alpha,boot.Z1,boot.Z2,tm.d);
               specification_test.lagorder(draw,lag_count) = results(1,1);
               if draw==1;
                  specification_test.lagorder_df(lag_count).df = degfree;
                  specification_test.lagorder_correct(1,lag_count) = mycorrect;
               end;
            end;
            %
            if lag_status(1,lag)==0;
               if (tm.p-lag)>=1;
                  lag_count = lag_count+1;
                  %
                  % the null is here by definition false. need to restrict Psi, alpha, beta such that the null
                  % hypothesis is true when generating data, and then reestimate the parameters without the
                  % lag order restrictions
                  if draw==1;
                     %
                     % Setting up the matrix with restrictions
                     %
                     R2 = [];
                     R3 = [];
                     R4 = [];
                     if tm.p-lag-1>0;
                        R1 = [zeros(tm.n*lag,tm.d) zeros(tm.n*lag,tm.n*(tm.p-lag-1)) eye(tm.n*lag)];
                     else;
                        R1 = [zeros(tm.n*lag,tm.d) eye(tm.n*lag)];
                     end;
                     if my_r>0;
                        R4 = zeros(tm.n*lag,my_r);
                     end;
                     if tm.pe-lag>0;
                        if (tm.q1>0)&(tm.q0==0);
                           R1 = [R1 zeros(tm.n*lag,tm.q1*tm.pe)];
                           R2 = [zeros(tm.q1*lag,tm.d) zeros(tm.q1*lag,tm.n*(tm.p-1)) zeros(tm.q1*lag,tm.q1*(tm.pe-lag)) eye(tm.q1*lag)];
                           if my_r>0;
                              R4 = [R4;zeros(tm.q1*lag,my_r)];
                           end;
                        elseif (tm.q1>0)&(tm.q0>0);
                           R1 = [R1 zeros(tm.n*lag,tm.q1*tm.pe) zeros(tm.n*lag,tm.q0*(tm.pe+1))];
                           R2 = [zeros(tm.q1*lag,tm.d) zeros(tm.q1*lag,tm.n*(tm.p-1)) zeros(tm.q1*lag,tm.q1*(tm.pe-lag)) eye(tm.q1*lag) zeros(tm.q1*lag,tm.q0*(tm.pe+1))];
                           R3 = [zeros(tm.q0*lag,tm.d) zeros(tm.q0*lag,tm.n*(tm.p-1)) zeros(tm.q0*lag,tm.q1*tm.pe) zeros(tm.q0*lag,tm.q0*(tm.pe-lag+1)) eye(tm.q0*lag)];
                           if my_r>0;
                              R4 = [R4;zeros((tm.q1+tm.q0)*lag,my_r)];
                           end;
                        elseif (tm.q1==0)&(tm.q0>0);
                           R1 = [R1 zeros(tm.n*lag,tm.q0*(tm.pe+1))];
                           R3 = [zeros(tm.q0*lag,tm.d) zeros(tm.q0*lag,tm.n*(tm.p-1)) zeros(tm.q0*lag,tm.q0*(tm.pe-lag+1)) eye(tm.q0*lag)];
                           if my_r>0;
                              R4 = [R4;zeros(tm.q0*lag,my_r)];
                           end;
                        end;
                     else;
                        if tm.q1+tm.q0>0;
                           R1 = [R1 zeros(tm.n*lag,(tm.q1*tm.pe)+(tm.q0*(tm.pe+1)))];
                        end;
                     end;
                     %
                     R = [R1;R2;R3];
                     R = [R R4];
                     R = kron(R,eye(tm.n));
                     r_vec = zeros(size(R,1),1);
                     %
                     % add any extra restrictions on alpha
                     %
                     if isfield(tm,'restrict')==1;
                        if (tm.restrict(1,1)==1)&(tm.r==my_r);
                           file = strcat(tm.modelsdir,'G-',int2str(tm.n),'x',int2str(my_r),'-',tm.modelfile,'.rest');
                           G = loaddata(file);
                           [Rmat,rvec] = rmatrix(G,tm.n,my_r);
                           tm.dfalpha = size(G,1);
                           if isempty(boot.Z2)==0;
                              Rmat = [zeros(tm.dfalpha,size(boot.Z2,1)*tm.n) Rmat];
                           end;
                           R = [R;Rmat];
                           r_vec = [r_vec;rvec];
                        end;
                     end;
                     rest_lag(lag).R = R;
                     rest_lag(lag).r_vec = r_vec;
                  end;
                  %
                  % estimate model under new restrictions
                  %
                  Theta = [Psi alpha];
                  if my_r>0;
                     if isempty(boot.Z2)==0;
                        boot.Z3 = [boot.Z2;beta'*boot.Z1];
                     else;
                        boot.Z3 = beta'*boot.Z1;
                     end;
                  else;
                     if isempty(boot.Z2)==0;
                        boot.Z3 = boot.Z2;
                     else;
                        boot.Z3 = [];
                     end;
                  end;
                  [nboot,nPsi,nalpha,nbeta,nepsilon,nSigma_theta,sample_status] = bootstrap_restrict(tm,curr_ini,boot,Epr,Omega_sig,my_r,my_T,Theta,beta,rest_lag(lag).R,rest_lag(lag).r_vec);
                  if sample_status==0;
                     %
                     % run the test
                     %
                     [results,degfree,lag_stat] = waldlagtest(nPsi,nalpha,nbeta,tm.p,tm.pe,lag,nepsilon,nboot.Z1,nboot.Z2,tm.q1,tm.q0,tm.d,my_T-tm.df,nSigma_theta);
                     specification_test.lagorder(draw,lag_count) = results(1,1);
                     if draw==1;
                        specification_test.lagorder_df(lag_count).df = degfree;
                     end;
                  end;
               end;
            end;
         end;
      end;
      %
      if isfield(specification_test,'weakexo')==1;
         %
         % we must restrict alpha to ensure that the null is true
         %
         results = zeros(tm.n,1);
         if curr_ini.sscorrect==1;
            degfree = zeros(tm.n,2);
         else;
            degfree = zeros(tm.n,1);
         end;
         for i=1:tm.n;
            %
            % set up a structure for the restrictions which is created during
            % the first bootstrap draw
            %
            if draw==1;
               Rmat = [];
               rvec = [];
               R = zeros(my_r,tm.n*my_r);
               for j=1:my_r;
                  R(j,i+tm.n*(j-1)) = 1;
               end;
               nr = size(R,1);
               r_vec = zeros(nr,1);
               if aind==1;
                  file = strcat(tm.modelsdir,'G-',int2str(tm.n),'x',int2str(my_r),'-',tm.modelfile,'.rest');
                  G = loaddata(file);
                  if isempty(G)==0;
                     [Rmat,rvec] = rmatrix(G,tm.n,my_r);
                     dfa = size(Rmat,1);
                     [delrest,keeprest] = getdelvars([Rmat' R'],[]);
                     if size(keeprest,1)==dfa;
                        nr = 0;
                     elseif size(keeprest,1)==dfa+nr;
                        Hcheck = null([Rmat;R]);
                        thisR = [Rmat;R];
                        thisr = [rvec;r_vec];
                        h_check = (thisR'/(thisR*thisR'))*thisr;
                        checkalpha = Hcheck*randn(size(Hcheck,2),1)+h_check;
                        checkalpha = vecinv(checkalpha,tm.n);
                        if rank(checkalpha)~=my_r;
                           nr = 0;
                        end; 
                     else;
                        keeprest = keeprest(dfa+1:size(keeprest,1),1);
                        keeprest = keeprest-dfa;
                        R = R(keeprest,:);
                        r_vec = r_vec(keeprest,:);
                        Hcheck = null([Rmat;R]);
                        thisR = [Rmat;R];
                        thisr = [rvec;zeros(size(R,1),1)];
                        h_check = (thisR'/(thisR*thisR'))*thisr;
                        checkalpha = Hcheck*randn(size(Hcheck,2),1)+h_check;
                        checkalpha = vecinv(checkalpha,tm.n);
                        if rank(checkalpha)==my_r;
                           nr = size(R,1);
                        else;
                           nr = 0;
                        end; 
                     end;
                  else;
                     rvec = [];
                  end;
               else;
                  rvec = [];
               end;
               if nr>0;
                  R = [R;Rmat];
                  if isempty(boot.Z2)==0;
                     R = [zeros(size(R,1),tm.n*size(boot.Z2,1)) R];
                  end;
                  r_vec = [r_vec;rvec];
                  rest_weakexo(i).R = R;
                  rest_weakexo(i).r_vec = r_vec;
                  rest_weakexo(i).nr = nr;
               else;
                  rest_weakexo(i).R = [];
                  rest_weakexo(i).r_vec = [];
                  rest_weakexo(i).nr = 0;
               end;
            end;
            %
            if rest_weakexo(i).nr>0;
               %
               % estimate under restrictions
               %
               Theta = [Psi alpha];
               if isempty(boot.Z2)==0;
                  boot.Z3 = [boot.Z2;beta'*boot.Z1];
               else;
                  boot.Z3 = beta'*boot.Z1;
               end;
               [nboot,nPsi,nalpha,nbeta,nepsilon,nSigma_theta,sample_status] = bootstrap_restrict(tm,curr_ini,boot,Epr,Omega_sig,my_r,my_T,Theta,beta,rest_weakexo(i).R,rest_weakexo(i).r_vec);
               if sample_status==0;
                  %
                  % get test results
                  %
                  [results(i,1),degfree(i,:)] = weakexo_boot(nalpha,nbeta,nepsilon,nboot.Z1,nboot.Z2,my_T-tm.df,aind,tm.modelsdir,tm.modelfile,Sigma_theta,i,use_c_restrict,nPsi,tm.p,tm.pe,tm.d,tm.q1,tm.q0);
                  if isequal(imag(results(i,1)),0)==0;
                     results(i,1) = 0;
                  end;
               end;
            end;
         end;
         specification_test.weakexo(draw,:) = results(:,1)';
         if draw==1;
            specification_test.weakexo_df = degfree;
         end;
      end;
      %
      if isfield(specification_test,'gctest')==1;
         %
         % we must restrict alpha and Psi such that the null is true
         %
         if draw==1;
            In = eye(tm.n);
            Rmat = [];
            if aind==1;
               file = strcat(tm.modelsdir,'G-',int2str(tm.n),'x',int2str(my_r),'-',tm.modelfile,'.rest');
               G = loaddata(file);
               [Rmat,rvec] = rmatrix(G,tm.n,my_r);
               tm.dfalpha = size(G,1);
               if isempty(boot.Z2)==0;
                  Rmat = [zeros(tm.dfalpha,size(boot.Z2,1)*tm.n) Rmat];
               end;
            else;
               Rmat = [];
               rvec = [];
               tm.dfalpha = 0;
            end;



%            if use_c_restrict==1;
%               file = strcat(tm.modelsdir,'C-',int2str(tm.n),'x',int2str(my_r),'-',tm.modelfile,'.rest');
%               F = loaddata(file);
%               [Rmat_C,rvec_C] = rmatrix(F,tm.n,tm.n);
%               if r<n;
%                  C = cmat(Psi,alpha,beta,epsilon,boot.Z1,boot.Z2,tm.p,tm.d,0);
%               else;
%                  C = cmat_stat(Psi,alpha,beta,epsilon,boot.Z1,boot.Z2,tm.p,tm.d,0,[]);
%               end;
%               xi = xi_mat(C,Psi,alpha,tm.p,tm.pe,my_r,tm.d,tm.q1,tm.q0);
%               Rmat_C = Rmat_C*kron(xi',C);
%               Rmat = [Rmat;Rmat_C];
%               if rank(Rmat)<size(Rmat,1);
%                  [red_rest,use_rest] = getdelvars(Rmat',[]);
%                  Rmat = Rmat(use_rest,:);
%               end;
%               tm.dfalpha = size(Rmat,1);
%            end;



            if my_r>0;
               beta_y = beta(1:tm.n,:);
            else;
               beta_y = [];
            end;
            nreg = size(boot.Z2,1)+my_r;
            if nreg>my_r;
               if my_r>0;
                  fixpi = [[eye(tm.n*(nreg-my_r)) zeros(tm.n*(nreg-my_r),tm.n*my_r)];[zeros(tm.n*tm.n,tm.n*(nreg-my_r)) kron(beta_y,eye(tm.n))]];
               else;
                  fixpi = [eye(tm.n*nreg);zeros(tm.n*tm.n,tm.n*nreg)];
               end;
            else;
               if my_r>0;
                  fixpi = kron(beta_y,eye(tm.n));
               end;
            end;
         end;
         %
         results = zeros(tm.n*(tm.n-1),1);
         if curr_ini.sscorrect==1;
            df = zeros(tm.n*(tm.n-1),2);
         else;
            df = zeros(tm.n*(tm.n-1),1);
         end;
         %
         num = 0;
         for i=1:tm.n;
            for k=1:tm.n;
               if isequal(i,k)==0
                  num = num+1;
                  %
                  % create restrictions matrices once and store in structure
                  %
                  if draw==1;
                     Nk = [];
                     ei = In(:,i);
                     ek = In(:,k);
                     %
                     % Setting up the matrix with restrictions
                     %
                     if tm.p>1;
                        if tm.d>0;
                           Nk = zeros(tm.d,tm.p-1);
                        end;
                        Nk = [Nk;kron(eye(tm.p-1),ek)];
                        if tm.q1>0;
                           Nk = [Nk;zeros(tm.pe*tm.q1,tm.p-1)];
                        end;
                        if tm.q0>0;
                           Nk = [Nk;zeros((tm.pe+1)*tm.q0,tm.p-1)];
                        end;
                     else;
                        Nk = [];
                     end;
                     Nklev = Nk;
                     if my_r>0;
                        Np = [];
                        Nplev = Np;
                        if tm.d>0;
                           Np = zeros(tm.d,1);
                           Nplev = Np;
                        end;
                        if tm.p>1;
                           Nk = [Nk;zeros(my_r,tm.p-1)];
                           Np = [Np;zeros(tm.n*(tm.p-1),1)];
                           Nklev = [Nklev;zeros(tm.n,tm.p-1)];
                           Nplev = [Nplev;zeros(tm.n*(tm.p-1),1)];
                        end;
                        if tm.q1>0;
                           Np = [Np;zeros(tm.pe*tm.q1,1)];
                           Nplev = [Nplev;zeros(tm.pe*tm.q1,1)];
                        end;
                        if tm.q0>0;
                           Np = [Np;zeros((tm.pe+1)*tm.q0,1)];
                           Nplev = [Nplev;zeros((tm.pe+1)*tm.q0,1)];
                        end;
                        if max(abs(beta_y'*ek))>1.0e-005;
                           Np = [Np;beta_y'*ek];
                           Nplev = [Nplev;ek];
                        else;
                           Np = [];
                           Nplev = [];
                        end;
                        Nk = [Nk Np];
                        Nklev = [Nklev Nplev];
                     end;
                     R = kron(Nk',ei');
                     Rlev = kron(Nklev',ei');
                     r_vec = zeros(tm.p,1);
                     if isempty(R)==1;
                        Rlev = [];
                        r_vec = [];
                     else;
                        if my_r>0;
                           if isempty(Rmat)==0;
                              [delrest,keeprest] = getdelvars([Rmat' R'],[]);
                              if size(keeprest,1)==tm.dfalpha;
                                 Rlev = [];
                                 r_vec = [];
                              elseif size(keeprest,1)==tm.dfalpha+size(R,1);
                                 R = [R;Rmat];
                                 r_vec = [r_vec;rvec];
                              else;
                                 keeprest = keeprest(tm.dfalpha+1:size(keeprest,1),1);
                                 keeprest = keeprest-tm.dfalpha;
                                 Rlev = Rlev(keeprest,:);
                                 R = R(keeprest,:);
                                 R = [R;Rmat];
                                 r_vec = r_vec(keeprest,:);
                                 r_vec = [r_vec;rvec];
                              end;
                           else;
                              r_vec = [r_vec;rvec];
                           end;
                        else;
                           if tm.p>1;
                              Rlev = [Rlev zeros( size(Rlev,1) , size(fixpi,1)-size(Rlev,2) )];
                              r_vec = zeros(tm.p-1,1);
                           else;
                              Rlev = [];
                              r_vec = [];
                           end;
                        end;
                     end;
                     rest_gctest(i,k).Rlev = Rlev;
                     rest_gctest(i,k).R = R;
                     rest_gctest(i,k).r_vec = r_vec;
                  end;
                  %
                  % create new pseudo data based on the restrictions and estimate new values for
                  % the parameters using the new pseudo data
                  %
                  if isempty(rest_gctest(i,k).Rlev)==0;
                     Theta = [Psi alpha];
                     if my_r>0;
                        if isempty(boot.Z2)==0;
                           boot.Z3 = [boot.Z2;beta'*boot.Z1];
                        else;
                           boot.Z3 = beta'*boot.Z1;
                        end;
                     else;
                        if isempty(boot.Z2)==0;
                           boot.Z3 = boot.Z2;
                        else;
                           boot.Z3 = [];
                        end;
                     end;
                     [nboot,nPsi,nalpha,nbeta,nepsilon,nSigma_theta,sample_status] = bootstrap_restrict(tm,curr_ini,boot,Epr,Omega_sig,my_r,my_T,Theta,beta,rest_gctest(i,k).R,rest_gctest(i,k).r_vec);
                     if sample_status==0;
                        %
                        % computing the test
                        %
                        [results(num,1),df(num,:)] = waldgc_boot(nPsi,nalpha,nbeta,tm.p,nepsilon,nboot.Z1,nboot.Z2,tm.q1,tm.q0,tm.d,my_T-tm.df,aind,tm.modelsdir,tm.modelfile,nSigma_theta,rest_gctest(i,k).Rlev,use_c_restrict);
                     end;
                  end;
               end;
            end;
         end;
         %
         % collecting results
         %
         specification_test.gctest(draw,:) = results(:,1)';
         if draw==1;
            specification_test.gctest_df = df;
         end;
      end;
      if sample_status==0;
         draw = draw+1;
         prev_sample_status = 0;
      else;
         prev_sample_status = 1;
      end;
   end;
   %
   % bootstrap has finished
   %
   if showprog==1;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   else;
      set(waitf.text,'UserData','done');
      delete(mywait);
      drawnow;
      new_time = toc;
      my_hrs = '00';
      my_min = '00';
      my_sec = num2str(new_time,'%0.2f');
      if new_time>=60;
         ch_min = floor(new_time/60);
         my_sec = num2str(new_time-(ch_min*60),'%0.2f');
         my_min = num2str(ch_min,'%0.0f');
         if ch_min>=60;
            ch_hrs = floor(ch_min/60);
            my_min = num2str(ch_min-(ch_hrs*60),'%0.0f');
            my_hrs = num2str(ch_hrs,'%0.0f');
         end;
      end;
      if size(my_sec,2)==4;
         my_sec = ['0' my_sec];
      end;
      if size(my_min,2)==1;
         my_min = ['0' my_min];
      end;
      if size(my_hrs,2)==1;
         my_hrs = ['0' my_hrs];
      end;
      clock_str = [my_hrs ':' my_min ':' my_sec];
      this_text = strvcat('The bootstrapping process took:',' ',['    ' clock_str ' (hrs:min:sec)']);
      about(this_text,'bootstrap','Simulation Time',120,350);
   end;
   %
   % if we don't cancel
   %
   if (strcmp(abort,'cancel')==0)&(isempty(specification_test)==0);
      this_text = strvcat(' ','Saving bootstrap results to disk...','Please hold!');
      mywait = waitdlg(this_text,'bootstrap','Specification Tests Bootstrap Simulation');
      waitf = get(mywait,'UserData');
      if get(boot_specification.bootstrap,'Value')==1;
         if load_eps==0;
            this_text = strvcat(' ','Saving bootstrapped residuals to disk...','Please hold!');
            set(waitf.text,'String',this_text);
            save(epsfile,'bootstrap');
         end;
         clear('bootstrap');
         testfile = strrep(epsfile,'.mat','-specification-data.mat');
         save(testfile,'specification_test');
         clear('test_data');
         set(boot_specification.bootstrapgraph,'Enable','on','UserData',epsfile);
         set(boot_specification.bootstrapgraphmenu,'Enable','on','UserData',testfile);
      end;
      setlogtext(['Bootstrap simulation completed at: ' datestr(now,14) '!']);
      %
      % sort the test
      %
      specification_sorted = [];
      %
      % serial correlation
      %
      if isfield(specification_test,'serial')==1;
         specification_sorted.serial = specification_test.serial;
         for i=1:size(specification_test.serial,2);
            specification_sorted.serial(:,i) = sort(specification_sorted.serial(:,i));
         end;
         specification_sorted.serial_df = specification_test.serial_df;
      end;
      %
      % portmanteau test
      %
      if isfield(specification_test,'portmanteau')==1;
         specification_sorted.portmanteau = sort(specification_test.portmanteau);
         specification_sorted.portmanteau_df = specification_test.portmanteau_df;
      end;
      %
      % arch test
      %
      if isfield(specification_test,'arch')==1;
         specification_sorted.arch = specification_test.arch;
         for i=1:size(specification_test.arch,2);
            specification_sorted.arch(:,i) = sort(specification_sorted.arch(:,i));
         end;
         specification_sorted.arch_df = specification_test.arch_df;
      end;
      %
      % march test
      %
      if isfield(specification_test,'march')==1;
         specification_sorted.march = sort(specification_test.march);
         specification_sorted.march_df = specification_test.march_df;
      end;
      %
      % normality tests
      %
      if isfield(specification_test,'normality')==1;
         specification_sorted.normality = specification_test.normality;
         for i=1:3;
            specification_sorted.normality(:,i) = sort(specification_sorted.normality(:,i));
         end;
         specification_sorted.normality_df = specification_test.normality_df;
      end;
      %
      % omnibus test
      %
      if isfield(specification_test,'omnibus')==1;
         specification_sorted.omnibus = sort(specification_test.omnibus);
         specification_sorted.omnibus_df = specification_test.omnibus_df;
      end;
      %
      % lag order test
      %
      if isfield(specification_test,'lagorder')==1;
         specification_sorted.lagorder = specification_test.lagorder;
         for i=1:size(specification_test.lagorder,2);
            specification_sorted.lagorder(:,i) = sort(specification_test.lagorder(:,i));
         end;
         specification_sorted.lagorder_df = specification_test.lagorder_df;
         specification_sorted.lagorder_correct = specification_test.lagorder_correct;
      end;
      %
      % weak exogeneity tests
      %
      if isfield(specification_test,'weakexo')==1;
         specification_sorted.weakexo = specification_test.weakexo;
         for i=1:tm.n;
            specification_sorted.weakexo(:,i) = sort(specification_test.weakexo(:,i));
         end;
         specification_sorted.weakexo_df = specification_test.weakexo_df;
      end;
      %
      % Granger causality tests
      %
      if isfield(specification_test,'gctest')==1;
         specification_sorted.gctest = specification_test.gctest;
         for i=1:tm.n*(tm.n-1);
            specification_sorted.gctest(:,i) = sort(specification_test.gctest(:,i));
         end;
         specification_sorted.gctest_df = specification_test.gctest_df;
      end;
      %
      % empirical size
      %
      e_size = [];
      if isfield(specification_test,'serial')==1;
         this_text = strvcat(' ',['Determining the empirical size of the serial correlation tests...'],'Please hold!');
         set(waitf.text,'String',this_text);
         e_size.serial = zeros(size(specification_sorted.serial,2),5);
         for j=1:size(specification_sorted.serial,2);
            if curr_ini.sscorrect==1;
               my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.serial_df(j,1)*ones(5,1),specification_sorted.serial_df(j,2)*ones(5,1));
            else;
               my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.serial_df(j,1)*ones(5,1));
            end;
            for i=1:5;
               for j1=1:rep;
                  if my_cv(i,1)>=specification_sorted.serial(rep+1-j1,j);
                     e_size.serial(j,i) = (rep+1-j1)/rep;
                     break;
                  end;
               end;
            end;
         end;
      end;
      %
      if isfield(specification_test,'portmanteau')==1;
         this_text = strvcat(' ',['Determining the empirical size of the Portmanteau test...'],'Please hold!');
         set(waitf.text,'String',this_text);
         e_size.portmanteau = zeros(1,5);
         my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.portmanteau_df(1,1)*ones(5,1));
         for i=1:5;
            for j1=1:rep;
               if my_cv(i,1)>=specification_sorted.portmanteau(rep+1-j1,1);
                  e_size.portmanteau(1,i) = (rep+1-j1)/rep;
                  break;
               end;
            end;
         end;
      end;
      %
      if isfield(specification_test,'arch')==1;
         this_text = strvcat(' ',['Determining the empirical size of the univariate ARCH tests...'],'Please hold!');
         set(waitf.text,'String',this_text);
         e_size.arch = zeros(5,size(specification_sorted.arch,2));
         if curr_ini.sscorrect==1;
            my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.arch_df(1,1)*ones(5,1),specification_sorted.arch_df(1,2)*ones(5,1));
         else;
            my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.arch_df(1,1)*ones(5,1));
         end;
         for j=1:5;
            for i=1:tm.n;
               for j1=1:rep;
                  if my_cv(j,1)>=specification_sorted.arch(rep+1-j1,i);
                     e_size.arch(j,i) = (rep+1-j1)/rep;
                     break;
                  end;
               end;
            end;
         end;
         if strcmp(tm.freq,'')==0;
            if curr_ini.sscorrect==1;
               my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.arch_df(1,3)*ones(5,1),specification_sorted.arch_df(1,4)*ones(5,1));
            else;
               my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.arch_df(1,2)*ones(5,1));
            end;
            for j=1:5;
               for i=1:tm.n;
                  for j1=1:rep;
                     if my_cv(j,1)>=specification_sorted.arch(rep+1-j1,tm.n+i);
                        e_size.arch(j,tm.n+i) = (rep+1-j1)/rep;
                        break;
                     end;
                  end;
               end;
            end;
         end;
      end;
      %
      if isfield(specification_test,'march')==1;
         this_text = strvcat(' ',['Determining the empirical size of the multivariate ARCH test...'],'Please hold!');
         set(waitf.text,'String',this_text);
         e_size.march = zeros(1,5);
         if curr_ini.sscorrect==0;
            my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.march_df(1,1)*ones(5,1));
         else;
            my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.march_df(1,1)*ones(5,1),specification_sorted.march_df(1,2)*ones(5,1));
         end;
         for i=1:5;
            for j=1:rep;
               if my_cv(i,1)>=specification_sorted.march(rep+1-j,1);
                  e_size.march(1,i) = (rep+1-j)/rep;
                  break;
               end;
            end;
         end;
      end;
      %
      if isfield(specification_test,'normality')==1;
         this_text = strvcat(' ',['Determining the empirical size of the Normality tests...'],'Please hold!');
         set(waitf.text,'String',this_text);
         e_size.normality = zeros(3,5);
         for i=1:3;
            if curr_ini.sscorrect==1;
               my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.normality_df(i,1)*ones(5,1),specification_sorted.normality_df(i,2)*ones(5,1));
            else;
               my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.normality_df(i,1)*ones(5,1));
            end;
            for j=1:5;
               for j1=1:rep;
                  if my_cv(j,1)>=specification_sorted.normality(rep+1-j1,i);
                     e_size.normality(i,j) =(rep+1-j1)/rep;
                     break;
                  end;
               end;
            end;
         end;
      end;
      %
      if isfield(specification_test,'omnibus')==1;
         this_text = strvcat(' ',['Determining the empirical size of the Shenton-Bowman/Doornik-Hansen test...'],'Please hold!');
         set(waitf.text,'String',this_text);
         e_size.omnibus = zeros(1,5);
         if curr_ini.sscorrect==1;
            my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.omnibus_df(1,1)*ones(5,1),specification_sorted.omnibus_df(1,2)*ones(5,1));
         else;
            my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.omnibus_df(1,1)*ones(5,1));
         end;
         for i=1:5;
            for j=1:rep;
               if my_cv(i,1)>=specification_sorted.omnibus(rep+1-j,1);
                  e_size.omnibus(1,i) = (rep+1-j)/rep;
                  break;
               end;
            end;
         end;
      end;
      %
      if isfield(specification_test,'lagorder')==1;
         this_text = strvcat(' ',['Determining the empirical size of the Lag Order Tests...'],'Please hold!');
         set(waitf.text,'String',this_text);
         e_size.lagorder = zeros(5,size(specification_sorted.lagorder,2));
         for lag_count=1:size(specification_test.lagorder,2);
            if specification_sorted.lagorder_correct(1,lag_count)==1;
               my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.lagorder_df(lag_count).df(1,1)*ones(5,1),specification_sorted.lagorder_df(lag_count).df(1,2)*ones(5,1));
            else;
               my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.lagorder_df(lag_count).df(1,1)*ones(5,1));
            end;
            for i=1:5;
               for j=1:rep;
                  if my_cv(i,1)>=specification_sorted.lagorder(rep+1-j,lag_count);
                     e_size.lagorder(i,lag_count) = (rep+1-j)/rep;
                     break;
                  end;
               end;
            end;
         end;
      end;
      %
      if isfield(specification_test,'weakexo')==1;
         this_text = strvcat(' ',['Determining the empirical size of the Weak Exogeneity Tests...'],'Please hold!');
         set(waitf.text,'String',this_text);
         e_size.weakexo = zeros(5,tm.n);
         for i=1:tm.n;
            if specification_test.weakexo_df(i,1)>0;
               if curr_ini.sscorrect==1;
                  my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.weakexo_df(i,1)*ones(5,1),specification_sorted.weakexo_df(i,2)*ones(5,1));
               else;
                  my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.weakexo_df(i,1)*ones(5,1));
               end;
               for i1=1:5;
                  for j=1:rep;
                     if my_cv(i1,1)>=specification_sorted.weakexo(rep+1-j,i);
                        e_size.weakexo(i1,i) = (rep+1-j)/rep;
                        break;
                     end;
                  end;
               end;
            end;
         end;
      end;
      %
      if isfield(specification_test,'gctest')==1;
         this_text = strvcat(' ',['Determining the empirical size of the Granger Causality Tests...'],'Please hold!');
         set(waitf.text,'String',this_text);
         e_size.gctest = zeros(5,tm.n*(tm.n-1));
         for i=1:tm.n*(tm.n-1);
            if specification_test.gctest_df(i,1)>0;
               if curr_ini.sscorrect==1;
                  my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.gctest_df(i,1)*ones(5,1),specification_sorted.gctest_df(i,2)*ones(5,1));
               else;
                  my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.gctest_df(i,1)*ones(5,1));
               end;
               for i1=1:5;
                  for j=1:rep;
                     if my_cv(i1,1)>=specification_sorted.gctest(rep+1-j,i);
                        e_size.gctest(i1,i) = (rep+1-j)/rep;
                        break;
                     end;
                  end;
               end;
            end;
         end;
      end;
      %
      % p-values
      %
      pval = [];
      if my_T==tm.T;
         %
         % serial correlation tests
         %
         if isfield(specification_test,'serial')==1;
            pval.serial = zeros(1,size(specification_sorted.serial,2));
            for i=1:size(specification_sorted.serial,2);
               for j=1:rep;
                  if tm.serial(1,i)>=specification_sorted.serial(rep+1-j,i);
                     pval.serial(1,i) = (j-1)/rep;
                     break;
                  end;
                  if j==rep;
                     pval.serial(1,i) = 1;
                  end;
               end;
            end;
         end;
         %
         % portmanteau test
         %
         if isfield(specification_test,'portmanteau')==1;
            pval.portmanteau = 0;
            for j=1:rep;
               if tm.portmanteau>=specification_sorted.portmanteau(rep+1-j,1);
                  pval.portmanteau = (j-1)/rep;
                  break;
               end;
               if j==rep;
                  pval.portmanteau = 1;
               end;
            end;
         end;
         %
         % arch test
         %
         if isfield(specification_test,'arch')==1;
            pval.arch = zeros(1,size(specification_sorted.arch,2));
            for i=1:size(specification_sorted.arch,2);
               for j=1:rep;
                  if tm.arch(1,i)>=specification_sorted.arch(rep+1-j,i);
                     pval.arch(1,i) = (j-1)/rep;
                     break;
                  end;
                  if j==rep;
                     pval.arch(1,i) = 1;
                  end;
               end;
            end;
         end;
         %
         % march test
         %
         if isfield(specification_test,'march')==1;
            pval.march = 0;
            for j=1:rep;
               if tm.march>=specification_sorted.march(rep+1-j,1);
                  pval.march = (j-1)/rep;
                  break;
               end;
               if j==rep;
                  pval.march = 1;
               end;
            end;
         end;
         %
         % normality test
         %
         if isfield(specification_test,'normality')==1;
            pval.normality = zeros(1,3);
            for i=1:3;
               for j=1:rep;
                  if tm.normality(1,i)>=specification_sorted.normality(rep+1-j,i);
                     pval.normality(1,i) = (j-1)/rep;
                     break;
                  end;
                  if j==rep;
                     pval.normality(1,i) = 1;
                  end;
               end;
            end;
         end;
         %
         % omnibus test
         %
         if isfield(specification_test,'omnibus')==1;
            pval.omnibus = 0;
            for j=1:rep;
               if tm.omnibus>=specification_sorted.omnibus(rep+1-j,1);
                  pval.omnibus = (j-1)/rep;
                  break;
               end;
               if j==rep;
                  pval.omnibus = 1;
               end;
            end;
         end;
         %
         % lag order tests
         %
         if isfield(specification_test,'lagorder')==1;
            pval.lagorder = zeros(1,size(specification_test.lagorder,2));
            for i=1:size(specification_test.lagorder,2);
               for j=1:rep;
                  if tm.lagorder(1,i)>=specification_sorted.lagorder(rep+1-j,i);
                     pval.lagorder(1,i) = (j-1)/rep;
                     break;
                  end;
                  if j==rep;
                     pval.lagorder(1,i) = 1;
                  end;
               end;
            end;
         end;
         %
         % weak exogeneity tests
         %
         if isfield(specification_test,'weakexo')==1;
            pval.weakexo = zeros(1,tm.n);
            for i=1:tm.n;
               if specification_test.weakexo_df(i,1)>0;
                  for j=1:rep;
                     if tm.weakexo(i,1)>=specification_sorted.weakexo(rep+1-j,i);
                        pval.weakexo(1,i) = (j-1)/rep;
                        break;
                     end;
                     if j==rep;
                        pval.weakexo(1,i) = 1;
                     end;
                  end;
               end;
            end;
         end;
         %
         % Granger causality tests
         %
         if isfield(specification_test,'gctest')==1;
            pval.gctest = zeros(1,tm.n*(tm.n-1));
            for i=1:tm.n*(tm.n-1);
               if specification_test.gctest_df(i,1)>0;
                  for j=1:rep;
                     if tm.gctest(i,1)>=specification_sorted.gctest(rep+1-j,i);
                        pval.gctest(1,i) = (j-1)/rep;
                        break;
                     end;
                     if j==rep;
                        pval.gctest(1,i) = 1;
                     end;
                  end;
               end;
            end;
         end;
      end;
      %
      set(boot_specification.rep,'UserData',rep);
      set(boot_specification.obs,'UserData',my_T);
      set(boot_specification.my_r,'UserData',my_r);
      set(boot_specification.displaymenu,'Enable','on','UserData',tm.const_model);
      if tm.const_model(2)==1;
         my_mod = 'Restricted constant';
      elseif tm.const_model(3)==1;
         my_mod = 'Constant';
      elseif tm.const_model(4)==1;
         my_mod = 'Restricted linear trend';
      elseif tm.const_model(5)==1;
         my_mod = 'Linear trend';
      end;
      %
      % save full simulations
      %
      if get(boot_specification.save,'Value')==1;
         this_text = strvcat(' ','Saving bootstrapped specification tests to disk...','Please hold!');
         set(waitf.text,'String',this_text);
         setlogtext('Saving results to mat-files...');
         if tm.const_model(1)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-specification-boot-full-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
         elseif tm.const_model(2)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-specification-boot-full-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
         elseif tm.const_model(3)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-specification-boot-full-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
         elseif tm.const_model(4)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-specification-boot-full-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
         elseif tm.const_model(5)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-specification-boot-full-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
         end;
         Number = (1:1:rep)';
         save(full_mat,'Number','specification_sorted');
         set(boot_specification.fullmenu,'Enable','on','UserData',full_mat);
         set(boot_specification.full,'Enable','on');
      end;
      setlogtext('Saving simulation summary to text file...');
      clear('specification_test');
      this_text = strvcat(' ','Writing bootstrap summary information to disk...','Please hold!');
      set(waitf.text,'String',this_text);
      %
      % write summary to file
      %
      if tm.const_model(1)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-specification-boot-summary-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
      elseif tm.const_model(2)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-specification-boot-summary-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
      elseif tm.const_model(3)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-specification-boot-summary-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
      elseif tm.const_model(4)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-specification-boot-summary-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
      elseif tm.const_model(5)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-specification-boot-summary-' bootstyle tm.testtype tm.resalpha tm.resbeta num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
      end;
      %
      my_80 = floor(0.8*rep);
      my_90 = floor(0.9*rep);
      my_95 = floor(0.95*rep);
      my_975 = floor(0.98*rep);
      my_99 = floor(0.99*rep);
      prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
      prt_tex = ['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'];
      sp_str = spacestr(curr_ini.decimals-2);
      res_str = strvcat(' ','**************************************************************','*                          Results                           *');
      res_str = strvcat(res_str,'**************************************************************',' ',['  Model:                   ' my_mod],['  Endogenous variables:    ' num2str(tm.n,'%0.0f')],['  Cointegration relations: ' num2str(my_r,'%0.0f')],['  Replications:            ' num2str(rep,'%0.0f')],['  Draws per replication:   ' num2str(my_T,'%0.0f')],' ');
      if blocksize>1;
         res_str = strvcat(res_str,strrep(block_txt,'.',''),' ');
      end;
      %
      % create tex-file and write model info into it
      %
      file_tex = strrep(file_txt,'.txt','.ltx');
      f_id = fopen(file_tex,'wt');
      fprintf(f_id,'\\begin{tabular}{ll}\n');
      fprintf(f_id,['Model: & ' my_mod ' \\\\\n']);
      fprintf(f_id,['\\#Endogenous variables: & ' num2str(tm.n,'%0.0f') ' \\\\\n']);
      fprintf(f_id,['\\#Cointegration relations: & ' num2str(my_r,'%0.0f') ' \\\\\n']);
      fprintf(f_id,['\\#Replications: & ' num2str(rep,'%0.0f') ' \\\\\n']);
      fprintf(f_id,['\\#Draws per replication: & ' num2str(my_T,'%0.0f') ' \\\\\n']);
      if blocksize>1;
         fprintf(f_id,['Block size length: & ' num2str(blocksize,'%0.0f') ' \\\\\n']);
      end;
      fprintf(f_id,'\\end{tabular}\n\n');
      fclose(f_id);
      %
      % serial correlation test
      %
      if isfield(specification_sorted,'serial')==1;
         res_str = strvcat(res_str,'            Serial Correlation Tests','            ------------------------',' ',['Lag      80%    ' sp_str '    90%   ' sp_str '     95%   ' sp_str '     98%    ' sp_str '    99%   ' sp_str '     Mean  ' sp_str '  Std. Dev.']);
         s_std = sqrt( (1/rep)*sum( ( specification_sorted.serial(:,1) - ( (1/rep)*sum(specification_sorted.serial(:,1)) ) ).*( specification_sorted.serial(:,1) - ( (1/rep)*sum(specification_sorted.serial(:,1)) ) ) ) );
         res_str = strvcat(res_str,sprintf(['%2.0f   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],1,specification_sorted.serial(my_80,1),specification_sorted.serial(my_90,1),specification_sorted.serial(my_95,1),specification_sorted.serial(my_975,1),specification_sorted.serial(my_99,1),(1/rep)*sum(specification_sorted.serial(:,1)),s_std));
         if strcmp(tm.freq,'')==0;
            s_std = sqrt( (1/rep)*sum( ( specification_sorted.serial(:,2) - ( (1/rep)*sum(specification_sorted.serial(:,2)) ) ).*( specification_sorted.serial(:,2) - ( (1/rep)*sum(specification_sorted.serial(:,2)) ) ) ) );
            if strcmp(tm.freq,'q')==1;
               lag_val = 4;
               add_str = ' 4';
            else;
               lag_val = 12;
               add_str = '12';
            end;
            res_str = strvcat(res_str,sprintf(['%2.0f   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],lag_val,specification_sorted.serial(my_80,2),specification_sorted.serial(my_90,2),specification_sorted.serial(my_95,2),specification_sorted.serial(my_975,2),specification_sorted.serial(my_99,2),(1/rep)*sum(specification_sorted.serial(:,2)),s_std));
         end;
         if curr_ini.sscorrect==1;
            my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.serial_df(1,1)*ones(5,1),specification_sorted.serial_df(1,2)*ones(5,1));
            res_str = strvcat(res_str,['From the F(' num2str(specification_sorted.serial_df(1,1),'%0.0f') ',' num2str(specification_sorted.serial_df(1,2),'%0.0f') ') distribution we have the following:'],sprintf(['     ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1)));
            if strcmp(tm.freq,'')==0;
               my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.serial_df(2,1)*ones(5,1),specification_sorted.serial_df(2,2)*ones(5,1));
               res_str = strvcat(res_str,['And from the F(' num2str(specification_sorted.serial_df(2,1),'%0.0f') ',' num2str(specification_sorted.serial_df(2,2),'%0.0f') ') distribution we have the following:'],sprintf(['     ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1)));
            end;
         else;
            my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.serial_df(1,1)*ones(5,1));
            res_str = strvcat(res_str,['From the Chi-square(' num2str(specification_sorted.serial_df(1,1),'%0.0f') ') distribution we have the following:'],sprintf(['     ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.serial_df(1,1),sqrt(2*specification_sorted.serial_df(1,1))));
         end;
         res_str = strvcat(res_str,' ','                      Empirical size','                      --------------',' ','Test level     20%      10%       5%       2%       1%',sprintf('Lag  1:      %6.2f   %6.2f   %6.2f   %6.2f   %6.2f',100*(1-e_size.serial(1,5)),100*(1-e_size.serial(1,4)),100*(1-e_size.serial(1,3)),100*(1-e_size.serial(1,2)),100*(1-e_size.serial(1,1))));
         if size(e_size.serial,1)==2;
            res_str = strvcat(res_str,sprintf('Lag %s:      %6.2f   %6.2f   %6.2f   %6.2f   %6.2f',add_str,100*(1-e_size.serial(2,5)),100*(1-e_size.serial(2,4)),100*(1-e_size.serial(2,3)),100*(1-e_size.serial(2,2)),100*(1-e_size.serial(2,1))),' ');
         else;
            res_str = strvcat(res_str,' ');
         end;
         if tm.T==my_T;
            res_str = strvcat(res_str,'            Empirical p-values','            ------------------',' ');
            if curr_ini.sscorrect==1;
               res_str = strvcat(res_str,['Lag 1: F(' num2str(specification_sorted.serial_df(1,1),'%0.0f') ',' num2str(specification_sorted.serial_df(1,2),'%0.0f') ') = ' num2str(tm.serial(1,1),prt_val)]);
            else;
               res_str = strvcat(res_str,['Lag 1: LM(' num2str(specification_sorted.serial_df(1,1),'%0.0f') ') = ' num2str(tm.serial(1,1),prt_val)]);
            end;
            res_str = strvcat(res_str,['       p-value = ' num2str(pval.serial(1,1),prt_tex)],' ');
            if strcmp(tm.freq,'')==0;
               if curr_ini.sscorrect==1;
                  res_str = strvcat(res_str,['Lag' add_str ': F(' num2str(specification_sorted.serial_df(2,1),'%0.0f') ',' num2str(specification_sorted.serial_df(2,2),'%0.0f') ') = ' num2str(tm.serial(1,2),prt_val)]);
               else;
                  res_str = strvcat(res_str,['Lag' add_str ': LM(' num2str(specification_sorted.serial_df(2,1),'%0.0f') ') = ' num2str(tm.serial(1,2),prt_val)]);
               end;
               res_str = strvcat(res_str,['       p-value = ' num2str(pval.serial(1,2),prt_tex)],' ');
            end;
         end;
         %
         % write to tex-file
         %
         f_id = fopen(file_tex,'at');
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrrr}\n');
         fprintf(f_id,'\\multicolumn{8}{c}{Serial Correlation Tests} \\\\\n');
         fprintf(f_id,'Lag & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% & Mean & Std. Dev. \\\\\n');
         s_std = sqrt( (1/rep)*sum( ( specification_sorted.serial(:,1) - ( (1/rep)*sum(specification_sorted.serial(:,1)) ) ).*( specification_sorted.serial(:,1) - ( (1/rep)*sum(specification_sorted.serial(:,1)) ) ) ) );
         fprintf(f_id,['1 & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],specification_sorted.serial(my_80,1),specification_sorted.serial(my_90,1),specification_sorted.serial(my_95,1),specification_sorted.serial(my_975,1),specification_sorted.serial(my_99,1),(1/rep)*sum(specification_sorted.serial(:,1)),s_std);
         if strcmp(tm.freq,'')==0;
            s_std = sqrt( (1/rep)*sum( ( specification_sorted.serial(:,2) - ( (1/rep)*sum(specification_sorted.serial(:,2)) ) ).*( specification_sorted.serial(:,2) - ( (1/rep)*sum(specification_sorted.serial(:,2)) ) ) ) );
            if strcmp(tm.freq,'q')==1;
               add_str = '4';
            else;
               add_str = '12';
            end;
            fprintf(f_id,[add_str ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],specification_sorted.serial(my_80,2),specification_sorted.serial(my_90,2),specification_sorted.serial(my_95,2),specification_sorted.serial(my_975,2),specification_sorted.serial(my_99,2),(1/rep)*sum(specification_sorted.serial(:,2)),s_std);
         end;
         fprintf(f_id,'\\multicolumn{8}{c}{ } \\\\\n');
         if curr_ini.sscorrect==1;
            my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.serial_df(1,1)*ones(5,1),specification_sorted.serial_df(1,2)*ones(5,1));
            fprintf(f_id,'\\multicolumn{8}{c}{From the F(%0.0f,%0.0f) distribution we have the following:} \\\\\n',specification_sorted.serial_df(1,1),specification_sorted.serial_df(1,2));
            fprintf(f_id,[' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & & \\\\\n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1));
            if strcmp(tm.freq,'')==0;
               my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.serial_df(2,1)*ones(5,1),specification_sorted.serial_df(2,2)*ones(5,1));
               fprintf(f_id,'\\multicolumn{8}{c}{ } \\\\\n');
               fprintf(f_id,'\\multicolumn{8}{c}{From the F(%0.0f,%0.0f) distribution we have the following:} \\\\\n',specification_sorted.serial_df(2,1),specification_sorted.serial_df(2,2));
               fprintf(f_id,[' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & & \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1));
            end;
         else;
            my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.serial_df(1,1)*ones(5,1));
            fprintf(f_id,'\\multicolumn{8}{c}{from the $\\chi^2 (%0.0f)$ distribution we have the following:} \\\\\n',specification_sorted.serial_df(1,1));
            fprintf(f_id,[' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.serial_df(1,1),sqrt(2*specification_sorted.serial_df(1,1)));
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
         fprintf(f_id,'\\multicolumn{6}{c}{Empirical size} \\\\\n');
         fprintf(f_id,'Test level & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
         fprintf(f_id,'Lag 1 & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',100*(1-e_size.serial(1,5)),100*(1-e_size.serial(1,4)),100*(1-e_size.serial(1,3)),100*(1-e_size.serial(1,2)),100*(1-e_size.serial(1,1)));
         if size(e_size.serial,1)==2;
            fprintf(f_id,'Lag %s & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',add_str,100*(1-e_size.serial(2,5)),100*(1-e_size.serial(2,4)),100*(1-e_size.serial(2,3)),100*(1-e_size.serial(2,2)),100*(1-e_size.serial(2,1)));
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
         if tm.T==my_T;
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{ll}\n');
            fprintf(f_id,'\\multicolumn{2}{c}{Empirical $p$-values:} \\\\\n');
            if curr_ini.sscorrect==1;
               fprintf(f_id,['Lag 1: & F(%0.0f,%0.0f) = ' prt_tex ' \\\\ \n'],specification_sorted.serial_df(1,1),specification_sorted.serial_df(1,2),tm.serial(1,1));
            else;
               fprintf(f_id,['Lag 1: & LM(%0.0f) = ' prt_tex ' \\\\ \n'],specification_sorted.serial_df(1,1),tm.serial(1,1));
            end;
            fprintf(f_id,[' & $p$-value = ' prt_tex ' \\\\ \n'],pval.serial(1,1));
            if strcmp(tm.freq,'')==0;
               if curr_ini.sscorrect==1;
                  fprintf(f_id,['Lag %s: & F(%0.0f,%0.0f) = ' prt_tex ' \\\\ \n'],add_str,specification_sorted.serial_df(2,1),specification_sorted.serial_df(2,2),tm.serial(1,2));
               else;
                  fprintf(f_id,['Lag %s: & LM(%0.0f) = ' prt_tex ' \\\\\n'],add_str,specification_sorted.serial_df(2,1),tm.serial(1,2));
               end;
               fprintf(f_id,[' & $p$-value = ' prt_tex ' \\\\ \n'],pval.serial(1,2));
            end;
            fprintf(f_id,'\\end{tabular}\n\n');
         end;
         fclose(f_id);
      end;
      %
      % portmanteau test
      %
      if isfield(specification_sorted,'portmanteau')==1;
         res_str = strvcat(res_str,'            Ljung-Box Portmanteau Test','            --------------------------',' ',['    80%    ' sp_str '    90%    ' sp_str '    95%    ' sp_str '    98%    ' sp_str '    99%   ' sp_str '     Mean  ' sp_str '  Std. Dev.']);
         s_std = sqrt( (1/rep)*sum( ( specification_sorted.portmanteau(:,1) - ( (1/rep)*sum(specification_sorted.portmanteau(:,1)) ) ).*( specification_sorted.portmanteau(:,1) - ( (1/rep)*sum(specification_sorted.portmanteau(:,1)) ) ) ) );
         res_str = strvcat(res_str,sprintf([prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],specification_sorted.portmanteau(my_80,1),specification_sorted.portmanteau(my_90,1),specification_sorted.portmanteau(my_95,1),specification_sorted.portmanteau(my_975,1),specification_sorted.portmanteau(my_99,1),(1/rep)*sum(specification_sorted.portmanteau(:,1)),s_std));
         my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.portmanteau_df(1,1)*ones(5,1));
         res_str = strvcat(res_str,['From the Chi-square(' num2str(specification_sorted.portmanteau_df(1,1),'%0.0f') ') distribution we have the following:'],sprintf([prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.portmanteau_df(1,1),sqrt(2*specification_sorted.portmanteau_df(1,1))),' ');
         res_str = strvcat(res_str,'                      Empirical size','                      --------------',' ','Test level     20%      10%       5%       2%       1%',sprintf('             %6.2f   %6.2f   %6.2f   %6.2f   %6.2f',100*(1-e_size.portmanteau(1,5)),100*(1-e_size.portmanteau(1,4)),100*(1-e_size.portmanteau(1,3)),100*(1-e_size.portmanteau(1,2)),100*(1-e_size.portmanteau(1,1))),' ');
         if tm.T==my_T;
            res_str = strvcat(res_str,'            Empirical p-value','            -----------------',' ');
            res_str = strvcat(res_str,['LB(' num2str(specification_sorted.portmanteau_df(1,1),'%0.0f') ') = ' num2str(tm.portmanteau,prt_tex)]);
            res_str = strvcat(res_str,['p-value = ' num2str(pval.portmanteau,prt_tex)],' ');
         end;
         f_id = fopen(file_tex,'at');
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
         fprintf(f_id,'\\multicolumn{7}{c}{Ljung-Box Portmanteau Test} \\\\\n');
         fprintf(f_id,'80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% & Mean & Std. Dev. \\\\\n');
         fprintf(f_id,[prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],specification_sorted.portmanteau(my_80,1),specification_sorted.portmanteau(my_90,1),specification_sorted.portmanteau(my_95,1),specification_sorted.portmanteau(my_975,1),specification_sorted.portmanteau(my_99,1),(1/rep)*sum(specification_sorted.portmanteau(:,1)),s_std);
         fprintf(f_id,'\\multicolumn{7}{c}{ } \\\\\n');
         fprintf(f_id,'\\multicolumn{7}{c}{From the $\\chi^2 (%0.0f)$ distribution we have the following:} \\\\\n',specification_sorted.portmanteau_df(1,1));
         fprintf(f_id,[prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.portmanteau_df(1,1),sqrt(2*specification_sorted.portmanteau_df(1,1)));
         fprintf(f_id,'\\end{tabular}\n\n');
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
         fprintf(f_id,'\\multicolumn{6}{c}{Empirical size} \\\\\n');
         fprintf(f_id,'Test level & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
         fprintf(f_id,'Lag 1 & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',100*(1-e_size.portmanteau(1,5)),100*(1-e_size.portmanteau(1,4)),100*(1-e_size.portmanteau(1,3)),100*(1-e_size.portmanteau(1,2)),100*(1-e_size.portmanteau(1,1)));
         fprintf(f_id,'\\end{tabular}\n\n');
         if tm.T==my_T;
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{ll}\n');
            fprintf(f_id,'\\multicolumn{2}{c}{Empirical $p$-value} \\\\\n');
            fprintf(f_id,[' & LB(%0.0f) = ' prt_tex ' \\\\ \n'],specification_sorted.portmanteau_df(1,1),tm.portmanteau);
            fprintf(f_id,[' & $p$-value = ' prt_tex ' \\\\ \n'],pval.portmanteau);
            fprintf(f_id,'\\end{tabular}\n\n');
         end;
         fclose(f_id);
      end;
      %
      % arch test
      %
      if isfield(specification_sorted,'arch')==1;
         if size(tm.myvars,2)<=10;
            add_sp_str = spacestr(10-size(tm.myvars,2));
         else;
            add_sp_str = '';
         end;
         res_str = strvcat(res_str,'            Univariate ARCH Tests','            ---------------------',' ',[' Lag    Equation         80%    ' sp_str '    90%   ' sp_str '     95%   ' sp_str '     98%   ' sp_str '     99%    ' sp_str '    Mean  ' sp_str '  Std. Dev.']);
         for i=1:tm.n;
            s_std = sqrt( (1/rep)*sum( ( specification_sorted.arch(:,i) - ( (1/rep)*sum(specification_sorted.arch(:,i)) ) ).*( specification_sorted.arch(:,i) - ( (1/rep)*sum(specification_sorted.arch(:,i)) ) ) ) );
            res_str = strvcat(res_str,sprintf([' %2.0f     %s%s   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],1,tm.myvars(i,:),add_sp_str,specification_sorted.arch(my_80,i),specification_sorted.arch(my_90,i),specification_sorted.arch(my_95,i),specification_sorted.arch(my_975,i),specification_sorted.arch(my_99,i),(1/rep)*sum(specification_sorted.arch(:,i)),s_std));
         end;
         if curr_ini.sscorrect==1;
            my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.arch_df(1,1)*ones(5,1),specification_sorted.arch_df(1,2)*ones(5,1));
            res_str = strvcat(res_str,['From the F(' num2str(specification_sorted.arch_df(1,1),'%0.0f') ',' num2str(specification_sorted.arch_df(1,2),'%0.0f') ') distribution we have the following:'],sprintf(['                     ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1)),' ');
         else;
            addres_str = ['   ' num2str(specification_sorted.arch_df(1,1),'%3.4f') '   ' num2str(sqrt(2*specification_sorted.arch_df(1,1)),'%3.4f')];
            my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.arch_df(1,1)*ones(5,1));
            res_str = strvcat(res_str,['From the Chi-square(' num2str(specification_sorted.arch_df(1,1),'%0.0f') ') distribution we have the following:'],sprintf(['                     ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.arch_df(1,1),sqrt(2*specification_sorted.arch_df(1,1))),' ');
         end;
         if strcmp(tm.freq,'')==0;
            mystr = ' 4';
            if strcmp(tm.freq,'m')==1;
               mystr = '12';
            end;
            res_str = strvcat(res_str,'--------------------------------------------------------------',' ');
            for i=1:tm.n;
               s_std = sqrt( (1/rep)*sum( ( specification_sorted.arch(:,tm.n+i) - ( (1/rep)*sum(specification_sorted.arch(:,tm.n+i)) ) ).*( specification_sorted.arch(:,tm.n+i) - ( (1/rep)*sum(specification_sorted.arch(:,tm.n+i)) ) ) ) );
               res_str = strvcat(res_str,sprintf([' %s     %s%s   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],mystr,tm.myvars(i,:),add_sp_str,specification_sorted.arch(my_80,tm.n+i),specification_sorted.arch(my_90,tm.n+i),specification_sorted.arch(my_95,tm.n+i),specification_sorted.arch(my_975,tm.n+i),specification_sorted.arch(my_99,tm.n+i),(1/rep)*sum(specification_sorted.arch(:,tm.n+i)),s_std));
            end;
            if curr_ini.sscorrect==1;
               my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.arch_df(1,3)*ones(5,1),specification_sorted.arch_df(1,4)*ones(5,1));
               res_str = strvcat(res_str,['From the F(' num2str(specification_sorted.arch_df(1,3),'%0.0f') ',' num2str(specification_sorted.arch_df(1,4),'%0.0f') ') distribution we have the following:'],sprintf(['                     ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1)),' ');
            else;
               my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.arch_df(1,2)*ones(5,1));
               res_str = strvcat(res_str,['From the Chi-square(' num2str(specification_sorted.arch_df(1,2),'%0.0f') ') distribution we have the following:'],sprintf(['                     ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.arch_df(1,2),sqrt(2*specification_sorted.arch_df(1,2))),' ');
            end;
         end;
         res_str = strvcat(res_str,'                      Empirical size','                      --------------',' ','Test level           20%      10%       5%       2%       1%');
         for i=1:tm.n;
            res_str = strvcat(res_str,sprintf('Lag  1: %s%s %6.2f   %6.2f   %6.2f   %6.2f   %6.2f',tm.myvars(i,:),add_sp_str,100*(1-e_size.arch(5,i)),100*(1-e_size.arch(4,i)),100*(1-e_size.arch(3,i)),100*(1-e_size.arch(2,i)),100*(1-e_size.arch(1,i))));
         end;
         res_str = strvcat(res_str,' ');
         if strcmp(tm.freq,'')==0;
            for i=1:tm.n;
               res_str = strvcat(res_str,sprintf(['Lag %s: %s%s %6.2f   %6.2f   %6.2f   %6.2f   %6.2f'],mystr,tm.myvars(i,:),add_sp_str,100*(1-e_size.arch(5,tm.n+i)),100*(1-e_size.arch(4,tm.n+i)),100*(1-e_size.arch(3,tm.n+i)),100*(1-e_size.arch(2,tm.n+i)),100*(1-e_size.arch(1,tm.n+i))));
            end;
            res_str = strvcat(res_str,' ');
         end;
         if tm.T==my_T;
            res_str = strvcat(res_str,'            Empirical p-values','            ------------------',' ');
            if curr_ini.sscorrect==1;
               for i=1:tm.n;
                  res_str = strvcat(res_str,sprintf(['Lag  1: %s%s   F(%2.0f,%3.0f) = ' prt_val],tm.myvars(i,:),add_sp_str,specification_sorted.arch_df(1,1),specification_sorted.arch_df(1,2),tm.arch(1,i)),sprintf(['                       p-value = ' prt_val],pval.arch(1,i)));
               end;
            else;
               for i=1:tm.n;
                  res_str = strvcat(res_str,sprintf(['Lag  1: %s%s  LM(%2.0f) = ' prt_val],tm.myvars(i,:),add_sp_str,specification_sorted.arch_df(1,1),tm.arch(1,i)),sprintf(['                   p-value = ' prt_val],pval.arch(1,i)));
               end;
            end;
            res_str = strvcat(res_str,' ');
            if strcmp(tm.freq,'')==0;
               if curr_ini.sscorrect==1;
                  for i=1:tm.n;
                     res_str = strvcat(res_str,sprintf(['Lag %s: %s%s   F(%2.0f,%3.0f) = ' prt_val],mystr,tm.myvars(i,:),add_sp_str,specification_sorted.arch_df(1,3),specification_sorted.arch_df(1,4),tm.arch(1,tm.n+i)),sprintf(['                       p-value = ' prt_val],pval.arch(1,tm.n+i)));
                  end;
               else;
                  for i=1:tm.n;
                     res_str = strvcat(res_str,sprintf(['Lag %s: %s%s  LM(%2.0f) = ' prt_val],mystr,tm.myvars(i,:),add_sp_str,specification_sorted.arch_df(1,2),tm.arch(1,tm.n+i)),sprintf(['                   p-value = ' prt_val],pval.arch(1,tm.n+i)));
                  end;
               end;
               res_str = strvcat(res_str,' ');
            end;
         end;
         f_id = fopen(file_tex,'at');
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrrrr}\n');
         fprintf(f_id,'\\multicolumn{9}{c}{Univariate ARCH Tests} \\\\\n');
         fprintf(f_id,'Lags & Equation & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% & Mean & Std. Dev. \\\\\n');
         for i=1:tm.n;
            s_std = sqrt( (1/rep)*sum( ( specification_sorted.arch(:,i) - ( (1/rep)*sum(specification_sorted.arch(:,i)) ) ).*( specification_sorted.arch(:,i) - ( (1/rep)*sum(specification_sorted.arch(:,i)) ) ) ) );
            fprintf(f_id,['1 & %s & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],txt2ltxmath(strtrim(tm.myvars(i,:))),specification_sorted.arch(my_80,i),specification_sorted.arch(my_90,i),specification_sorted.arch(my_95,i),specification_sorted.arch(my_975,i),specification_sorted.arch(my_99,i),(1/rep)*sum(specification_sorted.arch(:,i)),s_std);
         end;
         fprintf(f_id,'\\multicolumn{9}{c}{ } \\\\\n');
         if curr_ini.sscorrect==1;
            my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.arch_df(1,1)*ones(5,1),specification_sorted.arch_df(1,2)*ones(5,1));
            fprintf(f_id,'\\multicolumn{9}{c}{From the F(%0.0f,%0.0f) distribution we have the following:} \\\\\n',specification_sorted.arch_df(1,1),specification_sorted.arch_df(1,2));
            fprintf(f_id,[' & & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & & \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1));
         else;
            my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.arch_df(1,1)*ones(5,1));
            fprintf(f_id,'\\multicolumn{9}{c}{From the $\\chi^2 (%0.0f)$ distribution we have the following:} \\\\\n',specification_sorted.arch_df(1,1));
            fprintf(f_id,[' & & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.arch_df(1,1),sqrt(2*specification_sorted.arch_df(1,1)));
         end;
         if strcmp(tm.freq,'')==0;
            fprintf(f_id,'\\multicolumn{9}{c}{ } \\\\\n');
            mystr = '4';
            if strcmp(tm.freq,'m')==1;
               mystr = '12';
            end;
            for i=1:tm.n;
               s_std = sqrt( (1/rep)*sum( ( specification_sorted.arch(:,tm.n+i) - ( (1/rep)*sum(specification_sorted.arch(:,tm.n+i)) ) ).*( specification_sorted.arch(:,tm.n+i) - ( (1/rep)*sum(specification_sorted.arch(:,tm.n+i)) ) ) ) );
               fprintf(f_id,['1--%s & %s & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],mystr,txt2ltxmath(strtrim(tm.myvars(i,:))),specification_sorted.arch(my_80,tm.n+i),specification_sorted.arch(my_90,tm.n+i),specification_sorted.arch(my_95,tm.n+i),specification_sorted.arch(my_975,tm.n+i),specification_sorted.arch(my_99,tm.n+i),(1/rep)*sum(specification_sorted.arch(:,tm.n+i)),s_std);
            end;
            fprintf(f_id,'\\multicolumn{9}{c}{ } \\\\\n');
            if curr_ini.sscorrect==1;
               my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.arch_df(1,3)*ones(5,1),specification_sorted.arch_df(1,4)*ones(5,1));
               fprintf(f_id,'\\multicolumn{9}{c}{From the F(%0.0f,%0.0f) distribution we have the following:} \\\\\n',specification_sorted.arch_df(1,3),specification_sorted.arch_df(1,4));
               fprintf(f_id,[' & & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & & \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1));
            else;
               my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.arch_df(1,2)*ones(5,1));
               fprintf(f_id,'\\multicolumn{9}{c}{From the $\\chi^2 (%0.0f)$ distribution we have the following:} \\\\\n',specification_sorted.arch_df(1,2));
               fprintf(f_id,[' & & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.arch_df(1,2),sqrt(2*specification_sorted.arch_df(1,2)));
            end;
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
         fprintf(f_id,'\\multicolumn{7}{c}{Empirical size} \\\\\n');
         fprintf(f_id,'Lags & Equation$\\backslash$Test level & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
         for i=1:tm.n;
            fprintf(f_id,'1 & %s & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',txt2ltxmath(strtrim(tm.myvars(i,:))),100*(1-e_size.arch(5,i)),100*(1-e_size.arch(4,i)),100*(1-e_size.arch(3,i)),100*(1-e_size.arch(2,i)),100*(1-e_size.arch(1,i)));
         end;
         if strcmp(tm.freq,'')==0;
            fprintf(f_id,'\\multicolumn{7}{c}{ } \\\\\n');
            for i=1:tm.n;
               fprintf(f_id,'1--%s & %s & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',mystr,txt2ltxmath(strtrim(tm.myvars(i,:))),100*(1-e_size.arch(5,tm.n+i)),100*(1-e_size.arch(4,tm.n+i)),100*(1-e_size.arch(3,tm.n+i)),100*(1-e_size.arch(2,tm.n+i)),100*(1-e_size.arch(1,tm.n+i)));
            end;
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
         if tm.T==my_T;
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrr}\n');
            fprintf(f_id,'\\multicolumn{4}{c}{Empirical $p$-values} \\\\\n');
            if curr_ini.sscorrect==1;
               fprintf(f_id,'Equation & Lags & F(%0.0f,%0.0f) & $p$-value \\\\\n',specification_sorted.arch_df(1,1),specification_sorted.arch_df(1,2));
            else;
               fprintf(f_id,'Equation & Lags & LM(%0.0f) & $p$-value \\\\\n',specification_sorted.arch_df(1,1));
            end;
            for i=1:tm.n;
               fprintf(f_id,['%s & 1 & ' prt_tex ' & ' prt_tex ' \\\\ \n'],txt2ltxmath(strtrim(tm.myvars(i,:))),tm.arch(1,i),pval.arch(1,i));
            end;
            if strcmp(tm.freq,'')==0;
               fprintf(f_id,'\\multicolumn{4}{c}{ } \\\\\n');
               if curr_ini.sscorrect==1;
                  fprintf(f_id,'Variable & Lags & F(%0.0f,%0.0f) & $p$-value \\\\\n',specification_sorted.arch_df(1,3),specification_sorted.arch_df(1,4));
               else;
                  fprintf(f_id,'Variable & Lags & LM(%0.0f) & $p$-value \\\\\n',specification_sorted.arch_df(1,2));
               end;
               for i=1:tm.n;
                  fprintf(f_id,['%s & 1--%s & ' prt_tex ' & ' prt_tex ' \\\\ \n'],txt2ltxmath(strtrim(tm.myvars(i,:))),mystr,tm.arch(1,tm.n+i),pval.arch(1,tm.n+i));
               end;
            end;
            fprintf(f_id,'\\end{tabular}\n\n');
         end;
         fclose(f_id);
      end;
      %
      % multivariate ARCH test
      %
      if isfield(specification_sorted,'march')==1;
         res_str = strvcat(res_str,'            Multivariate ARCH Test','            ----------------------',' ',['    80%    ' sp_str '    90%    ' sp_str '    95%   ' sp_str '     98%    ' sp_str '    99%   ' sp_str '     Mean  ' sp_str '  Std. Dev.']);
         s_std = sqrt( (1/rep)*sum( ( specification_sorted.march - ( (1/rep)*sum(specification_sorted.march) ) ).*( specification_sorted.march - ( (1/rep)*sum(specification_sorted.march) ) ) ) );
         res_str = strvcat(res_str,sprintf([prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],specification_sorted.march(my_80,1),specification_sorted.march(my_90,1),specification_sorted.march(my_95,1),specification_sorted.march(my_975,1),specification_sorted.march(my_99,1),(1/rep)*sum(specification_sorted.march),s_std));
         if curr_ini.sscorrect==1;
            my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.march_df(1,1)*ones(5,1),specification_sorted.march_df(1,2)*ones(5,1));
            res_str = strvcat(res_str,['From the F(' num2str(specification_sorted.march_df(1,1),'%0.0f') ',' num2str(specification_sorted.march_df(1,2),'%0.0f') ') distribution we have the following:'],sprintf([prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1)),' ');
         else;
            my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.march_df(1,1)*ones(5,1));
            res_str = strvcat(res_str,['From the Chi-square(' num2str(specification_sorted.march_df(1,1),'%0.0f') ') distribution we have the following:'],sprintf([prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.march_df(1,1),sqrt(2*specification_sorted.march_df(1,1))),' ');
         end;
         res_str = strvcat(res_str,'                      Empirical size','                      --------------',' ','Test level    20%      10%       5%       2%       1%',sprintf('            %6.2f   %6.2f   %6.2f   %6.2f   %6.2f',100*(1-e_size.march(1,5)),100*(1-e_size.march(1,4)),100*(1-e_size.march(1,3)),100*(1-e_size.march(1,2)),100*(1-e_size.march(1,1))),' ');
         if my_T==tm.T;
            res_str = strvcat(res_str,'            Empirical p-value','            -----------------',' ');
            if curr_ini.sscorrect==1;
               res_str = strvcat(res_str,['F(' num2str(specification_sorted.march_df(1,1),'%0.0f') ',' num2str(specification_sorted.march_df(1,2),'%0.0f') ') = ' num2str(tm.march,prt_val)]);
            else;
               res_str = strvcat(res_str,['LM(' num2str(specification_sorted.march_df(1,1),'%0.0f') ') = ' num2str(tm.march,prt_val)]);
            end;
            res_str = strvcat(res_str,['p-value = ' num2str(pval.march,prt_tex)],' ');
         end;
         f_id = fopen(file_tex,'at');
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
         fprintf(f_id,'\\multicolumn{7}{c}{Multivariate ARCH Test} \\\\\n');
         fprintf(f_id,'80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% & Mean & Std. Dev. \\\\\n');
         s_std = sqrt( (1/rep)*sum( ( specification_sorted.march - ( (1/rep)*sum(specification_sorted.march) ) ).*( specification_sorted.march - ( (1/rep)*sum(specification_sorted.march) ) ) ) );
         fprintf(f_id,[prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],specification_sorted.march(my_80,1),specification_sorted.march(my_90,1),specification_sorted.march(my_95,1),specification_sorted.march(my_975,1),specification_sorted.march(my_99,1),(1/rep)*sum(specification_sorted.march),s_std);
         fprintf(f_id,'\\multicolumn{7}{c}{ } \\\\\n');
         if curr_ini.sscorrect==1;
            my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.march_df(1,1)*ones(5,1),specification_sorted.march_df(1,2)*ones(5,1));
            fprintf(f_id,'\\multicolumn{7}{c}{From the F(%0.0f,%0.0f) distribution we have the following:} \\\\\n',specification_sorted.march_df(1,1),specification_sorted.march_df(1,2));
            fprintf(f_id,[prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & & \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1));
         else;
            my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.march_df(1,1)*ones(5,1));
            fprintf(f_id,'\\multicolumn{7}{c}{From the $\\chi^2 (%0.0f)$ distribution we have the following:} \\\\\n',specification_sorted.march_df(1,1));
            fprintf(f_id,[prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.march_df(1,1),sqrt(2*specification_sorted.march_df(1,1)));
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
         fprintf(f_id,'\\multicolumn{6}{c}{Empirical size} \\\\\n');
         fprintf(f_id,'Test level & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
         fprintf(f_id,' & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',100*(1-e_size.march(1,5)),100*(1-e_size.march(1,4)),100*(1-e_size.march(1,3)),100*(1-e_size.march(1,2)),100*(1-e_size.march(1,1)));
         fprintf(f_id,'\\end{tabular}\n\n');
         if my_T==tm.T;
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrr}\n');
            fprintf(f_id,'\\multicolumn{3}{c}{Empirical $p$-value} \\\\\n');
            if curr_ini.sscorrect==1;
               fprintf(f_id,' & F(%0.0f,%0.0f) & $p$-value \\\\\n',specification_sorted.march_df(1,1),specification_sorted.march_df(1,2));
            else;
               fprintf(f_id,' & LM(%0.0f) & $p$-value \\\\\n',specification_sorted.march_df(1,1));
            end;
            fprintf(f_id,[' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],tm.march,pval.march);
            fprintf(f_id,'\\end{tabular}\n\n');
         end;
         fclose(f_id);
      end;
      %
      % normality test
      %
      if isfield(specification_sorted,'normality')==1;
         res_str = strvcat(res_str,'            Normality Tests','            ---------------',' ',['Moment                    80%   ' sp_str '     90%    ' sp_str '    95%    ' sp_str '    98%    ' sp_str '    99%    ' sp_str '    Mean  ' sp_str '  Std. Dev.']);
         s_std = sqrt( (1/rep)*sum( ( specification_sorted.normality(:,1) - ( (1/rep)*sum(specification_sorted.normality(:,1)) ) ).*( specification_sorted.normality(:,1) - ( (1/rep)*sum(specification_sorted.normality(:,1)) ) ) ) );
         res_str = strvcat(res_str,sprintf(['Skewness              ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],specification_sorted.normality(my_80,1),specification_sorted.normality(my_90,1),specification_sorted.normality(my_95,1),specification_sorted.normality(my_975,1),specification_sorted.normality(my_99,1),(1/rep)*sum(specification_sorted.normality(:,1)),s_std));
         s_std = sqrt( (1/rep)*sum( ( specification_sorted.normality(:,2) - ( (1/rep)*sum(specification_sorted.normality(:,2)) ) ).*( specification_sorted.normality(:,2) - ( (1/rep)*sum(specification_sorted.normality(:,2)) ) ) ) );
         res_str = strvcat(res_str,sprintf(['Kurtosis              ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],specification_sorted.normality(my_80,2),specification_sorted.normality(my_90,2),specification_sorted.normality(my_95,2),specification_sorted.normality(my_975,2),specification_sorted.normality(my_99,2),(1/rep)*sum(specification_sorted.normality(:,2)),s_std));
         if curr_ini.sscorrect==1;
            my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.normality_df(1,1)*ones(5,1),specification_sorted.normality_df(1,2)*ones(5,1));
            res_str = strvcat(res_str,['From the F(' num2str(specification_sorted.normality_df(1,1),'%0.0f') ',' num2str(specification_sorted.normality_df(1,2),'%0.0f') ') distribution we have the following:'],sprintf(['                      ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1)),' ');
         else;
            my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.normality_df(1,1)*ones(5,1));
            res_str = strvcat(res_str,['From the Chi-square(' num2str(specification_sorted.normality_df(1,1),'%0.0f') ') distribution we have the following:'],sprintf(['                      ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.normality_df(1,1),sqrt(2*specification_sorted.normality_df(1,1))),' ');
         end;
         s_std = sqrt( (1/rep)*sum( ( specification_sorted.normality(:,3) - ( (1/rep)*sum(specification_sorted.normality(:,3)) ) ).*( specification_sorted.normality(:,3) - ( (1/rep)*sum(specification_sorted.normality(:,3)) ) ) ) );
         res_str = strvcat(res_str,sprintf(['Skewness & Kurtosis   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],specification_sorted.normality(my_80,3),specification_sorted.normality(my_90,3),specification_sorted.normality(my_95,3),specification_sorted.normality(my_975,3),specification_sorted.normality(my_99,3),(1/rep)*sum(specification_sorted.normality(:,3)),s_std));
         if curr_ini.sscorrect==1;
            my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.normality_df(3,1)*ones(5,1),specification_sorted.normality_df(3,2)*ones(5,1));
            res_str = strvcat(res_str,['From the F(' num2str(specification_sorted.normality_df(3,1),'%0.0f') ',' num2str(specification_sorted.normality_df(3,2),'%0.0f') ') distribution we have the following:'],sprintf(['                      ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1)),' ');
         else;
            my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.normality_df(3,1)*ones(5,1));
            res_str = strvcat(res_str,['From the Chi-square(' num2str(specification_sorted.normality_df(3,1),'%0.0f') ') distribution we have the following:'],sprintf(['                      ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.normality_df(3,1),sqrt(2*specification_sorted.normality_df(3,1))),' ');
         end;
         res_str = strvcat(res_str,'                      Empirical size','                      --------------',' ','  Moments\\Test level     20%      10%       5%       2%       1%');
         res_str = strvcat(res_str,sprintf('Skewness               %6.2f   %6.2f   %6.2f   %6.2f   %6.2f',100*(1-e_size.normality(1,5)),100*(1-e_size.normality(1,4)),100*(1-e_size.normality(1,3)),100*(1-e_size.normality(1,2)),100*(1-e_size.normality(1,1))));
         res_str = strvcat(res_str,sprintf('Kurtosis               %6.2f   %6.2f   %6.2f   %6.2f   %6.2f',100*(1-e_size.normality(2,5)),100*(1-e_size.normality(2,4)),100*(1-e_size.normality(2,3)),100*(1-e_size.normality(2,2)),100*(1-e_size.normality(2,1))));
         res_str = strvcat(res_str,sprintf('Skewness & Kurtosis    %6.2f   %6.2f   %6.2f   %6.2f   %6.2f',100*(1-e_size.normality(3,5)),100*(1-e_size.normality(3,4)),100*(1-e_size.normality(3,3)),100*(1-e_size.normality(3,2)),100*(1-e_size.normality(3,1))),' ');
         if tm.T==my_T;
            res_str = strvcat(res_str,'            Empirical p-values','            ------------------',' ');
            if curr_ini.sscorrect==1;
               res_str = strvcat(res_str,sprintf(['Skewness:             F(%2.0f,%3.0f) = ' prt_val ',   p-value = ' prt_val],specification_sorted.normality_df(1,1),specification_sorted.normality_df(1,2),tm.normality(1,1),pval.normality(1,1)));
               res_str = strvcat(res_str,sprintf(['Kurtosis:             F(%2.0f,%3.0f) = ' prt_val ',   p-value = ' prt_val],specification_sorted.normality_df(2,1),specification_sorted.normality_df(2,2),tm.normality(1,2),pval.normality(1,2)));
               res_str = strvcat(res_str,sprintf(['Skewness & Kurtosis:  F(%2.0f,%3.0f) = ' prt_val ',   p-value = ' prt_val],specification_sorted.normality_df(3,1),specification_sorted.normality_df(3,2),tm.normality(1,3),pval.normality(1,3)),' ');
            else;
               res_str = strvcat(res_str,sprintf(['Skewness:             W(%2.0f) = ' prt_val ',   p-value = ' prt_val],specification_sorted.normality_df(1,1),tm.normality(1,1),pval.normality(1,1)));
               res_str = strvcat(res_str,sprintf(['Kurtosis:             W(%2.0f) = ' prt_val ',   p-value = ' prt_val],specification_sorted.normality_df(2,1),tm.normality(1,2),pval.normality(1,2)));
               res_str = strvcat(res_str,sprintf(['Skewness & Kurtosis:  W(%2.0f) = ' prt_val ',   p-value = ' prt_val],specification_sorted.normality_df(3,1),tm.normality(1,3),pval.normality(1,3)),' ');
            end;
         end;
         f_id = fopen(file_tex,'at');
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrrr}\n');
         fprintf(f_id,'\\multicolumn{8}{c}{Normality Tests} \\\\\n');
         fprintf(f_id,'Moments & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% & Mean & Std. Dev. \\\\\n');
         s_std = sqrt( (1/rep)*sum( ( specification_sorted.normality(:,1) - ( (1/rep)*sum(specification_sorted.normality(:,1)) ) ).*( specification_sorted.normality(:,1) - ( (1/rep)*sum(specification_sorted.normality(:,1)) ) ) ) );
         fprintf(f_id,['Skewness & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],specification_sorted.normality(my_80,1),specification_sorted.normality(my_90,1),specification_sorted.normality(my_95,1),specification_sorted.normality(my_975,1),specification_sorted.normality(my_99,1),(1/rep)*sum(specification_sorted.normality(:,1)),s_std);
         s_std = sqrt( (1/rep)*sum( ( specification_sorted.normality(:,2) - ( (1/rep)*sum(specification_sorted.normality(:,2)) ) ).*( specification_sorted.normality(:,2) - ( (1/rep)*sum(specification_sorted.normality(:,2)) ) ) ) );
         fprintf(f_id,['Kurtosis & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],specification_sorted.normality(my_80,2),specification_sorted.normality(my_90,2),specification_sorted.normality(my_95,2),specification_sorted.normality(my_975,2),specification_sorted.normality(my_99,2),(1/rep)*sum(specification_sorted.normality(:,2)),s_std);
         fprintf(f_id,'\\multicolumn{8}{c}{ } \\\\\n');
         if curr_ini.sscorrect==1;
            my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.normality_df(1,1)*ones(5,1),specification_sorted.normality_df(1,2)*ones(5,1));
            fprintf(f_id,'\\multicolumn{8}{c}{From the F(%0.0f,%0.0f) distribution we have the following:} \\\\\n',specification_sorted.normality_df(1,1),specification_sorted.normality_df(1,2));
            fprintf(f_id,[' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & & \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1));
         else;
            my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.normality_df(1,1)*ones(5,1));
            fprintf(f_id,'\\multicolumn{8}{c}{From the $\\chi^2 (%0.0f)$ distribution we have the following:} \\\\\n',specification_sorted.normality_df(1,1));
            fprintf(f_id,[' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.normality_df(1,1),sqrt(2*specification_sorted.normality_df(1,1)));
         end;
         fprintf(f_id,'\\multicolumn{8}{c}{ } \\\\\n');
         s_std = sqrt( (1/rep)*sum( ( specification_sorted.normality(:,3) - ( (1/rep)*sum(specification_sorted.normality(:,3)) ) ).*( specification_sorted.normality(:,3) - ( (1/rep)*sum(specification_sorted.normality(:,3)) ) ) ) );
         fprintf(f_id,['Skewness \\& Kurtosis & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],specification_sorted.normality(my_80,3),specification_sorted.normality(my_90,3),specification_sorted.normality(my_95,3),specification_sorted.normality(my_975,3),specification_sorted.normality(my_99,3),(1/rep)*sum(specification_sorted.normality(:,3)),s_std);
         fprintf(f_id,'\\multicolumn{8}{c}{ } \\\\\n');
         if curr_ini.sscorrect==1;
            my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.normality_df(3,1)*ones(5,1),specification_sorted.normality_df(3,2)*ones(5,1));
            fprintf(f_id,'\\multicolumn{8}{c}{From the F(%0.0f,%0.0f) distribution we have the following:} \\\\\n',specification_sorted.normality_df(3,1),specification_sorted.normality_df(3,2));
            fprintf(f_id,[' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & & \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1));
         else;
            my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.normality_df(3,1)*ones(5,1));
            fprintf(f_id,'\\multicolumn{8}{c}{From the $\\chi^2 (%0.0f)$ distribution we have the following:} \\\\\n',specification_sorted.normality_df(3,1));
            fprintf(f_id,[' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.normality_df(3,1),sqrt(2*specification_sorted.normality_df(3,1)));
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
         fprintf(f_id,'\\multicolumn{6}{c}{Empirical size} \\\\\n');
         fprintf(f_id,'Moments$\\backslash$Test level & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
         fprintf(f_id,'Skewness & %0.2f & %0.2f & %0.2f & %0.2f & %0.2f \\\\\n',100*(1-e_size.normality(1,5)),100*(1-e_size.normality(1,4)),100*(1-e_size.normality(1,3)),100*(1-e_size.normality(1,2)),100*(1-e_size.normality(1,1)));
         fprintf(f_id,'Kurtosis & %0.2f & %0.2f & %0.2f & %0.2f & %0.2f \\\\\n',100*(1-e_size.normality(2,5)),100*(1-e_size.normality(2,4)),100*(1-e_size.normality(2,3)),100*(1-e_size.normality(2,2)),100*(1-e_size.normality(2,1)));
         fprintf(f_id,'Skewness \\& Kurtosis & %0.2f & %0.2f & %0.2f & %0.2f & %0.2f \\\\\n',100*(1-e_size.normality(3,5)),100*(1-e_size.normality(3,4)),100*(1-e_size.normality(3,3)),100*(1-e_size.normality(3,2)),100*(1-e_size.normality(3,1)));
         fprintf(f_id,'\\end{tabular}\n\n');
         if tm.T==my_T;
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrr}\n');
            fprintf(f_id,'\\multicolumn{4}{c}{Empirical $p$-values} \\\\\n');
            if curr_ini.sscorrect==1;
               fprintf(f_id,' & Moments & F(%0.0f,%0.0f) & $p$-value \\\\\n',specification_sorted.normality_df(1,1),specification_sorted.normality_df(1,2));
            else;
               fprintf(f_id,' & Moments & W(%0.0f) & $p$-value \\\\\n',specification_sorted.normality_df(1,1));
            end;
            fprintf(f_id,[' & Skewness & ' prt_tex ' & ' prt_tex ' \\\\ \n'],tm.normality(1,1),pval.normality(1,1));
            fprintf(f_id,[' & Kurtosis & ' prt_tex ' & ' prt_tex ' \\\\ \n'],tm.normality(1,2),pval.normality(1,2));
            fprintf(f_id,'\\multicolumn{4}{c}{ } \\\\\n');
            if curr_ini.sscorrect==1;
               fprintf(f_id,' & Moments & F(%0.0f,%0.0f) & $p$-value \\\\\n',specification_sorted.normality_df(3,1),specification_sorted.normality_df(3,2));
            else;
               fprintf(f_id,' & Moments & W(%0.0f) & $p$-value \\\\\n',specification_sorted.normality_df(3,1));
            end;
            fprintf(f_id,[' & Skewness \\& Kurtosis & ' prt_tex ' & ' prt_tex ' \\\\ \n'],tm.normality(1,3),pval.normality(1,3));
            fprintf(f_id,'\\end{tabular}\n\n');
         end;
         fclose(f_id);
      end;
      %
      % omnibus test
      %
      if isfield(specification_sorted,'omnibus')==1;
         res_str = strvcat(res_str,'            Shenton-Bowman/Doornik-Hansen Omnibus Test','            ------------------------------------------',' ',['Moment                    80%   ' sp_str '     90%    ' sp_str '    95%    ' sp_str '    98%    ' sp_str '    99%    ' sp_str '    Mean  ' sp_str '  Std. Dev.']);
         s_std = sqrt( (1/rep)*sum( ( specification_sorted.omnibus - ( (1/rep)*sum(specification_sorted.omnibus) ) ).*( specification_sorted.omnibus - ( (1/rep)*sum(specification_sorted.omnibus) ) ) ) );
         res_str = strvcat(res_str,sprintf(['Skewness & Kurtosis   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],specification_sorted.omnibus(my_80,1),specification_sorted.omnibus(my_90,1),specification_sorted.omnibus(my_95,1),specification_sorted.omnibus(my_975,1),specification_sorted.omnibus(my_99,1),(1/rep)*sum(specification_sorted.omnibus),s_std));
         if curr_ini.sscorrect==1;
            my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.omnibus_df(1,1)*ones(5,1),specification_sorted.omnibus_df(1,2)*ones(5,1));
            res_str = strvcat(res_str,['From the F(' num2str(specification_sorted.omnibus_df(1,1),'%0.0f') ',' num2str(specification_sorted.omnibus_df(1,2),'%0.0f') ') distribution we have the following:'],sprintf(['                      ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1)),' ');
         else;
            my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.omnibus_df(1,1)*ones(5,1));
            res_str = strvcat(res_str,['From the Chi-square(' num2str(specification_sorted.omnibus_df(1,1),'%0.0f') ') distribution we have the following:'],sprintf(['                      ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.omnibus_df(1,1),sqrt(2*specification_sorted.omnibus_df(1,1))),' ');
         end;
         res_str = strvcat(res_str,'                      Empirical size','                      --------------',' ','Test level    20%      10%       5%       2%       1%',sprintf('            %6.2f   %6.2f   %6.2f   %6.2f   %6.2f',100*(1-e_size.omnibus(1,5)),100*(1-e_size.omnibus(1,4)),100*(1-e_size.omnibus(1,3)),100*(1-e_size.omnibus(1,2)),100*(1-e_size.omnibus(1,1))),' ');
         if my_T==tm.T;
            res_str = strvcat(res_str,'            Empirical p-value','            -----------------',' ');
            if curr_ini.sscorrect==1;
               res_str = strvcat(res_str,['F(' num2str(specification_sorted.omnibus_df(1,1),'%0.0f') ',' num2str(specification_sorted.omnibus_df(1,2),'%0.0f') ') = ' num2str(tm.omnibus,prt_val)]);
            else;
               res_str = strvcat(res_str,['E_' num2str(tm.n,'%0.0f') '(' num2str(specification_sorted.omnibus_df(1,1),'%0.0f') ') = ' num2str(tm.omnibus,prt_val)]);
            end;
            res_str = strvcat(res_str,['p-value = ' num2str(pval.omnibus,prt_tex)],' ');
         end;
         f_id = fopen(file_tex,'at');
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrrr}\n');
         fprintf(f_id,'\\multicolumn{8}{c}{Shenton-Bowman \\& Doornik-Hansen Omnibus Test} \\\\\n');
         fprintf(f_id,'Moment & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% & Mean & Std. Dev. \\\\\n');
         s_std = sqrt( (1/rep)*sum( ( specification_sorted.omnibus - ( (1/rep)*sum(specification_sorted.omnibus) ) ).*( specification_sorted.omnibus - ( (1/rep)*sum(specification_sorted.omnibus) ) ) ) );
         fprintf(f_id,['Skewness \\& Kurtosis & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],specification_sorted.omnibus(my_80,1),specification_sorted.omnibus(my_90,1),specification_sorted.omnibus(my_95,1),specification_sorted.omnibus(my_975,1),specification_sorted.omnibus(my_99,1),(1/rep)*sum(specification_sorted.omnibus),s_std);
         fprintf(f_id,'\\multicolumn{8}{c}{ } \\\\\n');
         if curr_ini.sscorrect==1;
            my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.omnibus_df(1,1)*ones(5,1),specification_sorted.omnibus_df(1,2)*ones(5,1));
            fprintf(f_id,'\\multicolumn{8}{c}{From the F(%0.0f,%0.0f) distribution we have the following:} \\\\\n',specification_sorted.omnibus_df(1,1),specification_sorted.omnibus_df(1,2));
            fprintf(f_id,[' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & & \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1));
         else;
            my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.omnibus_df(1,1)*ones(5,1));
            fprintf(f_id,'\\multicolumn{8}{c}{From the $\\chi^2 (%0.0f)$ distribution we have the following:} \\\\\n',specification_sorted.omnibus_df(1,1));
            fprintf(f_id,[' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\\n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.omnibus_df(1,1),sqrt(2*specification_sorted.omnibus_df(1,1)));
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
         fprintf(f_id,'\\multicolumn{6}{c}{Empirical size} \\\\\n');
         fprintf(f_id,'Test level & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
         fprintf(f_id,' & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',100*(1-e_size.omnibus(1,5)),100*(1-e_size.omnibus(1,4)),100*(1-e_size.omnibus(1,3)),100*(1-e_size.omnibus(1,2)),100*(1-e_size.omnibus(1,1)));
         fprintf(f_id,'\\end{tabular}\n\n');
         if my_T==tm.T;
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrr}\n');
            fprintf(f_id,'\\multicolumn{3}{c}{Empirical $p$-value} \\\\\n');
            if curr_ini.sscorrect==1;
               fprintf(f_id,' & F(%0.0f,%0.0f) & $p$-value \\\\\n',specification_sorted.omnibus_df(1,1),specification_sorted.omnibus_df(1,2));
            else;
               fprintf(f_id,' & $E_{%0.0f} (%0.0f)$ & $p$-value \\\\\n',tm.n,specification_sorted.omnibus_df(1,1));
            end;
            fprintf(f_id,[' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],tm.omnibus,pval.omnibus);
            fprintf(f_id,'\\end{tabular}\n\n');
         end;
         fclose(f_id);
      end;
      %
      % lag order tests
      %
      if isfield(specification_sorted,'lagorder')==1;
         if curr_ini.bartserial==1;
            res_str = strvcat(res_str,'            Lag Order Tests','            ---------------',' ','Bartlett corrected tests',' ',['Null Alternative     80%   ' sp_str '    90%    ' sp_str '   95%    ' sp_str '   98%   ' sp_str '    99%   ' sp_str '    Mean  ' sp_str ' Std. Dev.']);
         else;
            res_str = strvcat(res_str,'            Lag Order Tests','            ---------------',' ',['Null Alternative     80%   ' sp_str '    90%    ' sp_str '   95%    ' sp_str '   98%   ' sp_str '    99%   ' sp_str '    Mean  ' sp_str ' Std. Dev.']);
         end;
         lag_count = 0;
         for lag=1:curr_ini.lagtest;
            if ((my_T-tm.df)-lag*(tm.n+tm.q1+tm.q0))>0;
               lag_count = lag_count+1;
               s_std = sqrt( (1/rep)*sum( ( specification_sorted.lagorder(:,lag_count) - ( (1/rep)*sum(specification_sorted.lagorder(:,lag_count)) ) ).*( specification_sorted.lagorder(:,lag_count) - ( (1/rep)*sum(specification_sorted.lagorder(:,lag_count)) ) ) ) );
               res_str = strvcat(res_str,sprintf(['%2.0f vs. %2.0f        ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val],tm.p,tm.p+lag,specification_sorted.lagorder(my_80,lag_count),specification_sorted.lagorder(my_90,lag_count),specification_sorted.lagorder(my_95,lag_count),specification_sorted.lagorder(my_975,lag_count),specification_sorted.lagorder(my_99,lag_count),(1/rep)*sum(specification_sorted.lagorder(:,lag_count)),s_std));
               if specification_sorted.lagorder_correct(1,lag_count)==1;
                  my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.lagorder_df(lag_count).df(1,1)*ones(5,1),specification_sorted.lagorder_df(lag_count).df(1,2)*ones(5,1));
                  res_str = strvcat(res_str,['From the F(' num2str(specification_sorted.lagorder_df(lag_count).df(1,1),'%0.0f') ',' num2str(specification_sorted.lagorder_df(lag_count).df(1,2),'%0.0f') ') distribution we have the following:'],sprintf(['                 ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1)),' ');
               else;
                  my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.lagorder_df(lag_count).df(1,1)*ones(5,1));
                  res_str = strvcat(res_str,['From the Chi-square(' num2str(specification_sorted.lagorder_df(lag_count).df(1,1),'%0.0f') ') distribution we have the following:'],sprintf(['                 ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.lagorder_df(lag_count).df(1,1),sqrt(2*specification_sorted.lagorder_df(lag_count).df(1,1))),' ');
               end;
            end;
            if (tm.p-lag)>=1;
               lag_count = lag_count+1;
               s_std = sqrt( (1/rep)*sum( ( specification_sorted.lagorder(:,lag_count) - ( (1/rep)*sum(specification_sorted.lagorder(:,lag_count)) ) ).*( specification_sorted.lagorder(:,lag_count) - ( (1/rep)*sum(specification_sorted.lagorder(:,lag_count)) ) ) ) );
               res_str = strvcat(res_str,sprintf(['%2.0f vs. %2.0f        ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val],tm.p-lag,tm.p,specification_sorted.lagorder(my_80,lag_count),specification_sorted.lagorder(my_90,lag_count),specification_sorted.lagorder(my_95,lag_count),specification_sorted.lagorder(my_975,lag_count),specification_sorted.lagorder(my_99,lag_count),(1/rep)*sum(specification_sorted.lagorder(:,lag_count)),s_std));
               if curr_ini.sscorrect==1;
                  my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.lagorder_df(lag_count).df(1,1)*ones(5,1),specification_sorted.lagorder_df(lag_count).df(1,2)*ones(5,1));
                  res_str = strvcat(res_str,['From the F(' num2str(specification_sorted.lagorder_df(lag_count).df(1,1),'%0.0f') ',' num2str(specification_sorted.lagorder_df(lag_count).df(1,2),'%0.0f') ') distribution we have the following:'],sprintf(['                 ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1)),' ');
               else;
                  my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.lagorder_df(lag_count).df(1,1)*ones(5,1));
                  res_str = strvcat(res_str,['From the Chi-square(' num2str(specification_sorted.lagorder_df(lag_count).df(1,1),'%0.0f') ') distribution we have the following:'],sprintf(['                 ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.lagorder_df(lag_count).df(1,1),sqrt(2*specification_sorted.lagorder_df(lag_count).df(1,1))),' ');
               end;
            end;
         end;
         res_str = strvcat(res_str,'                      Empirical size','                      --------------',' ','Null Alternative\\Test level    20%      10%       5%       2%       1%');
         lag_count = 0;
         for lag=1:curr_ini.lagtest;
            if ((my_T-tm.df)-lag*(tm.n+tm.q1+tm.q0))>0;
               lag_count = lag_count+1;
               res_str = strvcat(res_str,sprintf('%2.0f vs. %2.0f                    %6.2f   %6.2f   %6.2f   %6.2f   %6.2f',tm.p,tm.p+lag,100*(1-e_size.lagorder(5,lag_count)),100*(1-e_size.lagorder(4,lag_count)),100*(1-e_size.lagorder(3,lag_count)),100*(1-e_size.lagorder(2,lag_count)),100*(1-e_size.lagorder(1,lag_count))));
            end;
            if (tm.p-lag)>=1;
               lag_count = lag_count+1;
               res_str = strvcat(res_str,sprintf('%2.0f vs. %2.0f                    %6.2f   %6.2f   %6.2f   %6.2f   %6.2f',tm.p-lag,tm.p,100*(1-e_size.lagorder(5,lag_count)),100*(1-e_size.lagorder(4,lag_count)),100*(1-e_size.lagorder(3,lag_count)),100*(1-e_size.lagorder(2,lag_count)),100*(1-e_size.lagorder(1,lag_count))));
            end;
         end;
         res_str = strvcat(res_str,' ');
         %
         if my_T==tm.T
            res_str = strvcat(res_str,'            Empirical p-values','            ------------------',' ');
            lag_count = 0;
            for lag=1:curr_ini.lagtest;
               if ((my_T-tm.df)-lag*(tm.n+tm.q1+tm.q0))>0;
                  lag_count = lag_count+1;
                  if specification_sorted.lagorder_correct(1,lag_count)==1;
                     res_str = strvcat(res_str,sprintf(['%2.0f lags vs. %2.0f lags: F(%2.0f,%3.0f) = ' prt_val],tm.p,tm.p+lag,specification_sorted.lagorder_df(lag_count).df(1,1),specification_sorted.lagorder_df(lag_count).df(1,2),tm.lagorder(1,lag_count)),sprintf(['                     p-value   = ' prt_val],pval.lagorder(1,lag_count)));
                  else;
                     res_str = strvcat(res_str,sprintf(['%2.0f lags vs. %2.0f lags: LM(%2.0f)  = ' prt_val],tm.p,tm.p+lag,specification_sorted.lagorder_df(lag_count).df(1,1),tm.lagorder(1,lag_count)),sprintf(['                     p-value = ' prt_val],pval.lagorder(1,lag_count)));
                  end;
               end;
               if (tm.p-lag)>=1;
                  lag_count = lag_count+1;
                  if curr_ini.sscorrect==1;
                     res_str = strvcat(res_str,sprintf(['%2.0f lags vs. %2.0f lags: F(%2.0f,%3.0f) = ' prt_val],tm.p-lag,tm.p,specification_sorted.lagorder_df(lag_count).df(1,1),specification_sorted.lagorder_df(lag_count).df(1,2),tm.lagorder(1,lag_count)),sprintf(['                     p-value   = ' prt_val],pval.lagorder(1,lag_count)));
                  else;
                     res_str = strvcat(res_str,sprintf(['%2.0f lags vs. %2.0f lags: W(%2.0f)   = ' prt_val],tm.p-lag,tm.p,specification_sorted.lagorder_df(lag_count).df(1,1),tm.lagorder(1,lag_count)),sprintf(['                     p-value = ' prt_val],pval.lagorder(1,lag_count)));
                  end;
               end;
            end;
            res_str = strvcat(res_str,' ');
         end;
         %
         % write to tex-file
         %
         f_id = fopen(file_tex,'at');
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrrrr}\n');
         fprintf(f_id,'\\multicolumn{9}{c}{Lag order tests} \\\\\n');
         if curr_ini.bartserial==1;
            fprintf(f_id,'\\multicolumn{9}{c}{Bartlett corrected tests} \\\\\n');
         end;
         fprintf(f_id,'$H_0$ & $H_A$ & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% & Mean & Std. Dev. \\\\\n');
         lag_count = 0;
         for lag=1:curr_ini.lagtest;
            if ((my_T-tm.df)-lag*(tm.n+tm.q1+tm.q0))>0;
               lag_count = lag_count+1;
               s_std = sqrt( (1/rep)*sum( ( specification_sorted.lagorder(:,lag_count) - ( (1/rep)*sum(specification_sorted.lagorder(:,lag_count)) ) ).*( specification_sorted.lagorder(:,lag_count) - ( (1/rep)*sum(specification_sorted.lagorder(:,lag_count)) ) ) ) );
               fprintf(f_id,['%0.0f & %0.0f & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],tm.p,tm.p+lag,specification_sorted.lagorder(my_80,lag_count),specification_sorted.lagorder(my_90,lag_count),specification_sorted.lagorder(my_95,lag_count),specification_sorted.lagorder(my_975,lag_count),specification_sorted.lagorder(my_99,lag_count),(1/rep)*sum(specification_sorted.lagorder(:,lag_count)),s_std);
               if specification_sorted.lagorder_correct(1,lag_count)==1;
                  my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.lagorder_df(lag_count).df(1,1)*ones(5,1),specification_sorted.lagorder_df(lag_count).df(1,2)*ones(5,1));
                  fprintf(f_id,'\\multicolumn{9}{c}{ } \\\\\n');
                  fprintf(f_id,'\\multicolumn{9}{c}{From the F(%0.0f,%0.0f) distribution we have the following:} \\\\\n',specification_sorted.lagorder_df(lag_count).df(1,1),specification_sorted.lagorder_df(lag_count).df(1,2));
                  fprintf(f_id,[' & & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & & \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1));
                  fprintf(f_id,'\\multicolumn{9}{c}{ } \\\\\n');
               else;
                  my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.lagorder_df(lag_count).df(1,1)*ones(5,1));
                  fprintf(f_id,'\\multicolumn{9}{c}{ } \\\\\n');
                  fprintf(f_id,'\\multicolumn{9}{c}{From the $\\chi^2 (%0.0f)$ distribution we have the following:} \\\\\n',specification_sorted.lagorder_df(lag_count).df(1,1));
                  fprintf(f_id,[' & & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.lagorder_df(lag_count).df(1,1),sqrt(2*specification_sorted.lagorder_df(lag_count).df(1,1)));
                  fprintf(f_id,'\\multicolumn{9}{c}{ } \\\\\n');
               end;
            end;
            if (tm.p-lag)>=1;
               lag_count = lag_count+1;
               s_std = sqrt( (1/rep)*sum( ( specification_sorted.lagorder(:,lag_count) - ( (1/rep)*sum(specification_sorted.lagorder(:,lag_count)) ) ).*( specification_sorted.lagorder(:,lag_count) - ( (1/rep)*sum(specification_sorted.lagorder(:,lag_count)) ) ) ) );
               fprintf(f_id,['%0.0f & %0.0f & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],tm.p-lag,tm.p,specification_sorted.lagorder(my_80,lag_count),specification_sorted.lagorder(my_90,lag_count),specification_sorted.lagorder(my_95,lag_count),specification_sorted.lagorder(my_975,lag_count),specification_sorted.lagorder(my_99,lag_count),(1/rep)*sum(specification_sorted.lagorder(:,lag_count)),s_std);
               if curr_ini.sscorrect==1;
                  my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.lagorder_df(lag_count).df(1,1)*ones(5,1),specification_sorted.lagorder_df(lag_count).df(1,2)*ones(5,1));
                  fprintf(f_id,'\\multicolumn{9}{c}{ } \\\\\n');
                  fprintf(f_id,'\\multicolumn{9}{c}{From the F(%0.0f,%0.0f) distribution we have the following:} \\\\\n',specification_sorted.lagorder_df(lag_count).df(1,1),specification_sorted.lagorder_df(lag_count).df(1,2));
                  fprintf(f_id,[' & & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & & \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1));
                  fprintf(f_id,'\\multicolumn{9}{c}{ } \\\\\n');
               else;
                  my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.lagorder_df(lag_count).df(1,1)*ones(5,1));
                  fprintf(f_id,'\\multicolumn{9}{c}{ } \\\\\n');
                  fprintf(f_id,'\\multicolumn{9}{c}{From the $\\chi^2 (%0.0f)$ distribution we have the following:} \\\\\n',specification_sorted.lagorder_df(lag_count).df(1,1));
                  fprintf(f_id,[' & & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.lagorder_df(lag_count).df(1,1),sqrt(2*specification_sorted.lagorder_df(lag_count).df(1,1)));
                  fprintf(f_id,'\\multicolumn{9}{c}{ } \\\\\n');
               end;
            end;
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{llrrrrr}\n');
         fprintf(f_id,'\\multicolumn{7}{c}{Empirical size} \\\\\n');
         fprintf(f_id,'$H_0$ & $H_A$ $\\backslash$ Test level & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
         lag_count = 0;
         for lag=1:curr_ini.lagtest;
            if ((my_T-tm.df)-lag*(tm.n+tm.q1+tm.q0))>0;
               lag_count = lag_count+1;
               fprintf(f_id,'%0.0f & %0.0f & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',tm.p,tm.p+lag,100*(1-e_size.lagorder(5,lag_count)),100*(1-e_size.lagorder(4,lag_count)),100*(1-e_size.lagorder(3,lag_count)),100*(1-e_size.lagorder(2,lag_count)),100*(1-e_size.lagorder(1,lag_count)));
            end;
            if (tm.p-lag)>=1;
               lag_count = lag_count+1;
               fprintf(f_id,'%0.0f & %0.0f & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',tm.p-lag,tm.p,100*(1-e_size.lagorder(5,lag_count)),100*(1-e_size.lagorder(4,lag_count)),100*(1-e_size.lagorder(3,lag_count)),100*(1-e_size.lagorder(2,lag_count)),100*(1-e_size.lagorder(1,lag_count)));
            end;
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
         %
         if my_T==tm.T
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrr}\n');
            fprintf(f_id,'\\multicolumn{4}{c}{Empirical $p$-values} \\\\\n');
            lag_count = 0;
            for lag=1:curr_ini.lagtest;
               if ((my_T-tm.df)-lag*(tm.n+tm.q1+tm.q0))>0;
                  lag_count = lag_count+1;
                  if specification_sorted.lagorder_correct(1,lag_count)==1;
                     fprintf(f_id,'$H_0$ & $H_A$ & F(%0.0f,%0.0f) & $p$-value \\\\\n',specification_sorted.lagorder_df(lag_count).df(1,1),specification_sorted.lagorder_df(lag_count).df(1,2));
                  else;
                     fprintf(f_id,'$H_0$ & $H_A$ & LM(%0.0f) & $p$-value \\\\\n',specification_sorted.lagorder_df(lag_count).df(1,1));
                  end;
                  fprintf(f_id,['%0.0f & %0.0f & ' prt_tex ' & ' prt_tex ' \\\\ \n'],tm.p,tm.p+lag,tm.lagorder(1,lag_count),pval.lagorder(1,lag_count));
               end;
               if (tm.p-lag)>=1;
                  lag_count = lag_count+1;
                  if curr_ini.sscorrect==1;
                     fprintf(f_id,'$H_0$ & $H_A$ & F(%0.0f,%0.0f) & $p$-value \\\\\n',specification_sorted.lagorder_df(lag_count).df(1,1),specification_sorted.lagorder_df(lag_count).df(1,2));
                  else;
                     fprintf(f_id,'$H_0$ & $H_A$ & W(%0.0f) & $p$-value \\\\\n',specification_sorted.lagorder_df(lag_count).df(1,1));
                  end;
                  fprintf(f_id,['%0.0f & %0.0f & ' prt_tex ' & ' prt_tex ' \\\\ \n'],tm.p-lag,tm.p,tm.lagorder(1,lag_count),pval.lagorder(1,lag_count));
               end;
            end;
            fprintf(f_id,'\\end{tabular}\n\n');
         end;
         fclose(f_id);
      end;
      %
      % weak exogeneity tests
      %
      if isfield(specification_sorted,'weakexo')==1;
         if size(tm.myvars,2)<=10;
            add_sp_str = spacestr(10-size(tm.myvars,2));
         else;
            add_sp_str = '';
         end;
         res_str = strvcat(res_str,'            Weak Exogeneity Tests','            ---------------------',' ',['Equation         80%    ' sp_str '    90%   ' sp_str '     95%   ' sp_str '     98%   ' sp_str '     99%   ' sp_str '     Mean ' sp_str '   Std. Dev.']);
         for i=1:tm.n;
            if specification_sorted.weakexo_df(i,1)>0;
               s_std = sqrt( (1/rep)*sum( ( specification_sorted.weakexo(:,i) - ( (1/rep)*sum(specification_sorted.weakexo(:,i)) ) ).*( specification_sorted.weakexo(:,i) - ( (1/rep)*sum(specification_sorted.weakexo(:,i)) ) ) ) );
               res_str = strvcat(res_str,sprintf(['%s%s   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],tm.myvars(i,:),add_sp_str,specification_sorted.weakexo(my_80,i),specification_sorted.weakexo(my_90,i),specification_sorted.weakexo(my_95,i),specification_sorted.weakexo(my_975,i),specification_sorted.weakexo(my_99,i),(1/rep)*sum(specification_sorted.weakexo(:,i)),s_std));
            else;
               res_str = strvcat(res_str,sprintf('%s%s   Not computed',tm.myvars(i,:),add_sp_str));
            end;
         end;
         %
         % aasymptotic quantiles. write only the relevant distributions once
         %
         for i=1:tm.n;
            if i==1;
               prev_dist = 0;
            else;
               new_df = specification_sorted.weakexo_df(i,1);
               old_df = specification_sorted.weakexo_df(1:i-1,1);
               prev_dist = 1-isempty(old_df(old_df==new_df));
            end;
            if (specification_sorted.weakexo_df(i,1)>0)&(prev_dist==0);
               if curr_ini.sscorrect==1;
                  my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.weakexo_df(i,1)*ones(5,1),specification_sorted.weakexo_df(i,2)*ones(5,1));
                  res_str = strvcat(res_str,['From the F(' num2str(specification_sorted.weakexo_df(1,1),'%0.0f') ',' num2str(specification_sorted.weakexo_df(1,2),'%0.0f') ') distribution we have the following:'],sprintf(['             ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1)));
               else;
                  my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.weakexo_df(i,1)*ones(5,1));
                  res_str = strvcat(res_str,['From the Chi-square(' num2str(specification_sorted.weakexo_df(i,1),'%0.0f') ') distribution we have the following:'],sprintf(['             ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.weakexo_df(i,1),sqrt(2*specification_sorted.weakexo_df(i,1))));
               end;
            end;
         end;
         %
         res_str = strvcat(res_str,' ','                      Empirical size','                      --------------',' ','Equation\\Test level    20%      10%       5%       2%       1%');
         for i=1:tm.n;
            if specification_sorted.weakexo_df(i,1)>0;
               res_str = strvcat(res_str,sprintf('%s%s           %6.2f   %6.2f   %6.2f   %6.2f   %6.2f',tm.myvars(i,:),add_sp_str,100*(1-e_size.weakexo(5,i)),100*(1-e_size.weakexo(4,i)),100*(1-e_size.weakexo(3,i)),100*(1-e_size.weakexo(2,i)),100*(1-e_size.weakexo(1,i))));
            else;
               res_str = strvcat(res_str,sprintf('%s%s           Not computed',tm.myvars(i,:),add_sp_str));
            end;
         end;
         res_str = strvcat(res_str,' ');
         %
         if my_T==tm.T;
            res_str = strvcat(res_str,'            Empirical p-values','            ------------------',' ');
            for i=1:tm.n;
               if specification_sorted.weakexo_df(i,1)>0;
                  if curr_ini.sscorrect==1;
                     res_str = strvcat(res_str,sprintf(['%s%s       F(%2.0f,%3.0f) = ' prt_val ',  p-value = %0.' num2str(curr_ini.decimals,'%0.0f') 'f'],tm.myvars(i,:),add_sp_str,specification_sorted.weakexo_df(i,1),specification_sorted.weakexo_df(i,2),tm.weakexo(i,1),pval.weakexo(1,i)));
                  else;
                     res_str = strvcat(res_str,sprintf(['%s%s       W(%2.0f) = ' prt_val ',  p-value = %0.' num2str(curr_ini.decimals,'%0.0f') 'f'],tm.myvars(i,:),add_sp_str,specification_sorted.weakexo_df(i,1),tm.weakexo(i,1),pval.weakexo(1,i)));
                  end;
               else;
                  res_str = strvcat(res_str,sprintf('%s%s       Not computed',tm.myvars(i,:),add_sp_str));
               end;
            end;
            res_str = strvcat(res_str,' ');
         end;
         %
         % write to tex-file
         %
         f_id = fopen(file_tex,'at');
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrrr}\n');
         fprintf(f_id,'\\multicolumn{8}{c}{Weak exogeneity tests} \\\\\n');
         fprintf(f_id,'Equation & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% & Mean & Std. Dev. \\\\\n');
         for i=1:tm.n;
            if specification_sorted.weakexo_df(i,1)>0;
               s_std = sqrt( (1/rep)*sum( ( specification_sorted.weakexo(:,i) - ( (1/rep)*sum(specification_sorted.weakexo(:,i)) ) ).*( specification_sorted.weakexo(:,i) - ( (1/rep)*sum(specification_sorted.weakexo(:,i)) ) ) ) );
               fprintf(f_id,['%s & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],txt2ltxmath(strtrim(tm.myvars(i,:))),specification_sorted.weakexo(my_80,i),specification_sorted.weakexo(my_90,i),specification_sorted.weakexo(my_95,i),specification_sorted.weakexo(my_975,i),specification_sorted.weakexo(my_99,i),(1/rep)*sum(specification_sorted.weakexo(:,i)),s_std);
            else;
               fprintf(f_id,'%s & \\multicolumn{7}{l}{Not computed} \\\\\n',txt2ltxmath(strtrim(tm.myvars(i,:))));
            end;
         end;
%         res_str = strvcat(res_str,' ');
         for i=1:tm.n;
            if i==1;
               prev_dist = 0;
            else;
               new_df = specification_sorted.weakexo_df(i,1);
               old_df = specification_sorted.weakexo_df(1:i-1,1);
               prev_dist = 1-isempty(old_df(old_df==new_df));
            end;
            if (specification_sorted.weakexo_df(i,1)>0)&(prev_dist==0);
               fprintf(f_id,'\\multicolumn{8}{c}{ } \\\\\n');
               if curr_ini.sscorrect==1;
                  my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.weakexo_df(i,1)*ones(5,1),specification_sorted.weakexo_df(i,2)*ones(5,1));
                  fprintf(f_id,'\\multicolumn{8}{c}{From the F(%0.0f,%0.0f) distribution we have the following:} \\\\\n',specification_sorted.weakexo_df(i,1),specification_sorted.weakexo_df(i,2));
                  fprintf(f_id,[' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & & \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1));
               else;
                  my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.weakexo_df(i,1)*ones(5,1));
                  fprintf(f_id,'\\multicolumn{8}{c}{From the $\\chi^2 (%0.0f)$ distribution we have the following:} \\\\\n',specification_sorted.weakexo_df(i,1));
                  fprintf(f_id,[' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.weakexo_df(i,1),sqrt(2*specification_sorted.weakexo_df(i,1)));
               end;
            end;
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
         %
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{lrrrrr}\n');
         fprintf(f_id,'\\multicolumn{6}{c}{Empirical size} \\\\\n');
         fprintf(f_id,'Equation $\\backslash$ Test level & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
         for i=1:tm.n;
            if specification_sorted.weakexo_df(i,1)>0;
               fprintf(f_id,'%s & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',txt2ltxmath(strtrim(tm.myvars(i,:))),100*(1-e_size.weakexo(5,i)),100*(1-e_size.weakexo(4,i)),100*(1-e_size.weakexo(3,i)),100*(1-e_size.weakexo(2,i)),100*(1-e_size.weakexo(1,i)));
            else;
               fprintf(f_id,'%s & \\multicolumn{5}{l}{Not computed} \\\\\n',txt2ltxmath(strtrim(tm.myvars(i,:))));
            end;
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
         %
         if my_T==tm.T;
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrr}\n');
            fprintf(f_id,'\\multicolumn{4}{c}{Empirical $p$-values} \\\\\n');
            fprintf(f_id,' & Equation & Test & $p$-value \\\\\n');
            for i=1:tm.n;
               if specification_sorted.weakexo_df(i,1)>0;
                  if curr_ini.sscorrect==1;
                     fprintf(f_id,[' & %s & F(%0.0f,%0.0f) = ' prt_tex ' & ' prt_tex ' \\\\ \n'],txt2ltxmath(strtrim(tm.myvars(i,:))),specification_sorted.weakexo_df(i,1),specification_sorted.weakexo_df(i,2),tm.weakexo(i,1),pval.weakexo(1,i));
                  else;
                     fprintf(f_id,[' & %s & W(%0.0f) = ' prt_tex ' & ' prt_tex ' \\\\ \n'],txt2ltxmath(strtrim(tm.myvars(i,:))),specification_sorted.weakexo_df(i,1),tm.weakexo(i,1),pval.weakexo(1,i));
                  end;
               else;
                  fprintf(f_id,' & %s & \\multicolumn{2}{l}{Not computed} \\\\\n',txt2ltxmath(strtrim(tm.myvars(i,:))));
               end;
            end;
            fprintf(f_id,'\\end{tabular}\n\n');
         end;
         fclose(f_id);
      end;
      %
      % Granger causality tests
      %
      if isfield(specification_sorted,'gctest')==1;
         if size(tm.myvars,2)<=10;
            add_sp_str = spacestr(10-size(tm.myvars,2));
         else;
            add_sp_str = '';
         end;
         res_str = strvcat(res_str,'            Granger Causality Tests','            -----------------------',' ',['          Null                  80%    ' sp_str '    90%   ' sp_str '     95%    ' sp_str '    98%   ' sp_str '     99%   ' sp_str '     Mean  ' sp_str '  Std. Dev.']);
         gc_count = 0;
         for i=1:tm.n;
            for j=1:tm.n;
               if isequal(i,j)==0;
                  gc_count = gc_count+1;
                  if specification_sorted.gctest_df(gc_count,1)>0;
                     s_std = sqrt( (1/rep)*sum( ( specification_sorted.gctest(:,gc_count) - ( (1/rep)*sum(specification_sorted.gctest(:,gc_count)) ) ).*( specification_sorted.gctest(:,gc_count) - ( (1/rep)*sum(specification_sorted.gctest(:,gc_count)) ) ) ) );
                     res_str = strvcat(res_str,sprintf(['%s%s =|> %s%s   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],add_sp_str,tm.myvars(j,:),tm.myvars(i,:),add_sp_str,specification_sorted.gctest(my_80,gc_count),specification_sorted.gctest(my_90,gc_count),specification_sorted.gctest(my_95,gc_count),specification_sorted.gctest(my_975,gc_count),specification_sorted.gctest(my_99,gc_count),(1/rep)*sum(specification_sorted.gctest(:,gc_count)),s_std));
                  else;
                     res_str = strvcat(res_str,sprintf('%s%s =|> %s%s   Not computed',add_sp_str,tm.myvars(j,:),tm.myvars(i,:),add_sp_str));
                  end;
               end;
            end;
         end;
         %
         gc_count = 0;
         for i=1:tm.n;
            for j=1:tm.n;
               if isequal(i,j)==0;
                  gc_count = gc_count+1;
                  if gc_count==1;
                     prev_dist = 0;
                  else;
                     new_df = specification_sorted.gctest_df(gc_count,1);
                     old_df = specification_sorted.gctest_df(1:gc_count-1,1);
                     prev_dist = 1-isempty(old_df(old_df==new_df));
                  end;
                  if (specification_sorted.gctest_df(gc_count,1)>0)&(prev_dist==0);
                     if curr_ini.sscorrect==1;
                        my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.gctest_df(gc_count,1)*ones(5,1),specification_sorted.gctest_df(gc_count,2)*ones(5,1));
                        res_str = strvcat(res_str,['From the F(' num2str(specification_sorted.gctest_df(gc_count,1),'%0.0f') ',' num2str(specification_sorted.gctest_df(gc_count,2),'%0.0f') ') distribution we have the following:'],sprintf(['                            ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1)));
                     else;
                        my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.gctest_df(gc_count,1)*ones(5,1));
                        res_str = strvcat(res_str,['From the Chi-square(' num2str(specification_sorted.gctest_df(gc_count,1),'%0.0f') ') distribution we have the following:'],sprintf(['                            ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.gctest_df(gc_count,1),sqrt(2*specification_sorted.gctest_df(gc_count,1))));
                     end;
                  end;
               end;
            end;
         end;
         %
         res_str = strvcat(res_str,' ');
         %
         res_str = strvcat(res_str,'                      Empirical size','                      --------------',' ','          Null\\Test level     20%      10%       5%       2%       1%');
         gc_count = 0;
         for i=1:tm.n;
            for j=1:tm.n;
               if isequal(i,j)==0;
                  gc_count = gc_count+1;
                  if specification_sorted.gctest_df(gc_count,1)>0;
                     res_str = strvcat(res_str,sprintf('%s%s =|> %s%s   %6.2f   %6.2f   %6.2f   %6.2f   %6.2f',add_sp_str,tm.myvars(j,:),tm.myvars(i,:),add_sp_str,100*(1-e_size.gctest(5,gc_count)),100*(1-e_size.gctest(4,gc_count)),100*(1-e_size.gctest(3,gc_count)),100*(1-e_size.gctest(2,gc_count)),100*(1-e_size.gctest(1,gc_count))));
                  else;
                     res_str = strvcat(res_str,sprintf('%s%s =|> %s%s   Not computed',add_sp_str,tm.myvars(j,:),tm.myvars(i,:),add_sp_str));
                  end;
               end;
            end;
         end;
         res_str = strvcat(res_str,' ');
         %
         if my_T==tm.T;
            res_str = strvcat(res_str,'            Empirical p-values','            ------------------',' ');
            gc_count = 0;
            for i=1:tm.n;
               for j=1:tm.n;
                  if isequal(i,j)==0;
                     gc_count = gc_count+1;
                     if specification_sorted.gctest_df(gc_count,1)>0;
                        if curr_ini.sscorrect==1;
                           res_str = strvcat(res_str,sprintf(['%s%s =|> %s%s   F(%2.0f,%3.0f) = ' prt_val ',  p-value = %0.' num2str(curr_ini.decimals,'%0.0f') 'f'],add_sp_str,tm.myvars(j,:),tm.myvars(i,:),add_sp_str,specification_sorted.gctest_df(gc_count,1),specification_sorted.gctest_df(gc_count,2),tm.gctest(gc_count,1),pval.gctest(1,gc_count)));
                        else;
                           res_str = strvcat(res_str,sprintf(['%s%s =|> %s%s   W(%2.0f) = ' prt_val ',  p-value = %0.' num2str(curr_ini.decimals,'%0.0f') 'f'],add_sp_str,tm.myvars(j,:),tm.myvars(i,:),add_sp_str,specification_sorted.gctest_df(gc_count,1),tm.gctest(gc_count,1),pval.gctest(1,gc_count)));
                        end;
                     else;
                        res_str = strvcat(res_str,sprintf('%s%s =|> %s%s   Not computed',add_sp_str,tm.myvars(j,:),tm.myvars(i,:),add_sp_str));
                     end;
                  end;
               end;
            end;
            res_str = strvcat(res_str,' ');
         end;
         %
         % write to tex-file
         %
         f_id = fopen(file_tex,'at');
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrrr}\n');
         fprintf(f_id,'\\multicolumn{8}{c}{Granger Causality Tests} \\\\\n');
         fprintf(f_id,'$H_0$ & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% & Mean & Std. Dev. \\\\\n');
         gc_count = 0;
         for i=1:tm.n;
            for j=1:tm.n;
               if isequal(i,j)==0;
                  gc_count = gc_count+1;
                  if specification_sorted.gctest_df(gc_count,1)>0;
                     s_std = sqrt( (1/rep)*sum( ( specification_sorted.gctest(:,gc_count) - ( (1/rep)*sum(specification_sorted.gctest(:,gc_count)) ) ).*( specification_sorted.gctest(:,gc_count) - ( (1/rep)*sum(specification_sorted.gctest(:,gc_count)) ) ) ) );
                     fprintf(f_id,['%s $\\nRightarrow$ %s & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],txt2ltxmath(strtrim(tm.myvars(j,:))),txt2ltxmath(strtrim(tm.myvars(i,:))),specification_sorted.gctest(my_80,gc_count),specification_sorted.gctest(my_90,gc_count),specification_sorted.gctest(my_95,gc_count),specification_sorted.gctest(my_975,gc_count),specification_sorted.gctest(my_99,gc_count),(1/rep)*sum(specification_sorted.gctest(:,gc_count)),s_std);
                  else;
                     fprintf(f_id,'%s $\\nRightarrow$ %s & \\multicolumn{7}{l}{Not computed} \\\\\n',txt2ltxmath(strtrim(tm.myvars(j,:))),txt2ltxmath(strtrim(tm.myvars(i,:))));
                  end;
               end;
            end;
            fprintf(f_id,'\\multicolumn{8}{c}{ } \\\\\n');
         end;
         %
         gc_count = 0;
         for i=1:tm.n;
            for j=1:tm.n;
               if isequal(i,j)==0;
                  gc_count = gc_count+1;
                  if gc_count==1;
                     prev_dist = 0;
                  else;
                     new_df = specification_sorted.gctest_df(gc_count,1);
                     old_df = specification_sorted.gctest_df(1:gc_count-1,1);
                     prev_dist = 1-isempty(old_df(old_df==new_df));
                  end;
                  if (specification_sorted.gctest_df(gc_count,1)>0)&(prev_dist==0);
                     if curr_ini.sscorrect==1;
                        my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.gctest_df(gc_count,1)*ones(5,1),specification_sorted.gctest_df(gc_count,2)*ones(5,1));
                        fprintf(f_id,'\\multicolumn{8}{c}{From the F(%0.0f,%0.0f) distribution we have the following:} \\\\\n',specification_sorted.gctest_df(gc_count,1),specification_sorted.gctest_df(gc_count,2));
                        fprintf(f_id,[' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & & \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1));
                     else;
                        my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],specification_sorted.gctest_df(gc_count,1)*ones(5,1));
                        fprintf(f_id,'\\multicolumn{8}{c}{From the $\\chi^2 (%0.0f)$ distribution we have the following:} \\\\\n',specification_sorted.gctest_df(gc_count,1));
                        fprintf(f_id,[' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),specification_sorted.gctest_df(gc_count,1),sqrt(2*specification_sorted.gctest_df(gc_count,1)));
                     end;
                  end;
               end;
            end;
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
         %
         fprintf(f_id,'\\clearpage\n\\newpage\n\n\\begin{tabular}{lrrrrr}\n');
         fprintf(f_id,'\\multicolumn{6}{c}{Empirical size} \\\\\n');
         fprintf(f_id,'$H_0$ $\\backslash$ Test level & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
         gc_count = 0;
         for i=1:tm.n;
            for j=1:tm.n;
               if isequal(i,j)==0;
                  gc_count = gc_count+1;
                  if specification_sorted.gctest_df(gc_count,1)>0;
                     fprintf(f_id,'%s $\\nRightarrow$ %s & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',txt2ltxmath(strtrim(tm.myvars(j,:))),txt2ltxmath(strtrim(tm.myvars(i,:))),100*(1-e_size.gctest(5,gc_count)),100*(1-e_size.gctest(4,gc_count)),100*(1-e_size.gctest(3,gc_count)),100*(1-e_size.gctest(2,gc_count)),100*(1-e_size.gctest(1,gc_count)));
                  else;
                     fprintf(f_id,'%s $\\nRightarrow$ %s & \\multicolumn{5}{l}{Not computed} \\\\\n',txt2ltxmath(strtrim(tm.myvars(j,:))),txt2ltxmath(strtrim(tm.myvars(i,:))));
                  end;
               end;
            end;
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
         %
         if my_T==tm.T;
            fprintf(f_id,'\\clearpage\n\\newpage\n\n\\begin{tabular}{lllrr}\n');
            fprintf(f_id,'\\multicolumn{5}{c}{Empirical $p$-values} \\\\\n');
            fprintf(f_id,' & $H_0$ & Test & Value & $p$-value \\\\\n');
            gc_count = 0;
            for i=1:tm.n;
               for j=1:tm.n;
                  if isequal(i,j)==0;
                     gc_count = gc_count+1;
                     if specification_sorted.gctest_df(gc_count,1)>0;
                        if curr_ini.sscorrect==1;
                           fprintf(f_id,[' & %s $\\nRightarrow$ %s & F(%0.0f,%0.0f) = & ' prt_tex ' & ' prt_tex ' \\\\ \n'],txt2ltxmath(strtrim(tm.myvars(j,:))),txt2ltxmath(strtrim(tm.myvars(i,:))),specification_sorted.gctest_df(gc_count,1),specification_sorted.gctest_df(gc_count,2),tm.gctest(gc_count,1),pval.gctest(1,gc_count));
                        else;
                           fprintf(f_id,[' & %s $\\nRightarrow$ %s & W(%0.0f) = & ' prt_tex ' & ' prt_tex ' \\\\ \n'],txt2ltxmath(strtrim(tm.myvars(j,:))),txt2ltxmath(strtrim(tm.myvars(i,:))),specification_sorted.gctest_df(gc_count,1),tm.gctest(gc_count,1),pval.gctest(1,gc_count));
                        end;
                     else;
                        fprintf(f_id,' & %s $\\nRightarrow$ %s & \\multicolumn{3}{l}{Not computed} \\\\\n',txt2ltxmath(strtrim(tm.myvars(j,:))),txt2ltxmath(strtrim(tm.myvars(i,:))));
                     end;
                  end;
               end;
               if i<tm.n;
                  fprintf(f_id,'\\multicolumn{5}{c}{ } \\\\\n');
               end;
            end;
            fprintf(f_id,'\\end{tabular}\n\n');
         end;
         fclose(f_id);
      end;
      %
      res_str = strvcat(res_str,'**************************************************************',' ');
      set(boot_specification.display,'UserData',specification_sorted);
      clear('specification_sorted');
      %
      fid_txt = fopen(file_txt,'wt');
      for i=1:size(res_str,1);
         fprintf(fid_txt,[strrep(res_str(i,:),'%','%%') '\n']);
      end;
      fprintf(fid_txt,['Output created on: ' datestr(now,0) '\n']);
      fclose(fid_txt);
      f_id = fopen(file_tex,'at');
      fprintf(f_id,'\\ruler\n\n%%*************************************************************');
      fclose(f_id);
      if curr_ini.noprint==0;
         set(boot_specification.output,'Enable','on');
      end;
      set(boot_specification.summarymenu,'Enable','on','UserData',file_txt);
      set(boot_specification.summary,'Enable','on');
      set(boot_specification.display,'Enable','on');
      set(boot_specification.displaymenu,'Enable','on');
      set(boot_specification.histogram,'Enable','on');
      set(boot_specification.histogrammenu,'Enable','on');
      set(boot_specification.matfilebutton,'Enable','on');
      set(boot_specification.matfilemenu,'Enable','on');
      set(waitf.text,'UserData','done');
      delete(mywait);
      drawnow;
   else;
      setlogtext('Cancelled...');
   end;
   tm.specification_run = 0;
   set(specification_boot_gui,'Visible','on');
case 'done'
   if tm.specification_run==0;
      set(boot_specification.done,'UserData','done');
      pid = get(boot_specification.filemenu,'UserData');
      if isempty(pid)==1;
         delete(specification_boot_gui);
      else;
         close(specification_boot_gui);
      end;
   end;
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(specification_boot_gui,'Name') ' ' fix_filepath([pwd '\icons\bootstrap.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(boot_specification.filemenu,'UserData',pid);
         set(specification_boot_gui,'CloseRequestFcn','killwinpid');
      end;
   end;
   set(specification_boot_gui,'Visible','on');
end;

if strcmp(selector,'done')==0;
   curr_ini.models = tm;
   curr_ini.images = button_images;
   set(boot_specification.matfilebutton,'UserData',curr_ini);
end;

if my_exit==1;
   waitfor(boot_specification.done,'UserData','done');
end;

%
% end of specification_bootstrap.m
%
